(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1529783,      30850]
NotebookOptionsPosition[   1483581,      29738]
NotebookOutlinePosition[   1487610,      29825]
CellTagsIndexPosition[   1487567,      29822]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Mathematica Implementation of Triangle Theory", "Title",
 CellChangeTimes->{{3.7066974348555284`*^9, 3.706697437439438*^9}, {
  3.706697755371681*^9, 
  3.7066977698915873`*^9}},ExpressionUUID->"d64e7edc-5dca-405e-919b-\
43567e913504"],

Cell["Langmuir Isotherm", "Subtitle",
 CellChangeTimes->{{3.707042298161107*^9, 
  3.7070423051232166`*^9}},ExpressionUUID->"1a9c401d-e6ca-4da5-be73-\
c2aa9aa5ef56"],

Cell[CellGroupData[{

Cell["Section 1: Define the Problem\[CloseCurlyQuote]s Notation", "Section",
 CellChangeTimes->{{3.7066974806872473`*^9, 3.7066974820549045`*^9}, {
  3.706697785874885*^9, 
  3.7066978043710046`*^9}},ExpressionUUID->"2d7153d8-72bd-4358-af3f-\
3bd99ee7b74d"],

Cell[TextData[{
 "In this section, we \
\[OpenCurlyDoubleQuote]symbolize\[CloseCurlyDoubleQuote] some variables so \
that we can use them later.  By default, if we enter a variable with a \
subscript (e.g. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "3e87aae7-48f2-4072-9e9f-952834142d04"],
 ") Mathematica sees Subscript[a,1] instead of a regular symbol like a1.  So \
when you try to assign a value to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "3d5043cb-5120-4211-9aa6-b45e8af5998f"],
 " (e.g. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "6"}], TraditionalForm]],ExpressionUUID->
  "78221e02-b411-4dd1-85eb-2d8d5d507cda"],
 "), Mathematica instead says to itself:\n\[OpenCurlyDoubleQuote]the user \
wants to assign a value to Subscript[a,1].  I will add Subscript[_, 1] = 5 to \
the set of things I know about a.\[CloseCurlyDoubleQuote]\nWhen Mathematica \
does this, it is referred to as an \[OpenCurlyDoubleQuote]Upvalue\
\[CloseCurlyDoubleQuote] of the symbol a.\nUsing the Symbolize, function lets \
us tell Mathematica not to interpret ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "2a0194a6-a45e-400e-8aea-32a2eb5a0ae8"],
 " as a Subscript function, and so we avoid the use of upvalues.  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "ddd5518e-5b01-4c40-ae67-57970e6a3dbe"],
 " is treated as its own symbol and is no longer connected to the \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] symbol.  That way, when we \
say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "5"}], TraditionalForm]],ExpressionUUID->
  "a3e229bd-65eb-40c3-b6fb-e75a84aa4283"],
 " all Mathematica does is assign the value of 5 to the symbol ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "a37315fb-6804-4f10-825e-69f1a4b1fcfd"],
 " without any kind of upvalues."
}], "Text",
 CellChangeTimes->{{3.706697811970934*^9, 3.7066978572260523`*^9}, {
  3.706698028311755*^9, 3.706698138056162*^9}, {3.706698490209321*^9, 
  3.70669854546424*^9}, {3.7066988160465307`*^9, 3.7066988308940997`*^9}, {
  3.7067079136585436`*^9, 3.7067079851555705`*^9}, {3.7067080312762012`*^9, 
  3.706708071022498*^9}, {3.7067081321651993`*^9, 3.7067082954546*^9}, {
  3.7067083365748663`*^9, 
  3.706708366015239*^9}},ExpressionUUID->"388760df-8334-4667-a50b-\
5f312b37b6db"],

Cell[TextData[{
 "In most cases, the difference between upvalues and values is not important. \
 Algebra and calculus generally work fine with either, and you do not need to \
worry about the difference.  The one area where the difference does matter is \
",
 StyleBox["lexical scoping",
  FontSlant->"Italic"],
 ".  For example, if you want to temporarily assign a value to a variable \
like this:"
}], "Text",
 CellChangeTimes->{{3.706708370614149*^9, 3.7067084080783415`*^9}, {
  3.7067084449173512`*^9, 3.7067084752317624`*^9}, {3.7067085299593534`*^9, 
  3.706708533151581*^9}},ExpressionUUID->"7b8a40a8-c9b6-48b4-a315-\
859a2f763e43"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", " ", 
   RowBox[{"Evaluate", "[", 
    SuperscriptBox["a", "2"], " ", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706708477171032*^9, 3.7067084894642897`*^9}, {
  3.706708550313186*^9, 
  3.7067085573213086`*^9}},ExpressionUUID->"7f6b36a2-775e-49e9-8162-\
4d8094502003"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAWIR//zcP3NfO9pwsc0A0dvlkzL+A+kXUfunMMx77cj2
YK05I5C+3/FkiQqQLtzxU0UVSIucD7sNol8ys2xVA9KPL/zmVQfSUUtXi4Jo
G/YJx0C0RYXTbzMgfeSP/lovIP1OJ26rD5DuM/2UOh9Ib/tWW5qz8LVj1eqI
HZmLXztu0TVoywLSbgG1a7OBdHXgWoXE5a8dDf9r3gDRccp+19YD6X/WpUnb
gXT5vnsTbgPpi7b24aqrXjsuDYj9pwek13G+zzUG0he2aB0wA9IlV1/1mQPp
K8K7o0JB4pI3K0F0gZFbYziQDpPa0A2iXdTZLCKBNPedl7dAdNrTSTZRQLql
+agDiP5guKIWRM8++WMKmP9s20IQ7fD60lYQ/VLjRmAskJYSnzsPRLdsEF0N
og/+LLwIopsvPReMA9IsX4/agmgpJtWfSUD6ktWll8kgvor7zhQg/afsmNtK
IA0AIRbfgw==
  "],ExpressionUUID->"7f2f912e-776a-4986-9a80-78f55a17d8b3"]
}, Open  ]],

Cell[TextData[{
 "Mathematica\[CloseCurlyQuote]s scoping construct \
\[OpenCurlyDoubleQuote]With\[CloseCurlyDoubleQuote] can only create temporary \
",
 StyleBox["values,",
  FontSlant->"Italic"],
 " not ",
 StyleBox["upvalues.",
  FontSlant->"Italic"],
 "  So if we want to use these constructs, we need to use Symbolize."
}], "Text",
 CellChangeTimes->{{3.7067085051628046`*^9, 3.7067085982239428`*^9}, {
  3.7069640140917263`*^9, 
  3.7069640252575846`*^9}},ExpressionUUID->"7d1243a4-4dc2-4bd0-9c6b-\
fa6b4d54e86a"],

Cell[TextData[{
 "It is also possible to force Mathematica to say the following\n\
\[OpenCurlyDoubleQuote]the user wants to assign a value to Subscript[a,1].  I \
will add Subscript[a, 1] = 5 to the set of things I know",
 StyleBox[" about the Subscript function",
  FontWeight->"Bold"],
 ".\[CloseCurlyDoubleQuote]\nWhen Mathematica does this, 5 is called a \
\[OpenCurlyDoubleQuote]downvalue\[CloseCurlyDoubleQuote] of the symbol \
Subscript."
}], "Text",
 CellChangeTimes->{{3.7067080753723607`*^9, 3.7067081294614725`*^9}, {
  3.7067083297584944`*^9, 
  3.706708331542101*^9}},ExpressionUUID->"95a5935a-d2fd-4c0d-a52c-\
9a38198ed1dd"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.655654009881259*^9, 3.6556540709341335`*^9}, {
  3.6556541286705556`*^9, 3.6556541386071386`*^9}, {3.6556541826824427`*^9, 
  3.655654184784837*^9}, {3.65565422925277*^9, 3.6556542656382427`*^9}, {
  3.6556543549254217`*^9, 3.6556543753579626`*^9}, {3.6556545287943487`*^9, 
  3.6556545683435383`*^9}, {3.6556552151106796`*^9, 3.655655243548979*^9}, {
  3.6556559648318224`*^9, 3.6556559758281126`*^9}, {3.6556625350770884`*^9, 
  3.6556625553416767`*^9}, {3.6556636806921215`*^9, 3.655663711748703*^9}, {
  3.706709031947781*^9, 
  3.7067090324505415`*^9}},ExpressionUUID->"f269ec12-eabb-412a-8d8c-\
4126a0962bb5"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["\[Epsilon]", "*"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["v", "*"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["V", "s"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["V", "l"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["c", "ss"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["c", "a"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["c", "A"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["c", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["c", "B"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SuperscriptBox["n", "ss"]},
    "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"I\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"II\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"III\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"IV\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"F\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"R\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"E\""]},
      "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
    RowBox[{"Symbolize", "[", 
     TemplateBox[{SuperscriptBox["c", "\"D\""]},
      "NotationTemplateTag"], "]"}]}], "\[IndentingNewLine]", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["n", "a"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["n", "A"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["n", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SuperscriptBox["n", "B"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["q", "s"]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.677416137944186*^9, 3.6774161514053993`*^9}, {
   3.6774660264595203`*^9, 3.6774660267070684`*^9}, 3.7067090473430967`*^9, {
   3.7131823076392107`*^9, 3.7131823389931345`*^9}, {3.7131826431458406`*^9, 
   3.7131826501768527`*^9}, {3.7131827949595222`*^9, 
   3.7131828331137094`*^9}, {3.713185795357234*^9, 3.7131858154964914`*^9}, {
   3.713190321956678*^9, 3.713190325869963*^9}, {3.7131932046025476`*^9, 
   3.713193206328312*^9}, {3.7132006053541436`*^9, 
   3.7132006122003126`*^9}},ExpressionUUID->"1db33f99-6061-4533-9bd0-\
be12dcbfc7d0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"toNumericQ", "[", "any___", "]"}], ":=", 
  RowBox[{"NumericQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toStringQ", "[", "any___", "]"}], ":=", 
  RowBox[{"StringQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubscriptBox["n", 
      RowBox[{"a_", ",", "b_"}]]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{RowBox[{"D", "[", 
       RowBox[{
         SubscriptBox["n", "a_"], ",", 
         SubscriptBox["c", "b_"], ",", 
         RowBox[{"NonConstants", "\[Rule]", 
           RowBox[{"{", 
             RowBox[{
               SubscriptBox["n", "1"], ",", 
               SubscriptBox["n", "2"]}], "}"}]}]}], "]"}]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", "ss"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["n", "ss"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{SubscriptBox[
      RowBox[{"n", "[", 
        TemplateBox[{
          RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}], 
      "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{SubscriptBox[
      RowBox[{"c", "[", 
        TemplateBox[{
          RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}], 
      "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", "a"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["n", "a"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", "A"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["n", "A"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", "b"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["n", "b"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["n", "i_", "B"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["n", "B"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", "ss"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["c", "ss"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", "a"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["c", "a"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", "A"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["c", "A"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", "b"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["c", "b"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["c", "i_", "B"]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox[
      SuperscriptBox["c", "B"], "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubscriptBox["m", "\"I\""]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox["m", "1"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubscriptBox["m", "\"II\""]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox["m", "2"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubscriptBox["m", "\"III\""]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox["m", "3"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubscriptBox["m", "\"IV\""]},
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TemplateBox[{SubscriptBox["m", "4"]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6730395387344894`*^9, 3.6730395389293184`*^9}, {
   3.6730397530013943`*^9, 3.673039813047531*^9}, {3.6730398786177826`*^9, 
   3.6730398799994907`*^9}, {3.7131822664676666`*^9, 
   3.7131822704397187`*^9}, {3.713182359795407*^9, 3.7131824047425013`*^9}, {
   3.7131826147714963`*^9, 3.713182635906644*^9}, {3.713182942017948*^9, 
   3.713182943735614*^9}, {3.713185830391759*^9, 3.713185855418274*^9}, {
   3.713186714086252*^9, 3.7131867602088313`*^9}, {3.7131868357637234`*^9, 
   3.713186897995571*^9}, {3.713191599099545*^9, 3.7131916289423933`*^9}, {
   3.713192406116516*^9, 3.7131924084335814`*^9}, {3.7131928379400187`*^9, 
   3.7131928406404524`*^9}, {3.7131929192944574`*^9, 
   3.7131929305101767`*^9}, {3.7131931174880877`*^9, 
   3.7131931178295617`*^9}, {3.713193167847923*^9, 3.7131931680437202`*^9}, {
   3.713193259702511*^9, 3.713193359970992*^9}, {3.7131939457566924`*^9, 
   3.713193974121663*^9}, {3.713194246309847*^9, 3.713194252933566*^9}, {
   3.7131986094095325`*^9, 3.7131986301358824`*^9}, {3.7131992936387596`*^9, 
   3.713199335149845*^9}, {3.71319941344209*^9, 3.71319943562105*^9}, {
   3.713200052894246*^9, 3.713200067076292*^9}, {3.7132001333519306`*^9, 
   3.713200153111682*^9}, {3.713200186132353*^9, 3.7132002535776916`*^9}, {
   3.713200374258357*^9, 3.7132004268999624`*^9}, 
   3.713200461475029*^9},ExpressionUUID->"78080e82-5fa1-4e6a-9cd1-\
2627706bb684"],

Cell[TextData[{
 "Input aliases are handy if you know you will be typing in the same \
variables or equations many times.  Once we have added an input alias for eb, \
by pressing [esc] e b [esc] we will immediately get the symbol ",
 Cell[BoxData[
  SubscriptBox["\[Epsilon]", "b"]],ExpressionUUID->
  "f2b22982-228e-45f3-8c69-d3839d8a58fe"],
 "."
}], "Text",
 CellChangeTimes->{{3.7067090935473027`*^9, 
  3.7067091910122027`*^9}},ExpressionUUID->"55b7bde2-942e-4cd2-8efe-\
9604f196893a"],

Cell[BoxData[{
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<eb\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ep\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<phase\>\"", "\[Rule]", 
   TemplateBox[{FractionBox[
      SubscriptBox["\[Epsilon]", "p"], 
      RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}]]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ns\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["n", "i", "ss"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<cs\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["c", "i", "ss"]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6730390279117804`*^9, 3.6730390465081587`*^9}, {
  3.673039495572994*^9, 3.6730395172649775`*^9}, {3.673039559352255*^9, 
  3.6730395940884876`*^9}},ExpressionUUID->"0b034b46-b216-471d-b36c-\
1a557508e683"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 2: The Problem Statements", "Section",
 CellChangeTimes->{{3.7066974903265147`*^9, 3.706697491518673*^9}, {
  3.70670931119707*^9, 3.7067093114049063`*^9}, {3.706709660335001*^9, 
  3.70670967523917*^9}},ExpressionUUID->"27e42881-72c9-4446-b3fb-\
93671a9bffaf"],

Cell["Differential Equations", "Subsection",
 CellChangeTimes->{{3.706709785303831*^9, 
  3.7067097882479935`*^9}},ExpressionUUID->"5aaaad89-f065-4d8c-bd8b-\
dde2cc9c9774"],

Cell[CellGroupData[{

Cell["Vector Form", "Subsection",
 CellChangeTimes->{{3.7067097941442566`*^9, 3.7067097959839497`*^9}, {
  3.706710566253259*^9, 
  3.7067105689495792`*^9}},ExpressionUUID->"2cf22b89-24bd-4b08-a0af-\
62d793cf704d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "i"], "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", 
        SubscriptBox["n", "i"]}]}], ")"}], "\[Psi]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6708727048709126`*^9, 3.6708727359911118`*^9}, {
   3.6708727907652607`*^9, 3.670872819572259*^9}, {3.6709382570413556`*^9, 
   3.670938259664253*^9}, {3.6709405368011894`*^9, 3.670940537138198*^9}, {
   3.671029304846298*^9, 3.6710293064697495`*^9}, {3.6710298541293626`*^9, 
   3.671029855673336*^9}, {3.671124652134452*^9, 3.671124681417443*^9}, 
   3.671127406301955*^9, {3.6715557520240035`*^9, 3.6715557605592327`*^9}, {
   3.6720679602715406`*^9, 3.6720679618479347`*^9}, {3.6720698765620036`*^9, 
   3.6720698772975273`*^9}, {3.673691613022994*^9, 3.673691680780733*^9}, {
   3.706709626083665*^9, 
   3.70670962663951*^9}},ExpressionUUID->"0658c780-1a73-460f-92fe-\
84e48b417fb7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "1"], "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", 
       SubscriptBox["n", "1"]}]}], ")"}]}], ",", 
   RowBox[{"\[Psi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", 
       SubscriptBox["n", "2"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706709619232314*^9, 3.7067096277553377`*^9}, 
   3.7067149485694065`*^9, 3.7067173515194263`*^9, 3.7067186547939835`*^9, 
   3.706791208202544*^9, 3.706792232389271*^9, 3.7067936914055715`*^9, 
   3.7067954330539775`*^9, 3.706796147456889*^9, 3.7067962061626844`*^9, 
   3.706797621469384*^9, 3.7068287634196754`*^9, 3.706869098736105*^9, 
   3.7068732612754865`*^9, 3.7070426085385365`*^9, 3.70851114880727*^9, 
   3.7095541160779495`*^9, 3.709555763550147*^9, 3.7095581255250697`*^9, 
   3.711633670579173*^9, 3.7116351380409007`*^9, 3.7117948673808374`*^9, 
   3.711810324845785*^9, 3.7118844244247613`*^9, 3.713084091265323*^9, 
   3.713103860183627*^9, 3.7131129444382734`*^9, 3.713119746402571*^9, 
   3.7131214003964033`*^9, 3.7131824231436863`*^9, 3.7131826724391766`*^9, 
   3.7131868273986673`*^9, 3.713186911106224*^9, 3.7131903377979584`*^9, 
   3.713191640981623*^9, 3.713192455734313*^9, 3.7131929429931097`*^9, 
   3.7131931292021217`*^9, 3.713193231998707*^9, 3.7131933921557274`*^9, 
   3.713198736244508*^9, 3.7131993505960813`*^9, 3.713199450384358*^9, 
   3.713199757404251*^9, 3.7132002728785887`*^9, 3.7132006236541853`*^9, 
   3.7132103144285965`*^9, 3.713212240276202*^9, 3.7132138998746815`*^9, 
   3.713354295542099*^9},ExpressionUUID->"afa1dc0e-4702-453e-ab3f-\
73b16a5e6d8f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[Mu]", " ", 
          SubscriptBox["\[Epsilon]", "p"]}]}], ")"}], 
       SubscriptBox["c", "i"]}], "-", 
      RowBox[{"\[Mu]", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["n", "i"]}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7067096317247224`*^9, 
  3.7067096324238605`*^9}},ExpressionUUID->"2c5e0843-a842-4161-8bd4-\
631ec685fb1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
     SubscriptBox["c", "1"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     SubscriptBox["n", "1"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
     SubscriptBox["c", "2"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     SubscriptBox["n", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuLcdaoX/sx97djHOTnjP5DuaPk4hWHea8c8iVvmjEA6
bQ3HUhUg3bGLR1UVSLPY5N4G0dI8SlvVgHTrs2I+dSD9btJRURBttXH9MRC9
6kHubzMgzcsZsdYLSDs8XbXVB2ROp2DafCD9SG5Wac7C144SU5t3ZC5+7ejC
XNyWBaT7NDetzQbSOt8vKSQuf+1oo+N0A0T7z8q5th5IRzfPTtoOpF8p8U28
DaQNJDPDVVe9dtSKbvunB6TXTeXLMwbSTh6+B8yA9L0PPP3mQNrC82lUKJDW
+85XBaK37c5tDAfSE72fdIPoWl8ri0ggXWCncBtE/8j44RAFpDeefVALomsd
1KeC6CmBjItAtEE/6zYw/wBHUCyQlrG7Mg9EXw7yXQ2ibbjWXQTRZ5hkheKA
9LyWb7Yg2lDQ72cSkA44wfkqGUhv2FqzMwVIdxV/clsJpAH9DsxG
  "],ExpressionUUID->"25a99625-2ca7-43b6-860a-5f8a43819825"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isotherm", "=", 
  RowBox[{"Simplify", "@", 
   RowBox[{"Table", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "i"], 
       SubscriptBox["c", "i"]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "1"], 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["b", "2"], 
        SubscriptBox["c", "2"]}]}]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "2"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.706792219797352*^9, 3.7067922283038535`*^9}, {
  3.7067936736068945`*^9, 
  3.706793680610734*^9}},ExpressionUUID->"b03b973d-067d-4810-a562-\
ce42df7d9a36"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     SubscriptBox["c", "1"]}], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["c", "1"]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      SubscriptBox["c", "2"]}]}]], ",", 
   FractionBox[
    RowBox[{
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["c", "2"]}], 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["c", "1"]}], "+", 
     RowBox[{
      SubscriptBox["b", "2"], " ", 
      SubscriptBox["c", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7067096373586297`*^9, 3.7067149486214266`*^9, 3.7067173515744233`*^9, 
   3.70671865484348*^9, 3.7067912083300433`*^9, 3.7067922324067698`*^9, {
   3.7067936833278384`*^9, 3.706793691422075*^9}, 3.706795433074978*^9, 
   3.7067961476333895`*^9, 3.7067962061836843`*^9, 3.706797621513384*^9, 
   3.706828763448175*^9, 3.7068690987871037`*^9, 3.706873261445986*^9, 
   3.7070426085590363`*^9, 3.708511148851269*^9, 3.7095541161959515`*^9, 
   3.7095557636451473`*^9, 3.709558125612571*^9, 3.711633670641671*^9, 
   3.711635138094898*^9, 3.7117948674263372`*^9, 3.7118103248747845`*^9, 
   3.7118844244587617`*^9, 3.7130840913283224`*^9, 3.713103860222128*^9, 
   3.713112944478772*^9, 3.713119746424571*^9, 3.7131214004364023`*^9, 
   3.7131824231891866`*^9, 3.713182672494175*^9, 3.713186827456168*^9, 
   3.713186911163725*^9, 3.713190337845959*^9, 3.713191641048123*^9, 
   3.7131924557903156`*^9, 3.713192943053109*^9, 3.713193129251622*^9, 
   3.7131932320642114`*^9, 3.713193392194728*^9, 3.7131987363025055`*^9, 
   3.7131993506610813`*^9, 3.713199450447359*^9, 3.7131997574802494`*^9, 
   3.7132002729355893`*^9, 3.7132006237581873`*^9, 3.713210314450098*^9, 
   3.7132122403342032`*^9, 3.713213899920679*^9, 
   3.7133542956061096`*^9},ExpressionUUID->"6a797084-956a-4c3f-ada2-\
1f117530a8ad"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Jacobian", "Subsection",
 CellChangeTimes->{{3.706710577341215*^9, 
  3.706710579317483*^9}},ExpressionUUID->"bcaa0f8e-d803-445e-8175-\
b47071461acd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"jacobian", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"jacobian", "[", "x", "]"}], "=", 
   RowBox[{"Simplify", "@", 
    RowBox[{"D", "[", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "1"], ",", 
         SubscriptBox["c", "2"]}], "}"}], "}"}], ",", 
      RowBox[{"NonConstants", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["n", "1"], ",", 
         SubscriptBox["n", "2"]}], "}"}]}]}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"jacobian", "[", "f", "]"}]}], "Input",
 CellChangeTimes->{{3.7067100474744854`*^9, 3.7067100495382795`*^9}, {
   3.706710416805354*^9, 3.7067104192296705`*^9}, {3.706710792975384*^9, 
   3.706710836559243*^9}, {3.7067108702242255`*^9, 3.7067108952398148`*^9}, 
   3.7068690929765224`*^9},ExpressionUUID->"bd2017da-d06c-4f07-945f-\
1fc32ec02ae7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["n", 
       RowBox[{"1", ",", "2"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["n", 
       RowBox[{"2", ",", "1"}]]}], ",", 
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"2", ",", "2"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.706710837449156*^9, {3.7067108717369986`*^9, 3.7067108959788074`*^9}, 
   3.706714948645936*^9, 3.706717351601428*^9, 3.706718654867987*^9, 
   3.7067912083390446`*^9, 3.706792232415271*^9, 3.706793691431074*^9, 
   3.706795433085978*^9, 3.706796147644389*^9, 3.706796206194685*^9, 
   3.706797621532384*^9, 3.706828763462176*^9, {3.7068690937440233`*^9, 
   3.706869098799605*^9}, 3.706873261511986*^9, 3.7070426086155376`*^9, 
   3.7085111488752766`*^9, 3.7095541162259507`*^9, 3.70955576369915*^9, 
   3.709558125664572*^9, 3.7116336706951685`*^9, 3.7116351381113987`*^9, 
   3.7117948674548388`*^9, 3.7118103248947825`*^9, 3.711884424474262*^9, 
   3.7130840913583236`*^9, 3.7131038602526283`*^9, 3.713112944506772*^9, 
   3.713119746441572*^9, 3.713121400471402*^9, 3.7131824232146873`*^9, 
   3.713182672520677*^9, 3.713186827484668*^9, 3.7131869111922255`*^9, 
   3.713190337869957*^9, 3.713191641091627*^9, 3.713192455817812*^9, 
   3.7131929430816097`*^9, 3.7131931292771177`*^9, 3.7131932320892115`*^9, 
   3.7131933922202296`*^9, 3.713198736331004*^9, 3.713199350694582*^9, 
   3.7131994504778585`*^9, 3.713199757553752*^9, 3.71320027296559*^9, 
   3.713200623809188*^9, 3.7132103144621005`*^9, 3.7132122403657045`*^9, 
   3.7132138999516797`*^9, 
   3.71335429563111*^9},ExpressionUUID->"9bcf4eb0-eed2-4db3-a188-\
f4e6200d5c29"]
}, Open  ]],

Cell[TextData[{
 "This is a simple definition of the jacobian in Mathematica.  The \
\[OpenCurlyDoubleQuote]NonConstants\[CloseCurlyDoubleQuote] is a way of \
telling Mathematica that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "1"], " "}], TraditionalForm]],ExpressionUUID->
  "3dfc9ede-23e3-47cc-a265-4d87dfab86a0"],
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]],ExpressionUUID->
  "e0adfb36-a4df-4cfa-9ddc-afa569e44292"],
 " depend on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]],ExpressionUUID->
  "c1dd5ed1-fcf7-402b-8567-ea556621f4e9"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],ExpressionUUID->
  "d5419a3e-cdb3-4f1d-9e8e-397d37a4d692"],
 " without having to write ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "1"], "[", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"]}], "]"}], TraditionalForm]],ExpressionUUID->
  "31cba1a7-25c4-4bcb-862b-62dc21a8d9a7"],
 " every time.  The \[OpenCurlyDoubleQuote]Simplify\[CloseCurlyDoubleQuote] \
function just ensures that the result will be put into a simplest form.  The \
\[OpenCurlyDoubleQuote]double\[CloseCurlyDoubleQuote] assignment with both := \
and = is a way of memoizing the results.  That is, once we calculate \
jacobian[f], the results will not be recalculated the next time we call \
jacobian[f].  We can see this if we make a memoized and non-memoized function \
that just computes a random number.  The memoized function will return the \
same result for the same input, while the non-memoized function will \
calculate a new random number every time."
}], "Text",
 CellChangeTimes->{{3.7067098934248495`*^9, 3.706710002441619*^9}, {
  3.7067100548822365`*^9, 3.7067100681304336`*^9}, {3.706710142634621*^9, 
  3.7067101453948574`*^9}, {3.7067101966429877`*^9, 3.706710205594512*^9}, {
  3.706710425308665*^9, 3.706710522709372*^9}, {3.706710591301468*^9, 
  3.7067105933660336`*^9}, {3.7067107779513073`*^9, 3.70671077929521*^9}, {
  3.7067109150081353`*^9, 
  3.7067110389128895`*^9}},ExpressionUUID->"45dea960-689b-43fd-a127-\
e315f71eec4e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"memoized", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"memoized", "[", "x", "]"}], "=", 
   RowBox[{"RandomReal", "[", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nonmemoized", "[", "x_", "]"}], ":=", 
   RowBox[{"RandomReal", "[", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Grid", "[", 
  RowBox[{GridBox[{
     {
      RowBox[{"memoized", "[", "5", "]"}], 
      RowBox[{"memoized", "[", "5", "]"}]},
     {
      RowBox[{"nonmemoized", "[", "5", "]"}], 
      RowBox[{"nonmemoized", "[", "5", "]"}]}
    }], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7067106020973806`*^9, 3.7067107470029736`*^9}, {
  3.7067110475854263`*^9, 3.7067110578335557`*^9}, {3.706818594727132*^9, 
  3.7068186033532963`*^9}},ExpressionUUID->"88425244-ddd9-4c21-b47b-\
d4b8478e23d6"],

Cell[BoxData[
 TagBox[GridBox[{
    {"0.6817827768300484`", "0.6817827768300484`"},
    {"0.37281912328563127`", "0.8832328675763335`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.706710694808538*^9, 3.7067107475795884`*^9, {3.7067110518314695`*^9, 
   3.7067110583237753`*^9}, 3.706714948673947*^9, 3.706717351626932*^9, 
   3.7067186548939877`*^9, 3.7067912083989716`*^9, 3.70679223242327*^9, 
   3.706793691440074*^9, 3.706795433095977*^9, 3.70679614765639*^9, 
   3.7067962062061853`*^9, 3.706797621552885*^9, 3.706818604033022*^9, 
   3.7068287634761753`*^9, 3.706869098836604*^9, 3.7068732615629854`*^9, 
   3.7070426087595367`*^9, 3.708511148883278*^9, 3.7095541162629533`*^9, 
   3.7095557637421513`*^9, 3.7095581258000813`*^9, 3.7116336707486706`*^9, 
   3.711635138129897*^9, 3.711794867501839*^9, 3.711810324911784*^9, 
   3.711884424491762*^9, 3.713084091392324*^9, 3.7131038602776303`*^9, 
   3.713112944546771*^9, 3.713119746463571*^9, 3.713121400482402*^9, 
   3.713182423243185*^9, 3.713182672549673*^9, 3.7131868275166655`*^9, 
   3.7131869112232275`*^9, 3.7131903378969584`*^9, 3.713191641132123*^9, 
   3.713192455847312*^9, 3.7131929431121106`*^9, 3.713193129302619*^9, 
   3.713193232112712*^9, 3.7131933922472286`*^9, 3.7131987363600063`*^9, 
   3.713199350730582*^9, 3.71319945051186*^9, 3.713199757746752*^9, 
   3.713200272998601*^9, 3.713200623869687*^9, 3.7132103144736*^9, 
   3.7132122403967037`*^9, 3.713213899983183*^9, 
   3.7133542956571107`*^9},ExpressionUUID->"455c6185-7f8a-4f58-a923-\
02383fc9e459"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculate the jacobians", "Subsection",
 CellChangeTimes->{{3.706697495526374*^9, 3.706697497030451*^9}, {
  3.706711069760562*^9, 
  3.706711073424722*^9}},ExpressionUUID->"5d9c660f-35ba-437b-b7ba-\
9b184672f31e"],

Cell["Apply the jacobian function to f, g and isotherm.", "Text",
 CellChangeTimes->{{3.7067123489497547`*^9, 3.7067123630780377`*^9}, {
  3.706712423350319*^9, 
  3.70671242375065*^9}},ExpressionUUID->"4e2ad624-4d16-45ef-b7a0-\
ec9e706fcab1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jacobian", "[", "f", "]"}]], "Input",
 CellChangeTimes->{{3.70671238609459*^9, 3.706712386310689*^9}, {
  3.7067124261673813`*^9, 3.706712443767275*^9}, {3.7067124848328667`*^9, 
  3.7067124929444*^9}},ExpressionUUID->"eb9add44-9484-4a24-8cfc-31284dfcbf53"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["n", 
       RowBox[{"1", ",", "2"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["n", 
       RowBox[{"2", ",", "1"}]]}], ",", 
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"2", ",", "2"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.706712387098205*^9, {3.706712431880371*^9, 3.7067124443635178`*^9}, 
   3.7067124936788387`*^9, 3.7067149486989565`*^9, 3.7067173516519303`*^9, 
   3.7067186549159894`*^9, 3.70679120840847*^9, 3.7067922324317703`*^9, 
   3.706793691448575*^9, 3.7067954331074767`*^9, 3.706796147667389*^9, 
   3.7067962062166843`*^9, 3.706797621589383*^9, 3.7068287634916763`*^9, 
   3.7068690988456044`*^9, 3.7068732615754843`*^9, 3.7070426087695365`*^9, 
   3.708511148890278*^9, 3.709554116296954*^9, 3.70955576378715*^9, 
   3.7095581258465805`*^9, 3.7116336707941656`*^9, 3.711635138145897*^9, 
   3.711794867511338*^9, 3.71181032493478*^9, 3.711884424508262*^9, 
   3.7130840914133244`*^9, 3.713103860313631*^9, 3.713112944554772*^9, 
   3.713119746472571*^9, 3.7131214004934015`*^9, 3.7131824232686863`*^9, 
   3.713182672590178*^9, 3.713186827563169*^9, 3.7131869112512264`*^9, 
   3.7131903379379597`*^9, 3.713191641168123*^9, 3.713192455876315*^9, 
   3.7131929431566105`*^9, 3.7131931293276205`*^9, 3.7131932321397085`*^9, 
   3.713193392283228*^9, 3.7131987364030094`*^9, 3.7131993507685823`*^9, 
   3.7131994505868597`*^9, 3.713199757832752*^9, 3.7132002730406017`*^9, 
   3.7132006239466877`*^9, 3.713210314488101*^9, 3.713212240424205*^9, 
   3.71321390001268*^9, 
   3.7133542957003374`*^9},ExpressionUUID->"44b7bfec-296f-43c1-87dd-\
260f98e5b263"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jacobian", "[", "g", "]"}]], "Input",
 CellChangeTimes->{{3.706711077296154*^9, 3.706711083952488*^9}, {
  3.7067111464175863`*^9, 3.7067111802253585`*^9}, {3.7067121764203043`*^9, 
  3.7067122543805304`*^9}, {3.706712320325474*^9, 3.7067123205506167`*^9}, {
  3.706712375871264*^9, 
  3.7067123960705924`*^9}},ExpressionUUID->"c18c2cd9-de12-4593-9ea9-\
cae1ba426603"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
       SubscriptBox["n", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
      SubscriptBox["n", 
       RowBox[{"1", ",", "2"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
      SubscriptBox["n", 
       RowBox[{"2", ",", "1"}]]}], ",", 
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
       SubscriptBox["n", 
        RowBox[{"2", ",", "2"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAmIH3Rma/+a+dgyXmp7xH0gzHPo6hWHea8c0kXvmjEBa
7CHfUhUgfUKKT1UVSPetyLsNoj/fUt6qBqQn7C3lUwfStaHHRUH0pvzNx0C0
gHvBbzMgneIUs9YLSHcd27zVB0jPSZJKmw+kjzjOLc1Z+NpRa3rXjszFrx3t
dKrbsoC0wcE9a7OB9NQHNxUSl792dNBzvQGiha0Kr60H0iYh85K2A+lDxwQm
3gbS17bkhquueu34T737nx6Q/uotlGcMpD/s8j9gBqQX2Qj0mwPpbbEvo0KB
9Mou4SoQXXSrqDEcSC8796IbRB+6YWcRCaSTBNVug2gxp78OUUBahvNZLYg2
49aeCqKfxLIuAtEaOzi3gehvS3mDYoH0rU0354HoR/XBq0H0g8W7L4Lo4g+K
QnFA+lXqf1sQvfFs0M8kID35Et+rZCD9aX/jzhQgfUPju9tKIA0A9TLUDg==

  "],ExpressionUUID->"69f14e82-49ec-4ce7-b832-54095d256bf6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jacobian", "[", "isotherm", "]"}]], "Input",
 CellChangeTimes->{{3.7067124040782204`*^9, 
  3.706712408250148*^9}},ExpressionUUID->"d04c16b7-2455-4867-987a-\
0e5b630f90a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ")"}], "2"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "1"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "2"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]]}], ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}]}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ")"}], "2"]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7067124050488653`*^9, 3.706712408763545*^9}, 
   3.7067149488145003`*^9, 3.7067173517649364`*^9, 3.7067186550379934`*^9, 
   3.706791208541977*^9, 3.7067922324552712`*^9, 3.7067936914715757`*^9, 
   3.706795433133977*^9, 3.706796147691389*^9, 3.706796206244688*^9, 
   3.7067976216213837`*^9, 3.706828763525175*^9, 3.706869098921105*^9, 
   3.7068732616639833`*^9, 3.7070426088790364`*^9, 3.708511148938278*^9, 
   3.7095541163749547`*^9, 3.7095557638921504`*^9, 3.709558125943082*^9, 
   3.711633670858164*^9, 3.7116351381778965`*^9, 3.711794867565339*^9, 
   3.711810325000779*^9, 3.711884424547263*^9, 3.7130840914600086`*^9, 
   3.7131038603856325`*^9, 3.713112944589772*^9, 3.7131197465110707`*^9, 
   3.7131214005313773`*^9, 3.7131824233186903`*^9, 3.7131826726321754`*^9, 
   3.7131868276136694`*^9, 3.7131869112997255`*^9, 3.713190337992959*^9, 
   3.7131916412106237`*^9, 3.713192455942317*^9, 3.7131929432226105`*^9, 
   3.713193129365123*^9, 3.7131932321947117`*^9, 3.7131933923302283`*^9, 
   3.713198736455509*^9, 3.7131993508360825`*^9, 3.7131994506308594`*^9, 
   3.7131997578992534`*^9, 3.713200273082108*^9, 3.7132006240161915`*^9, 
   3.713210314646612*^9, 3.713212240494207*^9, 3.713213900093181*^9, 
   3.713354295747735*^9},ExpressionUUID->"315e52fd-fe9c-43d7-a9cb-\
a8dd326d81dd"]
}, Open  ]],

Cell[TextData[{
 "We can also imagine that we might try to simplify the differential \
equations by multiplying through by ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"Jacobian", "[", "g", "]"}], 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "bbf7e112-0483-4f71-88f8-e840d64221e7"],
 ".  If we do that, we\[CloseCurlyQuote]ll get a new matrix that we will call \
h."
}], "Text",
 CellChangeTimes->{{3.7067112999286165`*^9, 3.7067113779308724`*^9}, {
  3.7067114205720997`*^9, 
  3.7067114571805215`*^9}},ExpressionUUID->"ff19589d-df2a-44fa-a501-\
32e10ac17f73"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"jacobian", "[", "h", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Inverse", "[", 
      RowBox[{"jacobian", "[", "g", "]"}], "]"}], ".", 
     RowBox[{"jacobian", "[", "f", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Grid", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.70671123850519*^9, 3.7067112837222548`*^9}, {
   3.7067116740937614`*^9, 3.706711681525446*^9}, {3.706712284150115*^9, 
   3.7067123355659723`*^9}, 
   3.706712477048424*^9},ExpressionUUID->"829ddd87-ab17-4e25-ac2d-\
9db27fb5d662"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["v", "*"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
        "\[Psi]", " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Psi]", "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"]}], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}]], 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]"}], "+", 
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}]}]}], 
        ")"}], " ", "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"1", ",", "2"}]]}], 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}]]},
    {
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["v", "*"], "+", "\[Mu]", "-", 
         RowBox[{
          SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
       "\[Psi]", " ", 
       SubscriptBox["n", 
        RowBox[{"2", ",", "1"}]]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"]}], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}]], 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["v", "*"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
        "\[Psi]", " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Psi]", "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"]}], " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SubscriptBox["n", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["n", 
         RowBox[{"2", ",", "1"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}]]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{3}}, "Rows" -> {{3}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.7067112845027976`*^9, 3.7067116822060537`*^9, {3.706712292008176*^9, 
   3.706712309213183*^9}, {3.7067124535978265`*^9, 3.706712477742184*^9}, 
   3.7067149489345474`*^9, 3.706717351878442*^9, 3.7067186551565*^9, 
   3.7067912086670732`*^9, 3.7067922324672694`*^9, 3.7067936915220714`*^9, 
   3.7067954332609777`*^9, 3.706796147798889*^9, 3.7067962063481846`*^9, 
   3.706797621719884*^9, 3.7068287636506734`*^9, 3.706869099052107*^9, 
   3.706873261844985*^9, 3.707042609000037*^9, 3.7085111490342846`*^9, 
   3.7095541165279565`*^9, 3.709555764129154*^9, 3.709558126109084*^9, 
   3.7116336709691596`*^9, 3.711635138317892*^9, 3.7117948676803403`*^9, 
   3.711810325113696*^9, 3.711884424665763*^9, 3.7130840916060114`*^9, 
   3.713103860537636*^9, 3.7131129447032723`*^9, 3.7131197466300707`*^9, 
   3.713121400642376*^9, 3.7131824234361906`*^9, 3.713182672749679*^9, 
   3.7131868277546697`*^9, 3.7131869114247265`*^9, 3.7131903380959606`*^9, 
   3.7131916413206267`*^9, 3.713192456054319*^9, 3.713192943337615*^9, 
   3.713193129465623*^9, 3.7131932322277126`*^9, 3.71319339244473*^9, 
   3.7131987365855103`*^9, 3.7131993509585896`*^9, 3.713199450760865*^9, 
   3.713199758029252*^9, 3.713200273197339*^9, 3.7132006241501913`*^9, 
   3.7132103147711225`*^9, 3.7132122406342077`*^9, 3.713213900235183*^9, 
   3.713354295878309*^9},ExpressionUUID->"953e99ad-bfac-415d-b64c-\
8a55f0c69050"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 3: Analysis of the Problem", "Section",
 CellChangeTimes->{{3.7066975134945*^9, 3.7066975151664844`*^9}, {
  3.7067114786591363`*^9, 
  3.706711505603323*^9}},ExpressionUUID->"ff80a2b1-8068-489e-9928-\
37f7cafae5d9"],

Cell["\<\
Now that we have defined several equations relevant to the problem, it is \
time to analyze them.  Of course we know that the first step in the analysis \
of a matrix equation is:\
\>", "Text",
 CellChangeTimes->{{3.706711525275626*^9, 
  3.706711590764321*^9}},ExpressionUUID->"850117d9-9090-440d-8474-\
0e6759d84599"],

Cell[CellGroupData[{

Cell["Eigenvectors and Eigenvalues", "Subsection",
 CellChangeTimes->{{3.706711512587615*^9, 
  3.706711518187507*^9}},ExpressionUUID->"f1f9b472-3829-480f-8cbc-\
869b3892fd59"],

Cell["\<\
Just like with the jacobians, we will make a memoized function to find the \
eigenvalues and vectors of our matrices.  The Mathematica Eigensystem \
function returns {Eigenvalues[x],Eigenvectors[x]} so we will save the results \
that way.\
\>", "Text",
 CellChangeTimes->{{3.7067119594245577`*^9, 3.706711992933338*^9}, {
  3.706712886396757*^9, 3.706712897684767*^9}, {3.706713384794925*^9, 
  3.706713406179731*^9}, {3.7067136139183674`*^9, 
  3.7067136182540827`*^9}},ExpressionUUID->"8ffc406c-2914-49b1-b6b5-\
7d26c66168cc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eigenSystem", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"eigenSystem", "[", "x", "]"}], "=", 
   RowBox[{"Simplify", "@", 
    RowBox[{"Eigensystem", "@", 
     RowBox[{"jacobian", "[", "x", "]"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eigenSystem", "[", "f", "]"}]}], "Input",
 CellChangeTimes->{{3.7067120920514545`*^9, 3.706712118214448*^9}, {
   3.7067125244082756`*^9, 3.7067125314170847`*^9}, {3.706712764524149*^9, 
   3.7067127688916802`*^9}, {3.7067133283482494`*^9, 3.706713343499029*^9}, {
   3.706713548623397*^9, 3.706713559502245*^9}, {3.706714581223076*^9, 
   3.7067145890339394`*^9}, {3.706714647761443*^9, 3.706714649201081*^9}, 
   3.706869296370481*^9},ExpressionUUID->"0a621afe-d894-4d29-8ed6-\
21c2e5c5128a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "-", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "2"}]], "+", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["n", 
             RowBox[{"1", ",", "1"}], "2"], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            SubsuperscriptBox["n", 
             RowBox[{"2", ",", "2"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "1"}]]}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], "-", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}]], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.706712533705187*^9, 3.706712769686596*^9, 3.706713354919284*^9, {
   3.7067135506110044`*^9, 3.706713560377141*^9}, 3.7067145918390837`*^9, 
   3.7067146497443485`*^9, 3.706714949000572*^9, 3.7067173519459457`*^9, 
   3.7067186552320027`*^9, 3.7067912087355757`*^9, 3.7067922324767733`*^9, 
   3.7067936915330715`*^9, 3.706795433310979*^9, 3.706796147861889*^9, 
   3.706796206411685*^9, 3.7067976217903824`*^9, 3.7068287637206745`*^9, 
   3.706869099149105*^9, 3.70686929682683*^9, 3.706873261981985*^9, 
   3.7070426090915365`*^9, 3.7085111491518335`*^9, 3.7095541166329904`*^9, 
   3.7095557643281565`*^9, 3.7095581262820883`*^9, 3.711633671061657*^9, 
   3.7116351384789023`*^9, 3.711794867771841*^9, 3.711810325206667*^9, 
   3.7118844247602634`*^9, 3.713084091726014*^9, 3.7131038606471395`*^9, 
   3.713112944789272*^9, 3.7131197467305713`*^9, 3.713121400732267*^9, 
   3.71318242352219*^9, 3.7131826728316793`*^9, 3.7131868278391705`*^9, 
   3.713186911509227*^9, 3.713190338187961*^9, 3.713191641408126*^9, 
   3.7131924561408167`*^9, 3.713192943429615*^9, 3.7131931295546217`*^9, 
   3.7131932322532125`*^9, 3.7131933925302305`*^9, 3.71319873667101*^9, 
   3.7131993510615873`*^9, 3.7131994508738623`*^9, 3.7131997581742535`*^9, 
   3.7132002732908525`*^9, 3.713200624274191*^9, 3.7132103148656282`*^9, 
   3.7132122407297087`*^9, 3.713213900330185*^9, 
   3.713354295971814*^9},ExpressionUUID->"f8e86bdd-299f-4b22-b9b9-\
0654d0e3c24c"]
}, Open  ]],

Cell[TextData[{
 "Of course, our equations are still in terms of both concentration AND \
loading.  To eliminate the loading variables, we need to replace loading with \
explicit equations in terms of concentration.  To do that, we need a list of ",
 StyleBox["replacement rules",
  FontSlant->"Italic"],
 " that map ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", 
    RowBox[{"a", ",", "b"}]], TraditionalForm]],ExpressionUUID->
  "7302415e-97d5-45a5-b829-22850d4925e7"],
 " to the appropriate derivative.  We\[CloseCurlyQuote]ve already calculated \
the derivatives (the jacobian of the isotherm) so we just need to match them \
up."
}], "Text",
 CellChangeTimes->{{3.7067137263029785`*^9, 3.7067137744886074`*^9}, {
  3.706713833599678*^9, 3.706713848781175*^9}, {3.7067139004086905`*^9, 
  3.7067140012556887`*^9}, {3.7067145206155367`*^9, 
  3.706714526810363*^9}},ExpressionUUID->"09926698-e4b8-479d-9125-\
6924b6cba820"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"replacementTable", "=", 
  RowBox[{"Thread", "/@", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["n", 
        RowBox[{"i", ",", "j"}]], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "2"}], "}"}]}], "]"}], "\[Rule]", 
     RowBox[{"jacobian", "[", "isotherm", "]"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replacementRules", " ", "=", " ", 
   RowBox[{"Flatten", "[", "replacementTable", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7067138582489634`*^9, 3.7067138695365973`*^9}, {
  3.7067141528593388`*^9, 3.7067141716659865`*^9}, {3.706714386731142*^9, 
  3.706714387556119*^9}, {3.7067144190173063`*^9, 
  3.706714468667468*^9}},ExpressionUUID->"8cfaee93-93cc-49f1-9e81-\
cea7cb87bb72"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["n", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]]}], ",", 
     RowBox[{
      SubscriptBox["n", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "1"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}], "2"]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["n", 
       RowBox[{"2", ",", "1"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}], "2"]]}]}], ",", 
     RowBox[{
      SubscriptBox["n", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7067138618520985`*^9, 3.7067138702867374`*^9}, 
   3.7067143881842384`*^9, 3.706714423389299*^9, 3.7067144693447323`*^9, 
   3.706714594722907*^9, 3.706714949027082*^9, 3.706717351976447*^9, 
   3.7067186552575045`*^9, 3.706791208749072*^9, 3.70679223248777*^9, 
   3.7067936915460806`*^9, 3.7067954333259773`*^9, 3.7067961478768897`*^9, 
   3.7067962064266844`*^9, 3.7067976218048844`*^9, 3.7068287637376738`*^9, 
   3.7068690991636047`*^9, 3.706873261995485*^9, 3.7070426091030374`*^9, 
   3.708511149160837*^9, 3.70955411665399*^9, 3.7095557643471565`*^9, 
   3.7095581263325887`*^9, 3.7116336710779734`*^9, 3.7116351384914026`*^9, 
   3.711794867783342*^9, 3.711810325220666*^9, 3.711884424776265*^9, 
   3.7130840917410126`*^9, 3.7131038606726403`*^9, 3.713112944798272*^9, 
   3.713119746742071*^9, 3.713121400742265*^9, 3.7131824235891933`*^9, 
   3.7131826728506813`*^9, 3.7131868278656707`*^9, 3.713186911546229*^9, 
   3.7131903382089615`*^9, 3.713191641429125*^9, 3.7131924561618185`*^9, 
   3.713192943456114*^9, 3.713193129573124*^9, 3.7131932322807083`*^9, 
   3.7131933925477314`*^9, 3.7131987366915073`*^9, 3.7131993510900855`*^9, 
   3.713199450916862*^9, 3.713199758233254*^9, 3.7132002733115687`*^9, 
   3.7132006243531923`*^9, 3.7132103148771276`*^9, 3.7132122407907085`*^9, 
   3.713213900390188*^9, 
   3.71335429599132*^9},ExpressionUUID->"b639dc1c-3811-41f7-9782-\
b41325bc20ee"]
}, Open  ]],

Cell["\<\
So we should also make a function that calculates the eigenvalues and vectors \
with those replacement applied.\
\>", "Text",
 CellChangeTimes->{{3.706714606820258*^9, 
  3.706714663526163*^9}},ExpressionUUID->"a9f39401-71a6-466f-94df-\
5677106d3cae"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eigenSystemReplacements", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"eigenvalues", "[", "x", "]"}], ",", 
     RowBox[{"eigenvectors", "[", "x", "]"}]}], "}"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"eigenSystem", "[", "x", "]"}], "/.", "replacementRules"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
        RowBox[{
         SubscriptBox["c", "1"], "\[GreaterEqual]", "0"}], ",", 
        RowBox[{
         SubscriptBox["c", "2"], "\[GreaterEqual]", "0"}]}], "}"}]}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eigenSystemReplacements", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["n", "1"], ",", 
    SubscriptBox["n", "2"]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.706714664722443*^9, 3.706714664724963*^9}, {
  3.7067147013967113`*^9, 3.706714754442542*^9}, {3.7067150420877953`*^9, 
  3.70671507562928*^9}, {3.706797579635147*^9, 
  3.706797594147757*^9}},ExpressionUUID->"263085bb-d70f-42e9-a9ee-\
f4199378c6b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}]}], "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["c", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"], " ", 
          SubsuperscriptBox["c", "2", "2"]}]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["c", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"], " ", 
          SubsuperscriptBox["c", "2", "2"]}]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuF8wdL/c187iu3UrQTR27qdpjLMe+24wkvHghFI/wmP
XqoCpN+cUlJVBdJTLtbcBtEJIZZb1YD0/1/tfOpAekH0LVEQPevg3WMg2kdt
3m8zIF23fdJaLyDdJPVxqw+QTovwTpsPpNOXnS7NWfja0fP+/h2Zi187Cljt
bMsC0ut+fF+bDaSFPHgUE5e/dlyzpPUGiBaLWHRtPZAuEjidtB1IP5Gwnngb
SJ/bsyFcddVrx6S/x//pAWmLJKc8YyC9Tr/1gBmQbit36TcH0pLPxaJDgfSh
e3ZVIDpk+fzGcCCdISbWA6LnVWVZRALpL6pBt0H02ihBxygg7cH/uxZEv6q2
mwqiTzWpLwLRUyRMt4HovueWQbEgfRwc80G0akfjahBds+vNRRBdJe4rFAek
pQ/o24HokPdNP5OAdJOc3atkIG0ltWlnCpDetlXVfSWQBgC6kNEZ
  "],ExpressionUUID->"52456bd8-236f-4d90-9017-afe688afbbea"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Do the Eigensystem calculations", "Subsubsection",
 CellChangeTimes->{{3.7067133155144725`*^9, 3.70671332155459*^9}, {
  3.706713590934043*^9, 3.7067135960861516`*^9}, {3.7067148794410777`*^9, 
  3.7067148808494263`*^9}},ExpressionUUID->"0ef3c32a-2e66-411b-a06f-\
2693e51c5bf5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystem", "[", "f", "]"}]], "Input",ExpressionUUID->"bca9d8fa-2a58-4852-9330-ded82d0d4903"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "-", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "2"}]], "+", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["n", 
             RowBox[{"1", ",", "1"}], "2"], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            SubsuperscriptBox["n", 
             RowBox[{"2", ",", "2"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "1"}]]}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], "-", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}]], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuKa3qLUf3NfOwbtXpzxH0ivuO0+lWHea0dNE0MLRiCd
JpKwVAVIy/1TVlUF0k1L6m6D6OAgq61qQPrNsi4+dSA9Y/1dURB91evhMRC9
xGTxbzMgve3BtLVeQDoo4/NWHyBdeNs3bT6QvsB+tjRn4WvHG96Hd2Qufu0o
b7OnLQtI++z9tTYbSP+eyaeYuPy1o9Cj9hsg2v/h4mvrgbT8krNJ24G0yz/b
ibeBtNOvTeGqq1476nme/qcHpMsOOecZA2mPk20HzIC00gvXfnMgXbJQIjoU
SFsdc6gC0Z+nLWwMB9JpryV6QLSVSI5FJJBO4g25DaIvcIk4RgHpX9p/a0G0
l5nDVBA945zGIhCtdttsG4gWWWETFAukT4dxzQfRDIzNq0E0V9D7iyCaI8hf
KA5In5E0tQPRvWdafyYBaTFzh1fJQPpO/JadKUB6VYe6+0ogDQCagNC0
  "],ExpressionUUID->"ccd169f9-26b6-42c2-82c7-cdaca7bd6e32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystem", "[", "g", "]"}]], "Input",
 CellChangeTimes->{{3.706712882524826*^9, 
  3.706712882636503*^9}},ExpressionUUID->"ab60a5a2-4db6-459b-9fc9-\
6237365892f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], "-", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"2", " ", 
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]]}], "-", 
        RowBox[{"\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "2"}]], "+", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["n", 
             RowBox[{"1", ",", "1"}], "2"], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            SubsuperscriptBox["n", 
             RowBox[{"2", ",", "2"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "1"}]]}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], "-", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}]], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuKodelp/+a+dpxhsTzjP5CWyfWeyjDvtWNEn6kFI5BO
yEheqgKkb7irqKoCaYd3dbdB9L4dVlvVgPSsd7186kB6E/9DURDNdeXJMRC9
KHb5bzMgfdlq9lovIH0z+PtWHyB9fmpg2nwgvSf8QmnOwteOB44d35G5+LXj
Bd3DbVlAWi3x/9psIG0RIKSYuPy1I09y9w0QfaVs+bX1QPqQ4cWk7UA67abj
xNtA+tbz7eGqq4Du473wTw9IP/J3zzMG0gfauw6YAWk3J69+cyA9P1gmOhRI
f5vgUgWib9ksbQwH0j5psj0gevLCfItIIH3sePhtEL2DTcIxCkhbPGKoA9E1
+52nguigPM1FIPpmhdU2ED3D1iEoFkh/MuSbD6KPlbevBtEvyj5fBNHKf4KE
4oB0gIGVHYg26O/8mQSkFyi5vEoG0iIZO3amAOkj87TdVwJpAMCQ0+E=
  "],ExpressionUUID->"ba25bd37-ab54-46f8-a1d7-df5ee3297c10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystem", "[", "isotherm", "]"}]], "Input",
 CellChangeTimes->{{3.706713029000736*^9, 
  3.7067130351108665`*^9}},ExpressionUUID->"dbddcb24-cf6a-4682-8b63-\
a22cfdc85002"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "1"]}], "+", 
         SubscriptBox["a", "2"], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}], "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdxU0og3EcAOD3LVFas5Y1ly1b29TKaDKLaO9l08bBwoy2ZsZ8LC5mUUTh
IE2r7WBlyxjtk5YZtcNQTrSUttWOFHmV7WZW4/d3eHo4xgX1JI5hmBhUNbuX
Kwck8cxMTv/CLZ0GF+aBBUopDn+abX4e/L4o5PPhTGwrj87Ru+IC2FDnpDbB
1tY3BpqJk/foYUG0LIEl376IEk6WKvE+2N4+MuWFBy0Zq+WQJGpX01czRyRh
Yj9uz8IeFiU6Bxe+GjjjpySRCu/n0JLqaOYMLrizxgR88tLryMPr4ZSGHySJ
4GauIoJp2f75Npguc6QkMJYY2OuAzwPcsSFY16haQTOLoQ0N7GfzdtFC2pJU
C5M2fR7NvWMTozBFW7OGvmApXeh6qtCHLpZll/8/yNU6GN9heNGvaXsIfez6
eUIbb7R0PRxzEj1oc9JRMsLybtXHBHwrSl2bYEVErAjAf2Fez3I=
  "],ExpressionUUID->"72c688ee-66c8-422b-8382-adb6ed62ffe4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystem", "[", "h", "]"}]], "Input",
 CellChangeTimes->{{3.7067130462031765`*^9, 
  3.7067130491671314`*^9}},ExpressionUUID->"df0e4580-cc97-4c5e-94a6-\
cfb140eda709"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Psi]", " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["v", "*"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "2"}]], " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "1"}]]}], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["v", "*"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]"}], "-", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["v", "*"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "-", 
          RowBox[{"\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "2"}]], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Psi]", " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["v", "*"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "2"}]], " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "1"}]]}], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SubscriptBox["n", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["v", "*"], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]"}], "-", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["v", "*"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "+", 
          RowBox[{"\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}], "-", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
           SqrtBox[
            RowBox[{
             SubsuperscriptBox["n", 
              RowBox[{"1", ",", "1"}], "2"], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "2"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["n", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["n", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubsuperscriptBox["n", 
              RowBox[{"2", ",", "2"}], "2"]}]]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "2"}]], " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["n", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "2"}]], "+", 
          SqrtBox[
           RowBox[{
            SubsuperscriptBox["n", 
             RowBox[{"1", ",", "1"}], "2"], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["n", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["n", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            SubsuperscriptBox["n", 
             RowBox[{"2", ",", "2"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["n", 
           RowBox[{"2", ",", "1"}]]}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["n", 
          RowBox[{"1", ",", "1"}]], "-", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "2"}]], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["n", 
            RowBox[{"1", ",", "1"}], "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["n", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["n", 
             RowBox[{"2", ",", "2"}]]}], "+", 
           SubsuperscriptBox["n", 
            RowBox[{"2", ",", "2"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["n", 
          RowBox[{"2", ",", "1"}]]}]], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuLjq/yr/8197eg272TGfyBd8SR7KsO8145BF0ItGIH0
7SdNS1WA9HlXbVVVIM0t2HYbRF+aaL1VDUjnCC7kUwfSK5M/iYJoBo1vx0D0
mym7fpsBaQ2vjWu9gHTpW55tPkBa5kdy2nwgbbLjYWnOwteOVV/u7MhcDDTv
xr22LCCd9kJyXTaQ3uOoqpi4/LXj7qilN0C0wIqd19YD6VcKj5O2A+kf00Mn
3gbSOdUXwlVXvXacpPbinx6QTtgVmWcMpIUd5h4wA9Iti+L7zYF0kZxedCiI
vzSsCkSvurejMRxIu+zQ7wHR4r2NFpFA+rZX1m0QzZ2p5RgFpNmYhetAtGlb
6FQQXX1KaxGI5tH22QaixYKCgmKBdIOs0nwQzXFt9moQnXWd4xKItlibKhQH
pOfs9rMD0Toh834mAekXq8NfJQPpXdfO7EwBuXu9nftKIA0AjDDSEQ==
  "],ExpressionUUID->"04dd525c-6dec-448b-82d5-0749e9454dc1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Do the Eigensystem replacements", "Subsubsection",
 CellChangeTimes->{{3.7067148692610626`*^9, 
  3.7067148837383714`*^9}},ExpressionUUID->"6ed1adf5-a56a-498c-88fb-\
fdefac071c31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystemReplacements", "[", "f", "]"}]], "Input",
 CellChangeTimes->{
  3.706714922986961*^9},ExpressionUUID->"5b105114-bb30-43cf-af33-\
6f5d4afa930a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Psi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["v", "*"], "+", 
            RowBox[{
             SuperscriptBox["v", "*"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{"\[Psi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["v", "*"], "+", 
            RowBox[{
             SuperscriptBox["v", "*"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["v", "*"], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuKa3qLUf3NfO4otUsv8D6SL+OZMZZj32lGYqc2CEUhn
1GxcqgKkvTaYqqoCaZW9k26D6KCLLlvVgLTT1uV86kDa5dIPURBdtVviOIiW
cH342wxIbzG/t9YLSAcKmW/zAdJKP9rT5gPpqG7mspyFrx0fTGHembn4tePR
Qvb2LCB9/Ljjumwgvc3XVzFx+WvHvRNP3ADRfH53r60H0mWbWJO3A2lxl4aJ
t4H0N0OWCNVVrx1DBUT/6wHpaXl1ecZA+nTckQNmQNpJu6vfHEg3uAZGhwLp
R+srq0C0X9ndxnAgnZEW3AOiEw4ssYgE0ueO9t0G0XWqlo5RQJqjSbEOTF9J
ngqiL6yMWwSi29Lyt4Ho5XsqgmKBtLmV23wQHRR/cDWIfpauewlEc/Z3CMUB
6RS9YjsQnXP40M8kIL2npOZVMpD+q/VlZwqQlrue7L4SSAMAGSvOPg==
  "],ExpressionUUID->"4b7a73e7-9f66-4922-b446-590330e7d5d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystemReplacements", "[", "g", "]"}]], "Input",
 CellChangeTimes->{{3.706712882524826*^9, 3.706712882636503*^9}, 
   3.7067149243308744`*^9},ExpressionUUID->"d1eb5706-9e7a-4742-8858-\
c8b05b95e929"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], "-", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "-", 
        RowBox[{"\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuKodelp/+a+dtxS5Jv5H0h31x+cyjDvtaOH4moLRiB9
YOvVpSpA2muDq6oqkHabseA2iL6UFrJVDUjfUt7Cpw6kj+1lEQPRsw5GHgfR
Ccs1/5gB6bwww3VeQPrF6rptPkDar/5C2nyQ+E+nspyFQHv4vHZmLn7teDkz
sD0LSDPJTFyXDaQVvk9STFwOdNdy7psgun2N/PX1QDpMzD15O5DWO3xs4m0g
/TYlLUJ11WvHM+YZ//WAdAzf4TxjIK12mPugGZAuMr7Vbw6kf1ZNjQ4F0n/3
7q0C0Q0/5ZvCgbSP8bQeEP3H/KlFJJA+nnn5Noh2yk1wjALSCcludSB6zov2
qSB6kczmRSCaadGGbSD63tTdQbFA2ou3az6IfibLvAZEu80tvASiY1acEooD
0jzyO+1AdJE1+68kIH3j/YFXyUC6Qt9qVwqQtnq70n0lkAYAvJbTLA==
  "],ExpressionUUID->"b00e1454-ef64-44c9-89ca-5739c5bd2278"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystemReplacements", "[", "isotherm", "]"}]], "Input",
 CellChangeTimes->{{3.706713029000736*^9, 3.7067130351108665`*^9}, 
   3.70671492568357*^9},ExpressionUUID->"a3ca0518-7825-4d92-a0af-\
960f15988063"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}], "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAmIW3VmV/+a+dqzbHZH5H0hXnT4zlWHea8cA6W0WjEDa
2fvhUhUgLXDRU1UVSMsILrkNos0XRW5VA9KZz7byqQNplbdsYiB63puk4yC6
p8bkjxmQ/vDYZp0XSD6hc5sPkLarvZ02H0gvyfApy1n42pEnImxn5uLXjmyz
Y9uzgPSbaXPXZQNpO625ionLXzt+NRG9CaKLgjSvrwfSYQ6ByduBtNyUyxNv
A2kD8YoI1VWvHb+lFf/XA9KqG87kGQPpZbpiB82AtEXIs35zIH1eZn50KJC+
wnmiCkQ/2qzZFA6k78gt6AHRPh3vLCKBdNC1O7dB9I8tlY5RQPp6ZHwdiBb7
O38qiH5xYfciEK0TtHsbiPZTPxoUCzLn/OT5IHrabp41IHrF2upLIHqC9xWh
OCDtVHvUDkRX3xf8lQSkORRPv0oG0jt6XXalAGmt3i3uK4E0APqw0uI=
  "],ExpressionUUID->"1ba37dae-8776-47ed-8323-930c0de8651f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenSystemReplacements", "[", "h", "]"}]], "Input",
 CellChangeTimes->{{3.7067130462031765`*^9, 3.7067130491671314`*^9}, 
   3.7067149281567326`*^9},ExpressionUUID->"d2072a2f-64a6-4536-82cf-\
10d7abd6e5f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Psi]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["v", "*"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["a", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["v", "*"]}], "+", "\[Mu]", "-", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
                RowBox[{
                 SuperscriptBox["v", "*"], " ", 
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["v", "*"]}], "+", "\[Mu]", "-", 
                 RowBox[{
                  SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
                 RowBox[{
                  SuperscriptBox["v", "*"], " ", 
                  SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}]}], 
              " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "-", 
             RowBox[{"\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "+", 
             RowBox[{
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "+", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["a", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], " ", "\[Mu]", 
              " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}], "2"]}]}], ")"}]}]}], 
         ")"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Psi]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["v", "*"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["a", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["v", "*"]}], "+", "\[Mu]", "-", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
                RowBox[{
                 SuperscriptBox["v", "*"], " ", 
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["v", "*"]}], "+", "\[Mu]", "-", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
                RowBox[{
                 SuperscriptBox["v", "*"], " ", 
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "-", 
             RowBox[{"\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "+", 
             RowBox[{
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}], "+", 
             RowBox[{
              SuperscriptBox["v", "*"], " ", 
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
              SqrtBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "-", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["a", "1"], " ", 
                 SubscriptBox["b", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "1"], "+", 
                   RowBox[{
                    SubscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["a", "1", "2"], " ", 
                 SubsuperscriptBox["b", "2", "2"], " ", 
                 SubsuperscriptBox["c", "2", "2"]}]}]]}]}], ")"}]}]}], 
         ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
              SubscriptBox["a", "2"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], " ", "\[Mu]", 
              " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}], "2"]}]}], ")"}]}]}], 
         ")"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "2"]}]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], 
         RowBox[{"2", " ", 
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "2"]}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuLjq/yr/8197fjnyu7M/0DaxEZ7GsM8IL1J2JIRSF9L
tl6mAqQbVapVVYH01y1PboPoCYYLtqoBafPNT/jUgXTbXyMxEK0teP8UiL6/
Yd9/MyBdeertRi+Qeb0mu3yA9KedeVnzgfSD7L7KnIWvHSMCz+7JXPzacc3d
7u4sIB12q2xTNpBm9BNUTVz+2nHO6bY7INpl/tRb64F0FP/ytO1A+mKh59Tb
QFpDKjVWddVrxw/PljDrA+lWW6ciYyB9+MWpI2ZAOspnzWRzIC2hwR4fCqTl
uDXrQPSk9NbWcCD958GffhDtc9rOJhJI13Y43gfRLoJnHaOA9L3gbXUguoT9
7VQQHSiksxxExx0Q2QWiiw5ohsUC6azjQotBdEJL8XoQbfz1x1UQnSbkKhYH
pM9tM3YC0YEr2/4mAWkBHZ93yUCayfzC3hQg3bVNyHslkAYAmJnR+A==
  "],ExpressionUUID->"478213a7-256a-4a8d-97a0-1ced7274a146"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Demonstrate some properties of the eigenvalues and vectors", \
"Subsection",
 CellChangeTimes->{{3.7067151218299713`*^9, 
  3.7067151553470125`*^9}},ExpressionUUID->"5eab965c-f748-48bc-9b18-\
3c446daeb560"],

Cell[CellGroupData[{

Cell["The eigenvectors of the f, g, and h matrices are the same", \
"Subsubsection",
 CellChangeTimes->{{3.7067152496549425`*^9, 3.706715256649578*^9}, {
   3.7067153043000526`*^9, 3.7067153140635843`*^9}, {3.7067153745030117`*^9, 
   3.7067153787285357`*^9}, 
   3.7068186983430324`*^9},ExpressionUUID->"a8368a19-35d4-4cc4-bdf2-\
754ae7074754"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eigenvectors", "[", "f", "]"}], "==", 
  RowBox[{"eigenvectors", "[", "g", "]"}], "==", 
  RowBox[{"eigenvectors", "[", "h", "]"}]}]], "Input",
 CellChangeTimes->{{3.7067151607248864`*^9, 
  3.7067152006372733`*^9}},ExpressionUUID->"61785d16-741b-4798-aad8-\
763c0b9cb647"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7067151851309566`*^9, 3.7067152014788637`*^9}, 
   3.7067173614166007`*^9, 3.7067186646695127`*^9, 3.7067912179184065`*^9, 
   3.7067922358912067`*^9, 3.706793695190588*^9, 3.70679543705555*^9, 
   3.7067961512013764`*^9, 3.706796209617448*^9, 3.7067976549963465`*^9, 
   3.70682879800809*^9, 3.706869135490464*^9, 3.706873297709737*^9, 
   3.7070426435257096`*^9, 3.708511180494672*^9, 3.709554150508181*^9, 
   3.70955580444631*^9, 3.709558163798155*^9, 3.7116337045962677`*^9, 
   3.71163517223285*^9, 3.7117949007101917`*^9, 3.7118103572746215`*^9, 
   3.711884458345522*^9, 3.7130841392334447`*^9, 3.713103901188193*^9, 
   3.7131129781000085`*^9, 3.7131197823724127`*^9, 3.713121437415657*^9, 
   3.7131824562681484`*^9, 3.71318270533611*^9, 3.713186860238388*^9, 
   3.7131869439604635`*^9, 3.713190369997316*^9, 3.7131916740859137`*^9, 
   3.7131924624563627`*^9, 3.713192949761736*^9, 3.713193135441661*^9, 
   3.7131932734167376`*^9, 3.7131934246864853`*^9, 3.7131987693507433`*^9, 
   3.7131993846343436`*^9, 3.713199483654909*^9, 3.7131997918244348`*^9, 
   3.713200306204494*^9, 3.7132006576624975`*^9, 3.7132103482746754`*^9, 
   3.7132122744258795`*^9, 3.7132139345612125`*^9, 
   3.713354328623782*^9},ExpressionUUID->"f83e7e21-f9ad-4cc3-937b-\
9bedb0fddeb9"]
}, Open  ]],

Cell["\<\
With some assumptions, it can be shown that eigenvectors of the isotherm \
equation are also the same.\
\>", "Text",
 CellChangeTimes->{{3.706715337080372*^9, 3.7067153947907505`*^9}, {
  3.7067154806478367`*^9, 3.7067154819043355`*^9}, {3.706790798928074*^9, 
  3.7067907994131117`*^9}},ExpressionUUID->"20584ea3-8488-43e2-8811-\
b4c63daa70b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Thread", "/@", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"eigenvectors", "[", "h", "]"}], "\[Equal]", 
      RowBox[{"eigenvectors", "[", "isotherm", "]"}]}], "]"}]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[GreaterEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[GreaterEqual]", "0"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7067154150959487`*^9, 3.7067155344017467`*^9}, {
  3.7067155947649603`*^9, 3.706715606713121*^9}, {3.706792242350218*^9, 
  3.7067922424777164`*^9}, {3.706792886578766*^9, 3.7067929272796106`*^9}, {
  3.7067978348413467`*^9, 
  3.7067978352928333`*^9}},ExpressionUUID->"02994375-aa0a-488f-8914-\
4d9a13be513a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"True", ",", "True"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"True", ",", "True"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.706715428177367*^9, {3.706715463246236*^9, 3.7067154943509836`*^9}, {
   3.7067155895739202`*^9, 3.7067156081485367`*^9}, 3.7067173625606585`*^9, 
   3.706718665804654*^9, 3.706791219021855*^9, 3.706792236151207*^9, 
   3.7067926648502436`*^9, {3.7067928880195336`*^9, 3.706792928387638*^9}, 
   3.7067936953595915`*^9, 3.70679543724205*^9, 3.7067961513438773`*^9, 
   3.7067962097554483`*^9, 3.7067976551648445`*^9, 3.7067978364050226`*^9, 
   3.7068287982135887`*^9, 3.706869135674962*^9, 3.7068732979392395`*^9, 
   3.70704264372221*^9, 3.7085111806646805`*^9, 3.7095541507061834`*^9, 
   3.709555804663313*^9, 3.709558164028656*^9, 3.7116337047807612`*^9, 
   3.7116351724118476`*^9, 3.711794900897194*^9, 3.711810357454332*^9, 
   3.7118844585257587`*^9, 3.7130841395084515`*^9, 3.713103901409197*^9, 
   3.7131129782810087`*^9, 3.7131197825649133`*^9, 3.713121437604736*^9, 
   3.713182456447149*^9, 3.7131827055131097`*^9, 3.713186860419894*^9, 
   3.7131869441389656`*^9, 3.7131903701743164`*^9, 3.7131916742669144`*^9, 
   3.7131924681328983`*^9, 3.713192955393733*^9, 3.7131931408537006`*^9, 
   3.7131932735732365`*^9, 3.713193424866484*^9, 3.7131987695307455`*^9, 
   3.7131993848298454`*^9, 3.713199483827411*^9, 3.7131997919939356`*^9, 
   3.713200306396498*^9, 3.713200657845623*^9, 3.7132103484701877`*^9, 
   3.7132122746183815`*^9, 3.7132139347587147`*^9, 
   3.7133543288012996`*^9},ExpressionUUID->"30699dbb-e42c-45ce-9118-\
3b7db1d4a0eb"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The eigenvalues are related to each other in interesting ways\
\>", "Subsubsection",
 CellChangeTimes->{{3.7067943288854575`*^9, 
  3.706794342926218*^9}},ExpressionUUID->"bcbf2a1c-689a-4255-9d57-\
5e19fbe0f9e0"],

Cell[TextData[{
 "To show how the eigenvalues are related, we need to name the eigenvalues of \
the different matricies.  We can do the naming with a function that creates \
an equations of the form {",
 Cell[BoxData[
  FormBox[
   RowBox[{"eigenvalue1", "==", 
    SubscriptBox["\[Epsilon]", "1"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "53cbb5b0-50af-409d-a9ec-559cb81fcf38"],
 ",",
 Cell[BoxData[
  FormBox[
   RowBox[{"eigenvalue2", "==", 
    SubscriptBox["\[Epsilon]", "2"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "a16b91cc-6297-45a5-af4f-b1377b6cc8fb"],
 "}. "
}], "Text",
 CellChangeTimes->{{3.706794384352584*^9, 3.706794411030254*^9}, {
  3.7067945929986577`*^9, 
  3.7067946882187166`*^9}},ExpressionUUID->"ab0922be-1e38-4fdf-975b-\
db330cf31d7a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"name", "[", 
   RowBox[{"matrix_", ",", "symbol_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"namedEquations", "[", "matrix", "]"}], "=", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"eigenvalues", "[", "matrix", "]"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["symbol", "1"], ",", 
       SubscriptBox["symbol", "2"]}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"name", "[", 
  RowBox[{GridBox[{
     {"1", "0"},
     {"0", "1"}
    }], ",", "\[Gamma]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7067944216061263`*^9, 3.706794439991352*^9}, {
  3.706794572061047*^9, 3.7067945798388853`*^9}, {3.706794693461512*^9, 
  3.70679475926457*^9}, {3.7067948068056364`*^9, 3.706794815035385*^9}, {
  3.706794912893526*^9, 3.7067949301011124`*^9}, {3.706795192313853*^9, 
  3.706795196441598*^9}, {3.7067961724384947`*^9, 
  3.7067961869084744`*^9}},ExpressionUUID->"64f4eb82-7e35-4ef1-867a-\
40af77c9f6ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalues", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], "\[Equal]", 
    SubscriptBox["\[Gamma]", "1"]}], ",", 
   RowBox[{
    RowBox[{"eigenvalues", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], "\[Equal]", 
    SubscriptBox["\[Gamma]", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7067947610969577`*^9, 3.7067948173466234`*^9, {3.7067949160881824`*^9, 
   3.7067949306268396`*^9}, 3.70679543725505*^9, {3.706796151356877*^9, 
   3.7067961766469717`*^9}, 3.7067962097669487`*^9, 3.706797655177347*^9, 
   3.706828798231594*^9, 3.706869135690962*^9, 3.7068732979477367`*^9, 
   3.7070426437332106`*^9, 3.708511180672684*^9, 3.709554150725685*^9, 
   3.709555804696813*^9, 3.7095581640486574`*^9, 3.711633704793762*^9, 
   3.711635172421347*^9, 3.7117949009081945`*^9, 3.7118103574653316`*^9, 
   3.7118844585417585`*^9, 3.7130841395254507`*^9, 3.713103901424199*^9, 
   3.713112978289009*^9, 3.7131197825749135`*^9, 3.7131214376137342`*^9, 
   3.713182456465151*^9, 3.713182705602112*^9, 3.7131868604443893`*^9, 
   3.7131869441624637`*^9, 3.713190370192315*^9, 3.7131916742849135`*^9, 
   3.713192468191897*^9, 3.7131929554492345`*^9, 3.713193140893699*^9, 
   3.7131932735907373`*^9, 3.7131934248844857`*^9, 3.7131987695482454`*^9, 
   3.7131993848543453`*^9, 3.713199483849909*^9, 3.7131997920144367`*^9, 
   3.713200306419494*^9, 3.713200657876127*^9, 3.713210348484189*^9, 
   3.7132122746368814`*^9, 3.7132139347747154`*^9, 
   3.7133543288223*^9},ExpressionUUID->"32a2ba22-aac0-4700-8e88-646445c600b4"]
}, Open  ]],

Cell["Now we can do the naming", "Text",
 CellChangeTimes->{{3.706794966500885*^9, 
  3.7067949697428503`*^9}},ExpressionUUID->"5bb4a008-7b31-44fd-8204-\
7636b0a63a6b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"name", "[", 
  RowBox[{"isotherm", ",", " ", "\[Theta]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"name", "[", 
   RowBox[{"f", ",", "\[Phi]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"name", "[", 
   RowBox[{"g", ",", "\[Gamma]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"name", "[", 
   RowBox[{"h", ",", " ", "\[Eta]"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.706794822174926*^9, 3.706794873299258*^9}, {
   3.706795023223256*^9, 3.706795029447122*^9}, {3.70679517218958*^9, 
   3.70679518005027*^9}, 
   3.7067952289074926`*^9},ExpressionUUID->"257308ea-080b-46fc-b935-\
08cd7592e14d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "+", 
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["c", "1"]}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], "\[Equal]", 
    SubscriptBox["\[Theta]", "1"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "+", 
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["c", "1"]}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ")"}], "2"]}]], "\[Equal]", 
    SubscriptBox["\[Theta]", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7067948755607834`*^9, {3.7067949184967732`*^9, 3.706794934261159*^9}, 
   3.706795031066487*^9, {3.706795224438772*^9, 3.7067952298442507`*^9}, {
   3.706795427842586*^9, 3.7067954372710505`*^9}, {3.706796151368126*^9, 
   3.7067961767284718`*^9}, 3.7067962097794514`*^9, 3.706797655189844*^9, 
   3.7068287982500916`*^9, 3.706869135709464*^9, 3.706873297958737*^9, 
   3.7070426437467103`*^9, 3.7085111806816807`*^9, 3.7095541507461843`*^9, 
   3.7095558047228146`*^9, 3.709558164070657*^9, 3.711633704806262*^9, 
   3.711635172434346*^9, 3.711794900919198*^9, 3.711810357477333*^9, 
   3.7118844585587587`*^9, 3.7130841395424523`*^9, 3.7131039014406977`*^9, 
   3.7131129782985077`*^9, 3.713119782585414*^9, 3.7131214376227355`*^9, 
   3.713182456495651*^9, 3.713182705654112*^9, 3.71318686046939*^9, 
   3.7131869441874638`*^9, 3.7131903702108145`*^9, 3.713191674303913*^9, 
   3.7131924682174006`*^9, 3.713192955470733*^9, 3.713193140912702*^9, 
   3.7131932736112366`*^9, 3.713193424904486*^9, 3.7131987695652456`*^9, 
   3.7131993848778467`*^9, 3.7131994838724117`*^9, 3.7131997920374336`*^9, 
   3.713200306442995*^9, 3.713200657909133*^9, 3.7132103485051894`*^9, 
   3.7132122746553817`*^9, 3.7132139347927165`*^9, 
   3.71335432884531*^9},ExpressionUUID->"82c1a51e-b318-4fc1-afc8-\
b20525038a8d"]
}, Open  ]],

Cell["\<\
And calculate the relationships by attempting to eliminate all references to \
the isotherm parameters.\
\>", "Text",
 CellChangeTimes->{{3.706795046608757*^9, 3.7067950564829283`*^9}, {
  3.7067963231576304`*^9, 3.706796325369708*^9}, {3.7068177300653067`*^9, 
  3.706817747583186*^9}},ExpressionUUID->"37c2eab0-5a54-4b18-9ee7-\
cee788ae1c47"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"findRelationship", "[", "matrix_", "]"}], ":=", 
  RowBox[{
   RowBox[{"relationship", "[", "matrix", "]"}], "=", 
   RowBox[{"Eliminate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"namedEquations", "[", "matrix", "]"}], "~", "Join", "~", 
      RowBox[{"namedEquations", "[", "isotherm", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], ",", 
       SubscriptBox["a", "2"]}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"findRelationship", "[", "f", "]"}]}], "Input",
 CellChangeTimes->{{3.7067964052958765`*^9, 3.706796507540515*^9}, {
  3.706818727245631*^9, 
  3.706818745443163*^9}},ExpressionUUID->"a76a4270-cc1c-4d21-8248-\
95d54f6cef5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
    SubscriptBox["\[Theta]", "1"]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "\[Psi]"}], "+", 
    SubscriptBox["\[Phi]", "1"]}]}], "&&", 
  RowBox[{
   RowBox[{
    SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
    SubscriptBox["\[Theta]", "2"]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "\[Psi]"}], "+", 
    SubscriptBox["\[Phi]", "2"]}]}], "&&", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Theta]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Psi]"}], "+", 
      SubscriptBox["\[Phi]", "2"]}], ")"}]}], "\[Equal]", 
   RowBox[{
    SubscriptBox["\[Theta]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Psi]"}], "+", 
      SubscriptBox["\[Phi]", "1"]}], ")"}]}]}], "&&", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["c", "1"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["c", "2"]}]}], "\[NotEqual]", "0"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuJZy1ut1ee9dgz3bZwHor2yn58C0QJ9J/+bAekFy39s
9ALSRuYOu3yANL91VdZ8IP3fYXplzsLXjk8m3NqTufi14964md1ZQLq/p2VT
NpBe0iitmrj8tWOGW/8dEP2Bf/6t9UA67/SGtO1AelpW8NTbQLqgojhWddVr
x03MG5n1gfQGKe8iYyD9RfrKETMgvWTX1snmQHqRjWB8KJBOm2JWB6IzEye0
hgPpb/HsE0C0lrSHTSSQ5pHzvg+iN2Z2OEUB6UuXCupBtP/cedNA9LbvJstB
NOsGuV0g+kudcVgskN65QnYxiN6VXrseRJ/ZznQNRB9e6C8WB6TnX7VzAtFX
OKf8TQK5c1bYu2Qg7S1xe28KkO66LuO9EkgDAIxasqs=
  "],ExpressionUUID->"6ddabef7-86b4-4626-93a3-96eb2df6fa2a"]
}, Open  ]],

Cell["\<\
We can use the Solve function to get equations of the form \[Phi] = \
F(\[Theta])\
\>", "Text",
 CellChangeTimes->{{3.7068179853632717`*^9, 
  3.706818041895792*^9}},ExpressionUUID->"a52dcc1e-9e6a-40fd-9235-\
b36b412d5de1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"relationship", "[", "f", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Phi]", "1"], ",", 
     SubscriptBox["\[Phi]", "2"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7068177719427366`*^9, 
  3.706817791888262*^9}},ExpressionUUID->"d01f532d-bd99-4025-a047-\
a8255754f61d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", "1"], "\[Rule]", 
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["\[Theta]", "1"]}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Phi]", "2"], "\[Rule]", 
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["\[Theta]", "2"]}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOLLj3wXGM577XiF5dR/MyB9J/rnRi8gPaXIcZcPkPaR
qsmaD6TbGWdU5ix87ahbdHdP5uLXjn8zZnVnAemElrZN2UB60j8Z1cTlrx3b
FvTfAdELH82/tR5I16RuStsOpOf+Dp56G0h/8C6NVV312tG+YBOzPpD+ttS7
yBhIi525csQMSD+r3jbZHEhz/RSMDwXSnlYWdSA6z2xiaziQrvTkmACiC5Z5
2EQC6ZqN3vdBdEtyp1MUkDbaUVgPojdFzp8GomMnmy4H0XYp8rtAtAWXSVgs
kD4UIrcYRJ9xqFsPol+nM18D0TWvA8XiQOZscnAC0TP/T/mbBKQFtMLfJQPp
CYtv700B0mpHZb1XAmkA1s2qVg==
  "],ExpressionUUID->"18b3189e-e795-41b4-815d-2fa13a13db1b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"findRelationship", "[", "g", "]"}]], "Input",
 CellChangeTimes->{{3.7067965231912484`*^9, 
  3.7067965258865595`*^9}},ExpressionUUID->"14e2efdc-b372-49e7-b1be-\
617bb07a0a0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Gamma]", "1"], "\[Equal]", 
   RowBox[{"1", "-", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
    RowBox[{"\[Mu]", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
     SubscriptBox["\[Theta]", "1"]}]}]}], "&&", 
  RowBox[{
   SubscriptBox["\[Gamma]", "2"], "\[Equal]", 
   RowBox[{"1", "-", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
    RowBox[{"\[Mu]", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
     SubscriptBox["\[Theta]", "2"]}]}]}], "&&", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["c", "1"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["c", "2"]}]}], "\[NotEqual]", "0"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAmJ+3su26vNeOxboqM0D0f5vXpwC0Z6HT/83A9Kx/n82
egFpB0vnXT5A2iKnLms+kJbKm1mZs/C147e9D/ZkLn7tuIxlfncWkGb52rkp
G0hf3iKnmrj8taOR3cQ7IDqvZeGt9UA6SWtL2nYgXTIvdOptIP3tdHms6qrX
juUV25j1gXSJtW+RMZAua7t2xAxIT5XfMdkcSOdtFo4PBdIVbyzrQPTaN5Na
w4F0zmfOCSD6QoKXTSSQvpXtex9E8/zscooC0vv8S+pBtKHEwmkgusjRfDmI
Pl+juAtE371gGhYLpCsLFRaDaEuNhvUgOqCC9RqIdtoWLBYHsneXkxOIPrF+
+t8kIB1hFvkuGUhfunF3bwqQ7quX914JpAG4PLGf
  "],ExpressionUUID->"8f8619f2-4fef-4f3f-9b61-16e154d25839"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"relationship", "[", "g", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], ",", 
     SubscriptBox["\[Gamma]", "2"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706817822301546*^9, 
  3.7068178297450047`*^9}},ExpressionUUID->"30bcf909-fb31-4e87-a5e6-\
bdf1a13f6026"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], "\[Rule]", 
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
      RowBox[{"\[Mu]", " ", 
       SubscriptBox["\[Theta]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
       SubscriptBox["\[Theta]", "1"]}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Gamma]", "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
      RowBox[{"\[Mu]", " ", 
       SubscriptBox["\[Theta]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
       SubscriptBox["\[Theta]", "2"]}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.706817822593062*^9, 3.7068178303691683`*^9}, 
   3.7068287983825903`*^9, 3.70686913589419*^9, 3.7068732981097383`*^9, 
   3.707042643963711*^9, 3.7085111808026905`*^9, 3.709554151048689*^9, 
   3.7095558050378184`*^9, 3.70955816434566*^9, 3.711633704973073*^9, 
   3.711635172555842*^9, 3.711794901057415*^9, 3.711810357645172*^9, 
   3.7118844586912155`*^9, 3.7130841397592745`*^9, 3.7131039017202053`*^9, 
   3.713112978421509*^9, 3.713119782713913*^9, 3.713121437761857*^9, 
   3.7131824566361494`*^9, 3.7131827058626175`*^9, 3.7131868606163907`*^9, 
   3.713186944336465*^9, 3.713190370341316*^9, 3.7131916744374146`*^9, 
   3.7131924683638973`*^9, 3.713192955662735*^9, 3.7131931410547023`*^9, 
   3.7131932737452374`*^9, 3.7131934250659857`*^9, 3.713198769698249*^9, 
   3.7131993850393467`*^9, 3.7131994840269117`*^9, 3.713199792192935*^9, 
   3.7132003066379957`*^9, 3.7132006581093693`*^9, 3.7132103487532077`*^9, 
   3.713212274808383*^9, 3.713213934950217*^9, 
   3.7133543290083203`*^9},ExpressionUUID->"0c235560-ee86-42c7-bd1f-\
b4661088bbc6"]
}, Open  ]],

Cell["\<\
Unfortunately, this straightforward approach doesn\[CloseCurlyQuote]t work \
well with the h matrix.\
\>", "Text",
 CellChangeTimes->{{3.7067972283175273`*^9, 
  3.7067972551024013`*^9}},ExpressionUUID->"a5da4552-9a11-4a70-95e0-\
14b75c83dce6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimeConstrained", "[", 
  RowBox[{
   RowBox[{"findRelationship", "[", "h", "]"}], ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.706796529300133*^9, 3.706796531810134*^9}, {
   3.7067972624169674`*^9, 3.706797284100647*^9}, {3.7067976774428368`*^9, 
   3.706797677468845*^9}, 
   3.706817034091598*^9},ExpressionUUID->"45e19b01-4555-4958-86fc-\
6591d95fef34"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{
  3.706796713195201*^9, 3.706797290181183*^9, {3.706797660292347*^9, 
   3.706797687769139*^9}, 3.706817842905588*^9, 3.706828803397678*^9, 
   3.706869140918189*^9, 3.70687330312624*^9, 3.7070426489787955`*^9, 
   3.7085111858152604`*^9, 3.7095541560805836`*^9, 3.709555810087384*^9, 
   3.7095581693817263`*^9, 3.7116337099904327`*^9, 3.711635177578182*^9, 
   3.7117949060734816`*^9, 3.711810362661383*^9, 3.7118844637036457`*^9, 
   3.713084144778409*^9, 3.7131039067438374`*^9, 3.713112983434024*^9, 
   3.7131197877274127`*^9, 3.713121442776615*^9, 3.7131824616522183`*^9, 
   3.7131827108781815`*^9, 3.7131868656319265`*^9, 3.713186949352501*^9, 
   3.7131903753563724`*^9, 3.713191679457507*^9, 3.7131924733800645`*^9, 
   3.713192960675269*^9, 3.713193146068734*^9, 3.7131932787642736`*^9, 
   3.7131934300825195`*^9, 3.713198774717279*^9, 3.7131993900578833`*^9, 
   3.7131994890444775`*^9, 3.71319979721349*^9, 3.713200311656558*^9, 
   3.713200663132164*^9, 3.713210353771078*^9, 3.71321227982895*^9, 
   3.7132139399717836`*^9, 
   3.713354334026411*^9},ExpressionUUID->"4ed28ad6-a986-4cf7-9da5-\
28ec3fbb226c"]
}, Open  ]],

Cell[TextData[{
 "For some reason Mathematica simplifies the square roots in the h equations \
differently, and the different form of the resulting equation makes the \
calculations take a ",
 StyleBox["very",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 " long time.  First, lets convince ourselves that the square root terms in \
the h equations are the same as the ones in the isotherm equations"
}], "Text",
 CellChangeTimes->{{3.7068170198727927`*^9, 
  3.706817135578766*^9}},ExpressionUUID->"1ce335cf-fb24-47fe-92ff-\
0f965d748ed2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "+", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["c", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["a", "1", "2"], " ", 
      SubsuperscriptBox["b", "2", "2"], " ", 
      SubsuperscriptBox["c", "2", "2"]}]}]], "\[Equal]", 
   SqrtBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SubscriptBox["a", "1"], " ", 
      SubscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.706817256645631*^9, 
  3.7068172577717505`*^9}},ExpressionUUID->"91f7e226-a668-46df-9e90-\
e772f6b4b0fb"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOIuhzA/w3mvHT/N9IgF0XNi8xnMgbTR3AWbvED0w+e7
fIA02xzF7PlAumuPdVXOwteOv7e1781c/NpRpcmtJwtIB0812JwNpOOWH1JN
XP7acZ6RyV0QXevqcns9kPbijkjfDqQ/HP0x9TaQvhElG6e66rXjyqBYFn0g
PWHX+yJjIB3GWHnUDEiXbY+aYg6k/Q5tiw8F0ms77tWBaJcqs7ZwIH3k1NoJ
IPrRr7c2kUD60OwP90H0tDV6zlFAOopDsgFEv2F0mQ6iN9jfWg6i87iO7gLR
dqtuhMUCaZXII4tB9IZzyhtAdKXYymsgulv/u1gckObxfuYEosUFbf4lAWmN
6X/eJQPp166N+1KA9N61h71XAmkAOYCvIA==
  "],ExpressionUUID->"fe0607e8-8b69-410c-9e49-4cad77f1b78f"]
}, Open  ]],

Cell["Next, lets replace the h-form with the isotherm-form", "Text",
 CellChangeTimes->{{3.7068171615228744`*^9, 
  3.706817173277162*^9}},ExpressionUUID->"ad3c239d-1dfb-435e-a7c5-\
5d3bfd470643"],

Cell[BoxData[
 RowBox[{
  RowBox[{"substitutedEquations", "=", 
   RowBox[{
    RowBox[{"Transpose", "@", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"namedEquations", "[", "h", "]"}], ",", 
       RowBox[{"namedEquations", "[", "isotherm", "]"}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["c", "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["a", "1", "2"], " ", 
         SubsuperscriptBox["b", "2", "2"], " ", 
         SubsuperscriptBox["c", "2", "2"]}]}]], "\[Rule]", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
     "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7068171784224815`*^9, 3.7068172063813915`*^9}, 
   3.7068172443656597`*^9, {3.7068172752954965`*^9, 3.706817370023819*^9}, {
   3.7068174396642504`*^9, 3.7068174493442993`*^9}, {3.7068176382107153`*^9, 
   3.706817641218354*^9}, 
   3.706818055877178*^9},ExpressionUUID->"f9b5754e-ed46-444a-a281-\
24e06aff528e"],

Cell[TextData[{
 "One final aid we can give Mathematica is letting it perform the elimination \
on one pair of eigenvectors at a time.  That is, we will only look for a \
relationship between ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Eta]", "1"], TraditionalForm]],ExpressionUUID->
  "37646412-6e43-4329-9a04-ffd0a0a22e40"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "1"], TraditionalForm]],ExpressionUUID->
  "5a0e2792-bfa9-42e2-9acb-610e8213696e"],
 ", then look for a relationship between ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Eta]", "2"], TraditionalForm]],ExpressionUUID->
  "86e99c5c-c971-47bd-9f2f-52d0a31e4d71"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "2"], TraditionalForm]],ExpressionUUID->
  "7e316d71-5647-4ab7-a008-7679a58cd98d"],
 " "
}], "Text",
 CellChangeTimes->{{3.7068173887601085`*^9, 3.706817431341199*^9}, {
  3.706817522275346*^9, 3.70681761670396*^9}, {3.7068180982417107`*^9, 
  3.706818106384776*^9}},ExpressionUUID->"c3ce975d-f2c3-40e9-88b3-\
df07ac86c733"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r1", " ", "=", " ", 
  RowBox[{"Eliminate", "[", 
   RowBox[{
    RowBox[{"substitutedEquations", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["a", "1"], ",", 
      SubscriptBox["a", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7068174625264325`*^9, 3.7068174872892575`*^9}, {
  3.706817648299385*^9, 3.706817649456045*^9}, {3.7068179078117714`*^9, 
  3.706817909243718*^9}},ExpressionUUID->"1d0c751c-2078-4c37-a011-\
11530c2021d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       SubscriptBox["\[Eta]", "1"]}], "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
       SubscriptBox["\[Eta]", "1"]}]}], ")"}], " ", 
    SubscriptBox["\[Theta]", "1"]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "\[Psi]"}], "+", 
    SubscriptBox["\[Eta]", "1"], "-", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
     SubscriptBox["\[Eta]", "1"]}]}]}], "&&", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["c", "1"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["c", "2"]}]}], "\[NotEqual]", "0"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuJGJ/kqw3mvHb/cf9UHoq2mr1wPoivC2xjMgfSmjXs2
eQFppTjW3T5A+s8R8+z5QPpdS2BVzsLXjhkf5u/NXAzUF57ckwWk72t4b84G
0iue3VRNXA40t9D7LoiuEIu+vR5IL1ial74dSLe955t2G0S3WMeprnrt6JBc
zaIPpNeIsBUbA+koxslHzYB03uriKeZAeuuFs/GhQPrSg691ILrpv29bOJDO
enpkAog+VspiGwkSf8r1AETzOZg6RwFp4YuKDSDaMd57Ooju7P20HERPsLyz
C0Rfz/kQFguk35y9vRhEXwm23gCiU54fvAaiOZz4xOOAtLjCfycQ7XIn+F8S
kK7/Lvw+GUj3c8zclwKyX/iO90ogDQDC1rS0
  "],ExpressionUUID->"bfaa7369-27a9-43c9-b305-8b8d5d768b75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r2", " ", "=", " ", 
  RowBox[{"Eliminate", "[", 
   RowBox[{
    RowBox[{"substitutedEquations", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["a", "1"], ",", 
      SubscriptBox["a", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.7068175008300047`*^9, {3.706817650480256*^9, 3.706817651490014*^9}, {
   3.7068179134605775`*^9, 
   3.7068179143015776`*^9}},ExpressionUUID->"771fba96-30f9-432d-ba9c-\
26fd7008b21c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       SubscriptBox["\[Eta]", "2"]}], "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
       SubscriptBox["\[Eta]", "2"]}]}], ")"}], " ", 
    SubscriptBox["\[Theta]", "2"]}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "\[Psi]"}], "+", 
    SubscriptBox["\[Eta]", "2"], "-", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
     SubscriptBox["\[Eta]", "2"]}]}]}], "&&", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["c", "1"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["c", "2"]}]}], "\[NotEqual]", "0"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuI03yPVhvNeO1o81O8H0b7HmTeAaJfFKxnMgfQxrWeb
vIB0/Ev93T5A+p59VPZ8IH2xubgqZ+Frx6xph/dmLn7t+Ohgb08WkJ55oHBz
NpB+u+KvauLy145a7Pl3QfRumbrb64H0BNmJ6duB9Mpyw2m3gbSvWW6c6qrX
jrscVrDoA+ktBzSKjYG0yrmdR82A9E6zGVPMgbS9+af4UCCtuE+iHkT/sips
CwfSKTwvJoBoC1Z120ggHWpo8ABECx20co4C0pGGmg0g2ooxcDqIPjhZdAWI
XrLr/y4QrbBAODwWSK/J/r8YRKe9jNsAorteP70Goic1GorHAWm+2crOIHra
z/J/SUDadKL5+2QgzTRtz74UIG389J/3SiANADDfsKQ=
  "],ExpressionUUID->"0a1f857d-1506-460e-902a-5715e8891445"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"relationship", "[", "h", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"r1", "&&", "r2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.706817927067545*^9, 
  3.7068179468837767`*^9}},ExpressionUUID->"429dae3f-cedf-4986-a741-\
c7041b35c3b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{
     SubscriptBox["b", "1"], " ", 
     SubscriptBox["c", "1"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], " ", 
     SubscriptBox["c", "2"]}]}], "\[NotEqual]", "0"}], "&&", 
  RowBox[{
   RowBox[{"\[Psi]", "+", 
    RowBox[{
     SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{
     SubscriptBox["\[Eta]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "1"]}]}], ")"}]}]}], "\[Equal]", "0"}], "&&", 
  RowBox[{
   RowBox[{"\[Psi]", "+", 
    RowBox[{
     SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
     SubscriptBox["\[Theta]", "2"]}], "+", 
    RowBox[{
     SubscriptBox["\[Eta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "-", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}]}], ")"}], " ", 
        SubscriptBox["\[Theta]", "2"]}]}], ")"}]}]}], "\[Equal]", 
   "0"}]}]], "Output",
 CellChangeTimes->{{3.706817940683283*^9, 3.706817947374281*^9}, 
   3.706828805378177*^9, 3.706869143286583*^9, 3.7068733055902405`*^9, 
   3.707042650880678*^9, 3.708511187675374*^9, 3.709554158251115*^9, 
   3.7095558125489163`*^9, 3.709558171669263*^9, 3.7116337120188684`*^9, 
   3.71163517951312*^9, 3.7117949080040145`*^9, 3.711810364613855*^9, 
   3.711884465615316*^9, 3.7130841475222597`*^9, 3.7131039093634033`*^9, 
   3.7131129853244076`*^9, 3.7131197898564143`*^9, 3.713121444820677*^9, 
   3.713182463628747*^9, 3.713182712838711*^9, 3.713186867607946*^9, 
   3.713186951318016*^9, 3.7131903772713842`*^9, 3.7131916815720224`*^9, 
   3.7131924748180747`*^9, 3.71319296228078*^9, 3.7131931475084457`*^9, 
   3.7131932807262883`*^9, 3.7131934320620337`*^9, 3.713198776662794*^9, 
   3.7131993920578938`*^9, 3.7131994910359936`*^9, 3.713199799251006*^9, 
   3.713200313613566*^9, 3.713200665202175*^9, 3.7132103558447237`*^9, 
   3.7132122818074756`*^9, 3.7132139419633107`*^9, 
   3.7133543360344815`*^9},ExpressionUUID->"30253b3a-6834-4ef5-b44a-\
eeeb21cb8e84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenvalueRelationship", " ", "=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"relationship", "[", "h", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Eta]", "1"], ",", 
      SubscriptBox["\[Eta]", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.706817951855282*^9, 3.706817971429969*^9}, {
  3.7118820996328535`*^9, 3.7118821262331853`*^9}, {3.711882223135239*^9, 
  3.7118822237504816`*^9}, {3.7132032081039257`*^9, 
  3.7132032177466507`*^9}},ExpressionUUID->"1f6fc38b-fd42-42ff-9b16-\
b3a93fef9a55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Eta]", "1"], "\[Rule]", 
     FractionBox[
      RowBox[{"\[Psi]", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
        SubscriptBox["\[Theta]", "1"]}]}], 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
       RowBox[{"\[Mu]", " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
        SubscriptBox["\[Theta]", "1"]}]}]]}], ",", 
    RowBox[{
     SubscriptBox["\[Eta]", "2"], "\[Rule]", 
     FractionBox[
      RowBox[{"\[Psi]", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
        SubscriptBox["\[Theta]", "2"]}]}], 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
       RowBox[{"\[Mu]", " ", 
        SubscriptBox["\[Theta]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
        SubscriptBox["\[Theta]", "2"]}]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7068179723181486`*^9, 3.706828805393177*^9, 3.7068691433180833`*^9, 
   3.7068733056002393`*^9, 3.7070426508963027`*^9, 3.7085111876833735`*^9, 
   3.7095541582776127`*^9, 3.7095558125829177`*^9, 3.7095581716977625`*^9, 
   3.7116337120288677`*^9, 3.711635179523118*^9, 3.711794908030015*^9, 
   3.7118103646638513`*^9, 3.711880957090355*^9, 3.7118810332243857`*^9, 
   3.711881211900178*^9, {3.711882101921812*^9, 3.711882126999549*^9}, 
   3.7118822249523335`*^9, 3.711884465628314*^9, 3.713084147537879*^9, 
   3.713103909383904*^9, 3.7131129853399067`*^9, 3.713119789873416*^9, 
   3.713121444840803*^9, 3.7131824636602473`*^9, 3.7131827128787065`*^9, 
   3.7131868676334467`*^9, 3.7131869513450127`*^9, 3.713190377289386*^9, 
   3.7131916815925245`*^9, 3.7131924749785757`*^9, 3.7131929624497814`*^9, 
   3.713193147668481*^9, 3.7131932807452865`*^9, 3.7131934320815334`*^9, 
   3.713198776680794*^9, 3.713199392079895*^9, 3.713199491057994*^9, 
   3.7131997992725058`*^9, 3.7132003136365676`*^9, 3.7132006652311735`*^9, 
   3.713203219003437*^9, 3.713210355855225*^9, 3.7132122818254766`*^9, 
   3.7132139419793096`*^9, 
   3.7133543360514803`*^9},ExpressionUUID->"b3e499aa-51b6-4bb9-829c-\
2b2ecad56199"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
How are the eigenvalues of the h matrix related to the eigenvalues of the \
isotherm?\
\>", "Subsubsection",
 CellChangeTimes->{{3.711883801601486*^9, 
  3.711883858389243*^9}},ExpressionUUID->"5744268e-01bf-4a93-b401-\
ccdf07523f55"],

Cell["\<\
First, let us consider the derivative of the h-matrix eigenvalues (\[Eta]) \
with respect to the isotherm-matrix eigenvalues (\[Theta]).  If we can show \
that the derivative is always positive, then we will know that an increase in \
the \[Theta] values will always result in an increase in \[Eta] values.  This \
property will be useful later, when checking for shockwaves.  First, we will \
take the derivative:\
\>", "Text",
 CellChangeTimes->{{3.7118838706873856`*^9, 3.711884011059778*^9}, {
  3.711884096949951*^9, 
  3.711884103223671*^9}},ExpressionUUID->"fefa719c-d51f-414c-92f4-\
ca2cde285932"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Eta]derivative", " ", "=", " ", 
  RowBox[{"FullSimplify", "@", 
   RowBox[{"D", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Psi]", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
        SubscriptBox["\[Theta]", "1"]}]}], 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "-", 
       RowBox[{"\[Mu]", " ", 
        SubscriptBox["\[Theta]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]", " ", 
        SubscriptBox["\[Theta]", "1"]}]}]], ",", 
     SubscriptBox["\[Theta]", "1"]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7118831324674006`*^9, 3.7118832584377065`*^9}, {
  3.711883298454359*^9, 3.71188331633033*^9}, {3.7118833495929656`*^9, 
  3.711883409475977*^9}, {3.7118835577501183`*^9, 3.71188378508782*^9}, {
  3.711883830385389*^9, 3.7118838334644146`*^9}, {3.7118839986403837`*^9, 
  3.7118840434740505`*^9}},ExpressionUUID->"04fa6ee3-88dd-4085-be15-\
fc72628c955d"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["v", "*"], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"], "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["\[Epsilon]", "p"]}]}], ")"}], " ", "\[Mu]"}]}], ")"}], 
   " ", "\[Psi]"}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
      SubscriptBox["\[Theta]", "1"]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{{3.711883156535824*^9, 3.7118832414485283`*^9}, {
   3.7118832888709617`*^9, 3.7118833171803875`*^9}, 3.711883367037801*^9, {
   3.711883401457319*^9, 3.7118834102419376`*^9}, 3.7118835592970905`*^9, 
   3.7118836881755075`*^9, {3.7118837183508496`*^9, 3.711883785732171*^9}, {
   3.71188402097114*^9, 3.7118840442455654`*^9}, 3.7118844656842513`*^9, 
   3.713084147624868*^9, 3.7131039094804063`*^9, 3.713112985388407*^9, 
   3.7131197899244137`*^9, 3.713121444889421*^9, 3.713182463714245*^9, 
   3.713182712958212*^9, 3.7131868676879525`*^9, 3.713186951396516*^9, 
   3.713190377338889*^9, 3.7131916816480217`*^9, 3.713192475026078*^9, 
   3.7131929624977813`*^9, 3.7131931477230186`*^9, 3.7131932807965145`*^9, 
   3.7131934321350346`*^9, 3.713198776731795*^9, 3.7131993921463947`*^9, 
   3.713199491111991*^9, 3.713199799324006*^9, 3.7132003136915665`*^9, 
   3.713200665313176*^9, 3.71321035591473*^9, 3.7132122818864765`*^9, 
   3.713213942035311*^9, 
   3.713354336104488*^9},ExpressionUUID->"ffc92542-522a-4fd5-9568-\
a5e737b7b567"]
}, Open  ]],

Cell[TextData[{
 "Next we will check if the derivative is less than zero, and use \
\[OpenCurlyDoubleQuote]Reduce\[CloseCurlyDoubleQuote] to solve and simplify \
the inequality.  We will also replace ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["v", "*"], " ", "and", " ", 
    SuperscriptBox["\[Epsilon]", "*"]}], TraditionalForm]],ExpressionUUID->
  "58ad5452-c2df-4a5a-b962-326a23fd1c76"],
 " with their definitions, so that we can make clearer assumptions.  Finally \
we simplify this reduced form with some straightforward assumptions about the \
range of values our variables may take."
}], "Text",
 CellChangeTimes->{{3.711884108149646*^9, 3.711884252249724*^9}, {
  3.711884311281932*^9, 
  3.7118843441817245`*^9}},ExpressionUUID->"cf22eaef-8d02-4a40-b578-\
d62092725545"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"reducedForm", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Reduce", "[", 
       RowBox[{
        RowBox[{"\[Eta]derivative", "\[LessEqual]", "0"}], ",", 
        SubscriptBox["\[Theta]", "1"]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["v", "*"], "\[Rule]", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["\[Epsilon]", "*"]}], 
         SuperscriptBox["\[Epsilon]", "*"]]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "*"], "\[Rule]", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"reducedForm", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", ">", "0"}], ",", 
      RowBox[{"1", ">", 
       SubscriptBox["\[Epsilon]", "b"], ">", "0"}], ",", 
      RowBox[{"1", ">", 
       SubscriptBox["\[Epsilon]", "p"], ">", "0"}], ",", 
      RowBox[{"\[Psi]", ">", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "b"], "|", 
         SubscriptBox["\[Epsilon]", "p"], "|", 
         SubscriptBox["\[Theta]", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.711884068560934*^9, 3.7118840792933445`*^9}, {
  3.7118841836462684`*^9, 3.7118842054810963`*^9}, {3.711884247082957*^9, 
  3.7118843059320717`*^9}},ExpressionUUID->"1791ad09-9677-4574-ae5d-\
6e0e5adf963e"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.7118841946692286`*^9, {3.711884273002948*^9, 3.711884307836162*^9}, 
   3.711884466699188*^9, 3.7130841491078987`*^9, 3.713103910847943*^9, 
   3.7131129864054337`*^9, 3.7131197910329156`*^9, 3.71312144597042*^9, 
   3.713182464755761*^9, 3.713182714006223*^9, 3.7131868687109585`*^9, 
   3.7131869524310207`*^9, 3.713190378343893*^9, 3.71319168280503*^9, 
   3.713192476041583*^9, 3.713192963500288*^9, 3.7131931487237244`*^9, 
   3.7131932817495246`*^9, 3.713193433181542*^9, 3.7131987777678022`*^9, 
   3.713199393247405*^9, 3.7131994921910143`*^9, 3.713199800403544*^9, 
   3.713200314750079*^9, 3.713200666399183*^9, 3.7132103570448093`*^9, 
   3.713212282999492*^9, 3.7132139430913253`*^9, 
   3.713354337227458*^9},ExpressionUUID->"237403cb-234d-40ac-b4dd-\
dd5c85f5f9b3"]
}, Open  ]],

Cell[TextData[{
 "Since the reduced form simplifies to false, we know that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["d", "\[Theta]"], "\[Eta]"}], ">", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e12189e3-f725-4b96-818e-28908b948a57"],
 " always."
}], "Text",
 CellChangeTimes->{{3.711884349641356*^9, 
  3.7118843937856607`*^9}},ExpressionUUID->"6b38c918-a6c8-4b84-98b9-\
42d6c9234c63"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculate the slopes of the vectors", "Subsection",
 CellChangeTimes->{{3.7119106186662583`*^9, 
  3.7119106258448544`*^9}},ExpressionUUID->"460486db-e41d-4899-862e-\
762ab23219a1"],

Cell[TextData[{
 "The slope of the eigenvectors is equivalent to ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"\[PartialD]", 
     SubscriptBox["c", "2"]}], 
    RowBox[{"\[PartialD]", 
     SubscriptBox["c", "1"]}]], TraditionalForm]],ExpressionUUID->
  "6ca1a596-a85b-4985-a5aa-5890aaa60ddb"],
 ", but it would be nice in cases where the eigenvectors approach \
{\[Infinity],1}, we could calculate ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "\[Infinity]"], TraditionalForm]],ExpressionUUID->
  "4ff0fb2e-432c-4231-bd03-f9d9a900910e"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Infinity]", "1"], TraditionalForm]],ExpressionUUID->
  "a39fbbab-542e-4560-bd48-19446f67d5e5"],
 ".  Of course when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", 
      SubscriptBox["c", "2"]}], 
     RowBox[{"\[PartialD]", 
      SubscriptBox["c", "1"]}]], "=", "\[Infinity]"}], TraditionalForm]],
  ExpressionUUID->"407f61b8-3617-4510-8b61-0f30af1162a6"],
 " we can instead say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", 
      SubscriptBox["c", "1"]}], 
     RowBox[{"\[PartialD]", 
      SubscriptBox["c", "2"]}]], "=", 
    FractionBox["1", "\[Infinity]"]}], TraditionalForm]],ExpressionUUID->
  "94ae70dc-006d-4b53-921b-23f470dca2fc"]
}], "Text",
 CellChangeTimes->{{3.7067167635489397`*^9, 3.7067169453154006`*^9}, {
  3.7068236436585073`*^9, 
  3.7068236565562644`*^9}},ExpressionUUID->"ee82a2f6-91a2-4804-aa0e-\
65b6e735e4f7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"slope", "[", 
   RowBox[{"{", 
    RowBox[{"v1_", ",", "v2_"}], "}"}], "]"}], ":=", 
  RowBox[{"v2", "/", "v1"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["c", "2"], "'"}], "[", 
   SubscriptBox["c", "1"], "]"}], "\[Equal]", 
  RowBox[{"slope", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7068197538415174`*^9, 3.7068198015374837`*^9}, {
  3.706819859360956*^9, 3.7068198624938383`*^9}, {3.7068199218808413`*^9, 
  3.7068199463441687`*^9}, {3.7068199850004783`*^9, 3.706819985318046*^9}, {
  3.7068233616836777`*^9, 3.7068233641647673`*^9}, {3.706823684632197*^9, 
  3.706823686017906*^9}, {3.7119109634699125`*^9, 
  3.7119109709076724`*^9}},ExpressionUUID->"77327ac2-5166-4e9a-b8f7-\
178e9253cb51"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    SubscriptBox["c", "2"], "\[Prime]",
    MultilineFunction->None], "[", 
   SubscriptBox["c", "1"], "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.706819802198038*^9, {3.7068199251450605`*^9, 3.7068199470723553`*^9}, 
   3.7068200062616987`*^9, 3.7068233727720475`*^9, 3.706828806554679*^9, 
   3.7068691447550845`*^9, 3.7068733071477375`*^9, 3.7070426520528107`*^9, 
   3.708511188780895*^9, 3.7095542086652393`*^9, 3.709555870351433*^9, 
   3.7095582248416815`*^9, 3.711633760747467*^9, 3.711635226345024*^9, 
   3.71179490921453*^9, 3.7118103748851814`*^9, 3.711884477509082*^9, {
   3.7119109671386943`*^9, 3.7119109713807735`*^9}, 3.7130841492218995`*^9, 
   3.7131039109484463`*^9, 3.7131129864539323`*^9, 3.7131197910754147`*^9, 
   3.7131214460184193`*^9, 3.713182464790262*^9, 3.71318271408018*^9, 
   3.713186868782455*^9, 3.7131869525080214`*^9, 3.713190378387394*^9, 
   3.713191682855034*^9, 3.713192476089087*^9, 3.7131929635462894`*^9, 
   3.713193148763871*^9, 3.7131932817880235`*^9, 3.7131934332235413`*^9, 
   3.7131987778113017`*^9, 3.713199393298903*^9, 3.713199492241017*^9, 
   3.7131998004540443`*^9, 3.7132003148020763`*^9, 3.713200666452685*^9, 
   3.7132103571408157`*^9, 3.713212283049493*^9, 3.713213943139326*^9, 
   3.713354337273465*^9},ExpressionUUID->"76afab34-2600-4671-8f65-\
9b7014b0997f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"inverseSlope", "[", 
   RowBox[{"{", 
    RowBox[{"v1_", ",", "v2_"}], "}"}], "]"}], ":=", 
  RowBox[{"v1", "/", "v2"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["c", "1"], "'"}], "[", 
   SubscriptBox["c", "2"], "]"}], "\[Equal]", 
  RowBox[{"inverseSlope", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7068199515428295`*^9, 3.7068200024635906`*^9}, {
  3.7068233687092752`*^9, 3.7068233706250105`*^9}, {3.7068236885882673`*^9, 
  3.706823689944042*^9}, {3.7119109793120027`*^9, 
  3.711910986357953*^9}},ExpressionUUID->"01dcd7f1-81e5-4ecc-b862-\
f68c4893f579"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    SubscriptBox["c", "1"], "\[Prime]",
    MultilineFunction->None], "[", 
   SubscriptBox["c", "2"], "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.706820003435935*^9, 3.706823371034015*^9, 3.7068288065711803`*^9, 
   3.7068691447645855`*^9, 3.7068733071577373`*^9, 3.7070426520528107`*^9, 
   3.708511188789895*^9, 3.709554208689237*^9, 3.7095558703814383`*^9, 
   3.709558224878682*^9, 3.7116337607574663`*^9, 3.711635226357024*^9, 
   3.7117949092225304`*^9, 3.7118103748941827`*^9, 3.711884477535081*^9, {
   3.7119109822879496`*^9, 3.7119109868106055`*^9}, 3.713084149240897*^9, 
   3.713103910970446*^9, 3.7131129864609327`*^9, 3.713119791083415*^9, 
   3.7131214460254197`*^9, 3.7131824648057594`*^9, 3.713182714116681*^9, 
   3.7131868688069563`*^9, 3.7131869525375223`*^9, 3.7131903784053936`*^9, 
   3.7131916828750315`*^9, 3.713192476107087*^9, 3.713192963567788*^9, 
   3.713193148782127*^9, 3.713193281807026*^9, 3.7131934332425413`*^9, 
   3.7131987778283024`*^9, 3.7131993933199043`*^9, 3.7131994922630177`*^9, 
   3.7131998004745455`*^9, 3.713200314823576*^9, 3.7132006664801817`*^9, 
   3.713210357198323*^9, 3.7132122830664926`*^9, 3.7132139431543264`*^9, 
   3.713354337285014*^9},ExpressionUUID->"0ec93cc2-ca01-440f-abe5-\
aa38db243ae2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Prove that the eigenvectors define a linear vector field", "Subsection",
 CellChangeTimes->{{3.7068229795559554`*^9, 
  3.7068230052596893`*^9}},ExpressionUUID->"6afe0d6b-3e26-48f8-9753-\
f177842c47a2"],

Cell["\<\
The Langmuir isotherm has the fortunate property that the stream lines in the \
vector field defined by the eigenvectors are straight lines!  This makes it \
possible to do certain analyses analytically.  Here we will prove that they \
are linear. \
\>", "Text",
 CellChangeTimes->{{3.706823008435771*^9, 3.7068231076634555`*^9}, {
  3.7068231476473737`*^9, 
  3.706823148855874*^9}},ExpressionUUID->"828c04a0-8b9e-4d92-9e5e-\
353a10c194f5"],

Cell["\<\
To do this we start from the fact that we know the first derivative of the \
stream curves\
\>", "Text",
 CellChangeTimes->{{3.7068231513376803`*^9, 
  3.706823212971895*^9}},ExpressionUUID->"b8889d31-b223-4cba-a272-\
c7139bb44fbf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"firstD", "=", 
  RowBox[{"slope", "[", 
   RowBox[{
    RowBox[{"eigenvectors", "[", "f", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.706823120156397*^9, 3.706823136548184*^9}, 
   3.706823385055122*^9, {3.706823697494235*^9, 
   3.7068237053765078`*^9}},ExpressionUUID->"60053013-bf5c-4e3d-b3da-\
613207cce74f"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["a", "2"], " ", 
    SubscriptBox["b", "1"], " ", 
    SubscriptBox["c", "2"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["c", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "1", "2"], " ", 
       SubsuperscriptBox["b", "2", "2"], " ", 
       SubsuperscriptBox["c", "2", "2"]}]}]]}]]}]], "Output",
 CellChangeTimes->{
  3.7068231374623213`*^9, {3.706823377087902*^9, 3.7068233856152515`*^9}, 
   3.70682370626264*^9, 3.7068288066006775`*^9, 3.7068691447765846`*^9, 
   3.7068733071707373`*^9, 3.7070426520684395`*^9, 3.708511188797894*^9, 
   3.7095542087277393`*^9, 3.709555870419304*^9, 3.709558224996168*^9, 
   3.7116337607709665`*^9, 3.7116352263685217`*^9, 3.7117949092325306`*^9, 
   3.7118103749071803`*^9, 3.7118844775620823`*^9, 3.7130841492689*^9, 
   3.713103910995948*^9, 3.7131129864704323`*^9, 3.7131197910929136`*^9, 
   3.713121446033419*^9, 3.7131824648227587`*^9, 3.713182714160181*^9, 
   3.713186868835955*^9, 3.7131869525665226`*^9, 3.7131903784233923`*^9, 
   3.7131916828955345`*^9, 3.7131924761260843`*^9, 3.7131929635887885`*^9, 
   3.713193148801633*^9, 3.713193281826024*^9, 3.7131934332615414`*^9, 
   3.7131987778468018`*^9, 3.713199393342903*^9, 3.7131994922855177`*^9, 
   3.713199800499544*^9, 3.713200314845075*^9, 3.713200666508184*^9, 
   3.7132103572238216`*^9, 3.7132122830829935`*^9, 3.713213943169826*^9, 
   3.713354337296014*^9},ExpressionUUID->"ca6eb648-2f63-4337-8170-\
79a91d4f7623"]
}, Open  ]],

Cell[TextData[{
 "If the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], "[", 
    SubscriptBox["c", "2"], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "b7ad42bf-da39-4664-bc7e-ffa37db58272"],
 " curve is linear, then the second derivative will be zero.  Lets calculate \
the second derivative!"
}], "Text",
 CellChangeTimes->{{3.706823228437781*^9, 3.706823266341687*^9}, 
   3.70682333862994*^9},ExpressionUUID->"b41757ac-277b-4913-bb7e-\
676a0020f915"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondD", "=", 
  RowBox[{"Simplify", "@", 
   RowBox[{"D", "[", 
    RowBox[{"firstD", ",", 
     SubscriptBox["c", "1"], ",", 
     RowBox[{"NonConstants", "\[Rule]", 
      SubscriptBox["c", "2"]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7068233166443434`*^9, 3.706823335380273*^9}, {
  3.70682339190028*^9, 3.706823460156618*^9}, {3.706823617794181*^9, 
  3.706823621889987*^9}, {3.7068237153427844`*^9, 
  3.706823718644353*^9}},ExpressionUUID->"efff9b38-3a5c-478f-947e-\
1f7c6109ffec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SubscriptBox["a", "2"], " ", 
    SubscriptBox["b", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"D", "[", 
         RowBox[{
          SubscriptBox["c", "2"], ",", 
          SubscriptBox["c", "1"], ",", 
          RowBox[{"NonConstants", "\[Rule]", 
           RowBox[{"{", 
            SubscriptBox["c", "2"], "}"}]}]}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "2"]}], " ", 
          SubscriptBox["b", "1"]}], "+", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            SubscriptBox["c", "2"], ",", 
            SubscriptBox["c", "1"], ",", 
            RowBox[{"NonConstants", "\[Rule]", 
             RowBox[{"{", 
              SubscriptBox["c", "2"], "}"}]}]}], "]"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{
            SubsuperscriptBox["a", "2", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              SubscriptBox["c", "2"], ",", 
              SubscriptBox["c", "1"], ",", 
              RowBox[{"NonConstants", "\[Rule]", 
               RowBox[{"{", 
                SubscriptBox["c", "2"], "}"}]}]}], "]"}], " ", 
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"D", "[", 
                 RowBox[{
                  SubscriptBox["c", "2"], ",", 
                  SubscriptBox["c", "1"], ",", 
                  RowBox[{"NonConstants", "\[Rule]", 
                   RowBox[{"{", 
                    SubscriptBox["c", "2"], "}"}]}]}], "]"}]}], " ", 
               SubscriptBox["b", "2"]}], "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  RowBox[{"D", "[", 
                   RowBox[{
                    SubscriptBox["c", "2"], ",", 
                    SubscriptBox["c", "1"], ",", 
                    RowBox[{"NonConstants", "\[Rule]", 
                    RowBox[{"{", 
                    SubscriptBox["c", "2"], "}"}]}]}], "]"}], " ", 
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}]}], 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]]}], ")"}]}]}], ")"}]}], 
   ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "+", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["c", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["a", "1", "2"], " ", 
        SubsuperscriptBox["b", "2", "2"], " ", 
        SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.706823282156852*^9, {3.706823418968939*^9, 3.7068234672335563`*^9}, 
   3.706823623445629*^9, 3.7068237194195814`*^9, 3.706828807506678*^9, 
   3.7068691458350844`*^9, 3.706873308197344*^9, 3.707042652897539*^9, 
   3.708511189620412*^9, 3.709554209752364*^9, 3.7095558715868287`*^9, 
   3.7095582261361833`*^9, 3.711633761774434*^9, 3.711635227293995*^9, 
   3.7117949101389713`*^9, 3.7118103757811365`*^9, 3.7118844784878387`*^9, 
   3.7130841505489244`*^9, 3.7131039121434765`*^9, 3.7131129873124323`*^9, 
   3.7131197920289125`*^9, 3.71312144689493*^9, 3.713182465668769*^9, 
   3.7131827150121956`*^9, 3.713186869697463*^9, 3.71318695342553*^9, 
   3.7131903792623982`*^9, 3.713191683786041*^9, 3.7131924764215865`*^9, 
   3.713192963860791*^9, 3.7131931490723133`*^9, 3.7131932827585297`*^9, 
   3.713193434115548*^9, 3.7131987786998076`*^9, 3.713199394279935*^9, 
   3.7131994932055216`*^9, 3.7131998014040704`*^9, 3.713200315751086*^9, 
   3.7132006674446907`*^9, 3.7132103581453867`*^9, 3.7132122840000052`*^9, 
   3.7132139440803385`*^9, 
   3.7133543381687593`*^9},ExpressionUUID->"d1f5ab5d-b610-4b57-ba51-\
ac01edeb1a05"]
}, Open  ]],

Cell[TextData[{
 "Now we already know what the first derivative is, so we can substitute it \
in wherever we find it.  In this case, we\[CloseCurlyQuote]re looking to \
replace ",
 Cell[BoxData[
  FormBox[
   RowBox[{"D", "[", 
    RowBox[{
     SubscriptBox["c", "2"], ",", 
     SubscriptBox["c", "1"], ",", " ", 
     RowBox[{"NonConstants", "\[Rule]", 
      RowBox[{"{", 
       SubscriptBox["c", "2"], "}"}]}]}], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "5dff270c-9fa4-4889-adfe-a4620e81e88e"],
 " with firstD"
}], "Text",
 CellChangeTimes->{{3.7068234788919287`*^9, 3.706823493558076*^9}, {
  3.7068237675478997`*^9, 3.706823818852296*^9}, {3.70682467357551*^9, 
  3.7068246755011797`*^9}},ExpressionUUID->"18166f69-6fe5-4afa-b3ba-\
8cd6f71359ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"secondD", "/.", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      SubscriptBox["c", "2"], ",", 
      SubscriptBox["c", "1"], ",", 
      RowBox[{"NonConstants", "\[Rule]", 
       RowBox[{"{", 
        SubscriptBox["c", "2"], "}"}]}]}], "]"}], "\[Rule]", "firstD"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7068235030904336`*^9, 3.7068235756658993`*^9}, {
  3.7068236281003747`*^9, 3.7068236331280236`*^9}, {3.706823725058544*^9, 
  3.7068237520744815`*^9}},ExpressionUUID->"cfd14147-f468-4af7-abae-\
9cc75694f486"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.706823524288747*^9, 3.706823531084118*^9}, 
   3.706823577200262*^9, 3.706823636137227*^9, {3.7068237301655455`*^9, 
   3.7068237526100664`*^9}, 3.706828807585679*^9, 3.706869145935584*^9, 
   3.7068733082763405`*^9, 3.7070426529378476`*^9, 3.708511189643626*^9, 
   3.7095542098258657`*^9, 3.7095558717789993`*^9, 3.7095582262316837`*^9, 
   3.711633761849434*^9, 3.711635227375991*^9, 3.711794910171893*^9, 
   3.7118103758306856`*^9, 3.7118844785538397`*^9, 3.7130841506539288`*^9, 
   3.7131039122594805`*^9, 3.713112987330432*^9, 3.713119792048915*^9, 
   3.7131214469149303`*^9, 3.7131824656917706`*^9, 3.7131827150956936`*^9, 
   3.7131868697229614`*^9, 3.713186953451027*^9, 3.713190379289399*^9, 
   3.7131916838185387`*^9, 3.713192476458606*^9, 3.713192963895793*^9, 
   3.713193149115815*^9, 3.713193282789529*^9, 3.7131934341680503`*^9, 
   3.7131987787308087`*^9, 3.713199394331936*^9, 3.7131994932555227`*^9, 
   3.713199801428068*^9, 3.7132003157755814`*^9, 3.7132006674991903`*^9, 
   3.713210358224393*^9, 3.7132122840330057`*^9, 3.713213944115839*^9, 
   3.713354338193763*^9},ExpressionUUID->"e58cc4ff-59b9-455d-a27f-\
6609d54e513b"]
}, Open  ]],

Cell[TextData[{
 "We can of course repeat this analysis for the second eigenvector as well, \
but we have to remember to use the inverse slope and take the derivatives \
with respect to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],ExpressionUUID->
  "8de37b0b-3ced-460b-b90a-4fdffb35f581"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]],ExpressionUUID->
  "18a7132f-ffa9-4134-9f20-fbc739d3a851"]
}], "Text",
 CellChangeTimes->{{3.7068238452961807`*^9, 3.706823858291944*^9}, {
  3.7068239584099092`*^9, 3.7068239915502443`*^9}, {3.706824686502234*^9, 
  3.706824688979355*^9}},ExpressionUUID->"b5d33196-460e-43a3-b723-\
53e3aa859de6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"inverseSlope", "[", 
   RowBox[{
    RowBox[{"eigenvectors", "[", "f", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "@", 
   RowBox[{"D", "[", 
    RowBox[{"%", ",", 
     SubscriptBox["c", "2"], ",", 
     RowBox[{"NonConstants", "\[Rule]", 
      SubscriptBox["c", "1"]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      SubscriptBox["c", "1"], ",", 
      SubscriptBox["c", "2"], ",", 
      RowBox[{"NonConstants", "\[Rule]", 
       RowBox[{"{", 
        SubscriptBox["c", "1"], "}"}]}]}], "]"}], "\[Rule]", "%%"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.706823871723817*^9, 3.706823878294418*^9}, {
  3.706823915787055*^9, 
  3.706823956866205*^9}},ExpressionUUID->"979d7df4-0a9a-4331-862d-\
26527dfb092f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuLyHQ9mmMx77bh7MsciEB1q8GgFiM64wsxoDqTTPAI3
ewHpA3Pm7PYB0kf61mXPB9KP9h6pyln42pFZzfdI5uLXjh88+KdkAekLD6J3
ZQPpvPU+OonLXzsKJNQ+BtElXddurwfSPot5MrcD6SVaj6ffBtLTbryKU131
2tHyvjyrPpC28K4uNgbSB9JFj5kB6Qt976aYA2mdy24JoUB6ilBpPYgOkTjV
Fg6kC9gcJ4LoXa8qbSNB+n/1PADR98MmOUcBaa/ahgYQ7ZG5fDqI/lOUswJE
37UN2w2ig35khMcC6dNzY5eA6G/zd20A0e6fHK6D+Vt6xOOA9K2eJmcQ3Rx+
818SkF6VM/V9MshdguL7U4D0vY5wn5VAGgCLP7Wp
  "],ExpressionUUID->"22c9962b-da7e-498a-ab41-6ab4ed53960e"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 4: Solving the Riemann Problem", "Section",
 CellChangeTimes->{{3.7085131824977126`*^9, 
  3.7085131927738333`*^9}},ExpressionUUID->"148d8a72-9aa6-4ce0-ab7e-\
87dd4ee25032"],

Cell["\<\
We now have a great deal of information about the system of equations we\
\[CloseCurlyQuote]re solving, but we don\[CloseCurlyQuote]t yet know how to \
use that information to solve the problem.\
\>", "Text",
 CellChangeTimes->{{3.708513204826021*^9, 
  3.7085132832682667`*^9}},ExpressionUUID->"68a1ae69-d67b-4b2c-b6bc-\
c80dcd7dfaa2"],

Cell[TextData[{
 "It turns out that transitions in this system will proceed along the \
eigenvectors in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], ",", 
    SubscriptBox["c", "2"]}], TraditionalForm]],ExpressionUUID->
  "276f23a1-c17c-4840-86fe-906c52e54882"],
 " plane.  But there are two eigenvectors at the initial condition, and two \
at the final condition.  That means there are four places where the vectors \
intersect, and many possible paths from the initial to final state.  How can \
we determine which paths are possible? \nThe tool we have at our disposal is \
the direction of the eigenvectors: only paths which follow the eigenvector \
directions along the entire length can be achieved."
}], "Text",
 CellChangeTimes->{{3.708513288462144*^9, 3.708513492524292*^9}, {
  3.7085135270265465`*^9, 3.7085135439766083`*^9}, {3.7085136715804863`*^9, 
  3.708513699218684*^9}, {3.708513779162105*^9, 
  3.7085137919009495`*^9}},ExpressionUUID->"6e8f6cab-fa93-45e3-a451-\
43537ab7041f"],

Cell[CellGroupData[{

Cell["Consider the behavior of the eigenvectors at the origin", "Subsection",
 CellChangeTimes->{{3.7067158679645863`*^9, 
  3.7067158826185403`*^9}},ExpressionUUID->"b6304fa1-2305-4c90-a2a7-\
ab01f9c666dc"],

Cell[CellGroupData[{

Cell["Use limits to calculate the vectors at the origin", "Subsubsection",
 CellChangeTimes->{{3.711911029922102*^9, 
  3.711911042845354*^9}},ExpressionUUID->"990acbf6-15ab-446d-8e44-\
f2df21d71527"],

Cell[TextData[{
 "At the origin, it is common for the normalized eigenvectors to approach {0, \
1} and {1, 0}.  However, they occasionally do this by approaching \
{\[Infinity],1}, so there are divide-by-zero and infinity issues with the \
equations.  These can be worked around somewhat. The problem with the \
workaround is that it depends on whether or not ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ">", 
    SubscriptBox["a", "2"]}], TraditionalForm]],ExpressionUUID->
  "dc7818a9-91fd-4d78-b1d6-fdbd083e9934"],
 " or not."
}], "Text",
 CellChangeTimes->{{3.7067158883963995`*^9, 3.7067159749818535`*^9}, {
  3.706716034316533*^9, 3.7067161106965327`*^9}, {3.706819454597783*^9, 
  3.7068194551736345`*^9}, {3.706819579445668*^9, 
  3.7068196073535357`*^9}},ExpressionUUID->"5c4d0683-ed81-4bcd-bccd-\
381cde0e704d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"originVectors", "=", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{"eigenvectors", "[", "f", "]"}], ",", 
    RowBox[{
     SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "1"], ">", 
        SubscriptBox["a", "2"]}], ",", 
       RowBox[{
        SubscriptBox["a", "1"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["a", "2"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Equal]", "0"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7068182934564133`*^9, 3.7068184203864737`*^9}, {
   3.706818456863531*^9, 3.7068184632015696`*^9}, {3.706818532370002*^9, 
   3.7068185359736853`*^9}, {3.706818784242081*^9, 3.7068188387491083`*^9}, {
   3.706818875817554*^9, 3.7068188843111115`*^9}, {3.7068189269553623`*^9, 
   3.706818941237363*^9}, {3.7068189750512977`*^9, 3.706819019392021*^9}, {
   3.7068190514038687`*^9, 3.7068190852570295`*^9}, {3.7068191264580607`*^9, 
   3.7068191475637197`*^9}, {3.7068191833958206`*^9, 3.706819304462179*^9}, {
   3.706819347441681*^9, 3.7068193646132965`*^9}, {3.706819425347041*^9, 
   3.706819469825272*^9}, {3.706819501256138*^9, 3.706819566015872*^9}, {
   3.7068196384806337`*^9, 3.706819642927528*^9}, {3.7068197359741993`*^9, 
   3.706819745115991*^9}, {3.708515274900833*^9, 3.7085152852104683`*^9}, 
   3.7085156719692955`*^9},ExpressionUUID->"3045945b-2f49-4328-86aa-\
c864df92dcc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"-", "\[Infinity]"}], 
      SubscriptBox["b", "1"]], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7068192499395075`*^9, 3.7068193054670334`*^9}, {
   3.706819347582275*^9, 3.706819365149553*^9}, {3.706819434146343*^9, 
   3.7068194706205835`*^9}, 3.706819515949494*^9, {3.706819549452591*^9, 
   3.706819567361538*^9}, 3.706819651707801*^9, 3.706819746069005*^9, 
   3.7068288059596777`*^9, 3.7068691440345864`*^9, 3.7068733063267384`*^9, 
   3.707042651465892*^9, 3.7085111882203846`*^9, {3.708515276201855*^9, 
   3.708515285472003*^9}, 3.7085156726016808`*^9, 3.709554158912621*^9, 
   3.709555813338927*^9, 3.709558172394272*^9, 3.711633712595851*^9, 
   3.7116351800761027`*^9, 3.7117949086000223`*^9, 3.7118103652015543`*^9, 
   3.7118844673444242`*^9, 3.713084152175956*^9, 3.7131039138205204`*^9, 
   3.713112988502841*^9, 3.7131197933559136`*^9, 3.7131214481481357`*^9, 
   3.713182466869286*^9, 3.7131827162730417`*^9, 3.71318687095197*^9, 
   3.7131869546545377`*^9, 3.7131903804499073`*^9, 3.713191685036048*^9, 
   3.71319247715061*^9, 3.7131929645677953`*^9, 3.7131931499284286`*^9, 
   3.713193283998537*^9, 3.7131934353315563`*^9, 3.7131987799243145`*^9, 
   3.7131993956260166`*^9, 3.7131994944365325`*^9, 3.7131998026345787`*^9, 
   3.713200317069091*^9, 3.7132006687711997`*^9, 3.7132103594769816`*^9, 
   3.713212285378524*^9, 3.7132139453978558`*^9, 
   3.713354339415429*^9},ExpressionUUID->"b615a96b-2a5c-4cd5-ad6f-\
01df6fa169ad"]
}, Open  ]],

Cell[TextData[{
 "if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "<", 
    SubscriptBox["a", "2"]}], TraditionalForm]],ExpressionUUID->
  "db498dbe-ebf8-4259-9741-8fdfce5e249d"]
}], "Text",
 CellChangeTimes->{{3.706824885342865*^9, 
  3.706824892175603*^9}},ExpressionUUID->"362004c2-c211-4b74-ae73-\
84066d47b191"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"eigenvectors", "[", "f", "]"}], ",", 
   RowBox[{
    SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], "\[Equal]", "0"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706819617981431*^9, 3.7068196671883535`*^9}, 
   3.7085152943569174`*^9, 
   3.708515663265788*^9},ExpressionUUID->"2628d335-6941-411c-9ebd-\
783a2cc23340"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Infinity]", 
      SubscriptBox["b", "1"]], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.706819619295698*^9, 3.7068196680540795`*^9}, 
   3.7068288064906797`*^9, 3.7068691446815853`*^9, 3.7068733070512385`*^9, 
   3.707042651997932*^9, 3.7085111887248907`*^9, 3.708515295166106*^9, 
   3.7085156641440773`*^9, 3.7095541595436296`*^9, 3.7095558141049366`*^9, 
   3.709558173066781*^9, 3.7116337131553326`*^9, 3.7116351806230855`*^9, {
   3.7116378028507185`*^9, 3.7116378288904667`*^9}, {3.7116378784988055`*^9, 
   3.711637908124406*^9}, 3.7116379496752844`*^9, 3.71179490916003*^9, 
   3.711810365747589*^9, 3.711884467901428*^9, 3.7130841529679704`*^9, 
   3.7131039146310406`*^9, 3.713112989056841*^9, 3.713119793995914*^9, 
   3.7131214487341375`*^9, 3.713182467423793*^9, 3.713182716915266*^9, 
   3.7131868715849743`*^9, 3.71318695528104*^9, 3.713190381005412*^9, 
   3.713191685691052*^9, 3.713192477731115*^9, 3.7131929651408834`*^9, 
   3.7131931504762216`*^9, 3.713193284631542*^9, 3.7131934358885612`*^9, 
   3.7131987804898176`*^9, 3.713199396285021*^9, 3.7131994950885344`*^9, 
   3.713199803277584*^9, 3.713200317713114*^9, 3.7132006694762044`*^9, 
   3.713210360157029*^9, 3.7132122860535326`*^9, 3.713213946064419*^9, 
   3.7133543399804983`*^9},ExpressionUUID->"06c33caa-e0b9-4e1a-809a-\
422e9d17c163"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use limits to calculate the direction of the vectors at the origin\
\>", "Subsubsection",
 CellChangeTimes->{{3.711911052489887*^9, 
  3.711911074267638*^9}},ExpressionUUID->"85aca3a0-61ab-4add-8cc0-\
e2075abae5d6"],

Cell[TextData[{
 "We can also consider the eigenvector ",
 StyleBox["direction",
  FontSlant->"Italic"],
 " at the origin.  From this point on, we will restrict ourselves to the case \
where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "<", 
    SubscriptBox["a", "2"]}], TraditionalForm]],ExpressionUUID->
  "e9962ba8-e6ce-4378-9f21-fe21dbfbe1f2"]
}], "Text",
 CellChangeTimes->{{3.7118026820372896`*^9, 
  3.711802780624932*^9}},ExpressionUUID->"ab839c3b-d2c7-4514-9b45-\
908396a1420c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generalVectorDirections", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Normalize", "/@", 
     RowBox[{"eigenvectors", "[", "f", "]"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "1"], "<", 
        SubscriptBox["a", "2"]}], ",", 
       RowBox[{
        SubscriptBox["a", "1"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["a", "2"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[GreaterEqual]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[GreaterEqual]", "0"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.711802852081673*^9, 3.7118028739538236`*^9}, {
  3.7118029521520243`*^9, 3.7118030175327835`*^9}, {3.711907938124662*^9, 
  3.7119079403336763`*^9}},ExpressionUUID->"1f76264d-e392-4722-a365-\
0c021f101b3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "1"]}], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["c", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"], " ", 
          SubsuperscriptBox["c", "2", "2"]}]}]]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"4", "+", 
         SuperscriptBox[
          RowBox[{"Abs", "[", 
           FractionBox[
            RowBox[{
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "-", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["b", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "+", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["a", "1", "2"], " ", 
                SubsuperscriptBox["b", "2", "2"], " ", 
                SubsuperscriptBox["c", "2", "2"]}]}]]}], 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "2"]}]], "]"}], "2"]}]], " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["c", "2"]}]], ",", 
     FractionBox["2", 
      SqrtBox[
       RowBox[{"4", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["b", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["c", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"], " ", 
               SubsuperscriptBox["c", "2", "2"]}]}]]}], 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "2"]}]], "]"}], "2"]}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "1"]}], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["c", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"], " ", 
          SubsuperscriptBox["c", "2", "2"]}]}]]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"4", "+", 
         SuperscriptBox[
          RowBox[{"Abs", "[", 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["a", "2"]}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "-", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["b", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "+", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["a", "1", "2"], " ", 
                SubsuperscriptBox["b", "2", "2"], " ", 
                SubsuperscriptBox["c", "2", "2"]}]}]]}], 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "2"]}]], "]"}], "2"]}]], " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["c", "2"]}]], ",", 
     FractionBox["2", 
      SqrtBox[
       RowBox[{"4", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "2"]}], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["b", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["c", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"], " ", 
               SubsuperscriptBox["c", "2", "2"]}]}]]}], 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "2"]}]], "]"}], "2"]}]]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.711802949116004*^9, 3.711802984698248*^9}, {
   3.711803015444768*^9, 3.7118030190922947`*^9}, 3.711810366597714*^9, 
   3.7118844687610197`*^9, 3.7119079431456957`*^9, 3.711908153391721*^9, 
   3.7130841541569934`*^9, 3.7131039156690674`*^9, 3.7131129899058475`*^9, 
   3.713119794864414*^9, 3.713121449584135*^9, 3.713182468269306*^9, 
   3.7131827177247763`*^9, 3.7131868724289813`*^9, 3.7131869560945454`*^9, 
   3.7131903818334165`*^9, 3.7131916865615573`*^9, 3.713192477929113*^9, 
   3.713192965344884*^9, 3.7131931506644635`*^9, 3.713193285487048*^9, 
   3.713193436724067*^9, 3.7131987813678284`*^9, 3.7131993971445265`*^9, 
   3.7131994959400425`*^9, 3.7131998041150894`*^9, 3.713200318566614*^9, 
   3.7132006703377094`*^9, 3.71321036101359*^9, 3.713212286932044*^9, 
   3.7132139469269295`*^9, 
   3.713354340881635*^9},ExpressionUUID->"1dd1c605-3aa6-4433-88c1-\
838f4bfca764"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"originVectorDirections", "=", 
  RowBox[{"Limit", "[", 
   RowBox[{"generalVectorDirections", ",", 
    RowBox[{
     SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "1"], "<", 
        SubscriptBox["a", "2"]}], ",", 
       RowBox[{
        SubscriptBox["a", "1"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["a", "2"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Equal]", "0"}], ",", 
       RowBox[{
        SubscriptBox["b", "1"], "\[Element]", "Reals"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.7118030252851343`*^9, 
  3.7119081447626615`*^9},ExpressionUUID->"92feb9f0-44d9-4802-8cce-\
6184630f308e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Abs", "[", 
       SubscriptBox["b", "1"], "]"}], 
      SubscriptBox["b", "1"]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7118027443892303`*^9, 3.711803037267714*^9, 3.71181037479261*^9, 
   3.711884477413453*^9, {3.711908134750079*^9, 3.7119081535927243`*^9}, 
   3.7130841664225287`*^9, 3.713103926418357*^9, 3.7131129983343487`*^9, 
   3.713119804112415*^9, 3.7131214584987965`*^9, 3.713182476675414*^9, 
   3.7131827262999506`*^9, 3.713186880857052*^9, 3.7131869645416813`*^9, 
   3.7131903901679935`*^9, 3.7131916952916374`*^9, 3.713192830090023*^9, 
   3.7131931543046217`*^9, 3.71319329458263*^9, 3.713193445189624*^9, 
   3.7131987899108458`*^9, 3.713199403983105*^9, 3.713199505033617*^9, 
   3.713199813129776*^9, 3.7132003276337743`*^9, 3.713200679449773*^9, 
   3.713210370095326*^9, 3.713212296262167*^9, 3.7132139560783195`*^9, 
   3.713354349396972*^9},ExpressionUUID->"fbd02054-9201-4e22-a164-\
5482281e4632"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Calculate the vector directions when ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "19343cf5-019c-4a4a-a3e8-d11e31fe35aa"],
 " is zero"
}], "Subsubsection",
 CellChangeTimes->{{3.7119110951141148`*^9, 
  3.7119111192342353`*^9}},ExpressionUUID->"818c22db-707d-4613-a6c3-\
0675acdf07b9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vectorDirections", "[", 
   RowBox[{"{", 
    RowBox[{"c1_", ",", "c2_"}], "}"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"generalVectorDirections", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[Rule]", "c1"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Rule]", "c2"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vectorDirections", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], "]"}], ":=", "originVectorDirections"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"vectorDirections", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7119079463437185`*^9, 3.71190803388766*^9}, {
  3.7119085382990055`*^9, 3.711908640301512*^9}, {3.711910469070053*^9, 
  3.711910476169975*^9}, {3.7119105079487123`*^9, 
  3.7119105116708956`*^9}},ExpressionUUID->"178bdfb5-6264-4d5a-b675-\
09b038576bdf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "1"]}], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["b", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"]}]}]]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"4", "+", 
         SuperscriptBox[
          RowBox[{"Abs", "[", 
           FractionBox[
            RowBox[{
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SubscriptBox["b", "1"]}], ")"}]}], "-", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SubscriptBox["b", "2"]}], ")"}]}], "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "-", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "+", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["b", "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["a", "1", "2"], " ", 
                SubsuperscriptBox["b", "2", "2"]}]}]]}], 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"]}]], "]"}], "2"]}]], " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"]}]], ",", 
     FractionBox["2", 
      SqrtBox[
       RowBox[{"4", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "2"]}], ")"}]}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["b", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"]}]}]]}], 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}]], "]"}], "2"]}]]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "1"]}], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"]}], "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["b", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"]}]}]]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"4", "+", 
         SuperscriptBox[
          RowBox[{"Abs", "[", 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["a", "2"]}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SubscriptBox["b", "1"]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SubscriptBox["b", "2"]}], ")"}]}], "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "-", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "+", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["b", "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["a", "1", "2"], " ", 
                SubsuperscriptBox["b", "2", "2"]}]}]]}], 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"]}]], "]"}], "2"]}]], " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"]}]], ",", 
     FractionBox["2", 
      SqrtBox[
       RowBox[{"4", "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "2"]}], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "2"]}], ")"}]}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["b", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"]}]}]]}], 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}]], "]"}], "2"]}]]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.711908609092698*^9, 3.711908644455041*^9}, {
   3.711910496550064*^9, 3.711910511771598*^9}, 3.7130841666102057`*^9, 
   3.71310392653136*^9, 3.713112998403348*^9, 3.7131198041759157`*^9, 
   3.713121458572612*^9, 3.7131824767389174`*^9, 3.7131827263634515`*^9, 
   3.713186880945052*^9, 3.71318696461668*^9, 3.7131903902154922`*^9, 
   3.7131916953726354`*^9, 3.7131932946291304`*^9, 3.713193445237625*^9, 
   3.7131987899573417`*^9, 3.7131995050876207`*^9, 3.7131998131882753`*^9, 
   3.713200327690271*^9, 3.713200679512272*^9, 3.7132103702058353`*^9, 
   3.7132122963291683`*^9, 3.7132139561343203`*^9, 
   3.7133543494537845`*^9},ExpressionUUID->"48144dd9-6654-4d6a-9896-\
92838d85f029"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Make a function that calculates the eigenvectors through a particular point\
\>", "Subsection",
 CellChangeTimes->{{3.711907610975114*^9, 
  3.7119076305807486`*^9}},ExpressionUUID->"618f4f33-0c7e-4a51-9af6-\
e957586d7fa7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vectorDirections2", "[", 
   RowBox[{"{", 
    RowBox[{"c1_", ",", "c2_"}], "}"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{"eigenvectors", "[", "f", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[Rule]", "c1"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Rule]", "c2"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vectorDirections2", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], "]"}], ":=", 
  "originVectorDirections"}], "\[IndentingNewLine]", 
 RowBox[{"vectorDirections2", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.713111669527098*^9, 
  3.7131117424171658`*^9}},ExpressionUUID->"ed8440be-6f5c-4d9d-a044-\
f0e1290df08a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["b", "1"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["b", "2"]}], ")"}]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["b", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"]}]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"]}]], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["b", "1"]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["b", "2"]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "-", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "+", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["b", "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "1", "2"], " ", 
           SubsuperscriptBox["b", "2", "2"]}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"]}]]}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7131117427871804`*^9, 3.713112998419848*^9, 
  3.713119804191415*^9, 3.7131214585926085`*^9, 3.7131824767644176`*^9, 
  3.7131827264004507`*^9, 3.7131868809725513`*^9, 3.713186964643181*^9, 
  3.713190390233492*^9, 3.7131916954056354`*^9, 3.7131932946566267`*^9, 
  3.713193445262624*^9, 3.713198789976341*^9, 3.71319950511112*^9, 
  3.713199813211776*^9, 3.7132003277127724`*^9, 3.713200679536273*^9, 
  3.713210370233835*^9, 3.713212296349169*^9, 3.7132139561588216`*^9, 
  3.7133543494777827`*^9},ExpressionUUID->"7c79e9e4-2cb2-4c08-9c90-\
38dfd49e0b6f"]
}, Open  ]],

Cell["\<\
The vectors will be expressed as the particular point + a multiple of the \
eigenvectors.\
\>", "Text",
 CellChangeTimes->{{3.7119077257473183`*^9, 
  3.711907782335929*^9}},ExpressionUUID->"dfcaa602-ff66-48b0-8a28-\
f43d17a4eeec"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vectorsFrom", "[", 
   RowBox[{"{", 
    RowBox[{"c1_", ",", "c2_"}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c1", ",", "c2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c1", ",", "c2"}], "}"}]}], "}"}], "+", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"v1", ",", "v2"}], "}"}], "*", 
    RowBox[{"vectorDirections2", "[", 
     RowBox[{"{", 
      RowBox[{"c1", ",", "c2"}], "}"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"vectorsFrom", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["c", "1"], ",", 
    SubscriptBox["c", "2"]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.711907650183883*^9, 3.711907721381697*^9}, {
   3.711907806149336*^9, 3.711907893030282*^9}, {3.7119107859735117`*^9, 
   3.71191083151868*^9}, {3.7119128334975195`*^9, 3.7119128836897078`*^9}, {
   3.71191303589515*^9, 3.711913052779771*^9}, {3.7119132434361467`*^9, 
   3.711913273989683*^9}, {3.711913354007312*^9, 3.7119133581844*^9}, {
   3.711913397641373*^9, 3.7119134265099964`*^9}, {3.7119134668042436`*^9, 
   3.7119135552662535`*^9}, {3.71191363128329*^9, 3.7119136450348015`*^9}, 
   3.711914003156397*^9, {3.7119141590682*^9, 3.711914183855321*^9}, {
   3.711914280538731*^9, 3.7119143019540663`*^9}, {3.711914397532638*^9, 
   3.711914429572302*^9}, {3.7119155053874645`*^9, 3.7119156400734777`*^9}, {
   3.7119160290406485`*^9, 3.7119160312563353`*^9}, {3.71309870116339*^9, 
   3.713098748991642*^9}, {3.7131007347580786`*^9, 3.713100747734827*^9}, {
   3.7131009127100086`*^9, 3.713100931883662*^9}, {3.713101332189478*^9, 
   3.7131013330118756`*^9}, {3.713104762322652*^9, 3.713104766175252*^9}, 
   3.713111750522481*^9, {3.71312411034424*^9, 
   3.713124117035815*^9}},ExpressionUUID->"cd4e4923-6130-4f50-9e64-\
1efec812e54f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], "+", 
      FractionBox[
       RowBox[{"v1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "2"]}]]}], ",", 
     RowBox[{"v1", "+", 
      SubscriptBox["c", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], "-", 
      FractionBox[
       RowBox[{"v2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "2"]}]]}], ",", 
     RowBox[{"v2", "+", 
      SubscriptBox["c", "2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.71190789400529*^9, 3.711910838233595*^9, 3.711912844350752*^9, 
   3.7119128966158257`*^9, {3.7119130407804174`*^9, 3.711913053422636*^9}, {
   3.7119132670457973`*^9, 3.7119132745565844`*^9}, 3.711913371771158*^9, {
   3.711913509219056*^9, 3.7119135563756056`*^9}, {3.7119136328730497`*^9, 
   3.711913645567113*^9}, 3.71191400587395*^9, {3.7119141782845745`*^9, 
   3.711914186946418*^9}, {3.7119142936289687`*^9, 3.7119143026552067`*^9}, 
   3.7119143979032035`*^9, 3.711914436539174*^9, {3.7119155092278595`*^9, 
   3.7119156408886538`*^9}, 3.711916032053081*^9, 3.713084151353938*^9, 
   3.713098615437541*^9, 3.713098752454768*^9, 3.713100748709978*^9, {
   3.7131009334969687`*^9, 3.713100943973013*^9}, 3.7131013339619017`*^9, 
   3.7131039266008615`*^9, 3.7131047674117856`*^9, 3.713111752469556*^9, 
   3.7131129984323487`*^9, 3.7131198042039156`*^9, 3.7131214586055803`*^9, 
   3.713124117809641*^9, 3.713124205553585*^9, 3.713182476786916*^9, 
   3.7131827264394507`*^9, 3.7131868810030518`*^9, 3.7131869646716824`*^9, 
   3.7131903902519917`*^9, 3.7131916954326363`*^9, 3.7131932946791306`*^9, 
   3.7131934452836237`*^9, 3.7131987899968424`*^9, 3.7131995051346197`*^9, 
   3.713199813235938*^9, 3.71320032773577*^9, 3.7132006795632706`*^9, 
   3.713210370252836*^9, 3.7132122963701687`*^9, 3.7132139561773214`*^9, 
   3.713354349498783*^9},ExpressionUUID->"30916735-bb67-496e-ad13-\
5c15275c271e"]
}, Open  ]],

Cell["The intersections will occur when the values are the same", "Text",
 CellChangeTimes->{{3.713098762663475*^9, 
  3.7130987877720346`*^9}},ExpressionUUID->"98c66410-34a5-4747-a6c4-\
838ec234f77a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Outer", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"#1", "\[Equal]", "#2"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"v1", ",", "v2"}], "}"}]}], "]"}], "&"}], ",", 
   RowBox[{"vectorsFrom", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
   RowBox[{"vectorsFrom", "[", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["c", "1"], ",", 
      SubscriptBox["c", "2"]}], "}"}], "]"}], ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"vectorIntersections", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"%", ",", "2"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7130987894011664`*^9, 3.7130989634792857`*^9}, {
  3.7130990622400694`*^9, 
  3.713099065706235*^9}},ExpressionUUID->"ecf030f8-37cd-4353-a49c-\
9585af89f1e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v1", "\[Rule]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "1"]}], "+", 
            SubscriptBox["a", "2"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["b", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["c", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"], " ", 
               SubsuperscriptBox["c", "2", "2"]}]}]]}], 
           RowBox[{"2", " ", 
            RowBox[{"Abs", "[", 
             SubscriptBox["b", "1"], "]"}], " ", 
            SubscriptBox["a", "2"]}]]}]}], ",", 
        RowBox[{"v2", "\[Rule]", 
         RowBox[{"-", 
          SubscriptBox["c", "2"]}]}]}], "}"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v1", "\[Rule]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"], " ", 
            SubscriptBox["c", "2"]}], 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["a", "1"]}], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["b", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "+", 
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["c", "2"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "1", "2"], " ", 
               SubsuperscriptBox["b", "2", "2"], " ", 
               SubsuperscriptBox["c", "2", "2"]}]}]]}]]}]}], ",", 
        RowBox[{"v2", "\[Rule]", 
         FractionBox[
          RowBox[{
           SubscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "-", 
             SubscriptBox["a", "2"], "+", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}], "-", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "-", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["b", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "1"], "+", 
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["a", "1", "2"], " ", 
                SubsuperscriptBox["b", "2", "2"], " ", 
                SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}]}], 
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              SubscriptBox["b", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["c", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"], " ", 
              SubsuperscriptBox["c", "2", "2"]}]}]]}]]}]}], "}"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7130987933222303`*^9, {3.713098870392101*^9, 3.7130989210835695`*^9}, 
   3.713098964272477*^9, 3.7130990664368324`*^9, 3.7131010068272543`*^9, 
   3.7131011087107735`*^9, 3.7131039268758693`*^9, 3.7131047780945606`*^9, 
   3.713111756697719*^9, 3.713112998522348*^9, 3.713119804298415*^9, 
   3.7131214587010574`*^9, {3.713124123973424*^9, 3.7131241423850617`*^9}, 
   3.713124198449585*^9, 3.7131824768909206`*^9, 3.71318272654445*^9, 
   3.713186881103053*^9, 3.713186964771182*^9, 3.7131903903454914`*^9, 
   3.7131916955311375`*^9, 3.71319329477313*^9, 3.713193445380125*^9, 
   3.7131987900853443`*^9, 3.713199505231119*^9, 3.71319981332794*^9, 
   3.7132003278287725`*^9, 3.7132006796657715`*^9, 3.7132103703468447`*^9, 
   3.7132122964661703`*^9, 3.7132139562828226`*^9, 
   3.7133543496102934`*^9},ExpressionUUID->"44294e02-9447-4fb5-b18f-\
066f69de3a10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v1", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "1"]}], "+", 
         SubscriptBox["a", "2"], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}], "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}], 
        RowBox[{"2", " ", 
         RowBox[{"Abs", "[", 
          SubscriptBox["b", "1"], "]"}], " ", 
         SubscriptBox["a", "2"]}]]}]}], ",", 
     RowBox[{"v2", "\[Rule]", 
      RowBox[{"-", 
       SubscriptBox["c", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"v1", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"], " ", 
         SubscriptBox["c", "2"]}], 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "1"]}], "+", 
         SubscriptBox["a", "2"], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "-", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["c", "2"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "1", "2"], " ", 
            SubsuperscriptBox["b", "2", "2"], " ", 
            SubsuperscriptBox["c", "2", "2"]}]}]]}]]}]}], ",", 
     RowBox[{"v2", "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}], "-", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "-", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["c", "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["a", "1", "2"], " ", 
             SubsuperscriptBox["b", "2", "2"], " ", 
             SubsuperscriptBox["c", "2", "2"]}]}]]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["a", "2"], "-", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}], "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "-", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "+", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["c", "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "1", "2"], " ", 
           SubsuperscriptBox["b", "2", "2"], " ", 
           SubsuperscriptBox["c", "2", "2"]}]}]]}]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7130987933222303`*^9, {3.713098870392101*^9, 3.7130989210835695`*^9}, 
   3.713098964272477*^9, 3.7130990664368324`*^9, 3.7131010068272543`*^9, 
   3.7131011087107735`*^9, 3.7131039268758693`*^9, 3.7131047780945606`*^9, 
   3.713111756697719*^9, 3.713112998522348*^9, 3.713119804298415*^9, 
   3.7131214587010574`*^9, {3.713124123973424*^9, 3.7131241423850617`*^9}, 
   3.713124198449585*^9, 3.7131824768909206`*^9, 3.71318272654445*^9, 
   3.713186881103053*^9, 3.713186964771182*^9, 3.7131903903454914`*^9, 
   3.7131916955311375`*^9, 3.71319329477313*^9, 3.713193445380125*^9, 
   3.7131987900853443`*^9, 3.713199505231119*^9, 3.71319981332794*^9, 
   3.7132003278287725`*^9, 3.7132006796657715`*^9, 3.7132103703468447`*^9, 
   3.7132122964661703`*^9, 3.7132139562828226`*^9, 
   3.713354349618294*^9},ExpressionUUID->"8d73fa0e-d646-43cb-bd07-\
cc15cceefd7f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Make a functions that calculate the properties of the eigenvector lines \
through a specified point\
\>", "Subsection",
 CellChangeTimes->{{3.7068278036725245`*^9, 
  3.7068278595485725`*^9}},ExpressionUUID->"9da6dc2f-7177-4b8d-b956-\
bf54bfa114f8"],

Cell[CellGroupData[{

Cell["The first property is the slope", "Subsubsection",
 CellChangeTimes->{{3.706830107373764*^9, 
  3.706830128348392*^9}},ExpressionUUID->"f43563ca-3f48-4f95-b60d-\
68ed9a1aa370"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vectorSlope1", "[", 
   RowBox[{"c1_", ",", "c2_"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", " ", 
   RowBox[{
    RowBox[{"inverseSlope", "[", 
     RowBox[{
      RowBox[{"eigenvectors", "[", "f", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[Rule]", "c1"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Rule]", "c2"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vectorSlope1", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"vectorSlope1", "[", 
  RowBox[{"1", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7068279246495433`*^9, 3.706827962408034*^9}, {
  3.706828082028393*^9, 3.7068281343971334`*^9}, {3.70682817959746*^9, 
  3.7068281908993196`*^9}, {3.706828564441964*^9, 3.7068286012762284`*^9}, {
  3.7068286376641436`*^9, 3.7068286565753727`*^9}, {3.7068286941017184`*^9, 
  3.706828708893406*^9}, {3.706828936947422*^9, 
  3.706828966825901*^9}},ExpressionUUID->"c60af8b5-0b3b-4056-90b8-\
6e334f30da2c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SubscriptBox["b", "1"]}], ")"}]}], "-", 
   RowBox[{
    SubscriptBox["a", "1"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SubscriptBox["b", "2"]}], ")"}]}], "+", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["a", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "+", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
      SubscriptBox["b", "2"]}], "+", 
     RowBox[{
      SubsuperscriptBox["a", "1", "2"], " ", 
      SubsuperscriptBox["b", "2", "2"]}]}]]}], 
  RowBox[{"2", " ", 
   SubscriptBox["a", "2"], " ", 
   SubscriptBox["b", "1"]}]]], "Output",
 CellChangeTimes->{{3.7068279402943153`*^9, 3.706827962897681*^9}, 
   3.7068281179269886`*^9, 3.7068281999005117`*^9, 3.7068286573114853`*^9, 
   3.706828808138178*^9, 3.7068288429108057`*^9, 3.7068289409926314`*^9, 
   3.7068289747346935`*^9, 3.7068691465501986`*^9, 3.706873308905134*^9, 
   3.7068743429492683`*^9, 3.7070426534830565`*^9, 3.708511190182679*^9, 
   3.70955421042689*^9, 3.709555872512159*^9, 3.7095582268931923`*^9, 
   3.7116337624059153`*^9, 3.7116352279284725`*^9, 3.7117949107549005`*^9, 
   3.7118103764069324`*^9, 3.711884479114582*^9, 3.7130841666472063`*^9, 
   3.7131039269043694`*^9, 3.7131129985408487`*^9, 3.7131198043174157`*^9, 
   3.713121458728058*^9, 3.713182476921921*^9, 3.713182726599951*^9, 
   3.7131868811335535`*^9, 3.713186964804681*^9, 3.713190390368993*^9, 
   3.7131916955681353`*^9, 3.7131932948041325`*^9, 3.7131934454096255`*^9, 
   3.7131987901098423`*^9, 3.713199505260619*^9, 3.7131998133569393`*^9, 
   3.7132003278587704`*^9, 3.7132006796987743`*^9, 3.7132103703623447`*^9, 
   3.7132122964901705`*^9, 3.7132139563128223`*^9, 
   3.713354349639817*^9},ExpressionUUID->"43b8b054-40ac-4831-8a42-\
87f067563756"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vectorSlope2", " ", "[", 
   RowBox[{"c1_", ",", "c2_"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", " ", 
   RowBox[{
    RowBox[{"slope", "[", 
     RowBox[{
      RowBox[{"eigenvectors", "[", "f", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[Rule]", "c1"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Rule]", "c2"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"vectorSlope2", "[", 
  RowBox[{"1", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7068290999451413`*^9, 
  3.706829138035736*^9}},ExpressionUUID->"f296f86d-ea39-4d43-8cea-\
06260d7c210d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["a", "2"], " ", 
    SubscriptBox["b", "1"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["a", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["b", "1"]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SubscriptBox["b", "2"]}], ")"}]}], "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "-", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "1"], "+", 
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
       SubscriptBox["b", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "1", "2"], " ", 
       SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]], "Output",
 CellChangeTimes->{{3.706829130715721*^9, 3.7068291383584814`*^9}, 
   3.7068691465615845`*^9, 3.706873308917135*^9, 3.706874343058268*^9, 
   3.7070426534986815`*^9, 3.7085111901907835`*^9, 3.70955421044289*^9, 
   3.70955587255016*^9, 3.709558227015206*^9, 3.711633762415914*^9, 
   3.7116352279404736`*^9, 3.7117949107649007`*^9, 3.711810376416935*^9, 
   3.7118844791336412`*^9, 3.7130841666732073`*^9, 3.7131039269213696`*^9, 
   3.7131129985498486`*^9, 3.7131198043259153`*^9, 3.7131214587470584`*^9, 
   3.7131824769419184`*^9, 3.713182726643454*^9, 3.7131868811580515`*^9, 
   3.713186964836182*^9, 3.713190390387493*^9, 3.7131916955951376`*^9, 
   3.713193294824628*^9, 3.7131934454336247`*^9, 3.713198790127842*^9, 
   3.713199505284619*^9, 3.7131998133794374`*^9, 3.713200327882771*^9, 
   3.713200679725275*^9, 3.713210370372845*^9, 3.713212296508173*^9, 
   3.713213956327823*^9, 
   3.7133543496588144`*^9},ExpressionUUID->"1967aa8d-b89e-4cf3-99a9-\
5e4335409af9"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The second property is the full line equation", "Subsubsection",
 CellChangeTimes->{{3.7068301398761983`*^9, 
  3.7068301632124577`*^9}},ExpressionUUID->"3a2af8f7-92a9-4e32-9d05-\
17b0d63f15d1"],

Cell[TextData[{
 "We are thinking about ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], "[", 
    SubscriptBox["c", "2"], "]"}], TraditionalForm]],ExpressionUUID->
  "bbbc6d6a-6b9d-4c91-aadc-f1c8291a0753"],
 " for the first eigenvector"
}], "Text",
 CellChangeTimes->{{3.7068304839957323`*^9, 
  3.7068305208617196`*^9}},ExpressionUUID->"28688462-2a5c-4826-8286-\
3a93d47e0b33"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vector1From", "[", 
   RowBox[{"{", 
    RowBox[{"c1_", ",", "c2_"}], "}"}], "]"}], ":=", 
  RowBox[{
   SubscriptBox["c", "1"], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", "c2"}], ")"}], "*", 
     RowBox[{"vectorSlope1", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}]}], "+", 
    "c1"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"vector1From", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7068283523903313`*^9, 3.706828381783224*^9}, {
  3.70682911176993*^9, 3.70682911402567*^9}, {3.7068303707987075`*^9, 
  3.706830391597953*^9}, {3.7068304304463873`*^9, 3.706830476604097*^9}, {
  3.7068305612368436`*^9, 3.7068305863289204`*^9}, {3.706831054435986*^9, 
  3.70683109864293*^9}, {3.7068317735098295`*^9, 3.706831779659936*^9}, {
  3.7068743036247663`*^9, 
  3.7068743095481677`*^9}},ExpressionUUID->"fb2525b5-2e52-487b-811b-\
076ba6ada001"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["c", "1"], "\[Equal]", 
  RowBox[{"1", "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["b", "1"]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubscriptBox["b", "2"]}], ")"}]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["b", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"]}]}]]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["c", "2"]}], ")"}]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["b", "1"]}]]}]}]], "Output",
 CellChangeTimes->{{3.7068310924937863`*^9, 3.706831099544648*^9}, 
   3.706831789555847*^9, 3.706869146573086*^9, 3.7068733089301376`*^9, 
   3.706874343075268*^9, 3.7070426534986815`*^9, 3.7085111901997833`*^9, 
   3.7095542104593906`*^9, 3.709555872577164*^9, 3.7095582270792065`*^9, 
   3.7116337624264145`*^9, 3.711635227952972*^9, 3.7117949107769012`*^9, 
   3.7118103764279327`*^9, 3.7118844791496396`*^9, 3.7130841666992073`*^9, 
   3.71310392693937*^9, 3.713112998559348*^9, 3.713119804335416*^9, 
   3.713121458767059*^9, 3.7131824769619207`*^9, 3.713182726680952*^9, 
   3.7131868811830544`*^9, 3.7131869648676853`*^9, 3.7131903904039936`*^9, 
   3.7131916956251373`*^9, 3.7131932948441334`*^9, 3.7131934454541264`*^9, 
   3.713198790146845*^9, 3.713199505306622*^9, 3.71319981340294*^9, 
   3.713200327906272*^9, 3.7132006797492723`*^9, 3.713210370384846*^9, 
   3.7132122965256705`*^9, 3.713213956343323*^9, 
   3.7133543496778145`*^9},ExpressionUUID->"5a2aab5e-679f-4ec8-81ed-\
08c3f3d1ea46"]
}, Open  ]],

Cell[TextData[{
 "We are thinking about ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "2"], "[", 
    SubscriptBox["c", "1"], "]"}], TraditionalForm]],ExpressionUUID->
  "1e0069e5-8e14-44f5-8157-61eeb81b3042"],
 " for the second eigenvector"
}], "Text",
 CellChangeTimes->{{3.7068304839957323`*^9, 3.7068305208617196`*^9}, {
  3.7070426822696905`*^9, 
  3.7070426919415636`*^9}},ExpressionUUID->"bb3f3691-5921-42b6-8299-\
2c1e4bb1b74e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vector2From", "[", 
   RowBox[{"{", 
    RowBox[{"c1_", ",", "c2_"}], "}"}], "]"}], ":=", 
  RowBox[{
   SubscriptBox["c", "2"], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "1"], "-", "c1"}], ")"}], "*", 
     RowBox[{"vectorSlope2", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}]}], "+", 
    "c2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"vector2From", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.706831197752948*^9, 3.706831210379614*^9}, {
  3.7068317827999105`*^9, 3.706831786783612*^9}, {3.7068743108261766`*^9, 
  3.7068743350407667`*^9}},ExpressionUUID->"7554b372-16e3-4fa8-947e-\
ad5cc1337457"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["c", "2"], "\[Equal]", 
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["b", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["c", "1"]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubscriptBox["b", "1"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SubscriptBox["b", "2"]}], ")"}]}], "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "+", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["b", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["a", "1", "2"], " ", 
        SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]}]], "Output",
 CellChangeTimes->{3.706831211322985*^9, 3.7068317875689926`*^9, 
  3.706869146585585*^9, 3.706873308943635*^9, 3.70687434308927*^9, 
  3.7070426535143085`*^9, 3.7085111902067833`*^9, 3.709554210475891*^9, 
  3.7095558726551743`*^9, 3.709558227129208*^9, 3.7116337624369135`*^9, 
  3.7116352279649734`*^9, 3.7117949107894015`*^9, 3.711810376439934*^9, 
  3.711884479165639*^9, 3.713084166722207*^9, 3.7131039269563713`*^9, 
  3.7131129985688486`*^9, 3.713119804345416*^9, 3.7131214587790575`*^9, 
  3.7131824769814205`*^9, 3.713182726723451*^9, 3.7131868812070527`*^9, 
  3.713186964897682*^9, 3.7131903904229927`*^9, 3.7131916956556377`*^9, 
  3.7131932948631287`*^9, 3.7131934454746256`*^9, 3.7131987901658444`*^9, 
  3.7131995053301196`*^9, 3.7131998134264402`*^9, 3.7132003279292717`*^9, 
  3.713200679774276*^9, 3.7132103703948464`*^9, 3.7132122965426702`*^9, 
  3.7132139563588247`*^9, 
  3.7133543496968145`*^9},ExpressionUUID->"09af1a63-ea03-44a1-9334-\
12debf5f5ac4"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Given two initial ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "3f009df7-3d06-43ff-bf6b-798b276f56d0"],
 " points, find the points at which the eigenvectors from those points \
intersect"
}], "Subsection",
 CellChangeTimes->{{3.706831536357001*^9, 3.7068315706429524`*^9}, {
  3.7070427018475266`*^9, 
  3.707042716090497*^9}},ExpressionUUID->"4ad15631-d690-416e-ab2c-\
fd878248ace7"],

Cell["\<\
The \[OpenCurlyDoubleQuote]Outer\[CloseCurlyDoubleQuote] function is a \
generalization of the outer product.  \
\>", "Text",
 CellChangeTimes->{{3.709554884825861*^9, 3.70955489347546*^9}, {
  3.70955563717048*^9, 
  3.7095556831178484`*^9}},ExpressionUUID->"1b16dba1-9747-40a5-9559-\
83b6ca642335"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Outer", "[", 
   RowBox[{"func", ",", " ", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["w", "1"], ",", 
      SubscriptBox["w", "2"]}], "}"}]}], "]"}], "//", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{"#", ",", 
     RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.709555698599259*^9, 3.7095557312839184`*^9}, {
  3.7095560386821823`*^9, 
  3.7095560561636095`*^9}},ExpressionUUID->"a269fe5c-734b-4ecd-a3e2-\
fcd89047ec66"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"func", "[", 
      RowBox[{
       SubscriptBox["v", "1"], ",", 
       SubscriptBox["w", "1"]}], "]"}], 
     RowBox[{"func", "[", 
      RowBox[{
       SubscriptBox["v", "1"], ",", 
       SubscriptBox["w", "2"]}], "]"}]},
    {
     RowBox[{"func", "[", 
      RowBox[{
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["w", "1"]}], "]"}], 
     RowBox[{"func", "[", 
      RowBox[{
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["w", "2"]}], "]"}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.7095557261267643`*^9, 3.7095557321324396`*^9}, 
   3.7095558727271867`*^9, {3.709556040827834*^9, 3.7095560566106143`*^9}, 
   3.709558227187207*^9, 3.7116337624509134`*^9, 3.7116352279774737`*^9, 
   3.7117949108264027`*^9, 3.7118103764510574`*^9, 3.7118844791816387`*^9, 
   3.7130841667512083`*^9, 3.7131039269753714`*^9, 3.7131129985778475`*^9, 
   3.713119804354418*^9, 3.713121458792985*^9, 3.7131824770009212`*^9, 
   3.7131827267614517`*^9, 3.7131868812335525`*^9, 3.713186964929182*^9, 
   3.713190390440995*^9, 3.71319169568464*^9, 3.7131932948821316`*^9, 
   3.7131934454931264`*^9, 3.7131987901843433`*^9, 3.7131995053521223`*^9, 
   3.7131998134489403`*^9, 3.713200327954274*^9, 3.7132006798042755`*^9, 
   3.713210370406848*^9, 3.713212296560171*^9, 3.713213956372325*^9, 
   3.7133543497138147`*^9},ExpressionUUID->"37db6f40-94d8-412b-ad4f-\
22b0634f64fe"]
}, Open  ]],

Cell["\<\
We will use it to calculate the intersections of the eigenvectors, as follows:\
\>", "Text",
 CellChangeTimes->{{3.7095557372007494`*^9, 
  3.7095557508805933`*^9}},ExpressionUUID->"177eb6bd-524c-4fde-8902-\
169932584f3f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Outer", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Framed", "[", 
      RowBox[{
      "\"\<The intersection of \\n\>\"", "<>", "#1", "<>", "\"\<\\nand \>\"", 
       "<>", "#2"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<eigenvector 1 from initial point\>\"", ",", 
      "\"\<eigenvector 2 from initial point\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<eigenvector 1 from final point\>\"", ",", 
      "\"\<eigenvector 2 from final point\>\""}], "}"}]}], "]"}], "//", 
  "Grid"}]], "Input",
 CellChangeTimes->{{3.709554512085391*^9, 3.7095545157144384`*^9}, {
  3.709554552349591*^9, 3.7095548579506664`*^9}, {3.7095560332697825`*^9, 
  3.7095560338847895`*^9}},ExpressionUUID->"500bc4c4-2c81-4c83-a229-\
95b8c88d4555"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FrameBox["\<\"The intersection of \\neigenvector 1 from initial \
point\\nand eigenvector 1 from final point\"\>",
      StripOnInput->False], 
     FrameBox["\<\"The intersection of \\neigenvector 1 from initial \
point\\nand eigenvector 2 from final point\"\>",
      StripOnInput->False]},
    {
     FrameBox["\<\"The intersection of \\neigenvector 2 from initial \
point\\nand eigenvector 1 from final point\"\>",
      StripOnInput->False], 
     FrameBox["\<\"The intersection of \\neigenvector 2 from initial \
point\\nand eigenvector 2 from final point\"\>",
      StripOnInput->False]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.709554737005804*^9, 3.709554837087747*^9}, 
   3.70955587276519*^9, 3.7095560345068903`*^9, 3.7095582272647076`*^9, 
   3.7116337625069137`*^9, 3.7116352279889736`*^9, 3.7117949108419027`*^9, 
   3.7118103765010576`*^9, 3.7118844791888027`*^9, 3.713084166840212*^9, 
   3.7131039269908705`*^9, 3.713112998588849*^9, 3.7131198043729153`*^9, 
   3.7131214588029823`*^9, 3.7131824770229216`*^9, 3.7131827267984524`*^9, 
   3.713186881263053*^9, 3.713186964964181*^9, 3.713190390458493*^9, 
   3.713191695712637*^9, 3.7131932949051313`*^9, 3.7131934455166254`*^9, 
   3.7131987902028437`*^9, 3.7131995053816195`*^9, 3.7131998134759393`*^9, 
   3.7132003279812727`*^9, 3.713200679836276*^9, 3.7132103704628515`*^9, 
   3.713212296577671*^9, 3.713213956388324*^9, 
   3.71335434973482*^9},ExpressionUUID->"a92c73e2-d580-4ee0-979f-\
511805965109"]
}, Open  ]],

Cell["\<\
This complicated function calculates all the intersections of the \
eigenvectors from the initial and final points\
\>", "Text",
 CellChangeTimes->{{3.7068334615062103`*^9, 3.706833547088338*^9}, {
  3.707042744347938*^9, 3.707042766777766*^9}, {3.7085144557490015`*^9, 
  3.7085144707687407`*^9}},ExpressionUUID->"6ad57263-85c9-4b0a-b09b-\
19e8af5d514f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"intersections", "[", 
    RowBox[{"pt1_", ",", "pt2_"}], "]"}], ":=", 
   RowBox[{"Outer", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"First", "[", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#1", ",", "#2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["c", "1"], ",", 
           SubscriptBox["c", "2"]}], "}"}]}], "]"}], "]"}], "&"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"vector1From", "[", "pt1", "]"}], ",", 
       RowBox[{"vector2From", "[", "pt1", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"vector1From", "[", "pt2", "]"}], ",", 
       RowBox[{"vector2From", "[", "pt2", "]"}]}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"intersections", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "//", "Grid"}]}], "Input",
 CellChangeTimes->{{3.708514062122225*^9, 3.70851417471356*^9}, 
   3.708514389409835*^9, {3.7095548607841473`*^9, 3.7095548654718113`*^9}, {
   3.709556101380725*^9, 
   3.709556111013513*^9}},ExpressionUUID->"370d796a-12f8-4aab-b63f-\
c312b8f16e25"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]}]}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{"2", " ", 
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"]}]]}]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}]}], "}"}], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{"2", " ", 
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"]}]]}]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}]}], "}"}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.708514175368574*^9, 3.7085143906754313`*^9, 
  3.709554210550892*^9, 3.7095548677359486`*^9, 3.70955587288957*^9, 
  3.7095561116625214`*^9, 3.7095582273867087`*^9, 3.709560174239528*^9, 
  3.7116337625569115`*^9, 3.711635228051972*^9, 3.711794910900402*^9, 
  3.7118103765640507`*^9, 3.7118844792458525`*^9, 3.7130841669173512`*^9, 
  3.713103927090374*^9, 3.713112998642848*^9, 3.7131198044214153`*^9, 
  3.713121458851009*^9, 3.7131824770754185`*^9, 3.713182726851455*^9, 
  3.7131868813210535`*^9, 3.7131869650306826`*^9, 3.7131903905064964`*^9, 
  3.713191695774638*^9, 3.713193294954633*^9, 3.713193445587126*^9, 
  3.7131987902548456`*^9, 3.713199505446122*^9, 3.713199813537942*^9, 
  3.713200328048774*^9, 3.7132006799167767`*^9, 3.713210370572359*^9, 
  3.713212296632172*^9, 3.713213956462826*^9, 
  3.713354349803439*^9},ExpressionUUID->"58373512-5589-40f3-a7d6-\
ded2152f924e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Given a point, find the axis intercepts of the eigenvectors", \
"Subsection",
 CellChangeTimes->{{3.7068742613512087`*^9, 3.7068742903084574`*^9}, 
   3.706877486967834*^9, {3.7068775402421513`*^9, 
   3.7068775422341557`*^9}},ExpressionUUID->"adeaa360-ce3b-44f4-b51e-\
013d8446efa1"],

Cell["This will be accomplished the same way as the intersections", "Text",
 CellChangeTimes->{{3.7070428516574974`*^9, 3.7070429368377275`*^9}, {
  3.7070430012696276`*^9, 3.707043007239859*^9}, {3.7095584916028967`*^9, 
  3.7095585016088576`*^9}},ExpressionUUID->"dd2fe69c-9c13-4790-ae1d-\
d48745c5b139"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"intercepts", "[", "pt1_", "]"}], ":=", 
  RowBox[{"Outer", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", "#2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["c", "1"], ",", 
          SubscriptBox["c", "2"]}], "}"}]}], "]"}], "]"}], "&"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vector1From", "[", "pt1", "]"}], ",", 
      RowBox[{"vector2From", "[", "pt1", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], "\[Equal]", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Equal]", "0"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"intercepts", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.7095565796605463`*^9, {3.709556635443632*^9, 3.709556636745672*^9}, {
   3.7095566746760874`*^9, 3.7095566862587852`*^9}, {3.7095567568917193`*^9, 
   3.709556783159957*^9}, {3.709556832898875*^9, 3.7095570278216553`*^9}, {
   3.7095579686184616`*^9, 3.7095579748299065`*^9}, {3.709558008393345*^9, 
   3.7095580821514454`*^9}},ExpressionUUID->"a0030ff4-e7f3-4dd1-aa78-\
5bad2be46aca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{"2", " ", 
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"]}]]}]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"]}], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "-", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], "2"], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "1"], "+", 
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SubscriptBox["b", "1"]}], ")"}]}]}], ")"}], " ", 
              SubscriptBox["b", "2"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "1", "2"], " ", 
              SubsuperscriptBox["b", "2", "2"]}]}]]}], 
          RowBox[{"2", " ", 
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"]}]]}]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7095580519616694`*^9, {3.7095580830899467`*^9, 3.7095580856475353`*^9}, 
   3.7095582276822124`*^9, 3.7116337626109076`*^9, 3.711635228116969*^9, 
   3.711794910944406*^9, 3.7118103766232967`*^9, 3.7118844792878504`*^9, 
   3.713084166995352*^9, 3.7131039271713767`*^9, 3.7131129986753488`*^9, 
   3.713119804465415*^9, 3.713121458885008*^9, 3.7131824771134233`*^9, 
   3.713182726887454*^9, 3.7131868813695545`*^9, 3.713186965076682*^9, 
   3.7131903905399933`*^9, 3.713191695818638*^9, 3.713193294993633*^9, 
   3.713193445661626*^9, 3.7131987902918444`*^9, 3.713199505509621*^9, 
   3.71319981359744*^9, 3.7132003281017723`*^9, 3.7132006799812765`*^9, 
   3.7132103706358647`*^9, 3.7132122966706724`*^9, 3.7132139565253253`*^9, 
   3.713354349862445*^9},ExpressionUUID->"9472f181-ae1e-4b30-827d-\
d23f74038e8e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 5: Check for the presence of shockwaves", "Section",
 CellChangeTimes->{{3.70682699412429*^9, 3.706827060046103*^9}, {
  3.7131515769305954`*^9, 3.7131515870390215`*^9}, {3.7131940401277514`*^9, 
  3.7131940415515003`*^9}},ExpressionUUID->"863d1b5d-e0f7-490f-ad74-\
6461686b857d"],

Cell[TextData[{
 "Shockwaves form when the velocity at the end of a transition is larger than \
the velocity at the beginning.  What that means is, you will end up seeing \
the ",
 StyleBox["final",
  FontSlant->"Italic"],
 " state (i.e. the feed) leaving your column ",
 StyleBox["before",
  FontSlant->"Italic"],
 " the ",
 StyleBox["initial",
  FontSlant->"Italic"],
 " state (i.e. the liquid already in the column).  Clearly that can\
\[CloseCurlyQuote]t happen, so we need to correct our math in the case where \
the velocity increases along the transitions.  To \
\[OpenCurlyDoubleQuote]detect\[CloseCurlyDoubleQuote] this, all we need to do \
is calculate the derivative of the velocity in the direction of the \
transitions, and see if they are positive or negative."
}], "Text",
 CellChangeTimes->{{3.7118848279050283`*^9, 3.7118848541713424`*^9}, {
  3.71188493874168*^9, 3.711885206805913*^9}, {3.711885463190161*^9, 
  3.7118854861179533`*^9}},ExpressionUUID->"18c9f9e1-ca6d-4b4b-96f1-\
c22945e326a7"],

Cell[CellGroupData[{

Cell["\<\
Calculate the eigenvalues as a function of the independent variable at the \
initial point, final point, and intersections\
\>", "Subsection",
 CellChangeTimes->{{3.706880098957431*^9, 3.7068801184045825`*^9}, {
  3.708511443499866*^9, 3.708511445310341*^9}, {3.7095591406778812`*^9, 
  3.709559207712397*^9}},ExpressionUUID->"a54dd1c0-8c40-4faa-969d-\
571a12333e6b"],

Cell["\<\
Since we have previously calculated all the other eigenvalues as a function \
of the isotherm eigenvalues, we will calculate the isotherm eigenvalues first.\
\>", "Text",
 CellChangeTimes->{{3.7068801744600143`*^9, 
  3.7068802159444427`*^9}},ExpressionUUID->"ded25316-b5f8-40c3-86fa-\
4f1c797c0e92"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eigenvalueIntersections", "[", 
   RowBox[{"pt1_", ",", "pt2_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"eigenvalueIntersections", "[", 
    RowBox[{"pt1", ",", "pt2"}], "]"}], "=", 
   RowBox[{
    RowBox[{"eigenvalues", "[", "isotherm", "]"}], "/.", 
    RowBox[{"intersections", "[", 
     RowBox[{"pt1", ",", "pt2"}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allIntersections", "=", 
   RowBox[{"Simplify", "/@", 
    RowBox[{"eigenvalueIntersections", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["cF", "1"], ",", 
        SubscriptBox["cF", "2"]}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7095592505154614`*^9, 3.7095593394675193`*^9}, 
   3.709560815831182*^9, {3.709560972590847*^9, 3.709561046944084*^9}, {
   3.7095610906528263`*^9, 3.709561119613842*^9}, {3.709561240369368*^9, 
   3.7095612405463705`*^9}, {3.709561320726431*^9, 3.7095613263664913`*^9}, {
   3.7095637881801376`*^9, 3.7095638338458047`*^9}, 3.7095639103517413`*^9, 
   3.70956408819552*^9, 3.7095644865456066`*^9, {3.7116342971878233`*^9, 
   3.711634342903929*^9}, {3.711634575821165*^9, 3.711634580248226*^9}, {
   3.7116346236873693`*^9, 
   3.711634646624157*^9}},ExpressionUUID->"21395e4c-0b38-452c-bf6d-\
3d05aa5210f4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculate the directional derivatives", "Subsection",
 CellChangeTimes->{{3.7118852122802258`*^9, 3.7118852183777094`*^9}, 
   3.711886123264923*^9},ExpressionUUID->"9959928f-a4ee-4e94-8c79-\
656a4c5238bb"],

Cell[TextData[{
 "First, we just take the derivative of the eigenvalues with respect to \
concentrations.  We can do this using the ",
 Cell[BoxData[
  SubscriptBox["\[Del]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"]}], "}"}]]],
  CellChangeTimes->{{3.711885258284157*^9, 3.711885282258831*^9}},
  ExpressionUUID->"f6636c99-0f34-4d60-ba66-88bf5fe48c55"],
 " to be fancy."
}], "Text",
 CellChangeTimes->{{3.711885221981621*^9, 3.7118852355520134`*^9}, {
  3.7118852905686145`*^9, 
  3.711885320682351*^9}},ExpressionUUID->"db34ce8f-982c-4ba0-a664-\
c72be0b25589"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Del]", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"]}], "}"}]], 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["c", "1"], ",", 
    RowBox[{
     SubscriptBox["c", "1"], "*", 
     SubscriptBox["c", "2"]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.711885258284157*^9, 3.711885282258831*^9}, 
   3.711885332067744*^9},ExpressionUUID->"b15f6124-9d47-44ff-8ead-\
c9ea376f8ea6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["c", "2"], ",", 
     SubscriptBox["c", "1"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.71188526371174*^9, 3.7118852826137056`*^9}, 
   3.7118853324826*^9, 3.7130841744248857`*^9, 3.7131039336671057`*^9, 
   3.7131130036298494`*^9, 3.7131198098999157`*^9, 3.7131214649525385`*^9, 
   3.7131824820269885`*^9, 3.713182731866522*^9, 3.7131868862765994`*^9, 
   3.713186970006216*^9, 3.713190395364526*^9, 3.7131917012536755`*^9, 
   3.7131932999941654`*^9, 3.713193450666661*^9, 3.7131987951852713`*^9, 
   3.71319951075117*^9, 3.713199818758488*^9, 3.7132003333538113`*^9, 
   3.713200685116829*^9, 3.7132103758285217`*^9, 3.7132123018845425`*^9, 
   3.713213961680148*^9, 
   3.713354354955078*^9},ExpressionUUID->"6f58b117-2c86-49cb-90ad-\
afdac174dd01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenvalueDerivatives", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["\[Del]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["c", "1"], ",", 
       SubscriptBox["c", "2"]}], "}"}]], 
    RowBox[{"eigenvalues", "[", "isotherm", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7116363583181114`*^9, 3.711636412773017*^9}, {
   3.7116368212685647`*^9, 3.7116368316877613`*^9}, {3.7116370171263266`*^9, 
   3.711637023824596*^9}, {3.711637087562006*^9, 3.711637088019558*^9}, {
   3.7116376155904584`*^9, 3.711637683594438*^9}, 3.7116377181359463`*^9, {
   3.711638024135482*^9, 3.7116380481416254`*^9}, 3.711638330364546*^9, {
   3.7116383781777472`*^9, 3.7116383873226395`*^9}, {3.7116384438168716`*^9, 
   3.7116384607476006`*^9}, 3.7117951303654213`*^9, 3.711795168116579*^9, {
   3.7117953672083654`*^9, 3.711795377337409*^9}, {3.711795745172641*^9, 
   3.711795772133193*^9}, {3.711796141318904*^9, 3.711796164134101*^9}, {
   3.711796377965638*^9, 3.7117964197905316`*^9}, {3.71179648421952*^9, 
   3.711796495397351*^9}, {3.711796527449494*^9, 3.711796531563068*^9}, {
   3.7117966047405825`*^9, 3.711796641739848*^9}, {3.711796704002314*^9, 
   3.711796709103527*^9}, {3.711796819679927*^9, 3.7117968231080904`*^9}, {
   3.711796864837785*^9, 3.7117968670618377`*^9}, {3.7117969548917828`*^9, 
   3.711796968450944*^9}, {3.71179715079004*^9, 3.7117971833223004`*^9}, {
   3.7117981439134784`*^9, 3.711798144727006*^9}, {3.7117982035102396`*^9, 
   3.7117982041922455`*^9}, {3.7117982409151225`*^9, 
   3.7117982517987995`*^9}, {3.711798835162006*^9, 3.7117988449720125`*^9}, {
   3.7118011817778244`*^9, 3.711801371427644*^9}, {3.711801483587534*^9, 
   3.711801486561246*^9}, 3.711802044196473*^9, {3.7118021368797426`*^9, 
   3.7118021873080435`*^9}, {3.7118023240176287`*^9, 3.711802351671217*^9}, {
   3.7118024024031005`*^9, 3.711802434406349*^9}, 3.711802508307145*^9, {
   3.7118030983314753`*^9, 3.711803131460988*^9}, 3.7118171476788235`*^9, 
   3.7118177857108192`*^9, {3.711817928978982*^9, 3.7118179337889814`*^9}, 
   3.7118807530764303`*^9, {3.7118844185386024`*^9, 3.7118844193346753`*^9}, {
   3.711884684483101*^9, 
   3.711884684624445*^9}},ExpressionUUID->"895d846d-4c2a-488c-b856-\
690c2c88b048"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "3"]}]], ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "3"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "3"]}]], ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "3"]}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7118013350608644`*^9, 3.711801372853496*^9}, 
   3.7118014886388397`*^9, 3.7118020478715887`*^9, 3.71180214342241*^9, 
   3.7118021880472918`*^9, {3.711802338154306*^9, 3.7118023531807003`*^9}, {
   3.711802411939666*^9, 3.711802436976366*^9}, 3.7118025104311595`*^9, {
   3.711803111046318*^9, 3.7118031335140038`*^9}, 3.7118103837604103`*^9, 
   3.7118171495732408`*^9, 3.7118172033465576`*^9, 3.711817844248543*^9, 
   3.7118179985414605`*^9, 3.711884487074995*^9, 3.711884686980204*^9, 
   3.713084176028137*^9, 3.713103935026643*^9, 3.7131130046983485`*^9, 
   3.713119811058917*^9, 3.713121466388253*^9, 3.7131824830810003`*^9, 
   3.713182732929538*^9, 3.7131868873376074`*^9, 3.713186971075239*^9, 
   3.7131903964100356`*^9, 3.7131917023901863`*^9, 3.7131933011066713`*^9, 
   3.713193451736169*^9, 3.71319879623378*^9, 3.7131995118506813`*^9, 
   3.7131998198554935`*^9, 3.713200334464819*^9, 3.713200686234336*^9, 
   3.713210376947101*^9, 3.713212303038839*^9, 3.7132139627931757`*^9, 
   3.713354356071047*^9},ExpressionUUID->"03fc7750-d90d-46ba-9459-\
1e60fcb3a1c3"]
}, Open  ]],

Cell[TextData[{
 "Next, we calculate the dot product of these ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "f471d66b-601e-419f-ab62-d6eeffcb990d"],
 "} derivatives with the eigenvectors.  Note that we are not using normalized \
eigenvectors!  Doesn\[CloseCurlyQuote]t that mean our directional derivatives \
are wrong?  It depends on what we\[CloseCurlyQuote]re doing.  Since our goal \
is only to determine ",
 StyleBox["the sign ",
  FontSlant->"Italic"],
 "of the derivative, there is no problem if we leave out a constant positive \
scale factor (i.e. by not dividing by the vector magnitude.) "
}], "Text",
 CellChangeTimes->{{3.71188534855087*^9, 3.7118854551234045`*^9}, {
  3.711885599881572*^9, 3.7118856900932903`*^9}, {3.711885784049532*^9, 
  3.711885797576941*^9}, {3.711885833852654*^9, 
  3.7118858678046894`*^9}},ExpressionUUID->"f9eb51fc-9ca8-4580-807a-\
bccb37c7c5d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenvalueDirectionalDerivatives", "=", 
  RowBox[{"Outer", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#1", ".", "#2"}], "&"}], ",", "eigenvalueDerivatives", ",", 
    RowBox[{
     RowBox[{"eigenvectors", "[", "isotherm", "]"}], "*", "4", " ", 
     SubscriptBox["a", "2"], " ", 
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ")"}], "3"]}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.71180314061355*^9, 3.711803148755333*^9}, {
   3.711814097377879*^9, 3.711814128827219*^9}, {3.7118847163512897`*^9, 
   3.71188473204821*^9}, {3.713093019313972*^9, 3.7130930240080957`*^9}, {
   3.713116405699136*^9, 3.7131164305370264`*^9}, 3.713116472539161*^9, {
   3.713119062885612*^9, 3.713119096377015*^9}, {3.713119135876566*^9, 
   3.7131191476561036`*^9}, {3.7131243231274185`*^9, 3.71312432432942*^9}, {
   3.713124359965391*^9, 
   3.713124377075246*^9}},ExpressionUUID->"4edd9d03-5b58-45b6-9601-\
d380655a856b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}], "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "-", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["c", "1"]}], "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         ")"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}]}], 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubscriptBox["a", "1"], " ", 
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["a", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["a", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]]}], 
           ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["a", "1"], " ", 
               SubscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["c", "1"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["a", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["a", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
           ")"}]}]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.711803160104913*^9, 3.711810390391162*^9, 3.711814141129146*^9, 
   3.7118172061447954`*^9, 3.7118178549307756`*^9, 3.7118179987959585`*^9, 
   3.711884487187497*^9, {3.7118847057995596`*^9, 3.711884732891967*^9}, 
   3.7130841762361417`*^9, {3.7130930206207056`*^9, 3.713093024403418*^9}, 
   3.7131039351696453`*^9, 3.7131130047663517`*^9, 3.7131164731611614`*^9, {
   3.7131190636789155`*^9, 3.713119097690144*^9}, 3.713119149079955*^9, 
   3.7131193911279497`*^9, 3.7131198111304145`*^9, 3.713121466468253*^9, 
   3.71312415647586*^9, 3.7131243249464197`*^9, {3.713124370066183*^9, 
   3.713124377623248*^9}, 3.7131396203143654`*^9, 3.7131824831580005`*^9, 
   3.7131827330045385`*^9, 3.713186887426112*^9, 3.71318697117074*^9, 
   3.7131903964650326`*^9, 3.7131917024586835`*^9, 3.7131933011766753`*^9, 
   3.7131934517906675`*^9, 3.7131987962927766`*^9, 3.7131995119146814`*^9, 
   3.713199819920996*^9, 3.7132003345298176`*^9, 3.713200686302837*^9, 
   3.713210377067124*^9, 3.713212303110839*^9, 3.713213962907678*^9, 
   3.7133543561450553`*^9},ExpressionUUID->"d8a398dc-6577-4b0e-9bb1-\
cbf90392f536"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Consider the derivatives along the vectors from the \
\[OpenCurlyDoubleQuote]solvent only\[CloseCurlyDoubleQuote] condition\
\>", "Subsection",
 CellChangeTimes->{{3.7130906885867243`*^9, 3.7130907221007633`*^9}, {
  3.71309229505411*^9, 
  3.7130923113954973`*^9}},ExpressionUUID->"26ab9ce1-1e73-405c-9e4d-\
9ffdfb61c247"],

Cell["\<\
Remember that the initial condition is an empty column (0,0) and the \
directions lie along the axes\
\>", "Text",
 CellChangeTimes->{{3.713090732429269*^9, 
  3.7130907558087683`*^9}},ExpressionUUID->"b4caf3ef-999e-40e2-8c6a-\
95ebb9321d46"],

Cell[CellGroupData[{

Cell[BoxData["originVectorDirections"], "Input",
 CellChangeTimes->{{3.7130907573397703`*^9, 
  3.7130907749407806`*^9}},ExpressionUUID->"84c1e16a-f3ef-42ba-b093-\
cdf9d8eb24c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"Abs", "[", 
       SubscriptBox["b", "1"], "]"}], 
      SubscriptBox["b", "1"]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.71309077599028*^9, 3.713103935249648*^9, 
  3.7131130048173494`*^9, 3.713119811155916*^9, 3.7131214664934645`*^9, 
  3.713182483178501*^9, 3.713182733035535*^9, 3.7131868874521093`*^9, 
  3.713186971196241*^9, 3.713190396483034*^9, 3.7131917024796867`*^9, 
  3.713193301195175*^9, 3.7131934518196697`*^9, 3.7131987963127766`*^9, 
  3.713199511936679*^9, 3.7131998199459968`*^9, 3.7132003346053176`*^9, 
  3.713200686326838*^9, 3.7132103770836253`*^9, 3.71321230312934*^9, 
  3.7132139629236774`*^9, 
  3.713354356165056*^9},ExpressionUUID->"a5f9bf36-6cf3-4dbb-af8c-\
f5c2547e72a7"]
}, Open  ]],

Cell[TextData[{
 "This means that the first eigenvector proceeds along the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "af998855-195a-4110-a1c0-4339a4eaa3c1"],
 " axis, while the 2nd eigenvector falls along the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "5b93162a-3cae-4782-b062-2c501f640e23"],
 " axis.  So we need to know about the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f8b2a323-aa4a-4a62-8176-50f76ee0f5b7"],
 " derivative of the first eigenvalue and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7f19e3b0-0ffb-46d8-a137-37b9e593a44e"],
 " derivative of the second eigenvector."
}], "Text",
 CellChangeTimes->{{3.713090786548781*^9, 3.713090913501021*^9}, {
  3.713091020829388*^9, 
  3.713091023084888*^9}},ExpressionUUID->"147f09c6-676a-400f-a336-\
058cdf54682b"],

Cell[CellGroupData[{

Cell["Consider the first eigenvector", "Subsubsection",
 CellChangeTimes->{{3.7131517020112576`*^9, 
  3.713151707791849*^9}},ExpressionUUID->"475e4810-07d1-4f2d-94b8-\
b3b92c3c96b4"],

Cell[TextData[{
 "The transition from initial to final state proceeds along the first \
eigenvector first.  So we are transitioning from (0,0) to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", 
     SubscriptBox["c", "i"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "6a594f97-eb27-4545-ad7e-3ed101cd7c5f"],
 ".  A shockwave will form if the derivative of the eigenvalues along that \
transition is negative.  We can check for this by defining an equation to see \
when the derivative is less than zero."
}], "Text",
 CellChangeTimes->{{3.7130910262048883`*^9, 
  3.713091199946944*^9}},ExpressionUUID->"373311c1-8891-4845-b45f-\
8abdce0739a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalueDerivatives", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[LessEqual]", "0"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "1"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713090949074026*^9, 3.713090951617526*^9}, {
  3.713090991949826*^9, 3.713091011632389*^9}, {3.7130910940464196`*^9, 
  3.7130910977659197`*^9}},ExpressionUUID->"37719ca1-c44c-440e-ad3d-\
4f223ae2ac69"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["b", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "1"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}]}], ")"}]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}]}], "\[GreaterEqual]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7130909567185297`*^9, 3.713091115533924*^9, 
  3.7130915988229647`*^9, 3.7130916432119694`*^9, 3.713091825814599*^9, 
  3.7131039398832684`*^9, 3.7131058960094395`*^9, 3.7131130083388495`*^9, 
  3.713119198177837*^9, 3.7131198151079574`*^9, 3.713121470788622*^9, 
  3.7131520864019914`*^9, 3.713182486672048*^9, 3.713182736574084*^9, 
  3.713186890937133*^9, 3.7131869746892643`*^9, 3.713190399933058*^9, 
  3.713191706211234*^9, 3.713193305267215*^9, 3.713193455438746*^9, 
  3.713198799864825*^9, 3.7131995158092723`*^9, 3.713199823725218*^9, 
  3.7132003383168697`*^9, 3.71320069000345*^9, 3.713210380791393*^9, 
  3.7132123068363876`*^9, 3.7132139666537466`*^9, 
  3.713354359728855*^9},ExpressionUUID->"7f74995e-f604-45d0-89f3-\
35edfc7c51db"]
}, Open  ]],

Cell["\<\
Next, we can use the \[OpenCurlyDoubleQuote]Reduce\[CloseCurlyDoubleQuote] \
function to attempt to \[OpenCurlyDoubleQuote]solve\[CloseCurlyDoubleQuote] \
the inequality:\
\>", "Text",
 CellChangeTimes->{{3.7130912772829914`*^9, 
  3.713091367291091*^9}},ExpressionUUID->"346c400f-e393-4346-a53a-\
69da24809e95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", "%", "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "1"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713091239070485*^9, 3.7130912645189905`*^9}, {
  3.713091588853259*^9, 3.7130916313819675`*^9}, {3.7130918321327524`*^9, 
  3.7130918369902625`*^9}},ExpressionUUID->"32e888c4-f7d2-4492-8b22-\
b1897be3a35d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SubscriptBox["b", "1"]], "\[GreaterEqual]", "0"}]], "Output",
 CellChangeTimes->{{3.7130912482744865`*^9, 3.713091265249989*^9}, {
   3.713091599238962*^9, 3.713091604728964*^9}, 3.7130916437904696`*^9, {
   3.7130918261156015`*^9, 3.713091837635355*^9}, 3.713103940140274*^9, 
   3.713105896440951*^9, 3.713113008502849*^9, 3.7131191985373373`*^9, 
   3.7131198152739573`*^9, 3.713121471015623*^9, 3.713152086742498*^9, 
   3.7131824868320513`*^9, 3.7131827367400846`*^9, 3.7131868911076326`*^9, 
   3.7131869748607645`*^9, 3.713190400084561*^9, 3.713191706450738*^9, 
   3.713193305426717*^9, 3.7131934555997477`*^9, 3.713198800015826*^9, 
   3.7131995159792767`*^9, 3.713199823893217*^9, 3.713200338484373*^9, 
   3.7132006901764517`*^9, 3.713210380990907*^9, 3.7132123070078907`*^9, 
   3.7132139668502493`*^9, 
   3.713354359903371*^9},ExpressionUUID->"578baf0f-b542-4030-a346-\
3e4c635633cd"]
}, Open  ]],

Cell[TextData[{
 "Which means that the forward transition along the first eigenvector will be \
a shock when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "1"], ">", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "9d3b62f5-5bb8-46ff-9267-f07255687c1f"]
}], "Text",
 CellChangeTimes->{{3.71309217027726*^9, 
  3.713092204774563*^9}},ExpressionUUID->"5de18a9e-cfe3-4a0c-8233-\
a78634af34e3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Consider the second eigenvector", "Subsubsection",
 CellChangeTimes->{{3.7131517020112576`*^9, 
  3.713151721336489*^9}},ExpressionUUID->"ec00283a-c418-4f59-b611-\
04a579f4cfdb"],

Cell["We can repeat this process with the second eigenvector:", "Text",
 CellChangeTimes->{{3.7130913808131056`*^9, 
  3.7130913956631784`*^9}},ExpressionUUID->"015e9bd7-d78a-4b82-918e-\
1742690f8e78"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalueDerivatives", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[LessEqual]", "0"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], "\[Equal]", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713091454216957*^9, 3.713091471165984*^9}, {
  3.7130916135439653`*^9, 
  3.7130916136374645`*^9}},ExpressionUUID->"53dded53-6e75-43a8-9fcb-\
2716778c2192"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["b", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "1"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "\[GreaterEqual]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7130914793929873`*^9, 3.7130915797340007`*^9, 
  3.7130916300114675`*^9, 3.713103946374936*^9, 3.7131130126928496`*^9, 
  3.7131192153108826`*^9, 3.7131198201411095`*^9, 3.7131214761174245`*^9, 
  3.713182491025607*^9, 3.7131827409931445`*^9, 3.7131868953245497`*^9, 
  3.7131869790442944`*^9, 3.7131904042916765`*^9, 3.7131917110021257`*^9, 
  3.713193310762252*^9, 3.7131934598502874`*^9, 3.7131988042343597`*^9, 
  3.7131995208313074`*^9, 3.713199828721322*^9, 3.7132003429749017`*^9, 
  3.713200694973486*^9, 3.71321038574675*^9, 3.7132123120402875`*^9, 
  3.713213971589076*^9, 
  3.713354364188554*^9},ExpressionUUID->"39bab57a-07df-40fd-9258-\
580a8d818068"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", "%", "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713091566164465*^9, 3.713091569231965*^9}, {
  3.7130916165159655`*^9, 
  3.7130916165859666`*^9}},ExpressionUUID->"3df94447-f02e-489e-af7d-\
10e81a3eceaf"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["b", "2"], "\[GreaterEqual]", "0"}]], "Output",
 CellChangeTimes->{
  3.713091481776496*^9, {3.713091570137466*^9, 3.7130915799745035`*^9}, 
   3.7130916302924695`*^9, 3.7131039465519404`*^9, 3.7131130127828493`*^9, 
   3.713119215553895*^9, 3.713119820241609*^9, 3.7131214762174253`*^9, 
   3.7131824911421056`*^9, 3.713182741092146*^9, 3.713186895459551*^9, 
   3.713186979174296*^9, 3.713190404382679*^9, 3.7131917111001253`*^9, 
   3.71319331085925*^9, 3.7131934599618063`*^9, 3.713198804329857*^9, 
   3.7131995209333096`*^9, 3.7131998288348217`*^9, 3.713200343089904*^9, 
   3.713200695079488*^9, 3.713210385875759*^9, 3.713212312166789*^9, 
   3.7132139717220774`*^9, 
   3.713354364304562*^9},ExpressionUUID->"2b77d10f-0669-4991-871b-\
cec2268b01ac"]
}, Open  ]],

Cell[TextData[{
 "Now we should note that this result means that a shockwave will form along \
the second eigenvector ",
 StyleBox["while transitioning from (0,0) to ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["c", "i"], ",", "0"}], ")"}], TraditionalForm]],
  ExpressionUUID->"592b2287-ccf6-46e6-b016-268017770d13"],
 " ",
 StyleBox["only",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ".  In reality, this transition only occurs in reverse.  That is, in an \
elution scenario rather than an adsorption scenario.  Because we only care \
about the ",
 StyleBox["reverse",
  FontSlant->"Italic"],
 " transition, we really want to calculate when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "\[Theta]"}], 
     RowBox[{"\[PartialD]", " ", 
      RowBox[{"-", 
       SubscriptBox["c", "1"]}]}]], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[PartialD]", "\[Theta]"}], 
      RowBox[{"\[PartialD]", " ", 
       SubscriptBox["c", "1"]}]]}]}], TraditionalForm]],ExpressionUUID->
  "0689eb07-019a-4f06-80b8-5d7ced6c7c92"],
 " is less than or equal to zero.  This is equivalent to checking ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"\[PartialD]", "\[Theta]"}], 
    RowBox[{"\[PartialD]", " ", 
     SubscriptBox["c", "1"]}]], TraditionalForm]],ExpressionUUID->
  "b368bbee-c947-4f9b-8f14-50d8d07bae4e"],
 ">= 0"
}], "Text",
 CellChangeTimes->{{3.713091502702998*^9, 3.7130915348414593`*^9}, {
  3.7130916432259707`*^9, 3.713091802887845*^9}, {3.7130918513096538`*^9, 
  3.7130919163208213`*^9}, {3.713091957473381*^9, 3.7130919858375716`*^9}, {
  3.71309206034976*^9, 
  3.713092071601647*^9}},ExpressionUUID->"b78b3a5d-7f6f-4921-ac45-\
670b45b01848"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"eigenvalueDerivatives", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], "\[Equal]", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713091940081983*^9, 3.713091940704064*^9}, 
   3.7130919902504272`*^9, {3.7130920495338097`*^9, 
   3.713092049675931*^9}},ExpressionUUID->"4f25f2e8-604d-41b4-a366-\
01ace6e36f28"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["b", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"Sign", "[", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], "]"}]}], ")"}], " ", 
      SubscriptBox["a", "1"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], "\[LessEqual]", 
  "0"}]], "Output",
 CellChangeTimes->{3.7130919469617367`*^9, 3.7130920263288703`*^9, 
  3.713092056424693*^9, 3.7131039487629986`*^9, 3.7131130142448497`*^9, 
  3.7131192314248967`*^9, 3.71311982195961*^9, 3.713121477983425*^9, 
  3.7131824926071243`*^9, 3.7131827426036625`*^9, 3.7131868969385643`*^9, 
  3.713186980642805*^9, 3.713190405840418*^9, 3.7131917126481357`*^9, 
  3.7131933140102797`*^9, 3.7131934614398146`*^9, 3.7131988058108683`*^9, 
  3.7131995233508673`*^9, 3.7131998312648544`*^9, 3.7132003447094164`*^9, 
  3.7132006967211328`*^9, 3.7132103875083756`*^9, 3.7132123137053094`*^9, 
  3.7132139733485994`*^9, 
  3.713354365773471*^9},ExpressionUUID->"d3a73a5c-89f8-4d0a-a635-\
bc0300490d3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Reduce", "[", "%", "]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]], "Input",ExpressionUUID->"89877c96-ac1c-457e-9b14-\
bb83068774e3"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["b", "2"], "\[LessEqual]", "0"}]], "Output",
 CellChangeTimes->{
  3.7130919471182365`*^9, {3.7130920267303677`*^9, 3.7130920565816927`*^9}, 
   3.7131039489070015`*^9, 3.7131130143213496`*^9, 3.7131192315393963`*^9, 
   3.7131198220511093`*^9, 3.7131214780834255`*^9, 3.7131824926956277`*^9, 
   3.7131827426841645`*^9, 3.713186897043569*^9, 3.7131869807428064`*^9, 
   3.7131904063469467`*^9, 3.7131917127456384`*^9, 3.713193314097784*^9, 
   3.7131934615558167`*^9, 3.7131988058923717`*^9, 3.7131995234458685`*^9, 
   3.7131998313588533`*^9, 3.713200344801914*^9, 3.7132006968261337`*^9, 
   3.7132103876298847`*^9, 3.713212313807311*^9, 3.7132139734701014`*^9, 
   3.7133543658604765`*^9},ExpressionUUID->"c54a8dda-55f0-4764-b56f-\
a85541739669"]
}, Open  ]],

Cell[TextData[{
 "This means that the reverse transition along the 2nd eigenvector will be a \
shock when ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "2"], "<", "0"}], TraditionalForm]],ExpressionUUID->
  "a2164b83-2913-47f9-8258-6b6f0ec08c28"]
}], "Text",
 CellChangeTimes->{{3.7130922223014107`*^9, 
  3.7130922388364267`*^9}},ExpressionUUID->"f547f943-b6ea-4dba-becb-\
ad101f9a6cdf"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculate the derivatives along the vectors from the loaded liquid condition\
\>", "Subsection",
 CellChangeTimes->{{3.7118858840224457`*^9, 3.7118859280929193`*^9}, {
  3.7130922661402035`*^9, 
  3.7130923302258115`*^9}},ExpressionUUID->"6408adf2-bd4a-4988-ab2d-\
f0f8be6c2876"],

Cell[CellGroupData[{

Cell["Consider the first eigenvector", "Subsubsection",
 CellChangeTimes->{{3.7131517020112576`*^9, 
  3.713151707791849*^9}},ExpressionUUID->"86b891a1-838d-4268-ad68-\
c3ad549e65eb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Resolve", "[", 
    RowBox[{
     RowBox[{"ForAll", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "1"], ",", 
         SubscriptBox["c", "2"]}], "}"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["c", "1"], ">", "0"}], "&&", 
        RowBox[{
         SubscriptBox["c", "2"], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ">", "0"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"eigenvalueDirectionalDerivatives", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "<", "0"}], 
        "\[IndentingNewLine]", "&&", 
        RowBox[{"And", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "1"], "<", 
            SubscriptBox["a", "2"]}], ",", 
           RowBox[{
            SubscriptBox["a", "1"], ">", "0"}], ",", 
           RowBox[{
            SubscriptBox["a", "2"], ">", "0"}], ",", 
           RowBox[{
            SubscriptBox["c", "1"], ">", "0"}], ",", 
           RowBox[{
            SubscriptBox["c", "2"], ">", "0"}], ",", 
           RowBox[{
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
           RowBox[{
            SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
           RowBox[{
            SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["c", "1"], "|", 
              SubscriptBox["c", "2"], "|", 
              SubscriptBox["b", "2"], "|", 
              SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
          "}"}]}]}]}], "]"}], ",", "Reals"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "1"], "|", 
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}]}], 
     "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7118124375299687`*^9, 3.711812588514244*^9}, {
   3.711812673669264*^9, 3.711812687395051*^9}, {3.711812878082653*^9, 
   3.711812946888442*^9}, {3.711812984129407*^9, 3.711812987754466*^9}, {
   3.7118142836971874`*^9, 3.7118142841236167`*^9}, {3.711814371606347*^9, 
   3.711814381378421*^9}, {3.711814506365567*^9, 3.7118145064300714`*^9}, {
   3.7118151810878506`*^9, 3.711815191650391*^9}, {3.711815452660667*^9, 
   3.7118154528637085`*^9}, {3.7118155893655176`*^9, 3.711815593021207*^9}, {
   3.7118175793333488`*^9, 3.711817579591382*^9}, {3.7118176787456093`*^9, 
   3.711817679092715*^9}, {3.7118178708129654`*^9, 3.7118179019387827`*^9}, {
   3.7118847643398275`*^9, 3.7118847774677167`*^9}, {3.7118861345797787`*^9, 
   3.711886144521392*^9}, {3.7118862776548223`*^9, 3.711886282674024*^9}, {
   3.711886373011404*^9, 3.7118863740291824`*^9}, {3.711886435835936*^9, 
   3.711886459607622*^9}, 3.7118868331850643`*^9, {3.7118870490684752`*^9, 
   3.7118870774286766`*^9}, {3.7118879443928366`*^9, 
   3.7118879652064486`*^9}, {3.7118881754474354`*^9, 
   3.7118881777766037`*^9}, {3.711888269596793*^9, 3.7118882729607406`*^9}, {
   3.7118884267354856`*^9, 3.7118884556310434`*^9}, {3.711888725245737*^9, 
   3.7118887329414263`*^9}, {3.711888781557459*^9, 3.7118888023693047`*^9}, {
   3.711889040547867*^9, 3.711889071389602*^9}, {3.711889267065003*^9, 
   3.711889269652336*^9}, {3.711889373642537*^9, 3.711889397417743*^9}, 
   3.7118895075275173`*^9, {3.7118930784324303`*^9, 3.711893079114601*^9}, {
   3.7119053145208254`*^9, 3.7119053147828264`*^9}, 3.711906629037793*^9, {
   3.713093754253364*^9, 3.71309379392498*^9}, {3.7130941338601637`*^9, 
   3.713094134593932*^9}, {3.7130941803644733`*^9, 3.71309418364849*^9}, {
   3.713094269534953*^9, 3.7130943161190743`*^9}, {3.7130950541687555`*^9, 
   3.7130950611844516`*^9}, {3.713097410729635*^9, 3.7130974145049567`*^9}, 
   3.7130975594326878`*^9, {3.713100552103937*^9, 3.713100567369402*^9}, {
   3.713103735128065*^9, 3.7131038030333414`*^9}, {3.7131038519624133`*^9, 
   3.7131038544664783`*^9}, {3.7131049663118143`*^9, 
   3.7131049674033427`*^9}, {3.7131054299824295`*^9, 3.713105443083769*^9}, {
   3.713105954419804*^9, 3.713105974274351*^9}, {3.7131153567735415`*^9, 
   3.713115371786563*^9}, {3.7131158650013957`*^9, 3.7131158698794746`*^9}, {
   3.7131194661791735`*^9, 3.713119498940648*^9}, {3.713123702690422*^9, 
   3.7131237035722027`*^9}, {3.713144341652403*^9, 3.7131443707352457`*^9}, {
   3.713145457090843*^9, 3.7131455121961527`*^9}, {3.713150554644723*^9, 
   3.713150705949434*^9}},ExpressionUUID->"f3ff24d7-88ef-424c-b208-\
fc3977b839c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["b", "1"], "\[GreaterEqual]", "0"}], "||", 
  RowBox[{
   SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}]], "Output",
 CellChangeTimes->{
  3.711814316985712*^9, 3.711814392349147*^9, 3.711814517818816*^9, 
   3.71181520225179*^9, 3.711815306167244*^9, 3.711815464110038*^9, 
   3.711815603733725*^9, 3.7118174175371428`*^9, 3.711817611573427*^9, 
   3.71181789542918*^9, 3.711880812923318*^9, 3.7118845030533648`*^9, 
   3.711884748753951*^9, 3.711884798224105*^9, 3.711886274412204*^9, 
   3.7118863640677195`*^9, 3.7118864269314976`*^9, 3.711886604267902*^9, 
   3.7118868467537804`*^9, {3.71188706052604*^9, 3.7118870848530183`*^9}, {
   3.7118879553953695`*^9, 3.711887979249861*^9}, 3.7118881909203057`*^9, 
   3.711888279714082*^9, {3.711888433568424*^9, 3.711888458352393*^9}, 
   3.711888734293116*^9, 3.7118888085894413`*^9, {3.7118890533917956`*^9, 
   3.711889076217907*^9}, 3.7118892741214046`*^9, {3.7118893832494683`*^9, 
   3.7118893994711943`*^9}, 3.711889516830789*^9, 3.711893084893126*^9, 
   3.7119053240663605`*^9, 3.7119066487484264`*^9, 3.713084194129633*^9, 
   3.7130929436650667`*^9, 3.7130930341816015`*^9, {3.7130937608788013`*^9, 
   3.713093797072321*^9}, 3.713094137741596*^9, 3.7130941861043234`*^9, 
   3.713094334291252*^9, 3.713094651436033*^9, 3.713095844157533*^9, 
   3.7130974257927876`*^9, 3.7130975857458563`*^9, 3.7131005967247653`*^9, 
   3.7131010550283995`*^9, 3.7131039793073015`*^9, 3.713104796237565*^9, 
   3.7131049748135366`*^9, 3.7131054453718295`*^9, {3.7131059574188824`*^9, 
   3.713105975986895*^9}, 3.71311301593685*^9, 3.7131153745928664`*^9, 
   3.7131154536911993`*^9, 3.713115871199793*^9, 3.713119037895199*^9, 
   3.713119232101405*^9, 3.7131194021365595`*^9, {3.7131194675733986`*^9, 
   3.713119484215201*^9}, 3.71311982320411*^9, 3.7131214793504257`*^9, 
   3.7131237048676434`*^9, 3.7131243320860124`*^9, 3.7131331323114696`*^9, {
   3.7131443495843363`*^9, 3.7131443732983136`*^9}, {3.713145458946147*^9, 
   3.713145513807259*^9}, {3.7131506178772917`*^9, 3.713150651800352*^9}, 
   3.713150687091874*^9, 3.713182492957632*^9, 3.71318274295617*^9, 
   3.7131868973145685`*^9, 3.7131869810053077`*^9, 3.7131904066633453`*^9, 
   3.71319171302814*^9, 3.713193314372286*^9, 3.71319346183432*^9, 
   3.7131988061573687`*^9, 3.713199523724373*^9, 3.7131998316428585`*^9, 
   3.71320034508442*^9, 3.7132006971131363`*^9, 3.713210387909903*^9, 
   3.7132123140888147`*^9, 3.713213973763605*^9, 
   3.713354366149503*^9},ExpressionUUID->"d3e481de-55a7-4ee0-a72f-\
1d94afd8bd2d"]
}, Open  ]],

Cell[TextData[{
 "Now this tells us that the first eigenvector from the fully loaded state \
will be represented as a shock if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "1"], "\[GreaterEqual]", "0"}], "||", 
   RowBox[{
    SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}]],
  CellChangeTimes->{
   3.713103727685872*^9, 3.713103979441805*^9, 3.713104017747348*^9, {
    3.7131059368702106`*^9, 3.7131059776464376`*^9}, 3.7131130159773493`*^9, 
    3.71311982324261*^9, 3.713121479384426*^9, 3.7131266479261456`*^9, 
    3.713133136140061*^9},ExpressionUUID->
  "1de0dc24-b895-4e04-8def-88be7aec9edb"],
 ", but we must consider whether or not the transition from the \
\[OpenCurlyDoubleQuote]loaded\[CloseCurlyDoubleQuote] state to the \
intermediate state occurs in the + or - direction.  We can do this by \
checking the magnitude of the v1 vector in our intersection.  To avoid \
division by zero, we will consider the sign of 1/v1 which will always be the \
same as v1, except when v1 = 0.  That cannot happen, since we restrict the \
loaded state ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubsuperscriptBox["c", "1", "f"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "369ecf77-517d-4c9d-824c-0b77173d67c1"],
 ",",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "2", "f"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "798eec19-196b-4813-b4fb-9de0730faf68"],
 ") to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "1", "f"], TraditionalForm]],ExpressionUUID->
  "6b3c143a-6a16-44fa-b020-c9eebb3a0d3d"],
 " > 0 and ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "2", "f"], TraditionalForm]],ExpressionUUID->
  "9b7234f6-00f8-45b3-833d-0aa85807416a"],
 " > 0"
}], "Text",
 CellChangeTimes->{{3.713147222722052*^9, 3.7131472257344646`*^9}, {
   3.713147258049165*^9, 3.713147289882989*^9}, {3.7131473714896936`*^9, 
   3.7131473799911222`*^9}, {3.7131474701173124`*^9, 3.71314752310542*^9}, {
   3.7131475652519684`*^9, 3.713147593575786*^9}, {3.713147698282774*^9, 
   3.713147780953019*^9}, {3.713147819814066*^9, 3.713147829140627*^9}, {
   3.7131478714770355`*^9, 3.713147929678358*^9}, 3.7131479839226503`*^9, {
   3.7131481609574957`*^9, 
   3.713148358442274*^9}},ExpressionUUID->"3d2e3c1b-87b1-40a6-84f7-\
69596b234068"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Sign", "[", 
    RowBox[{"1", "/", "v1"}], "]"}], "/.", 
   RowBox[{"vectorIntersections", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "1"], "<", 
        SubscriptBox["a", "2"]}], ",", 
       RowBox[{
        SubscriptBox["a", "1"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["a", "2"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], ">", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], ">", "0"}], ",", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "1"], "|", 
          SubscriptBox["c", "2"], "|", 
          SubscriptBox["b", "2"], "|", 
          SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}], ",", 
       RowBox[{
        SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
       RowBox[{
        SubscriptBox["b", "1"], "\[NotEqual]", "0"}]}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"extraSimple", "[", 
  RowBox[{"%", ">", "0"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.71314648917799*^9, 3.7131469025326777`*^9, {3.713148129771249*^9, 
   3.7131481571155415`*^9}},ExpressionUUID->"657c0860-4e1c-4ac1-8604-\
f3b530fd95dd"],

Cell[BoxData[
 RowBox[{"extraSimple", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Sign", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], "2"], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["c", "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "1", "2"], " ", 
          SubsuperscriptBox["b", "2", "2"], " ", 
          SubsuperscriptBox["c", "2", "2"]}]}]]}], "]"}], 
     RowBox[{"Sign", "[", 
      SubscriptBox["b", "1"], "]"}]]}], ">", "0"}], "]"}]], "Output",
 CellChangeTimes->{
  3.713146122007246*^9, 3.7131464941097794`*^9, 3.713146908058212*^9, {
   3.7131481305636806`*^9, 3.7131481622701044`*^9}, 3.7131824966426773`*^9, 
   3.7131827466146145`*^9, 3.713186901039096*^9, 3.7131869846718597`*^9, 
   3.7131904103703346`*^9, 3.7131917168621836`*^9, 3.713193318912677*^9, 
   3.713193465577843*^9, 3.713198809822395*^9, 3.7131995277078996`*^9, 
   3.713199835593972*^9, 3.713200349032009*^9, 3.713200701193163*^9, 
   3.713210391971199*^9, 3.7132123179779196`*^9, 3.7132139778562145`*^9, 
   3.7133543699581866`*^9},ExpressionUUID->"c2cba35f-0bd9-4de3-81f1-\
254b31402bf2"]
}, Open  ]],

Cell[TextData[{
 "Now we know that the derivative is negative if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "1"], "\[GreaterEqual]", "0"}], "||", 
   RowBox[{
    SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}]],
  CellChangeTimes->{{3.713146399484261*^9, 3.7131464812110524`*^9}, {
   3.7131465124182577`*^9, 3.713146516887165*^9}, {3.713146564439435*^9, 
   3.713146566565344*^9}, {3.713146913603092*^9, 3.713146943172449*^9}},
  ExpressionUUID->"7e5862c0-3659-4ec6-ab8d-0c14dd3a6d44"],
 ", and the transition direction is positive if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "1"], "<", "0"}], "&&", 
   RowBox[{
    SubscriptBox["b", "2"], "<", "0"}]}]],
  CellChangeTimes->{{3.713146399484261*^9, 3.7131464812110524`*^9}, {
   3.7131465124182577`*^9, 3.713146516887165*^9}, {3.713146564439435*^9, 
   3.713146566565344*^9}, {3.713146913603092*^9, 3.713146943172449*^9}},
  ExpressionUUID->"b4db58d6-0983-46c8-a645-5e5504ec1834"],
 ".  By multiplying these signs together, we can get the final test for \
shockwave conditions along the transition."
}], "Text",
 CellChangeTimes->{{3.7131485378268785`*^9, 3.713148552440674*^9}, {
   3.7131485984861417`*^9, 3.7131486115724125`*^9}, 3.7131486883462305`*^9, {
   3.7131487503327312`*^9, 3.7131487506086597`*^9}, {3.7131488162584066`*^9, 
   3.713148892168787*^9}, {3.71314896119658*^9, 
   3.7131489724995294`*^9}},ExpressionUUID->"ec577f88-ea2d-4aa1-a852-\
5a462514846a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {"1", 
          RowBox[{
           RowBox[{
            SubscriptBox["b", "1"], "<", "0"}], "&&", 
           RowBox[{
            SubscriptBox["b", "2"], "<", "0"}]}]},
         {
          RowBox[{"-", "1"}], "True"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], "*", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{"-", "1"}], 
          RowBox[{
           RowBox[{
            SubscriptBox["b", "1"], "\[GreaterEqual]", "0"}], "||", 
           RowBox[{
            SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}]},
         {"1", "True"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.713146399484261*^9, 3.7131464812110524`*^9}, {
  3.7131465124182577`*^9, 3.713146516887165*^9}, {3.713146564439435*^9, 
  3.713146566565344*^9}, {3.713146913603092*^9, 
  3.713146943172449*^9}},ExpressionUUID->"68cefbe9-bd8f-4d2f-b253-\
287a6f6dc90e"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{"-", "1"}], 
        RowBox[{
         RowBox[{
          SubscriptBox["b", "1"], "<", "0"}], "&&", 
         RowBox[{
          SubscriptBox["b", "2"], "\[NotEqual]", "0"}]}]},
       {"1", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.713146519597859*^9, 3.7131465670476933`*^9, 
  3.713146945106911*^9, 3.713182496688682*^9, 3.7131827466551123`*^9, 
  3.713186901067094*^9, 3.71318698473086*^9, 3.7131904104123354`*^9, 
  3.713191716908187*^9, 3.7131933189601793`*^9, 3.713193465622343*^9, 
  3.713198809863894*^9, 3.7131995277593975`*^9, 3.713199835644476*^9, 
  3.7132003490845118`*^9, 3.7132007012471647`*^9, 3.713210392042718*^9, 
  3.7132123180289197`*^9, 3.7132139779257145`*^9, 
  3.7133543699931965`*^9},ExpressionUUID->"9f793ce1-253a-4628-be11-\
6a3fca0fdc09"]
}, Open  ]],

Cell[TextData[{
 "That is to say, a shockwave forms when ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["b", "1"], "<", "0"}], "&&", 
   RowBox[{
    SubscriptBox["b", "2"], "\[NotEqual]", "0"}]}]],
  CellChangeTimes->{3.713146519597859*^9, 3.7131465670476933`*^9, 
   3.713146945106911*^9},ExpressionUUID->
  "94f5f474-a5f6-4812-a5c4-6c7f54b90732"]
}], "Text",
 CellChangeTimes->{{3.71314952095352*^9, 
  3.7131495385970545`*^9}},ExpressionUUID->"622b2619-5593-482b-b1bb-\
884d464091c0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Consider the second eigenvector", "Subsubsection",
 CellChangeTimes->{{3.7131517020112576`*^9, 3.713151707791849*^9}, {
  3.71315186468626*^9, 
  3.713151866295821*^9}},ExpressionUUID->"d8a92a96-9054-4ae1-bf8e-\
fb69e0dc3754"],

Cell["\<\
We can repeat this process for the second.  Remember that this second \
transition occurs in the reverse direction, just like the first case.\
\>", "Text",
 CellChangeTimes->{{3.7131495667633686`*^9, 3.7131495816463685`*^9}, {
  3.713150748178372*^9, 
  3.7131507916957345`*^9}},ExpressionUUID->"30fab4ce-c0e8-4bd9-88e1-\
240e8de16344"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Resolve", "[", 
   RowBox[{
    RowBox[{"ForAll", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["c", "1"], ",", 
        SubscriptBox["c", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], ">", "0"}], "&&", 
       RowBox[{
        SubscriptBox["c", "2"], ">", "0"}], "&&", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubscriptBox["c", "1"]}], "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubscriptBox["c", "2"]}]}], ">", "0"}]}], ",", 
      RowBox[{
       RowBox[{"eigenvalueDirectionalDerivatives", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], ">", "0"}]}], "]"}], ",", 
    "Reals"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "1"], "|", 
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.713146399484261*^9, 3.7131464812110524`*^9}, {
  3.7131465124182577`*^9, 3.713146516887165*^9}, {3.713146564439435*^9, 
  3.713146566565344*^9}, {3.713146913603092*^9, 3.713146943172449*^9}, {
  3.713150008790374*^9, 3.71315005583316*^9}, {3.713150423258536*^9, 
  3.7131504890294485`*^9}, {3.7131510138113422`*^9, 
  3.713151021905828*^9}},ExpressionUUID->"49bb56fb-0de5-4c63-b6ab-\
6f67fe366e74"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["b", "2"], "<", "0"}]], "Output",
 CellChangeTimes->{
  3.713146519597859*^9, 3.7131465670476933`*^9, 3.713146945106911*^9, 
   3.713150056232731*^9, {3.713150455228486*^9, 3.713150490103459*^9}, {
   3.7131510149305887`*^9, 3.713151022843459*^9}, 3.713182497078189*^9, 
   3.7131827470411177`*^9, 3.7131869014600997`*^9, 3.7131869851193647`*^9, 
   3.7131904108078403`*^9, 3.7131917173181887`*^9, 3.7131933193561797`*^9, 
   3.713193466039847*^9, 3.7131988102618985`*^9, 3.7131995281679335`*^9, 
   3.713199836044976*^9, 3.713200349492015*^9, 3.7132007016606665`*^9, 
   3.7132103924472466`*^9, 3.713212318442925*^9, 3.71321397832872*^9, 
   3.7133543703830366`*^9},ExpressionUUID->"44d50836-97e9-43f3-967d-\
c49637ad241a"]
}, Open  ]],

Cell["Now we must also see if the transition direction is correct.", "Text",
 CellChangeTimes->{{3.713150817664813*^9, 
  3.7131508644727025`*^9}},ExpressionUUID->"58731ffe-1480-4479-888d-\
fb441f630f2e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"v2", ">", "0"}], "/.", 
   RowBox[{"vectorIntersections", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["a", "2"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["c", "2"], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["c", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["c", "2"]}]}], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "1"], "|", 
         SubscriptBox["c", "2"], "|", 
         SubscriptBox["b", "2"], "|", 
         SubscriptBox["b", "1"]}], ")"}], "\[Element]", "Reals"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[NotEqual]", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[NotEqual]", "0"}]}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.713111908008109*^9, 3.7131119335569015`*^9}, {
   3.7131296496339417`*^9, 3.7131296735392904`*^9}, 3.7131499607002115`*^9, 
   3.713150510098773*^9, {3.71315089756137*^9, 
   3.7131509221900864`*^9}},ExpressionUUID->"d9477aa6-82e0-40b0-ad12-\
ee31208f35e7"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.7131118899087505`*^9, 3.713111934307931*^9}, 
   3.713113016843548*^9, 3.7131198292381115`*^9, 3.7131214852134275`*^9, 
   3.713124184604875*^9, 3.7131296511696825`*^9, 3.713149961395035*^9, 
   3.713150510713382*^9, {3.713150898112215*^9, 3.7131509228469877`*^9}, 
   3.713182497097687*^9, 3.713182747073619*^9, 3.7131869014775963`*^9, 
   3.7131869851423626`*^9, 3.713190410825839*^9, 3.713191717337187*^9, 
   3.7131933193766823`*^9, 3.7131934660618467`*^9, 3.713198810280896*^9, 
   3.713199528192436*^9, 3.713199836069477*^9, 3.7132003495175123`*^9, 
   3.7132007016871667`*^9, 3.713210392459248*^9, 3.713212318461425*^9, 
   3.713213978345721*^9, 
   3.713354370399037*^9},ExpressionUUID->"5148ed7f-76cc-424c-b154-\
51cc1e83d37d"]
}, Open  ]],

Cell["\<\
Since the vector direction is negative, we need to reverse the condition, to \
end up with the shock condition\
\>", "Text",
 CellChangeTimes->{{3.71315093089554*^9, 3.7131509316374507`*^9}, {
  3.713150996298112*^9, 3.713151049465875*^9}, {3.7131511560143757`*^9, 
  3.713151159662694*^9}},ExpressionUUID->"176c7bb0-8a3b-40f7-9051-\
6ae58f352930"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"!", 
   RowBox[{
    SubscriptBox["b", "2"], "<", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.713151062745107*^9, 
  3.7131510696427813`*^9}},ExpressionUUID->"5ae15cec-f4ad-4da5-9ec5-\
0fa5aca33317"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["b", "2"], "\[GreaterEqual]", "0"}]], "Output",
 CellChangeTimes->{3.7131510702202578`*^9, 3.713182497119686*^9, 
  3.7131827471046166`*^9, 3.713186901494095*^9, 3.7131869851688633`*^9, 
  3.71319041084334*^9, 3.7131917173576884`*^9, 3.713193319396682*^9, 
  3.713193466081846*^9, 3.713198810299398*^9, 3.7131995282144356`*^9, 
  3.7131998360914755`*^9, 3.713200349540517*^9, 3.713200701711167*^9, 
  3.7132103924702473`*^9, 3.713212318478426*^9, 3.713213978360221*^9, 
  3.7133543704140368`*^9},ExpressionUUID->"e9e4264f-c113-49b8-a93e-\
60802009b73b"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summarize the findings", "Subsection",
 CellChangeTimes->{{3.713151876534219*^9, 
  3.7131518977116036`*^9}},ExpressionUUID->"cf5439b0-2c74-4496-854d-\
fb2959ea80db"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"shockTest", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["b", "1"], ">", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["b", "1"], "<", "0"}], ",", 
      RowBox[{
       SubscriptBox["b", "2"], "\[GreaterEqual]", "0"}]}], "}"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7131520477123184`*^9, 3.7131520605747643`*^9}, {
  3.7131520945895543`*^9, 
  3.713152140648426*^9}},ExpressionUUID->"86f068e3-0589-43c4-8b1a-\
4f0d0022c563"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "1"], ">", "0"}], ",", 
     RowBox[{
      SubscriptBox["b", "2"], "\[LessEqual]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "1"], "<", "0"}], ",", 
     RowBox[{
      SubscriptBox["b", "2"], "\[GreaterEqual]", "0"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.713152052221138*^9, 3.7131521743154063`*^9, 
  3.7131824971396866`*^9, 3.713182747136119*^9, 3.7131869015120955`*^9, 
  3.713186985191863*^9, 3.713190410861337*^9, 3.7131917173781853`*^9, 
  3.7131933194211082`*^9, 3.713193466102846*^9, 3.713198810317898*^9, 
  3.7131995282374363`*^9, 3.7131998361154757`*^9, 3.713200349564515*^9, 
  3.7132007017371645`*^9, 3.7132103924817486`*^9, 3.713212318497427*^9, 
  3.713213978375224*^9, 
  3.7133543704300375`*^9},ExpressionUUID->"8e8182c3-8ff9-4721-8d8c-\
40c1036cb6dc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 6: Mass Balances", "Section",
 CellChangeTimes->{{3.7131580573004265`*^9, 3.713158064268445*^9}, {
  3.7131940445753264`*^9, 
  3.713194044669498*^9}},ExpressionUUID->"12ab9af5-0498-4136-8690-\
cacd96426887"],

Cell[TextData[Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@001Mjl0@0006`00000000000000602000:0@00
00000000000l=`00;1P00215CDH00040_=h501<0000100000000000000000000L0d00:05000P0`00
C`400000000000000000000e302H70D0AP0002`0000P0000ADe6:`500@0L00004000008@`=/10000
H000060000160000V8l008b?0015CDH[<4020100000400000020?bY0000T000060000000P3l00000
00000000P3l0000000000390004L00004000000000000000040HA020QD<Z@000900001P00000080o
000000000000080o00000000000U@000400000@0000000007d0300`0000000008T0400`000000000
7T0900`000000000940400`0000000008D0700`000000000:T0002@0000H0000IRcL>00000000000
IRcL>0000000000024001D2>000dSP000Q30f`400000000000000000000000000@0008U@CTL=2QX:
00003DU8A580009Q00012`P60000TG9AjP00005cDTM20:k>7>T00004Id5=@@00/Hl;o64500002G18
FG<000k3000>``77KjQT002=[4U4@EAhG^fM1GQLamF6EDPaCM^o:OnUo6gCQ/V9hc0kC^:0aI8YRN<`
>=b0TiQIc6HkH:H`<a]UVMU>76IdV_>OMnj>O;eNBB]K/V3?nccOXg__[^k2WIgii/bI^DV6HAR6HAR6
HAR6HAR6TGQTSEY`B5I9eJWYIIDWVT`VTlUT<YTJD>D;ClVXZ3Xb:DVn4k5N0ANE_[IKIUUUSnb:Z_fb
:YK/KC:IC2JCbFAZ>:FE;oYgN]W2RllN?NlG4O/ET3:YlPMII@_?SN`JQV4HQV4H3DajjH:>inAGoBZb
6h09bbiMe2UUdZC_A@hIQV4HQV4H3DQjfL9cTl/[obNb6f0Vc30<`c0<Xg4a4fHHQV4HQ]44V0Tc3<<`
3<=X0/b46HIQ68IQ=05V`Pc3<0c3<9X0<f66HLC3?eFSE4Ni_H0OZGhFK=K:ojU:E4Nh_HJ1BV]GedoO
E@eCGNof6Xi]YjLKQY4`V0TcS=K;`JX9Z]FZCJ[kE<NXMX@cE::jb^d51^QIeM^Zgg:P5/iDlKmG^;fj
`Jb=E2eE[E5=EfFZ_Zn2HeDOZ_;MgZkSQjZ_E@_MG/>0XO]8UNKf3<=8:<b46DK[i4SEij[?E>=DV;4?
E>nZMU?EUe=E6:V;gEiP`Qi@HIBf[D2fic@Eom_3kMD>9XoWX/MELe@HB?H[E<1WFjoZkoIf7IR`]eC?
^KgjLIUZQ^[WKVl[65<nbmU^cc2<Q<9<V66dCYiD4KEQ6=6cQnYdED>H/?X@[`Wc4K>GE7oS@0@RH1NY
L]aNdk4c9VbRR/lFKL8<`dQPc8@IA^^3g:EeZ/e^[fin[68hk4kEKBY<DcBaC=Qa:R8hfmil=RWYL=G=
ZU]DoeJeDmEU`S1JUBZ<heliD0/oEFFY>;N7j=QI`FIB/^XoZX?LG/1_E;`nWi6o_eIioZCZ[PXO0gnL
ohFJC=S_E5eDMjUhgA=D7W;VcU4m[N8kj:U:EafXPSn[>Z]RiHDa17bkjPiE9aF_7hK[a_ojmlMkj:gR
^HIQ]03<Q1U6jhBQ`VSC50_<`38EcbDgjI?8mT>Zl4eUHiV`eeEOZS03WV]D?0la78ZYVQ[I[lf47J3R
>I?MG^eP[WS^4;LG<4_eSXYSo_G;E72lR]`eSWdJnL]WiCF1cl@aKn8ldLMSVC3<jeNZ;BZ<kaLZoVNX
2XQ4lYenZn8hco]6=E`5Uj/hCXCBl`OE<bZ><ia<oQ_KLeE<L_3/[N8hWiWX8NOnKnCH61EVg32<IXbI
<<=XWAbRnUQ5PgbgZXdZ6Z8dZe@dm2NZOZ;JGDDdQOmS=Z@WUPTS<AoS`oo1oRZN@n8jdBc>OdWT6;Y@
EA<Tg_>LGVj_M[`9jnOf0TJ[<3ZH`_=DV9moZ8P`HL0`CbClloWn[[YGaO0WH0hiWmogn>=4Y22F2N<i
A:Yn[l;dl7Z?Z?PoC19A@Xha:H9S6;lmEMjhn^nW_M/;c_6HRV<H?=h_gnoiTF??Zgbmc?Ta^AcWo?n[
h]`HDXjMXS8<XaUS9/``FRn7Z/P=Xd56i2DAIO7@b7?lB[Ng;Bn[R:ch8KYH9XaX3@K7Vc1<4LlibNe]
iE8Eaf^;Q?V4o6bgEc]4kgQ^GkLG@>B7H`c9QNVZhWP/0nR7DGV<igRciO77>kRmn7?2N3ko5hi^HFPi
iXL>?CkJiXN03e>aci8NdC31P/Ol<:^?Q3gXm[KRCBY3bhIQ=6?<Q1U6j`Lch8Ng5Z^8UT2NRV?k^;e]
HNHQSoUe`FXcHCjZPaW0^4GW=i4ka_oFI/8`PSbWVm^[WEPVc2NnKe^I1LWl7?M3Sk5X21=6Y97gO[G:
6bib`CaSEA`SFQDVfXAi`aXMU@=_:;gAm2I/T=_K2TJKhb?LWV4HcAHcHHJA>;3f5XgcMFi_JoB81?AX
B:[W<ImTGY/9Hm5FH9nL:a;W`l@c>i9TLYkCangECVdV;1cY0iJeh7PhUbXJ?ncXcIHW7Q?6T2NOVf71
UJYGE3k7[Z?:4jl9^dW5o]5^Ke]BE3c6n`9_`Z9WSI;/co5L]fLHA[?5C9QQ90hnIf^lf`^B`mT?cb;d
5:YhS8HNhXV4TEA?GQKiDF5H89Ko[Lf4oDE5D_TR]eLkmC5Qc5ST><=l=N4SC>7Q@f069/M[<V4<Ii:S
AO@__0R^=igQ]KohcSWfAkNgUFPCa^a9mYWQ6@e[SO6Hcan[bh@emI8NQV7DPIT``fQml8?nEk2i3NAK
dCQSC826W_e`PS^@hlGb5R]DOYGjN7;2KUCaW0bg]aDo?>LS>3E1/Sc?RgEK89J1>3OH[9i96Hl9lila
o5`P=l/o5e?3LhQ2NC1H?/6m9Q?f0aFc8OTN`WPS5Hj45JTh5Ve@XddH4b[HIdIY=>CY<O703oNJ2C><
5XjI<<=XOK1V5Xg`?BYV7M;0gjYRJ@A<4e4W888eGlEcBN;VohSN_10iaRa3ScLZA6<l;jYHQMl??g9N
UV]hGhGihGEWZgQMoSM/h6:1NN0fACbGof>=;]K1H[T7QSTIjP<O2A_PmP;lk<?XB1<;e2iGlASO`LTZ
9P4`LmBK@YKRH9HWBfYPE35M62/RG?aON8T:?Q]Vb?>DR^L`W<Z<D7;2V6g:/G1>V<oe8Tn;O2mVXh:?
K_TX7>J?fcAa[415Q8g_OU[TF=RPH[Cmll9`7CRnZfo[I1Q6?C4CIQR]3g:d1ZX`B3C6GQR;j:576Vbo
YYPG]m5Q:2h<JfeQ;/:9lj`UQVWb>F50]>X=UClGbeR@EhK9ZB/B1QPaQ^kldP/8<dBDc:oncd@2gP^V
bT?^5n]aALln19JTl8^UNTeAQAMW9M8GO]oLHPQ3R_Wc`goLJH3kL3k/mP:8bWTSbg]Rb@mFmnNmQ=LM
Xi;eBdlP7jGRnnCo`P^lHQam3YTGiXlef<;/YN9o`fHDb3_S>6G0<8aVS9T``fRm4:4RJ/@<Aa;8Jh?4
MI;1^NTg`fcAH42hUE1hHEH<CgBR>G1[7Z9ZnkVm0<aNM<9nKC23TbDf69j;WVe9_LAkHAdb3iDH[n6G
WHP5>G5lAYhGRenZX]lg[d<4c4>T;M[X<FB;^NEooON3V@bKD`oWiW?iLo9lGR?F[JBH<<7M1YQiRC6;
QSG5R;i5g`Z9hicCKY5T6<dL<f66HAR6HAQ=P9T``c0<`c2<9/1<V64HQV4HAQ=P9/``3<<`3:<9<1=V
68IQ68KA19P9<`c3<0c3J0;<Q1V6HAR6HC@1I/8<`c0<`c2J03=QQV4HQV4HCH2I<<<`3<<`S2K0C9QQ
68IQ64HCH2K<<0c3<0bS2C0CIQR6HAR6d@BH2C<<`c0<`fP2c8@IQV4HQV4d0FK23<<`3<<`VP0cHHIQ
68IQ64f0VC33<0c3<8`V`4bHHAR6HAQ64f0Vc30<`c2<A6MgeGk1iTkc:mFn`FK]V0Tc3<<`32>A>D;e
T2[;k@DLZ;YFMJD:PeHCNj^^DO5Lc1OlBCE>eMO]eH:I<<<`3<<`4YEoZ1J[SW9k0BNXGUNMZRYD?JOj
XBZJ@eGcE6NXnZWVZgjVP^nX9Z/6^kdJ<1=V68IQ64JR<T4E7K5j@GEW/9Wd8mEWZ[?Mg[K<DAD7Vhig
E3f2CLL_EJ]DOgMk<C0CIQR6HAQ68_9[eA[E_maN096/meE4]c`;E=4A[MeDVeCMg5k0DjXa`FHeA<<6
19_KHbK<<0c3<8a4Y9eZ[NX7KRmP;mFGZV?LG/3CZXYP/iXmEInXcW5k0E=E<h?=JViC?Aa/KXnI<<<`
3<<`4Y5DEJF:o2g??eEOZl8iHTBhbX?=JWj[HYRbXm/;`8A=3cJ[^DCeB[2i?FK23<<`3<=8A31@beAQ
[l<@9NJZPm/;V:^:cQ_k/NXmEENg5o2hZRcH[>IZeH_1i_JH2C<<`c0<8a4iB4ENUioAj5VZ^R?HM4>E
KjU>M7_1lQ?N=9707dk<IfPc9MR/QUbbFL7VmYP9<`c3<0`S4OV9ZTYe_=_KBYYZXjZmJZSZ?YGWFEG_
H=<]HO6VjR`E^El?Z<;iID0nfFG1i_JH2C<<`c0<8e71?4d;=[N1b1OA/0]Dc8Cd;56M7f`jSUCa?7:o
<7EQF0BFhLhmg5h<c8@IQV4HQY6XT=_eV>X6EJ`5FL>`R2/9nV5CEQ?L]^QE5E6e6S4CIQR6HAQ68T>T
:TMe/M^[6Fi;58l_nSlEjhFMh_IZ`DbHHAR6HAQ641E[2:;c`V[4C9QQ68IQ64HCH2K<<0c3<0bS2C0C
IQR6HAR6d@BH2C<<`c0<`fP2c8@IQV4HQV4d0FK23<<`3<<`VP0cHHIQ68IQ64f0VC33<0c3<8`V`4bH
HAR6HAQ64f0Vc30<`c0<X`T`4fHHQY5Ho:n:V`_o>j:oZGIGk@X>EafUn[kK<h`4YcFI<>incPOiIDAD
:[_boOlT8Z?UTjc:RhRK^_ICYJPJVa=EheACECeEge4IAT?CAoFDjTWEPj[=ZY]DSLU_E@n[WUD]E[fZ
`P`J[@?^^NSKG_ACeGME^i9]SD`;XCFI/<jZYeED;?cHGeN=E3DfO4LmE:]E5g70J?6LX;YNeD]eRNY[
eEQEHo8;eFaEGmF=Z/mESMd`6XT9i]hKO29RWjR>MW/1g7chEl5V=N4>0FDe5W]458/oZ4h?=Y=nY=ZX
^]?]6Jd1jT_OoSjTFZPJY=YEU:_XC1cRmUX@[LV44OWj_NYg4KfQfQDolS]D<eB;E;M`X1WCe96EGMdc
JPP`I6nZJ4B0g`AVVn_^6aGhXnY8eMjZojS>EHGi^NXb5LJ:idC3NL?Oc`3E:l5VZj:;jZo1IX^4R3/M
?^ZJe/1;:Z:m7SXN77]>AIC/;b[8E1FYR0joZ7YDmF^EQo;jQ>XI5I6f^Z3CNVf`fF9XROGG[P;ckM_O
_j_XA1:Lf1FLYUZQfZ@jQ@<]RMJJ4hHIZUCimgn`JYKZ<MDdeCmD/8mZR8YX1aG80bYOjL2Y:Z8C7>n_
fTdEcOm5oV;4NPNKc@i2aEBBFFi_:gcnL4GJf61XlUGNd3AgOZIjFgF1f`^nalLSbUF]E0eE0FGUOAF?
UJPnD5fQ0XIRJ=QXa>iB;ENeEMG6N=G4H;=E`7MgWfZPR^6:UPX=LKX:Tg8X1eX`U<l=:R9C`>MjAdGN
5PdZ`n94=X0>Q:S>Ei53AZNC^Q>^DCf_`Z3B6EjZRSElOjaZ/0XC=id3;@B<1OGFbFj_lL38D2N7lnD^
EM6YJdVY2FDZjT4?aXPfU?JG>/egH8RndZkNX:;mWJcJDnG1n?=oA=IhCRaXTaWJCUEAaf;8FQB]dHCm
BoFUbSMbOe8An^HRDVWB@>:JZC08GE:a<6aiS8[NgOdZ>5158d_5lFOE2j[JNWSd6Vl?=Y/ES<dc?8/a
mLVg_e6ANl@?P1m;=mF^P>llFlF?QHZl^D>iX;7eG:aJ5V`j3U1mYZ;RX49iCdD_40S?_aI/>^?eB;3Y
h;bHmYZP37nTJ^V=O1P<j:i83mQEW:fJ[l:X]dC8aj;/]WMk0MAmV2@?4D_:=0KjLQGiG1hjW7A/PO`b
33JAS`]EleBUZVR>D?5o=<@_ZeY2PdWkPL6TSZCnJRc81keGAOhYaYL94l2`<6Kg7UE;V<a`_8[femO_
]:>D8CZbe6L4=OPnhB`EkBnAF>Y?S3ge150^UjShO`8Mi176JZM8gO1e:LnW<mbRJ8dVS26L`V3C@F=8
cb/<YX`I>^A3<8i<3P@`_5@EK3Z3P/<nBDEU@Dk@0UE==5LCA^B1Z4XH2Ve1/>T:naNZGAVMHTR>R6Ac
iSPEUHV?M09UX2;H[6JmR/H5/cjG0a68>_[b@Z>3lJNQVZ:R0@ZGdC3dQWU^JlX7hgO6mmBB8f2aX==6
U:8U@ZN0ASl<7@kZB`lAX7MEU4TR<ShZ1YPY7lfRO^Ggc7O1LHHIJCa[PdhQiKbiAgR8c]`JK3HJo2kF
ZQPYP34ZlZ_2d96n<]Q/]]2>lSW2DB^6[hVXNS2EV3;JV`hZL/LlS4Si50cZC=YDXXlH:j9QLeAQ28k@
4O;iRkCMY8Bd:5ZK2B=TC_i>N9KRL5Fh400GoT`ESL<jUNoQD2SXa@6>W8/j@TDX6]=2;TQ==4LCAQhB
TI]`QLP?WV4cC0H`5<5nm52U1f=:Z=NGQOeEV0jP]mIM5CHZlD3dP0Yh?kOGo:0l<:AbUM_K2^G0moj1
L/K`3KdnNX1QTmiEA@D1E2PCE7a^XVInn2LJXYI46c3>[HUQ:Pa;Jh?L@7[O;FVX2<S;Xb<J7EUQU23L
n3=3Uj5c^5XEOXalfiW1YS<Z94KG1^DnW=1?9h?XAW?nkXQ8DgmBSg[XT3=/je=CZ<?lZ</oEMB7?QXN
;ieD30_k>YKQ>cZ0Y35hcU3A=/E:RFT^4;4SVQFnYW@jJH<m_7o:7Vd7KD/h@18fHI@]]XVBnOJGj7<H
S[fU`_aCIf;^j5S@[[LHFY<9Xb4TOlLK10oQlEG1YX?`<_Tj^>R3E1An`^e0@OL=ilfZL?Rm;VRL[`/f
V`eD62C0QWlD63:B9/Tml?3mg1I/KPMVHX_:mcH`Vmj8D=RoEF50jP^mjW2_^cW13i[_R6QY>aE3eGaF
]XTJT^m21DeTS4AT`=@cO>fQg?Um7R?RB[B<ka43S9T=`e0a<gXYOhC]NBg:/XoB]V@HUPeOJlXSNB5n
N1chW;hcA4N1BVUW6ac<;PeIn3_T]nk[=O8QJF1ge0S@nJ03hg=<F`Yd@^V/</A5E9cO<oUQG1<jWPa;
SU8A_JA>18Im`PdV`fI49h3O1VEmTXY>:d=>o7K2D1MQ^_S=414VRI[QZ>H<WK3X=X3>jSLZ?g;0MdNM
29@77Z]_kQQe;idn3lJ>li3;k:6LlYdeEh=aV8ZX:Ne[V>P9A]AY]==d>35EhLL8XS3j18`hD3i[PgZE
^YYXFk7Z@aGVSCBA5T=[<V7dhQQOaSFCSd1b894Y@^TdKXCOZCR8EU1A08d[5ljK/7=D_^6TidJUPK=V
aQ2A/ERA/3@E[dEUc6@0W^LC3i/JLYQlGY:7bY5NE[SQ82YEddaBlT;hlF=JnIjX_7d?V<Z62QMlPlWg
CB=JEoh2dJ6JQ^BJ6RX>l]K80fCXT8[1moA95RFWPLOYiC5T0iPVXUdNNWWTgGVh5T@BB4jU;8JG100Z
;``HnCFl;YDCbJ[No;IDR1IBjO;KlU2_d3_6`7X3a7M5@`ldcWB>M[K1hCO<mnTSRiPb[Q/=1]1cYfkH
DK=7@d8T=7XVK7>7b0ge5U4KA;j>ShccnbGiWQb`L=hVfn6Q7Z8nKH9=1mleolM@5<=7dM5N[S<9o`aE
4_6P?VW^d4h@i@]3;QdckhUfdFVPW98l3_bVZA_i[;i<lIbjfU7bl<9AM6I?/b`>giN7nYBXI7<e[QSb
CeDH8]onHV9Y2fUCZB]9lB6bj8L[ZD]mnPl``L>KDB9US59a7][OdJZjl[fh5WAdFaB]bHCa0b0BAA8d
2OALL2XBX;;T<D:Kig4P0[eTS9GoW5@<E4hNc8Co?`Y2[<D5jBWBJ5>i43g3c93hgQbP/=>PQb7:lYDZ
g<0A;J/Y:TGUbXn1BYRTNXb6ShCAZbEW3ZRDn25R=PR_dl>^[DM2CbM/DUXJU:TMPDH^TN0gANE<QbL<
@olHNQX[8UFDBFo:bHfQDJYYf;Hnd4?fSBA6VHjJCdJWlB?R/j?@<5;aHbZ<eTN/>XZD0XKC<:6H2>Y0
ga75<?RbQI6R0d1dT;Z@8N2J8>N<S[27:3TMiO1X1K=b6OYV:;@i`^NV_@Vg_cjAW_J@J1mY2@beNXPL
/S2fQcJ9]/=3gL5g@o];U8bfZ2IX`kTN;Fh1h=JHV6m/9D<E3W<3TAF6fWb_P^PFHNBJIRYA1VP@<EL/
94XDPBAAc^dSR/3@3/<EO^RWXlY7RF91aMGJLYn<kMU;aF:PhJ4E81F022^=2fF5G18J<L0haM?H49VY
JnR1cXG?IF9]=j89=8Q4:aQ62TMkXR4jBIB8hNM`ha66GShmN:?ePIW`@jiQZ0oYh?<haX68=FD4/n1Q
^99QGnY531/MfIY<11eoOR=nA8JjV3Xi?5a?QhCQhAHGjC5ZadaHjhHN5CoLj1F^<D1nYPW34@bknZP3
aX[YdV78Rb2WRE`5:PZB8EWJ8[c66?o3l1:m]gPR0`bmQJ>>A^^4WRT=C7CN88dD<jUH9PHcCZnIG25<
UAoF9DXF=TWTaK0X;XdIBO4dLWGU5I;3@oW5/=5CI`RBHA9b7Od<E2Y0Wn<3_0IAL6KjTI1>SiaQoNQL
7mhODA6kDdK[Q56Cj4Ac89nE>Y2bBQTPXX/A2gLjbEOb8`JD6oj7^Y?QBCXKhLh3mBQibWiaDbJBnJDJ
?1PiXZjeMFb=5XRI/=H?DH3XD3R=f=dZlYc8c@YG2?C0XULjY];`<ebXB6SD`Z_50`dJBf5@nMBfWQX@
5B4RdE;GF3;RQdJ7ARZL1P3dlYW]AGhL1XdL44`E1Xc>0`dO``^H7imcQLW7?36TRc5R`Mb`2F?HPn7a
l<[V36eBeRS_U7_B1XSH<_A9ah=cTD90M8?6T>PGNBZl7ioG0n@64[4;`fOPmd:I=eXOi3=BMZ8GERKo
f4NmR?cC8Hd^6bc1`BP4QXYl:7nG3<XLnEkATEEn0db880Y<^Hi>Mf0h;gZF_m4:<1?FnR6dcHB1F7UZ
hBW@@;B0]H:RShO;0HeSM<l@R6:4Tjm[b^OQG3BV=XBC>32A8MK/Fo9PO3h=`iKTJc6[52QS=8;TI=:P
HOZS5g_5B8E=60J<XOJ`^JOahk`<Y`<M36Kk<[/EJ4@A^C_TUG:o^nQ>2<J=2CYQD`H<AC4]7T=X]4jH
=D[i3EokN>Y331>MGg:N`WL7X3=2>XLONPa3ib6jkPG:<8J^[[GGS1I8PiV`U9A9?cSVR/9CfoG<jM2^
ic1CTbRW0mN0Ja6i;1jR1``oe[FD18f@KicZ0c=Pb7TPchbQ71Zbj=Uo@7@1/dJSFR?7mGkbnlMMGWBb
UJFVeO5G5IefG=OA=IWYn/0/iO2M1c`Tb_/l6@aG[3:38B8BbnfQ]ZfXPWF2`/_2n5GM`hdRSAgUgQlS
dQG[9[o<ZRIa>7Z]?bK^/11Y[8JFbC[<[Z`GQoH^oLVaUaNM7^/k=ndRGJYeiNE59oK^;N6XJDd@iFNF
I;c[6V;:ROijdlB`^ioEB0B<>S9NF<J1_;AJIdEJWMTl]2=eIX>I/4<cN^mibTegOi]Fn;XTikaXJP;a
gG<=^1JAba:69BW2DlXK4/`ENC4<bb3bNf8EA7YdOWV06STljhXmm7=lWUHh=nKW=3FnDP]NToJgCYJf
GO[FYl6X2AXU6Z8MRAPABL3PAjn[1TaKmhJNSPNcU<<cb^X3QXkIK>7IZbcW`W0nNFT<fDN_OLD@IKgc
`@kY<OSo>_BNk[kSF=nmZO6EESAGC[UahPMoKgn5Gi^^;S3^e7?aP5TSl^ZOSh6:7Xj?5lYLWKm1Zc>K
GS]JIcJH2O_G>IOmZ/<M<ckZ=V6mM1jmg=@4h[_W6W0]8YNUAK9g^hhojg3km;NkCKBbe5CZ=V6MW77W
k<l?kWQI>65mIb32i=NGZ`oLZRDl2aLH6V:92j:Z34Tb31T[DUDOb4F;G^n;a7b6Bc5kA9;3^Eld/YRf
N]o?kh3TFoifAYligo0Mao[^CHd_jYKCKi^f8NW_OhoGQ3E[[<i/N^eXWMVP9^cdg]<ok39VUFBE;cHe
POS^^@J]`HAY1OUFUk5FUYY:GLJ/U0igc_b/0DdHH:K8jhZEma8;XU_Thc1/6@K3iJO_<ic4D>K>@>B2
aG5[JY33@eJH;VI<T]Nc@kUPcXCM=F/;gg6/kmkDn:9^JGoKU?F]bHAIWMVdf]4jddaH:i:I<5=3ZI5<
6;2DBK`;:S8db78B/I:H6a9VjoZ59N/2HlPTPAenCfK2VUiV`T`=;C=QYYY=V<S>3]G/DZa2JG[EF:6d
/;;D734Ce_BZdHBed?9]MFKCZjHj/gO_g[E>oS0Ce^9D9IWUBeA;9J=lFDA;gF?>Q=dnkB>m7:iRjE:f
N5l]61FY5O?SWMGCG?SQjKM=gF`EBT>ZB[DTD8FF5nCfHcdgDZ7L<N_cGoib;aI8CLXXGOR_;^=FUFFF
;nBfElI>l?Of5ok_6GO>=1?FQ:XfHA4XemTSUhk9[5SlUlRQU/H?fe^MfJCb9Tb_QE_SCN_HTc;::b_>
[eQBjgZHjJFE7F>J/:cRQOFm:Nf?fmlnm@<cH@dSS5I6nG99[EPS:ADK9;URXfZCJ[fTjo7<//GB^Fbn
JZid;Yo_oXM2X4KhgK?k?WRJERQUfB>GOG7Qi;LUZjcZg<bA2oMZ:C[k[__g?n?>FNmJ8kDS`V@]UnbA
ZeE[8eZWaeJkac;;:UGcWK;:5TKmkeIe6K=2:i@I7gFhLlhIfJ>G5GHN]NcCRjJn9nUUUAVa[YTYOYeb
biAScnckh3MMAZn8nMgGYSBmSWC0//X[]g_<5;nXFdjkKO;Je;aGC]Jb?J7;Z>GOM9nh@K97EIhHjiXe
M`Eei^cjeiTE?;oVcYPYO_5keWK[hhh37nn^KNl<4_Gen9NjOF2/JhJjCebgUgI`NfHF;N@>7E/ikTWi
OYHnX0lNUe5BMFAMdTJnkEV3WfaoI]l7?^Vl0aF;2EFY^EZQQV^mM5:cUEJnD[ZE_RbG5DnG6`/;YGo1
3I:OWbTENNgUk]c3IG;^_S8[mjob@>jOI7c^TO[oUM9i]8^4_I>Blf:N=YcokC7UGNTjKSD=iaGIiIG]
FhZBLehhmjan3giPIBTNEKV:]=Y/HMj;WiOdPUVBUS]:DXKeUiC1edW:`8/T^GnVZY?Z3>WDmdA97Wb]
oVo/CQ?OOHLkIWc@JLBcNMVSUWm=FNXfOYeTUUAN6n^JVN;GfH>Ok7Kf`<NnHDIE[>nn9]4A^j[TG^UI
nXS[X<EjSRTnDKkKgcIUGG[QjdGDTCdV_j^oWjFRejMkm?EZ2G9eI_n7jeEWDVMT5<kFn^9Y[@N2dACC
ST_=_9cIIoHW:GV_?8`1XlkDhamd;Zlj;mHe@eg7[FVOE[cXn9S3h5e7;oU[E^VR=Yd[5QmLUkAgOE37
@HnML6JO>FK2jRV<5iE[B/EJjEkjP]aHE2@SlW_8a=bSi:7L?NGIo>o9Z`E9<ZlXBAHD9lW24UFYKZ>b
9:UBcLWiWFBEZ@TK^`HCaSg8M^/lM]FO/dH]6JhGnL?dX/GA=dm^kWbgoJeC;;ANXc1NZk@BGJoKbbBS
j0U9bbUFDgFM6ZaDBNikW:Cd?DaBnndWJOggTo@1ndW6`?dUHm11ZX<ULo2QTS5PKdTNd5G?/bKZg87X
DImaala?mE[/O_kMjok@NMBB@EZaO91M^RQjYZ9ACgjcgeVokG3WS7X<AeK9NAE_b[F59O;@l3gTbY;9
TUK3MC?59nXF8V5LSjbR1G]WSeiNTSeZfLL]N3Rb7WEVUMHM6kBC=U7>_N<X=F;g^hiLk>NJhQFoi`ig
c_cTUg_]mO?>HiLOg6GLVTVIiH/gM>fmYR4F_8j3gokfYne_WfHiHG68XLKDRWG>O66lNQOfTc6i9l_3
^OlS[nB[^E;3QMW2I<d_E`>VV^^Uaeh?JJ5ZI^iO]YZ`Z<Cli8;:_bN?W1^ndGJcai9<Je35/R3JEK5L
dP/OUYBQoMAdYD]bWkJBfSMR]]AXI@iY8eU3fjZ>M<XL/[db1QhPb@<_d7<aC;WmJdDZU6fBC3=7;]/[
_GaQ_<];63E@WlAljPX<f?Ei`fGYV>o;/S59LU7A73L/6N_iY_Q4gA;92J^n^dQFaI:m^hiNlh_8KX/R
oSYcRC=P:L=6BOJ8`bDki`Q9;gSDC5P3b=NIQicFPc_8>;96E^icDNU[>k^4CWaHHWkMXT9=[]PPZNF[
iJ[RNj@h[i<lX/K[m@8eDlEZ^=A@NL<E=UZeZBhCeQ8a4aHUUn>eGS9;id[ZR08eGQUZ_=Y8J[mme7@M
Z:KZl<1/eF2hHVU7C9SA<<A[`/Sm>Zol3KTemdiW_^Bi95TfHCNi00>^WCPG4HgaOjJjEFg24VV9RPX<
f7Y97YZ_1Zb=m9Ya_7@]>47B2YjD[954EZdlkHbJ_<hd4eJkR7bUUZnAj`_;I7c^/O92GV2lR7K5RW35
:c=Q[EPEBbEke7[9:7deR7[e?DEBn`K6:f_X4CE6^N:AVK2VXfhCE^UV?GLZgbQmLZjE]N?EP3f[NSi9
:TMoCbk96B/YYB/U^Fb]bam=[EQ[>F;eE<:I<3LSNZdT3ahPGO8>TF^VWbcGcSa=/W>>EU=f[mHa9>NC
h[1>YGE2aK;]cf6ZEFK2VZFXC9NkR_:bhVTb9_LTNAWcEE;oR5M=<Q?F>YF]?M?</RY97Ci2>_DiDLgG
_ed^elhH[k3<Q3DM]I/`[C<ZETQbnCXITW>Q_75ga80m[GXVBMjITBB_SObY?5Bj]h`]>4Gji]dPUnOO
;EW5[jUY2fIATfNjoGU=HBF>2J_DgcP6OKEd6WR[M2/lA7[=>4F^VMINSEQkjCWjN<TNLIaT33]7DPMO
Y9fm@I:J<dGBReoEoe_SC5W`on5cVV;9C5RcDjF;OV6>Q^IM8/oVO]m5_S1O[cN0nO8b4mKJ50`IY1O<
UTkm>TU:]OUZ5m=<kJS<Q3DM=I^`BTV_F2DYIJ/T;bM=gYVTa^^iR05k:R8eH/jD/Oe8TWbRYVc=a2Ai
Z_B?DYio]]bD=eBj5;oXXVP<FI82/Ne[V51RV30<f0[]c2eG0mI;cRo1P9dZEj/1^g[ZJDjme8RiHe>?
Ub_^>DYjSVZSA^d8=FG]9FG`II8b[5CBRekBlc3kV[[2QRa[TYV`IZI>5Fo8aBD?b>BLoFEn@I1P_j>A
;cMLZL;0LAk4<6Kek<SLgi/9Jo4:NZcIJXYBQPfBCWLMhXcBCTFnm7oiod1]9F_84G[lL:N<PO^Z2N]^
9Z`9Z<V4<@BIEKY@:W9?U`nWZ/W2P7Wc5Je8I<`I/XQAnnJQ97U;SM_cIKnFX[`d^CaoXZBF[GCA/F1]
/Ff_LB8[<DcHD[LNH?;0BjA7nB5^n=6K[ePR>]I[1V;kA;U/hY5b@NUQTSW/53ET_B@eMhJFXaEZa]KZ
^LgLAl]<F;=AUEIjKlQeAFGbJ<h_G?B[?^K;6bi_]=`/bB;M;dbBEmC<?IN__Mjl7lRS^CnG1mAl?Ick
6kTkie1mGC=Q;ELH/:11CQihQJCdnKLJYCIZX^XAoJXfFfZdF89Rd85^]VAJ_gdU]MonT];g4=GQT]bg
WNYX=GT7jf]M7>WMK_nNc8@e7[5<F:KF6dcH:AWA@Ck3P;fPRVFnJQ>V34>VOkLlT2B[9RC9U<;3i8Jl
4I9J^/a=2^9e`]LiDID89X`>GJL1el[iaOnFjfIgR6VlJQ?3UIRbJjJM99N>?d:ji1dQ:H>jB<Z8RA4c
I/^TQ6DV[9V82=S=QL?U^Ic_^OFlhS5P?/[5fUl;eG0aFo;Y_=eTE^kOI4cNlI:COkkLEG2kg51H;5LD
CiJN9@m;mm;WYF_Y:jZGYF_IZnjenNk=Q;DdEFYU^L95<Y?kMe73m2lG]HYY]:;T8e`IP`maQX]e`I8a
F_gJ^cG0DPIO;jW31T]JcRQ9ci/TjHGgBdKaDi9AlZ9Kd3FcU78C^e4f4mIhe1@9Bj]H9Kd:AlWLRYn:
?1TaEK7<EScb4K;7TVCC?DTb]N10^BJoc>FJ1L]K9?J:nhUP`XR/Ia@n:VV3fl/EmajUQ^[dV6H[7PG3
UZOYNMY9eh;396FPeUFi<o@eO<iHHYLWI2J/6HP4o9/;LnCig>nj:5IM^EoNN17YNS6?g:jo^F64f`X7
ZM5jD;;;iV__N:dKC^2FAMbnR=/HDEVCO4_BOj1P9X^I/1HX:[0b;C/3^TQJ_glkHaG;L5G;6jm11n_c
mi7T?XNXjNZXQ^]J=E^U[]9U:@/GFH^/XQmX]IXmoChaO;bVDle3E6K26XoJ4_<kEK`YEnEGb<::gKH>
>LHbFO6:LdC<f9[aBE:ANjId:g[:eEF9W=nC42J<3YkF0FWiSdWJX1?TZTW7Z9WJLB>6R8iM>k>mG7i?
>nVLLh@T3ka1>gEcgN^4_mm4U9V`9UFU^md@<b2Ob_VABiJ?IKZ@SgXaC<W2[3?DN0g;kbUG5dmDdkD`
H[Pf>Z<EV:_h:dXcHBe=g>MaUEITEdLRH35<EdA1H_kQ;^:Eg>LPhOI3ZD?k^`AnkPMIOM/Rc9NKG[ic
3JbI/<JS=Q>6F9ce^[`LFCYJcA<V;9bHcgIh?ei5QRZoOR19WR_i]IhoGcZEKh[D<HTGaDP<4hJX6mI;
J]i/BAml]5`eiCQWY:Y=eK@P5ba/]>9A<5AiZ_@LMJRT3SaCdW9W^MM9J6=_9ZcYA3@Z^fb1C<oIbnE`
aAb239V_io>BI6c^lFihTI/X<hC9C2HOdMYAV@U[FG:Eho0lU`=Fha2T<em]G6iGLYlS9GW@UI:N?dfH
mLKo1cUM3IlTJbJ/lJS;Q=6@HLA^bKeCEXmClnBGZ50cmMlWP[oE`hfQan8BcmNoW7M0c^FBG;I6<Q9`
>2UaC5PPEmOTC=;jY:eL<oF4JR=faGfWb9GgZC6KMZ8KKW@iH26CEYMjcCaMoomXMmkTHFFBADL`@I?f
cH@eXAPZ799oRI/56L^0^F57=FL_iBK9Z=aCG5hG`hY4_7KFN8EU9ZcUR3b`S>9WYE<O[L067kZmnA[B
CXgI4I;FOeoYM5MKBAUbRckoVLP@8`VaSE_AV@U[?>XfHOifAFo8GCWGblJ9JY`RQV_Ua>o:HdFoThES
ObbK9bG9Ug?dn>>ZB:@[[^5;C9^NjigkTR@_9cD`HVjael@aHXUV`Q16;6Gh6<TJg/HUfoNJfEjji1l[
b@<jjK4>d[FPWOBXJ>=VAEj]A/fK/Z^WaCIPGYPfC5cWW4<TNLQ@mcZ9614c4mI4BRmO9ANF?2V?ioiH
5T@K<=gWETAceIa=bSU0NQF=4FkDcM1UHlaB<Q?FL/C@8HWcJOf9PVdk2i9mkP6Ig8Ne_:j@S::WG<FF
_@__kfHV[?68ah@QS1Q3QX=b;iJge339BdVbN=a^LV7N=9OGMFenT@c=jbVC2XnDedK^kYJWn>I1OIhg
I;E5b7S/nBAiOhXJ/E`eH^F/^YlhbePTXPU3g3LbNFRAM<hmE:jKMJ:J/><U=NmabBQI::Vi/bEUF9kF
BeM8n]0ce9@M8AN?>Eb^WZ:6C0eKKA4b]kc5m9>UBjhJ/J5ifUW4R<En3jeEI/:JB4C11^EOjIJ@24O1
f6IXl^VL7dSoo>/UXfbYRg`eiQAa<f4]A1G;]M9k@I;k7Z^VZdfD0F^[aV`OjMBg_JCUgJ^Ei]XPXCkF
NAYAI/8JSgQ=6<X/GjH6JKgTi6C:9m>CI>GMgi<;2an@CR?OM1=eB;1?:E_YC=V=ND>U??m<NJWl5o:N
VR/G8J/[>ZI6k>ekTjA_kUFAI?gHkj>e:E5=614ZIlB639G^A@M9eoaS9:gP/DR4?KQ]4B_UTfc?l6Gb
h5_ET7FDk/F7bnEg]g=iH<bD[<V8GC?m91MYBaeaCg2^A8Z^VPWKmJ:WRZKVk^fFX`PK/0G5BC9ca5oU
R^99F[U]SP`k=Vj1=1?F<TCUU3ZRB5;kkZ^VJj/18o4nAHlU3ka<<T_WABZaYPW[V`U[?>YS`U1jnG8e
FZ]UE7h75eFoY6AFI9V9h77ZX?B:H55FKUgD]NPi^BF__d`^?4aFC`PFLJgAS4F69UN<BI:[lTNjLbA2
`iVh9P`]dHkM>TTINXMd^W<obBQj>9S@4gh>mjdUkD7[X8bB1EYOCI2D@AM8imbfL^V4]/j<aHZ<LNbZ
bLM9fZ2C9;gXAIMf/LeiFk7<Q3F1Z0QIBX;5DeUL]MZ05BG9_CT7BkOBUebT;=Ko=XK<Q;D<DKVi1?/1
nff=P0eY8lUgkNM^e4e?e2dUdHB=XIV`aZ>n9XabT5jnDS;:ZZ@lieBi^^CNKDaH]093]/V]U/nZnF?c
CY6Ehi;TfdODL<DJY/BL?I4T3aKnAC:e`@gb`f:O^kDX/DdHH^QiYJ@<_Tdb2^n?e3NaWZMbQX`U:5I9
J^hLkBANjYJWH9T:=d`I=K^BmLP^6J_efJ2[PkX/@O;3c8@ePLS]^ZV``2de@O:m=f1gia`F[?75@WJk
/24e4mHBA?Ad/BCgCg5[OOT8F?9Mnd_Zl1b]k<RUJ?[L73=QSDOmCAP:S5RGlWWB_NaU5of:oKb]hSWD
DNAkGI4oERKU7akTUTFRGm/H<CEW7da9TS]bKdj8HDTcHHQjA/^A]UGa6BF6<]GlZk5:cIdU:@>ci?cR
@nFJZBO9=E7[Sa4YbakAE];biPCo4o=l[D]V`YY0Q>k_;;Q3iQJZ2J/8IT1>cMUK^YBm[PJ<W/>^SFBH
2F/1dUhURjTVmn/@^C5gFdWY/jnT31fXUMD6ODkcV=i]9Zcaf34CQRYMFT=mk`=97RZg;4X]GB6gi_JA
Ul[fT6lN3XaG]@W3V3fI98lDodTbBnI7dRMRWjleb4bH5oE=OB=EV;4ek/KP9>5W33UJ[R0Z5UZAWeVE
g>XXIM2ET^fRHK7>dk[DjT`HdH9Hai^CF=m[D?iE;RVOVI6?in`^5aOOkbZlWCEP>o;icHC5YbH]FaGJ
R9Jl9<UmSe<3M[QKPX8L/63IRNHc>le<F>>ahbH/d8jFGlcKNAFKiOc2AfABgR7bbH`X8jKK6nm9TUki
aBj25^/LcD5loYgm3I/92kAcgbG3U1/T;OmABAU`SU`lYXeKCMlK<I;d<hNM:>U5;fRmU`13g:g1Q54H
cReLi=BYJ96LDk1@dTX[9C_ZNLe5g69TL?kU/X2IT@E9LVO1kJjBZl^0lCWiG=77nIc9aGcnQL7WekoY
mOSlI/9Z5]mQJTVU:e=l]iBaloA_[>LfZR8V[5>OHbAcd07BZNnYTUWj^Qi_^0AFbTa6FN`bB=WSLinW
Wknfb]M<F>>a8bJ<lT^MhL/_ehlb7>^i]J]BD]EPYIEDBG5>AgUgL/R8?I/TFni?T]bl;ViYS=SogoS:
X?c6Z1lcbaJk>]5moXRRWa>_4]V4DIJX8j[;TXXfQnlge_?[4_UR6BGcY5?oKW9AaF4^Cla5`oC_nBE]
96G4n4PW<oKo=jJX1oV//Ai3_Rg8f<7?7UJ;=f4D0;j@H@n_UiMGObBEVcjEVO?NTH_7;jgeBfa:1BK/
2UVHTbBCLoMc/iSR2N=g[UP/5hkIO]PYCDg27C?Gb;<[?YBZ=cjE6O[i^hj/R__cV`V;;Fm^NhaM:[?V
_b>;]FaAaXHl]<im]c_N4m`1>A?f/Yagem6BO=No92fWC2/XXPh=DlKi7IdoNXUd6eFeGJG:IjFb;GaR
Xcbmk0>i@<]PCFG;C5SS/B<V;:FhD[Z?FR9CGgoKeHf_[_UHlQoOX=MhAlY_T5oFZFb]i>ATKcER34Tn
[WEILE]9;E^Qimge@n>DfNiJOU7hLm58M]6jL>ccKl[lmIo8_?DObm27ekWOMOSoheDRVc3JVFa]Pnin
NK</f_R9_;k^HbUm>S3M>fK4>=m:kD`^UDh3NTS?DFgLL2A;FE`liXQP/Y6KjAg[Oa]?U1oZ@ENFXShG
niS@OW?FbS?;?i2[keW^>^WQimAG;Mj4lHF<Og6cO?7eOfGBZfniQX8OfgfjkB=2?0OAT?2SY21a7?>F
XSo6h37]hN]S76>O_ohef>J;i_miS1n`Sc9a`NQML_a/UB^XTLOX:OPX2XnacF</?C4hoa9i_TnBG3=R
X9aN55B:_2onWmOS=H;g]K3j?Eaamg8eFIni6cOcfCRGncomni`J<<aGPGkn3coO8TmYHgUNi7o[TYV`
f>9JH4cNo?0[IfhYFiBaiI/oTl/W;W?GdiLG[RmUbOl_amWgIHIcDNIh7_]/^n/ME@jAkeeaGGT=mcn5
EG9^oP]bm^f7BJLnIn]a369EZ9a/SE3aOib?o`_NEh`bZNn;aebIe?OA8GNn?;SXGAWg`Y]bb[1i[RO8
lgVOE4RDYcOdNoS_OknEBbH4Wig7XfDV[?6X[`WSf]5aFo?>5k;bkLnUn<V=<_6UcFkk^TT[94F_8NG7
Ua=_C2P?_Tcj^Xg[cOWH?Z]PRIaC/Tj:L/nCSjM6XV5?9<VL_=o8VGV;9;e/RB]_b4OQPS8JA4g2mI`_
mohamoZZjW:_l^l;lClla_>3/[g8OLKCLaO8m;U_>k=id]1i`Nl[l_bkIZma1[A8?om<kDaAQVnO/MXm
i/lK[a;EQ54WLLgh7ZT7<5lHfeEJUW[?G>f^TJmc^6Kn^nEJnlNXNgR<KLk7m]T52kB<;=LfKHVLfbm;
^ULL;5M>?dTk3__8jGd^ek:d[[X/nO:7^?he]NGDKN4jU?NmgO]B^OoAag`Iigeb_]=c5[Qjl8VU7lPY
`nNi</cc:IoDR`Aie[ggQFPaLYmmIb:[Z4FK<7j<UfUSn>FFokY8f6TSiUOo<>V]l`Ege@ITe7=_b?d;
giDlk@5b`FRD[U@7fon1]G;CU9D^b/5SG5S><g_1>g9kY63A/0enJ9eLZ@IX[5hHS<jeFX6iaoBRl7O`
Pn_dOmie?HB;aReeanQm4C6in]kU<T4[?QY_XW>^0RWO90?c;YDU/e=TS[iFgQ=_A]kG8[UnlTYGJMbV
U@@G>nNa3Nilin_WNFCaNli/c]7G6ZB_bKUhOa@L2PT5jFA]@4^NfRS_OOZe:c2nHZ]=I/9RRk;dh:;g
I?ekGkXOfUWiFVVX^;JD:gjlE>JDRBV__BgGg;_2oK2iUP>dK55>bYkIY8e349VUC<k@KCX=A2Zi[Sb7
jggce5DbAl/XUA/E2>9aoXmb=G_1nc9PCZFLNM_nL/k0jnBVjNo87K?F^0PXiHAbBgWPOO<N>>ldKI2V
Z2R3__:Q;;<oAR_@:JnmiL`TUAHm>lcVR[LnMnFeYiIS?PLEd1Eg;g?VW_Oh`FMKi58cHDe2ODdHmL5T
;IM_OobeJhS>bP_:;jJU^iIOj[^Km9YBCS0_K5=>^>KmkUo[jR8j7YA_jT_:?NGYgULfBkLaf_PDc9MY
Xc^9c3mJi;EmIL>2@RUoI[?FAd]LgN?[hO4__^WZ[>6?16FDnYObfFOfFUNV:;nnK^ImlakXL?:Kh[O3
nn0H_`WZ_J_eMeJ^_b_N<kli?Q?eiHKg_mC6lD]W=2VcO6K>ao_VMC_ZlfQPJD0i=olGo[kRDJ:J<<XB
goVWGghSgDMGbAUZN_ggAlB8CR3GU?96NN5jL<ghg_]XoGKCe9G^n]?FLSdY7oMX_CKieKMMGI=L/T9j
SWi=1TjiE^ij85/NZAXSHiilD3^0Zebih3ad1WeKG_3haTPIZiB[]6aBgg9NGY/jU7K?]loDX@AUN>cF
jL7kZZjSke^QMM/6mmR=nQkiC3OXNJP7gogTJgf?KkW?aN]CoRS?9Dm]LWiPd`MObYeJ1g>nj>n[?V[A
9Xb2DJB6hagm/Ya;SOb8fDh]FN@J^ZE_ORH;=WcR6[;=7gdUCbaiGlkD0T@U/nFKKfGAaV3hlZ??_i5i
jcnAUeImY6KWOOULc@iO?Pg]B[dPKn[o?UCiWSbko4?ij8]_G>=eE_h2EbUAbE4a4IkMY0dI`eNl3oj7
QXd:J8VnSnEjW_CBaG9^dF9iJ_56TKLVb4>?SY9UkhQk3RJbF2l`YY9cCIog]WbUfa@hc_MHeO_bROh8
7]12>3CDj2;_o?U/O^P<hn2S8kG9C=SfhPO>goLngB:SmHO?]@hoAP=6caYC<Tekh4l^OEo;aAJiDDdm
cefXIHk7:3?cm5Y^e1l/@b6HML[4Tm[;hW[WZ/VV[<eMmhUFH6ni:2JEc9Ui2ea3A9UUV9W7?_klFiWd
hU0inHiSI>CCZi`QIgR9l_^eUVD<>iDSkh7NjSf_11D?[dMWQDIa[CI0KfUiOF3A^k9@boijKKSB]Ncd
eml3kg7Ii/oT?_foBbH/MHeal7V9U77NEO:aUWdcHDe3OD`HMB3GNoDkPN6P??W7O?W5T;n_IICjhV4]
Ym@]OMF<DbiOGO>AeXUKi56]LeiJoI6l[GD/mBQU4a?3hjOWE/TM/cN8O?^Qb8McI?V[^O;fAeo:dl/o
LXdIZA?n^OMZVN;g`?nO>Wbn<oEOKOUFGU_k/O_mD<oA`9jA>mleZQPZc26=9hfQnegYIj0>YKkWoI8J
`6>M:j[T=VeLekkkQH_jlEZL`iMAgb3Cl?:GolWCg`[OPOm>hUDRVS2n<mY1f[37]OfTS_6?DIIhS8P@
7Glj[MAaV;DASjigTBCZ>^X=X^VT<kb_ci^[MB;GT?IibA^OJE^n@?hcOJ=lnMDGD[GQNBdWhfCMi/GJ
3WkVC0hM1nXVb^14KL]YLcTOmA;6W?Y__Sj6<NNe2GY@iS5ho0HXMdBg:3^H@/`h8fJDbLOd<o6nN8nd
gMM=GR7;=go^jUk>PkU;eMnBnbiDV7U6B=kBaa?NQ16Yh4/W98[SYK247j?aY07RBcYE2d<_MKgll>TU
4NWRBjNQ>gK`G6M/n=8aKjOWc=L;mkW[`G4QnG7Cd55iD16/dGdZ1j8QWggeSOKVE[[cliXdJU`h2RHE
eiSWgi0CQlic4C8:1jmgmJCel^EWfW0nl@^IW?<G_I1[AL^UNmoTJe19d=/hC]lGTC8Jbe>eHZCG]o63
[jZSG_ceWiM]C1M3AK`>;SoN<:VI/>f50N47BL<dl47m;_Ejn/Nl@J<RX5O4l5ek_ChHn>OE<;GGlT?H
WQlgTDUn/5mY9L5`d363GWOGiUfmh?CRQSflcQV_W]YK>f78G1VXSgfRiI8>1ADJIZj3EQRla[27gi;?
_WU7^YJdTL;IYK;iHg4=4?m7iOR:=WHWjO=NdLJ9OBX;QZBYj1R68I97hdI_UNMedc;6Kh0:U7>@hd23
cG_fWm6;gaMA2c=QCDMmC1SGS`Pi3@FM1NZ;l6<H4R:lMkndfID]6T/jNIAKC1SVj5DEIIWWde4Hml9V
EbOmIeX@4JG>^FgFVo;eIno:iho_:C>6oD1^V;a:?]>jS>P8mB13WiC3DkC^97;knEOoMIeS6VQ<gXES
UkQcC]OjUHhS[ofXMX;i;If[kaTcAf=9fN@gAUgol>;gG5g<Ij3Q7o;@NWL>S_>K>G78e^78l7N2NJ3N
aQSB/O0MeoXXDDdHgnM6[C/`^5c?l6>M]6hPGH=00^dPeiXjQWHBTdCPPc@JoXmbb3FS_NDj4LbP_L8/
GJMVAo^aL_>hFjCSl=o:YLFmA1mbKBKA;B9?_1J_@H24</Wo<i;0>C3N]>FHNMY_[SOnP7:51j1co;RF
LH8]U3?:eH^[?WB6S?M5gLS[73?`MEL?lQ/hFEo;3dOjcncK1S=Q:WjP50[<4em<n4O51JLQNUYo_1RY
C99:]C:QhNBRdO1P[RQL=4j4AOWQMm@;aINjL<>WL/l[VigYhXM?<^OIfZ3aG5`c5AJm<ejKej>R>T>O
nlCBmefdS7=`DGTMc1W3RO@j[kV?HM2=l]l_giD]VjO:OcM?TIF[ilW2=oo[cT=3CH6VUlI[4l5Kl^JW
[T1AnA7QX<3j:0FRP=3[iCgPnXUbl9[nlKYT9VakII@6`kaD61SSl?OYQk>iWPc]lMeCgTHnnhI[M2Q_
6>L:gJM<G:0=4VF1jlMe_6_fJUM^Z<1b]35JZSdlC0kWXL;1U56i^5jO=Y:D>Dc?aN=Gb<MOORTgccaK
ASmiVeHV8^LFEKWG9Qn6bXGcdf>Tc;jbiV=GTBcCGQg3Si@YbPO3ig`N31boQgkg[g4=g0/[Pkc2L8?]
IBJ/jJVO2M>6Dn/36ZiafYUT:=8oa[DSBTGI_VEj<0A9NJ2LHlcHY]c@P?5oo1KNd<hO9XZbCFNFLX>I
^W?>9WW[gKOUaK8mi>72gkU906mmlXgFLb]LNJ9QY_aBGf6hR4C@P6;2J2PYlmCSXiikdaU0c/lX04K9
Uelj4D5THj4K9Z:Qi9bl;gi_36ER8ZUkRMb5CH8GijGLOjjMIU9@MSB?9b5=V8Xb@[g2mNBkm8oAOWKF
LT1mAPNBHDTj[7gW[77G>UG[BZh;ZCAL<n[>EEX7<La=gDQ`PW9hjOQULX=NUkLn4NUJ?4<jmMm7<XIO
8fml5>AMdJHAnJ9mmR=N15QhWC^e?BLh`C7:4Z<;e7nD0iO;ZXoA<JD/H@J9R_7JV3266bWSbOZn:7nS
Wgo3iA@BM:4n9EG3OeH_<f4QlN5kce`SP272dG:<aXJ:Q093HdQTRgdR4_BnZ0ChlZQ`J6PY73QOQWKh
GliAZOn70G:A[dRQ`CgSk6TLZJ1XR8UJL5k>kd>LG41ni0c_D4QhS0Z8AY/:k;KIKlZFSkA1Ng0gTNNo
:l_6kRIGS/RCd`XgB[UF<1Af:RMN6i>9:J=aYL:Th7DW7bUdhBTDo1P8lE89TFA=@aZ>3=HV<f7KRhZ7
bV@1/h3dad/dRPZ6l/5aS0SGoUJm9_bP:A/<jc2/B1UQV9/L@RX/6Sc:0YD9ei4b@JE5@cUL6b>6234i
U=>KeJQQ`XRbl[X?EPJmO/ichiCeJ/8nT6^VWbYCiPnENJ_FBjN2EjES`I;ZBX?g@OVQdJ;LnG`H:QW<
>RI/a2?[gF<dXUBD_1lObL?</Ag^d?1Md8^lm[jEKRRN_0RnRo3giFDV[?6XMdjHUUF<T6n@Z/]_4GEQ
UCInFfC@Pf]M_GFJUS4<?bJ7LTSI8g[:oe6?D>n@`T4i9:WOVk2kIZlEoHW8f=bSi;jn^kW>`hMOR=Ig
Bmd@?A>6:4nLQ`h6@oHd_3BD_Q=<`dTWPMl<_`oZ<AYMjS3:;oDKSCM3@ZB64>W`kh_?a[T`HGB>ZOoh
_KQ8H>Akh3?O<F^e:n^mIjafSg>nj>l[7RFR2D=lgebC]cl>AYJh=X7Q2TIT:1o5Cfedei[X:M5G>P2H
9XHSRHIAie0G4B73B5>Fb=O2Q5fR9^ajKL<on>bodV?L4SW^n/<UJnQ5X]FTm;YgQL/=G;3QDeL?LakZ
8=YbbV8O[Kl8CU0N:D]d9S3W]>^lmX]J[o5nNIcbA]]:ndTkC[_?Ij<l;=IfU[:52J<^Yc?0In5o`Y4`
bQ?UL[>niRgCEk]f>_aMeEL]fX@Q2/@;:cmBPo>ei3bj@Nk@QPkGcE3R=OL^MkT65Lm/LQD05h?aIkid
aY6YB31QInXnSASA;bX^c[URlnL^3hL6UXZ97c36SEhG@d]41GPN5@V_OoWMbecTPhJIHD<J<HJLB?k_
Z0FPQiZ`;oBm40e9;jfBMNm_4EWGFnBU_NGKE`jEUfMdTH`ALjChnDne5aSd4<W_L/>]fV>T`5j^Wh4@
K:4FL0`P[n665UADH4@YN;f13jacTC/Jog1SFY?<Q<DFeaMC]>FogkZQAD`D^B@dD0`OTZ]5KikTC/XC
@iM3m7^W8B6WP=`5]W_XMJ0/D7jXA1R>Y0;Qf[3=;1/j30bCDa7@Hj<QY:bAmlD43lckl/eKi;VUDjGc
f0=Um^8:FK[^ACV[C`n]19JYFJ=/OnZ66FW@N3fBHbTWA=]8IRIAVLZ:cd2IY58RS4nIXF5jE7lgi=b@
V>[;3PdMcj>C`m3[]oYNP`TW@AV?o/k<Q3DNmCEQe254gRU3V37ZARI`<6a=^J1A9D[0]FEdP2566TN6
NaI_n/`mCT=66N2aPE[6:LlgC5kQj[U^FRi^Vki6bnng/WiN/LbY>4iNdg<_gOb5<ngT6E9GDXj_d[ZH
CX8_fk`>7A4J>>YS9X=@cg;no<N36MkTkU1_lihYTcBT38Vib5kTOM7@Teo643Ye>8ocNH:99D44maKm
3@<VSHTdW8oOLSaeHk@BeHBAYW>IMSbi;^BhDYMAie6Fn;k_O_T]5f@PlIf>:NdUYYk[@[^;6JO>`HBA
:lfX0MOj4Ze7RDkBZJFmYRilNMGKdS<WEAinMK9/n>0KBJHNe_JFE2;OUSn_iITL=LX>KAf_CCg5?PJ@
CRm]>CV>e74<FM=180nBNY7fe:EYJ9Wa4KZEFYNC=hH9HnJWSaBChT<imMl5IW60][6lkm7?_NWZITaJ
??WG/MCRCAQO3SlV4^@aA3B:i0l@kO8GR10TGcQ3TcQ_O/cl<1UBa8CQj8Ud<HhM30]E^V4I4Yei;/J=
XDfL<HdD?gX:1/nShJB@4GeHZ5e2NX_N:O<oc0ZQ<BO7RdJK2gIV`C;YNoOml]Wjnd@nNU[eZ<RbkS9c
n6mTf<bGIMZRKkC137Z]m?9`iOim4IdSE8o9i3g@BjAGP34P2T?TShJLd2[VP?n9mKf5IBJ/I]5ShXO8
]FE8TO`2LPfYC9R]@lnK9B_h__WaLjfIUL^?VlZNRZ2k?XnbL;dfGY@W:RejJ9PRIPaAKS5Q=4;TU14Y
2:9GReaUAMVR3<iIl9iT3L^D7Q<>UHXGki37U]lSG@[gTm?__4YOnafI?^lSEfKhG``PIIkgBdGYQde9
QZDaiWdb74W3a:`hNYLlQ`P`UA/E7NNQO64h>@MURmhSQYo>0FD[^^8a4mIhe=N4dC1`WBUge0f^o6[M
P>7a1XAUBBQOA=]7JEVSCZ7<4b70M1?eaNa@GVT8:LoDNI@Ko_of>Fo9UamDbNJiONGm=ejAUeMo;9M=
3<XJ[le_PW98VB;GRe`abQZcLBV;e=nl1Q>=R;cAf5?^nHga?k`_jUf64?W]T4]4@n[Oed>;gW<6T/L`
2Ha4l3/RVI[bbFOQ=nK?`nn1mP23bF]cS_1gEYLBeHCi/TB`POJ>//CeXAk`dDXVF0AUjC?GCU5od;KB
EV5^^1HlSlU:M3hYBh`@?K/RF7^@RCnK?oYBI[hdAiJ^Oe7V[UhU_BH5ZaC`fY@A[Z=[bkGlHK@YBkMY
oOc4TPnTRmIWU0_<>kV1U75NTc;8ob7:1`JBCP;_UgJOoj4^YYfUPlTi2IX`lH=8:hJMeoOAENYbGaOb
5ao1a04NSoGMeJDFKl8@?bHJ7on3lPdAGiRkl;[=UlBf>njn/63mT?0i:21nWlL@afTTBJ1fhm7jAG?A
N0kWlID=3AZ=;m_n7;aFn4O^mm<[ET_Gg=W^UTGbo?OM_MMHJfO;`dWbL?hOiH:lZFi1EnjeiMjGoQoo
klOVnEcQ2liac^gNLnAcX7P[63=Q]H__W8Z0</CgC?WR>=laIH5b`7IhR8imLQNhE^ckJamL>glNc7n@
_n3?bF_a6>OTnAcg?oicReK9N@>_eQiMFkUZfRUbaNBCg>:65iHM:^Odjb6YA@^T<j]@jo?mkh4:T_O>
nn4LU17O06oc_R:O3G4lo1c:5nD@lKSOmXn7IBJ/lJR_2O?bSIP_YaPFSW<=OKT;bTaPK7`i2EoSjW:R
foc5;9eM^4Cj??R>O?=AUL`_CY8I>GmbMFa:bA;gF_`Oin@lk;_6;[;=joVbiUnOamSVo;kLDgjYHgV^
;j?QEO5mNGJOCKOm>L?UUmOW>>M7k8LoFgfDZ2H<LNfi5UaS_Vnn@lXBeh__fiNU[ML_DYJR_Vmg3OGJ
lYSOkeBTIV[V9WWgX`lTLn0aT]cg7m:aoaFBF[[F_AK?lnfgJl^e;;4MU:GP7?klk5<Fo3iUT?M0Y8cW
HLimN@Vo[j0/AAkChgcFh7cKUQEOOSRGg`hoGUne2Q?VaIN?XXok@Q;MJnMhmGKdO^Aon89ag[V?[GL5
;^KiEEbXl?nkhcG//j9dF]UbVEYhX<QSJ/1HLCYbnhm_MOnEdYo:3KW3iKcbCI9F_T[oKm^;k5h[]8lh
MkC2SmLV<f5eRnlceSE6[Va57GOG86XonW4Z1lXE?D[>WEJjkOmhLGk4KCiBQXmf]oCX=N<d^F[:ZNhf
7magkJ9AQdUbog<U;Nl1MelfK_S=>J?;BZcg4KdO/hc[/FQ5?`NI2F/lM]B4XI[Z:5ColZ]U]Gb591O>
UEUCKiE_gW]A5UFX2A_nNiL/7gfSL?jgYS9E_Afekan?O/naWQ>m_c?U]bhU/PWcZZ//AGook]Z6mj<O
eg>UU2bEodaK:a_NGRTGiIlRioGiQb@?^U[[/VeGc>MoGGT=7O?7jmZ?EIJRgeOdOV>F9JmFIL8J@e`D
eUPRnGiW_nb`>UE/T]ii]lZ7[3PM_QV^6S7n[Yf@9?TijI9Mo9:;R/EcFj>`<7[aoXnI/:HAiHUbAOV:
mOQfZUPV6LEc9Gg8jG;eU>?UjVW13FoMoMIVW2jGgg>DI0i]9lV31dYVJEFT0Z_?;FCDk:]iLh[iN=db
4mIhE9/`;MoI8i_^Y^gD:lTE6b@g=l=5`1I=o8</;4fB:GWodTJ;f`K]n]/FkBZI2F/4EJc@^W29Y0fn
F2h]>4FbQadUj@?fUI@Q=fmW`UZSc8C58L:>^>QHSnfX</ZGBeKajo9TjNn3B9R?QR6feIQm=R]9WRki
_MbJfdM8iTmFhaJ?/LX/[i:^IJm;Uo9ikUi_MMeOd4aHdhUb5@jUebDZYN@QPnG2lT?TfYUZaR8V35dc
_KeL<neT=cbI<ZRCY8bHZ?nc@_mW[Oj=Yf5L:YTUcdVF^c6hU/ljbTd/eE:Qk:_jG[3IK?RgjS_1IZg/
[_Y9/=UdH<;>k3=k2mmcJ]i;dVf2=U0EEC6_@n=8jd4RH1DKIFQNCgTm?dWVUBG9Jf[45YHTbHBlMY:V
mHfI/9I3dmJIM?YXWiI;l/1;9JG__bAeh:7JTCaBd_[_9jW31YT9faFd11?FF28JMU_^7O;>OFZjWPnI
<:m8Q>c]BDTb^g0O^C5_Z:A[PmfYhPe9Zn3kRUd1Yf]5fK?dDBW;JBmMBUoEijkFhcDgZ6K2FY28QYD^
T=A1IlUEThiAdmEn6b=6M>cJ6JO;UOLM8egc3i>DPEgES=dMRHb]SeAj/L]=m/PeTYhgA/k[eeGgRHQQ
a;IoGVgb5LZ1IoClHnBbo5`e@GFCj[/LJ4ILY9Z^nUng5i]cEGN[o^;fVQ1<f5Wm7]RBGSA?mS[ZG6WK
[JmdWlPegAE6C3/;5F_M<6A1K[ZlQP4[Ci;GeHC=eKl;RY8T9knkjbS6o_oF8C=Q3BLjQiUU2jECo`/T
]MlnTZGV:g?8TNi_B]l39Bg_7ULWaO[OeR@cHDdXLRMBbeK:a;c3IL^3FdgG=XY4aNCa97UCcMY3aOn@
?[Tgb_V5SdYbfEYGjF78`[e?C5Rgd^OU^Oc_bGgiKBF]M:VT^lHg]Q6[Y`TkAiDMK5KC65627jR^EQgV
m^8P8DbHGT=jQjTimd[WW4>UehaCe7a56C4Ei^cJ6NgM46Fg`SJB=SQ5TXL<TKB29oDL36Mi@kJeg53Q
YNGM9fT3ob6Y@jkDHoZhV[i]Gkmfn@[UR?BKOa^i;7=D]`FKcI;cELnYHYGQleB_Z9[LP84OS^`nHKeN
amOT=om/8dMd_T>jgagLeZbaA3e5B/B59Ho;Q9`SIEk1EP>6f7i5CMT=ADFBD[4QiSUJRgK@Q?eEmOeP
/e7iLnA_g3A=WKUDjiZ=TU7dZ7CZNhjTmMmZ`0:eTNBnadUVbH/ke15/JC8CeZBRMkU6^QDm9DlDo]XI
;IlCEZ<INc99?YZ^5Mo8WlRho9?U?gT3iObRaibIjeBnbEF2i6]T5kl/[hki]G`i:dW:Lm];B]TZbJQH
hEhcnWgD`hCMYIZZf]o]1D<i]jR6ZBJYCU<e59ck5=DCZP`>e4ERV31D9ET<B`k^;mf;3Y9[Ifi[`<9R
R9;4oJ/V7B/m:PjC[177B<ZP2bAiJ9jTiCo^LS6b:]HjHmMie9^BVS]5;RPoDRhJNHPT3ka17m>NJ3eb
a7b5<U[TAgY9dUD_^h_C_<4XgQi/E_<ce@[EdFj_6K0e<Gn5M9n`CS[fNe1fgo=oiKbQCkW_?MKef3UE
JGfbGU;E]?L^j2^?i?aB5QH7TBm_`=02eNcL?dSW/[Uaij6fE=GCQ36<GJbRgVcXb=VYZ/]E1k^mP0]D
e<?oM7]a/6_[C:;aY4J/T=CQ^M;Y[R<UON01J/3JEA/`c1SiH<V3[W:M`]SWJEdb4mKTZW@i5YLFg2L_
Un`N;5MATa53V34NIbKU8dWbkVB]54OmA:HD7BK3lRjBJo>;Y6_QDm:ih2Ui[^:g8RlT^NCoo9`DBBiK
5k>BS=>44AEhGKFKf`^hFOFTRV=4b3iE=GCDH2oE<]Dog5h]98h9@aRSEFZD[YD;BR96;9BX7je[m36F
/kQVnRUbnCg]i<;b`b@kieQ96i8Z:D=^T9CQII9Fl8Ad6S9:^QNgTn_WW2KW5j/A6gB7V[3h4obYD<jh
LmJWIoLNo@^m92nXR6HfMe9DJeGQ/WfYJU6`fCcHJ/82`gGn?I_Tmo^dTgdkm73KdMMRAdE>:NH[FGEU
lKdb?_LH=ob8fHXfH>c?;dRB@OUG^CB9F>M[CJZ72F?XOHJZ]m][F8P/gj^RTk<ll]M3?D`moA^gE`Nk
Y/k4O:ef1RbmH:HTmlnDU3kkZ>Tjc4dTfQX1`h@M8LUm3];WcG;o4o]l[D]V`YZ9Z<2^:1P[;iG/8Mln
ZRH[e]1T]9iAlCa<fN=9l]FL97UcDY8/7?=3NJSX;k9`m0n2icb_ITf?3ldiGcZEKgC32n7GS/>44IEj
FYGYmP:XI8PDT5OSND]5kj`f_ZLjDDGD[;ILW33d9_>3cIY9;1>VLT>5:ec4ZU_Q`FiXT/QG;1<F5/o1
T?EB@gKEi6?Ud_57b8EUQd_GPZ<UOO09J]2>Lk<]NldhEKXEZ14K?4Rb6;hT0QO[OHA4QG9F_hONoOEN
1a11fZcJcefLiPe3YnnZ3WMk0HnZQPNKcH?]C=SMVnB`m9_U5golYg@I_D:bMc8gS<U2Y3NTUZmFlgFO
U>NN8LoW1TWghN77/9PE>B_WOjE;fN/^3B;FNE^CjV72R=hcc=g@o4ge]^Y?KRoX2:mGQHLk2eEeeYO@
Z7EV1L>>C1iI;NV53kSTnnBke62ij=MFhkGEP;Ec@i?90joDnPH3]R]b7I]NI/:JTJP0;bZL9@lEo4fn
E4?UT_G3/bI[Thn@NE>VaokkA?3G3fFnNDnBm<^idTd82>N@aF72R49]D?Tl7oRMjW?EBFh_h3EE@K0I
4bZ>VJ[;E1=Em1CSXH=ZRBXLZMR>Q3=Q22=F/DJ=dP397W6X<eDHZ5SV:iJ8T5FK<SEMc:h<?hJaji:W
AVa8_UJXi?_DGS5BXI`cn8U=^ooZ3dBBeZUnjRk>]_aMeDMeYhYb45N_?@HWZcQ?[VX@1gH28PZDBb0O
TOM>Q2`F9>_Cn0eE]N=00m5FMJ=ZR2[LhG54Vk2^hmM8nooL8cojfBnUdk1WW16;_QjeZlXIYb25HJ=d
;Ge5KRTL;^=bSiGWlmAP5@GV:c[jiCEOSknT9^g6`P9GMmFDLmZJE0lCAQX5_h5X<55mEOeEXeAkZ^X3
@hi[PTd7WId]:_;>?8NXj20CSJjE1ZlcWO5JhlaGI]TlBL/M;lT3NTQbWd<UKL1nTSGTR>fRGdhL6gb8
M>YcW6@D_j3WJHcQmNHY<f7=C5B8i7>=c3e==]lK<E7aA<FRQO4:6kR84E/o8DUjioa7cZ]hd`dkl9Ya
V32RE_bX`aD?a^a[eI5^;h1XfKQPLc^8YSfV^/?]1DVTlNKK44eiDoE[]eL32FW2W5RQO9fTS;Q7DPNN
9QN?>B``E754aNXB2OkGC3m9/W<>TiAQ5EZi4Q6;mAh21BK/bHdoo_VN0oFB;5IagL<`Jg:NjPcEojS8
H@VKngPiBlF`2nF@b6ZiJVMhEHFY0SXH7j/hKcA4agS?6<W9ZX]E3@53BT`2>4R5`A^SfXKfoIkimCHV
K>aZ>J_?7=W]AcnE3[fWBMMa=@oOl5/W0/h47HHJjHRUUZnEKZD_ZXTZTZ:l=7TPmgM^f=57_VXbGhS7
inUcQnCeS1R`18UJa6O2b2MLYC[2kFf5AYJbOkJ:<WJoZ[hM40cLdV3C`M8_GjWJ^;f0?EB[EISjF]Vi
>Y=ldVEJmc3AIieTZOW:;5GSUCMIDPKO;9gjWRHYOOJCm87k^f76V>J[FVdTnBho8k;e;d/AUYV`IZM:
]jA4B]UZ^BFg[caClQ_iO9HJZ4PNf3I6Zkj:A<]FSTfBVg87>2?6JlIQ`^REEjW2B`c@loYBMJcK2gQA
EAA/KPNEa4HEbJYQZ<a^SBQEAH9dM1B0egY?AL=G8hU[`P9ANFDD_b[9PjjEc[V7baGg72VmIPJA[UP6
:ehi8cK]A<TLMXAKNbakE<e6c9^`7og/ObP7U8MXBUDSPldMQTSE0UFbfh/?6S^oK4H/j22D19_>f672
<4AQ3UE]D_gBk@G_8iiIKgD]cL5_HZG:CfcQnKjAicegEGGIhoOoMoVIONIlhDdH2O[W3GUBM__akW;b
cE<UJl8kKZ8?BdUP]7b4ReB7e?8eTUEF:Ce:WYANAJ=TH<6e<RKg17TXmgoTEHaGLI3cEM>`HeS>P1DT
BDW^fFkX/[DWhhLEY`VS_WY3ACi[67hCHG?m_LQOX/FD0H`I1ZhfO>O6`eYge<?QXGC:3i7MCVj_5VZ/
<mfRcB/RFQTaFTBhPTTlPE5JYZK[=DT_N41BAaA8bZ3;9KTOaT_=E?mm9F?`XC677KME>lW2P?GIGlm1
]3fa31Pb4mH/aJeVU[S:/d_a2c8R]k_<7OVCH8SBih65Xece4OnWiePfmW]bBl5P]ka5Uc6[jc9Qc<BQ
IoMS]aM0aO61:SacTAon=L7VMY0[5Z]A1VILGQ]/^Z77]62cVP=EA<9Z3MdW^PUc`d6^dU`WZKWC]E;/
;5d;3U<ce/i5aQQb[2ei_cH5ji6M85W3Si:dG3ER=@`GE9^`?Gk5426AZS0dG9BSWIe5B`nOhO6j6R`?
bM7mE3eDi<[4FXkRFAFi=?1oZTmDV:h`c0:>M`RM221VS]OcIK/VR0XB^HR>6P;[Zc5/nodOoVc?2JOO
?_fK[BI/YI`kn0UW`/jkJHCd6_f0G54lACE9[RdJ:KLD3Y=n1CM9GWiW6IEgRTc?oHLlTKNk_:BVJgiQ
4?7baZ^fZ5MH345j0lK2[44NF>/OQ_BZQ`VS_PYg6S7[G>?fKVmK6170F8eG?J3Z[:Z9jeCTP7TXXjB5
Q0dO[lG81I>YJREfWEVUi^YEbBQj@_FTjW4eF[<U;GnBY>EDB<Z`0I8bn5Y97Y0]bGe?UYBnKBBeggjB
?V1obGC6ZfdLiT_UQR0?UNBke80=ce<35UoNJF^CVK1V[DXgO<3@`@F53dUnGZJlD_4;]dB5T>oUlkoZ
JlQNB98]/i9T@ThK[DBGBNNaJnXbHOc0ZEBR4nW9kd:`]hZ4DG8NP;G4SPXf7NCKH=:0aY=l6enAT@Am
W8ZQcERc:`WO4hWc?LNHV0WKZV1jm`XG^DXIe5djikJCBlJfLDJ:9B]j4Af[Sb7CiehkjcCYG[R_M1[d
7mLcSUEQNQ?fTeoliSmjBFP8`Y4RXU5<gPPgCShbb]0TIHH6R3:0LO4VRg;9XZlNC7YhB8J85?T_M02^
i832?WURA1MXS?biN4oQXA_?@YEOc`bcoj6:9E;2/9@5>FQQR4B@`nFGKJ5LHoJ8U_5IkU5QB6_S1QFc
S<=h@lK_jWgE8L^ooOJ77NjLEFg268hlhjhil[dOod9:KmaMGR_iSSbGUbC?ZlURgJkGF<l;/aEIdGi1
ZIXX=E;e<EeN?9lTo9McTfAhGXn4=60XCQ=6FL=`QO<5:O_DSn6bkc/3A;6N3cKM42IUU;Z><T3i3NO2
7ZlRl/G_1NP4<k>Ggh27g`[7XXM3]f?k>U=odm[V90nlB3[MY@JYkm6Bd^lX=EZ7Z@i@/kFoFldnOL1n
TS7X83ECQkVQa[Q<EdPThFL<>T1Ohg0eMZ<R4K34<f38C5P;4D>Dc6c/E_Bdm<fm@FHEkB^[aRO95k?E
E678<6>H<R9U]ITbOLiW<i?Tk[afdZGd5KMfF1c3TO2D:S`C4VP/We7Af17=X_7a<5`DWUe69LA/8B89
i=C`G2XJT_GWZ`RM<nfJj44dXeEe=FAV`[KC4ZgLeTZV=YQYNOM[koDoTSkT3>UNe4H^7GN4^onTSi0a
I4TROR`3AQB/ehaCY5/Q<bE_eo?Bn<IN/X8:YN>0AmojnNona_ETn3VLkdE3@NiEWZZSRS`^5^<U`TX^
8Hd6DH5:5M4ObPL`O1W>nOZGRPJ]VjZ;RW:62L:LHJHh7l?J6:1`HgV2R]Og3IR7AXkXPXlLl;XdQ9`k
3>nKICMh[D]Do1ihck`g7V=]=5ho?5WUNUE>/5T=kb^LBlIgaNMQn9?_QLPMkhV8g0PEQ_C9?kGYN=QI
oAkle9^`K^?Gb/TgS9LOk?5K^Fo0kfC9Z<1PQHEiZZoQRQKW8DWoTIaObGl:QkU>HC04VEP63<EY`^1a
EGQDP;9?fJ0N8inAXFno43G?8dTO^=I4a81bC>NC2BPNbPE[ke7V6270_?T99AhRaICO>R?5=IZ`o^UZ
T_IE`gBhThm^NLDbEW59cENFWRn]gknUDmnc9;g`oXB=P7VI2F]QlY6a]=8ULWW1A1VV_M9IAO]9iIPO
b3]CTVC;0fZdF?@E<hJR3=Q7di:T8_LdoOlZ=GI4Bb[S=F6WZePg:GZf6iD23FMhMPj6RhHd70T3:R:R
43c^X@4R`AURcJBS`F<8:cZoHS_<Q=FTZ^[TfHbBNI8bHX8J/Q_DT9dSGO:>TP_;flQU4m/6]d6JOW9T
j76[0B<a_d^NmXYIZZ9R[J[VaE^YD<k/<nNSOaam7]N;J<2Ik^9/1F?1/1o6a9L?IWciAPRSQ>4?lk0:
Ta>68O8b5HHU73fU;;5F4/Hm?>c80YK?ZYPi5Pe3>^@L4WG`d:WP767hOO2JmjW8HO@CAFQDJE`IL^o9
PA0l3b<EQPJBj9N771hF?IjVhSbHC8hANO<c=:OnM<lo3cQWb9=_Na=foSe_b?hM;iOofN/`VEUbZ2b:
HJ1fAYR_1BE9lTYNTXc<KBlGU3jED4Wh/E@?4dJ7H6j`F@eACLX?ICUL=i8WQ[4R;i6LBFnNR>IB;Z<S
]g@RR<Pb`c8jM@?6Z_`TTeZYdH@=b5HCMV1/8kDSL^J][A^bC;k[H9NhWeVf:1:agoikCRBI2F^QL[Ll
ZUSW35Vj6[8NQ@o8cOU39CloFjHF7Bk?UNdY6jMl9hR:8CEPkde>T/:LI4TYGJUVS^lkj<W6JL:0QX?Q
aeS3>F58ePl_85PCQ=]YO<VKl@K=Am]XQ<REHIR6j42MV0V;@i4Yi:bhWe6jD=;b7Y2DH@FB<ZBGY0g=
TXbQ9l[5Hhh?8V=XjXVB?J:=90l]R:`EE_^R[Ki2NN3KKfVTF:hTWUV;A0Ej1I]93j[24@@J;Z:WlEI@
g:MbR^X0]aM0XhDilhWfdCUQc3SSML<@5L?lD`k[P/PG4@Wb]j;Q=c<hf7B``SVV/ZhIXL`N9T;/QbG_
fOdgOkgeW<5?_<=gc9YPg;kXEg/M90NWgBJc:mZjhL9HIZXn8V[V8UnL:cm99^O/ifI?YYB_RGCJHUog
A54mC1SG3B>?6JY[lPJS2DBe^8EF>76O^S0jRUXGA6mOD]EEUc/Jfh@ak9PeA<gG@3EOOE@3^TUj`AaG
obC2;HWRTIV`ER0<6L>Eg:j8FaMe:U/[GO8OEB?f?mG3U:`AaV:]g6lb>YNS7RH<R5CD>N/VC^SaTDm3
0db?SZR67l[1U5fXXQ6>2c=QmIDJ/TR4c4Fhb]M:Yj5SYE]QFkUfe^UbmICSPQVA`lWIR6o8`5LXIm`d
TI`XLPSS^M_1EBY<30d8T@0<4M6/kjV8V]IW;BGFIkXRf:b6XDk<?8dJji:5Uik0X34c<GXj?jm=M::k
fj/MlQUIalk?V_@@7FJ8WJD8R01Rj8S8eCI;dl=_0o=9U8f932?f?^gR_Lo/NknK7GW1OI_UY5hEl_<o
oU=BRb]UF/5n>fc2iR8eG^B;TCofLUjBC<Xm@6h[7:Ae2n/G//1cO7M<J>fZQ`T3WX<1anACWlF2//=<
B/Xh^Ea/nbPIdFA_`^>1R39A/;PKldHaHME3UXM9N_mmeG`M[>O[ZQfn^mfi;OZe[Lb4]D:ULH?VhYOU
YE6oM@I/gH@TjI]kSL/YRiG;DDlCeV`a4kIc`XbUiTbF2lZ>TV^V7R/I@hkFoO_dN=f;]7[i2^G0<gYj
Xd7R<<>0dC<=`f1hF9j4mN0`:TBQMZ@/4SfJ[@XgN3ARc4PS<T/SQM7cBOkkZ8Q:H@9S@NB<MIfH/E]K
A8b4o^PIT;`^nF:HBLB@?Inc?S0LaG^WHo;M]Sf;odQR?[UPYmlbBGkiigo;bMN?TbhCgY0Y^OnZU`Wc
4BmVAi:d?kLPBAk;gD?:lljDjh/Zg8@MQQhCJOV9N5A?4nIQf;ZVJ1RADLZ7Kh0II]oA1H33JAiadE0V
;<PEJj_KJ[`6kRLYOMElmCeADPIMjfi159P_>W[aeB>993=Q[E14^USJhYFA?i>ehi;T]]cKiKcb=ec4
;=KcFj`94oW>nAE;ZY=?cHC]W>RQY^GN9eebmi><XBM8J]i/?DH4;?KcHjV62PD3P]6YJeQVIb7I?Mhe
b319A5Z9==D6Rf6b_U==>HTH:fKge[T`i/jbogTgkGEF_`NfY1Fl9W^OV2FWgGbgM9^hBGo_BkLcHCjj
iHGQHWT9KkXF52K9boU9lU3^WS8jmfBi/n1>^J3dJCEN[2nf_/Jj8]6ePbJ/6A5MIkJ;ghA58UcNL;WE
k`LOhVi3U=I_7cEN1dZW_RNkfa>UiIBkIBkXf0GgP3CcEI?<Q;E2HL9jU3hYLhK_:KLFm8^/SUocL88c
HKM?Hlf_l3YP;H;<l/FC^dgHT9LfJY6kUe[kFjNlfFD/?o[HWmED/m`=M_?6bKUg7RoYQHoFfh2QX4:I
lMW?oo:G>VnIdPR4Yo;_BV:]>mHPI9IGC^/jO^g`[?5E_dm:n^G?]K;n^_?XiOXm[i2^hmJhgcEAZaTi
OiDUJZh`HYP/IkAHP;E8CIPJ[QOEL3fEm`>IWO]G6IegXPc:_dJ^:a[YE/a?:Eo[XUi<n[76/WIQETjk
M@Zg]6ZaI9@]:^djHMfX]995395[WCTiE6M6C5SoE4TOl0leHPLi<hKAHUT:k^g8VV0YO@nAi;i7BW:o
<mab5ZU3nd]JgRBgN6]fAG3KX^3N]]]oQjI]IBJ/5HYNk?UUcl]E9ONjGVeM5F_WdB^d4<cji9`QSifN
FKkXZ9JT[;;:AAM=ne1om4/oBBnJ=oJ<^fJofgVD9Gc^T;CBc2QnC?F4OYo1c=VHcj]5g;o`c3jc_cR[
kibcHef_aUCg^cLLLL5mKahNjk7Je;URlL7I8aLO4N/aU3eZBC/Djc7DHnXkKFYkO4O5>ODkGG;A]0od
fRci83WWQLTMncodQB_OTI]eHl;h_EOT]ILY>@O9_KT7bkRlXgGoM;M8:fJ[Md5OjEDdERhZNE@jUlee
]b_2M54g1?VQI[cR5GGUjGM<Oj_CR6N?SgG=FX:dcWbjioB?96_TTRoCR^M=>K??oNmg7^D=4c>YEdSb
X5kBZMliJ/KBe6Aedoe;9FG8CI8j[;nTiQA;N_iD[BNND]<eGl_RJVNjG9eQaZ_NlRH/U<:aJc4CeSRR
LRII?mISdNXlfQF2Cc[fNnR4[9:Z@aYJWB^F79II]^SFF8o]S6Pl]D9Id7<j9Vb9V[3GcHC]U=Ad^M^E
l?gEgh0QC9QNPbo>^7?jJK6^FG=CI/V2oC=:5Xc<:UUhAUK9PYS?JBYA_S?;5bl>C5SEQbVi;dljZmn3
J/:R6k[PF[60:_VPg4Z8j1Jg;F;f=8J;VMCL7B?8lC;C]J?Z?4I=F>mYVc^=N>J8F=N/`EAFMKGneC8I
hk6MTYKaR/F?Hl:dc_`b[FSNi6e=F5RHOCGYA4SM11hRG>]ETB56miP=Fnn/_0WKkl@;OW_AY5DokcYj
CE^moZX5LJRZKOK8ILb/gG7<Q3Fm@/>ASCN/D[:XcU]Xk0RIIIEC^XiMTmmUc3;GRk3Qb:JE7hklloi7
AllDK9ITSe_iVjkSegjBDK[Xd/RQIPG3TEg6[AjAG[j:9Beng^6>VEoc7DMokd54S9]dHk32f_IiYYgC
[QZ>k5bjn>C/X_WeC[B?QjbbaJEMajhJVefn`ZgNgojfbFm/GfNB_V9UJEMXIdeHITTU/fmg73=QCBmW
`_@JL2dRUjE1BITTgm=6;Yie`nZ79NHg>oT:YLWb6nZ9U//28ZWjg]MTSi/OJk7P9Z=gKoW^YI<ZZfmh
Od3b;GlkhjiIFf:I<=>^dJi:c>mL_[Q3im9:I_/f>5ViboN8K5ZMf@cTjl`M7Hi<;e[8nW8kaOM?_gfJ
VK0VE8/eHE5HQM;dJTTV;;FRJSo:O_N96jCWS8mI`I_EkI/]I/:JGZg1Q8Fa>[?Y]K=eIVI9IOC]1><W
^f;9WLTicej^1^1MlY9R_D5Chl]<V:VQe99<F7KId[me7kong:b:aOfkCUbOUEFfh9S8@ldB<f5=;c=Q
YXIFXiV`SQE;OWKAY4eocZaHo9LJEKIh0B/oYaO=L`Vm_1WC[UOgRA^U`adc?Vd=9Zc3kM?OjgkgaYRO
dmCh8ZYdaUfc_fXY`i6@?J[ZU:BTg_7LWZQ9HIf`<o_<LMma[>oNe?RRKVUoni@gFY<9/cZcJKFcMFJ=
9Rbk[;9K]g/fWIfQQJTVIIIE;^PaiCeQ1NSTg9NnhXfX8eC=<^e2WMG_`Jm>_V7lffdjmfoA9ZcMnMOo
k>C[9f`hZmm3<CnWZO5eI]l7_S[UaPTO7==Sn>lSUjGITcFbj]cTlTY^GmB/>J;WR;nNO>>4coR>Hggg
Y/KGFOdOXZiLnOOfEk@:4fIeI]=[In_<6TeHUk:ZLb>K=L9j9MdVK7Pe^f;a>BMOFO[W@e=^=3FAS[/`
mgm918iLVPIUEiV`Y=jmgJeMHWdndjkC<IL<oE?:Y4WORebEITm;<F77mGkbngbg/KicdjiCfik3o/RT
X<QUJAAfU@Vc>[=iJ6OZc1Y=F>ObZ_>Bke]Ol`[/FXPcbbX?BTY9JC6E]K5Sk38CIQPk@4/aHDKR/<]<
V=7RfG4CIR@<I/:<iXbI<:>iHBK<R1LcHDJMV0TcVS=V`XcVQYT`8ek<Q1UeHRK<J<jH2C>J6fK2S7Pa
4fKDRIT`XcUS9/aXKYP9<n;5C9QA9fK2S>J<VC2S^F4Vc8PG<f56WIP9<iXcI/:<iXJI<2=Nc8@IMF8V
c6S>V0TcVQ]V`Xah<A=Ve8VI<:<iHbK<J6jH2C?RaDbHDBMV`XcVS9T`XkUQ9/b85c=QAYfH2C>J<fK2
S>J6VC0SG/b46GER9/aXcYP9<iXKI/:<N34CI/A5N_62i<RVHC@[c8@IcHg/lZYC^QIDoRjbJaPeHRK<
Z9F^XmOlhZ:97nnIFKcXPT_VO?S;[Z?WoB;bT64d2lb46Lf5<d]OndW6a4ekIYD]C<d/FK1oA^WB?I=4
_Q=if32f`dbHDB_IIH/_j3YnkLMIiEFOl3NcK=45THL<XeUP9/aX;W@^ZoYWE/FB=k=7;O^hfhCe7fFF
;kZ_MfoiK^AQ`mP><f56[A09bbaOo4J?bNm8IWWU6aH9<iXKI/:<iXCFUa=jC7UG^TeH9iVU2dn>73J<
V9P9<nXTZjcbRT]VObHIiIFGA`hIA[?1C9SAW<PZF[1g]`W[9J=ThA>A@hIA8fK2S3Zi@1^h[?953f@F
;OaUi91Q=1/jSejLL/kHZUm5MPfSbLT/GC@Z/fc1fI5M`jPA<f56G6B?VooCb:IQ=2_BARgjDlZTbQm4
MPfSbNTjN/f?;1O<R0LcHHIQ68IQ64f0VC33<0c3<8`V`4bHHAR6HAQ64f0Vc30<`c0<X`T`4fHHQV4H
mBMj</R?8Wl=8fk<Q;E^OZ<jBGEFA:N[OZPbS>K:WeBWZ7bI?D;E470ciFVZWk/m`dQ:n[GZA1GUk3QE
_;<I3e6mY7Y:aM8Xe;<?ZeiE7J@jCmE6IAQeHRJ/MC=LmJV:A@>OE/eAeKKFemjZVh;=1^<ZUEE8A[b<
DkfSX/`nZaZTJPSnYGYKAL=[6=17mHGZLMG[ZUMDOeGEaFaERFX_5LJ][nY9eMmD?e>=EWEGkBQkZ^h<
=XgFSYV`e/ghR:;iGaFEQHN6jKNZJeG_ZOIGnAG8oB:H1jSf23IMPdJ48UKhoF2E[lSnX=ZTXR7mQl[F
cC7ZHYJZGk2i7GmADKiR@@@REP?jAaFM2oigQHX6cS2PD3Dmf7Ae4nD3LnGQ5VgDLooWmP:8e:iDgJRR
@d_mR073N?eN1MB]OZRBNY@KN??L0cT@1FGfB9F_Kkn_BU=mXn;hke@NWU]CnCMJ:6K2FSMS8h[VNQDm
?l2@cE=UZIJZ_U@]DWEADB4lZYZ/X^;9E0e@?J<RDS5GmFlEL1j>_jbZDW6SKgYcW0lSAVoCVcS3Z8TI
Z]k1iSKLXB8bM[n://C`8U3^60XRb_^2RZR4Qm]/[E4A1Gi8AB=[Mgd`??VZBL6VPdPHah1QB_JYoiJX
R9Y1TNY[eDIEOaFAOTHKgUG=E66hYZRXof2HRS9=ij9BACWd7N1KE=BGU>OUZ^=EU4oZgbfZaJ[oZ82>
RBooSjWXh1X=Ad=ecUSDO?MP<ck<Q;E^lU@<`F2RJ:AlR9b2@^=dQNY^5AD;d0?3@94gmSdE?D4Z69i3
;PdV:SbdB>E2Ka;8]d7l7e67HeBH>?8T;U=I;YXA3a=EM126Z79Ei>Y`4f@j2;h<4MfUC09UKVR`jL[W
FbZR5dAg?eJMY]Y=aG<nD=T=j0d?4OYETKl?Z318g]clDnF=o[hZbQFS1IBUQJX;8m_DLMB3e;FnO=8I
_C;HC1ZYFZLRVTKS_5WUjn73EO`od64UXPI4`=i@H@ah_:<:8nS??d4EZg=]e1lRiD@aNkRm0=ZjCZYC
gEk=o4AeSZZ3f`]PR9Y[@e0S;/b4]Fk:E?BNB<PWnG@OUHL:@5CcEKhR>5M5Kle3@dKdP>77<1@``_7d
hXXiX13]HQ90=3`WG<0=XcH`HD@Pj?USW8iE4G6P71:5iAR=5@dMDHNeZW]D7:LaaFQA<F:nR2AhZ6aG
Zf`hd_0<EQ5e8R:5jAVX2T=JaSDZbQKVRI`_X<iTY<0cEDG4bd=TRhhWH9PX]ahRHWL5V`kZIDHV<794
K86QMNYCgoibKS[7_3oN2lmkCVG/70`U<l4RO2eYjjQOR6CNZb97UGXV6R;`A2@aD;BcG3lo1<d@<_FC
;`>eHRJ/MH<S7aE/KTMKU@minaiFRR[JQ=43XbL8Q=4IQR@B@Dn@j9XgHCB6Q=>SNDgU@o>6DAMDIP`m
QRUGdNS@H=53?E?eMaFA21Y?>PAd87S/11Dme:hZ6UP?UBIA3c=QQXNQAdH9P<PG`hcT_/;i:Z:_6:A;
EN]EgX@]D7D;=Qe4HdL4Vhj`2J>^9:[[8JWOUflNHbRMCRZS4LbfQ<=DHA=6WQ[6P8RH;onlGf?W`=`B
Z@acWlZ?355Gd4HBSHn64B0oU8ginTbEk?H2^3kD=lbL[ADcHJdKNV5D<SAF51@OlF8hTQb4M1DQN9`l
43fPanM_e^dSHKiR8WY6HO?WXL6TY`0dTSBF@98Y8GEhDNEWn/CZDAQ66285A2S2<7a3QAK6Ma`XMn4l
<<XH@n:7Z[iBkJN2feBOZ2`Wc?3@T6::?8nXaPBK[UaiHdE4k7fE=f5dE35Y7W;163[gH:I8m@26cIVU
kWU@MJ^:R@3TboZjUCZBe0ePa88d4::g@?TW9cN<;oo6ST7Z`S8EQ]N3gb5mQ`jMQ`QTm4aE[QgY?67c
A3jZ3dQh6>:n8MR/6C=Q[A^BBCmD4HdRnIj:1H=5Chb4Dn07oi6:43RA;_8M64;4X67LR9CiQXc72L7B
:l?PdB?d5@`6SN4N7RMQgbNDdX^TH9>/JPfPDAND4hHO`f3j<O^DHHHN2ODCj@9VRa7aXW5SF8R6e3MN
1B[bLGR<FG0<?OSI_XI1gDFIlA1YOE=5^dMDPk93NL>XdF3kfKOT;8J7/>SX<TcXX@aN4V`jDaMNIXF>
:bH<:U@<KC84CfNE3PP`ja`SAcej]HY>1FJ>N]bGoo3[6oD7lkE15OHhi3:cI0TY41kBNKQ>H@PbT6o:
NW0NjQN^KASJGdJ;J/E<F>/6`dEHU=hF`T`A5B=iT24K3hF?Z1N@^<b@3TVX`9A/?mH=o3n?dc_T7>7Q
7OjGFDDl5XK53M^YK8T:XbhXMgjjOSA<lBNoTK;/Xk50>FO8P4ENXfN=DOJH90:DLAXd``3:VJoW?4Bk
O7g7dRI<2R5Z`W?mLDanN0ILM9UUZ@Xo4i`b5gj<ihHkXdN[63G0N?Tj66Qk:M?QIELXobB1lmO:lLj1
PB;041jMHATUX^M7^Kd0dVnRCASGT14QQXLm674RXV6HWHfi[QDcHHIQ68IQ91;TeS7D60h<d84S4TIJ
SXOXHcS:2H`8<L8DWP59KYm?cO5P`QQEZQDcHHIQ68IQ91:Tcc0L6Ei`74?643A[_gUH3nk/H==5g7dd
U;BMl:;B35LcFBd</f39^JhE<f66HAR6HB@BY<h`fHL9?66hJ`c7BN=QVcaZDW20hDJF;05Vac8cVa@O
]/UGmD?@7_;1V11D:fK23<<`3<=8=5R:`Rlf7XK9I2aO`OY^hM]6/E`Ca/c3[=DL5D^@n9Vc7YK4H@JU
WbAD8fK24Xm`TWeSHDVSAR`8jhOc;IXKe7LGZl;g2S@<9X4dm_8jW=m7G8aM0cUPc?1WLNNjH5e=8U/e
CAX:`j@=I/SNk?KZ`4aHhT3QHMfKE;LG`8nNFH_<UVa8V?e3Ch;K81T6T1o13:;VK7382F764f_nn7G^
S<CV>QG;kCCdc6hR92b5h=]HC1P;`cK6JaTe`k0SRnf6egf;1FeTW@^_:/aVILVAL5iI[IP9B`aH6hVe
IGZZO2B<6foSk?WQ<`dg[U//e0>F_F2a>RXa8k71S=?Sg1EAf8J0NlHaLhYkb1V92d/C/5Ym@mm_U0A^
KXV3hF890glk>G::6=YR;C0cH[/>3;2oCnS>`SD<3f7FRIV`a82:18EQ0D:oR21[hG3;3]H4JdR8_W7[
So0m:hg4PZ5Y34e;RhZbV76MBKE6ZhDA0niQf]0`1<H]RGbMR1VS4acVFIGMKcM1<1?FnV5Q>FIk/12M
Qf>/T^n7G5QdUOe/]eLcc2BiD/F:nn5EQF^SY^A78c6PW;bSJVUA9J8EM20/8Y5hL<eI/CiFhlPJDBAT
Tnm30WMmKao4R0>gS?>`<Sm[CXDGOnDN_QQ0bje=0<b4]Gi8>PcOb1RhI@>A;nhHkn7NI?if6[7P=S7d
f5QOQE/FTO<E3aTZK_=Q92KLei6Ql9XP8]16eI0geZICLHB:5Lmgm1ikg23l_LQO8k5PiGY^f1dM`BOG
UE^f4JERm81j=GYIP[[PEU[Q21^[/k=0J7QUO?;5F<<ZO<aXYIP9Jof@8?Ql/5T=4C3^3Qnn4cnm/mk1
iWJ@T<QdFknV2[e1:ZC`S:7`XWMQSUMaCdVkhFaR`_gDB5B=Q_:B[j;<SEGiNiW^;9@gLVYjZNQH45GH
4ERHTI/fnhDJSLAQGaGgT8a>a<iCQL/b^CoeWCE9FLO8NJR;jA279jaPk2RkoWIKAR_6C5S[idHE2lj5
hJK7gjSlSKVYB31I33G6hPXERm55@oVP8BGJ@F?73G49eHNQYlNZ`cAZA^91hS5[jDACZR8O1VS<`[=f
Ma@VPe2>oC0kDN1`Aj<n/2`1dI3H5JCAV^5nXfnY`SMkYm=0M8YkhdJ3hKmOaFe[Z0m[VdG7hm`:al?m
8KTIM3RIVj59DTR8]QV]73=Q[Io>ZVP3AL;lij[fKRn8K37dDU??RjCnF=4<H1GQm63CEBSA5@L=HJFZ
_Se6XgG`ZZYo/5T=`bgTRC53=aZFCB5?QW`KK/S]hJK5;81H6`=E[<lC2hKN6DIR]Rj=74>E_0jM1i:U
Hd5d^:5W3A_=7bHX/AYj>3Y5NJ4c6F_Vff0E4BhNVjZ:_]MP61[LcL6VPc@?XUkQo2m<78K?Mi:=EXbI
/=K?0JZeZ_2Mnh4eVkSY:0K/1QFm<kmHh1PEdo@mA=>h=aJ=h>VZZeFH:YHL8<Z6NN>^m;5VEc;3S:DZ
S<B4l/7TS30<lE6NXXdiII597dC9OZo2;57V<48dE=ad]cHHiZ6/A/<J?n@cdT6P0d9DHi;Z91GUUY`e
GS/<II/QZNS8[]7j8GER/NX<]aM0WQPM1fKiTRMhRl[WS;7>U>l`d5WeZjYCeS1UhFP/A^eM5I>P67IT
CCZF2@[3j04AgG2b_]5:<A>F63b]R[ji::J<21Mi3VFZL18XDC4RJ1iV]XeDTMo3C4MOnNb_8^TNHcIJ
5J^GR;VSXC<B4o:c<3aQJ<R8:WS8hf:hV]GdVKj?JOMUQ_EkR49`S_0b5iPVm/>9dG=E=`FKc[`a0HEQ
AJ8D_1iUUb4VI[oi1Pjc]d8E7WX2cT]>V0d99BImE7L7VmETZXRdgZO2A67D<FbD7l`GIOgfb35P5[ZX
R>:6HLH`iIVjUkG2XS/Se<OA7ANSUF8V;37PAlmJCK4FY6<VFAPJ7BZJF4/:d:25^D0e:]QdA4nYYX9i
D6EC[A<GKWPk?mR/QYV@35?BV67NVIE;`hDNElF:Z4iAQDdHmfZSPJ<Sh67EJhH@ReDdR9Pk89XE_DjN
QlHceWYPi0DAnL2T6HT7YY`d3^jPD1]<EWXilYMU;L9;mc2TC_VZJIVCF9>IR<jb=4Y3[mUX=5?<Q2D>
93hoY:Z[Illm/^[:_@6<eB`E:c`CMSmGiO=WZ5bhC@dmbHILN/1XNA0eIAfTj4J5B1@AE2J9N8QL<J@H
Zm6:=V5WZEPR87XHTN5gQY72`noU:RJGA<=RaD`VR@DM28J:S<B5FI8Tg7<odEPi[A`S3i6d3V1HTHEF
_KTj@AEM?V^3o30j[GhF^Y40V0U;;31GhLS1cT2TS0D;RC:@Zd<NQ3lgdCG<W670HbZ6JNZ2aVil/;TM
6?k`LQ>D=nik6Pm4:8h>=Z^QhR?gTHJDMLZH;126HGJ6Whc41T?5VW>aC1Pi]9M7a3K3Sbbi`RcMn^;;
XNF19AQV`Pc3J6`>D[5F7965fR1RaBBA<3A:c;0U[i5IJ3B8mH7QA8Hn`i4ajSF<8I=CF5J0hOM``dWB
=A49`c2<A/E<V64H^`:6234n/MII0/`F`h_A9X]QKjK/Tbm6m;Fn=e<V^QI]Z1S^i7bl9^Oc`dM4<hS^
CUOI<;YQ68f>VC33<7HE=@f74jER]]RMKZoQ84nA7;=hLfbHkNHGNSD<`fQdc8@IQ]7D<>^FO9Z61W=W
MIQQ6<dF<f4k3[=NjW_cE/<`3<<`34M;=f4<7C2EW1TY[17d3mF^HXB:mHP<`c0<`c3ZCD/gHLaZFZ9R
iN7I:^k9iFlIdMP`Zl[OP;RQ6:2bW1C3<0c3B01J^PWSOW2/]^gQ]RN/XQfNPLEm_[9D;0@IQY^c4SgS
_XOQ=F187>KihGF^V3g53H2IWLF2TNBJ40GSmQ:/g<d=[:?G6N8i?9Ogi67f5H]GTP3L@AFn?b>;C7:o
<1HoiMiQoSj>QV4HQV6d@UZj2F?:NmmP/aZVXg?;4/0L4BWS?UcL>/GOEhiK@g1;RUcEC9FoFcj6S_^0
/M8kOkWG7;264;M3hFK4[jP`J0b1HYZhNB_g^^>^nmkXHNAh?Fk9@[B>ml>dN:K3lgh`Sk`^mk?S?@2;
FGjTFZ3RonZcd[9Q68IQ62f<eVS2^5g><b[N>dK:[iA=_QPgi6DeMfiEPQ7b<3][?aFgEo4;BW93jlmD
Qj^8P7f[2RlTbA3X<QFgk06<5[Nh08aPn7id6eB/TdC4kA>E_f/nDCR<Ukm?8bH_O6/F`c0<`c1J:JgA
Q94`CoAY;mFW:/`A=`XVOf^CRY]HHlPZEMa;dMoTma8E]bX9PiWS9ZbH9?;=OZgbS5AE19/>k/fhF<GR
TR]EW9_Gi?EGZC1GV32RGckbmPLE:hWk6f]S`^aF:HIQ68JA0;@64dKT:``6R1VC;0ci[^X@5OULR:PE
9PUH<K^GR^N@PlG@9B]fQl6DLE=EKl;2=b76Q77_>@oiI@aa<^bhE/GoHOKn[F8=98jC9hHAm0]FH[ih
_ojl;jYh7hIQ68IQ]79J^PUkE/F`814ZE/FNZUZWnYF:8DKb^:iB0O/H8Z9A63<oS4SdR^MPU1QnC5Km
=?;g?AD9mmaoSZ7:l?gUlUDOZaR^a5aQh8JYP7_B8H`NH039lB8WS7<NZ0;>ae2U?nm;:^k:coYS_5o3
<0c3<5XY;Mf4<I>@17S<60J6j=C_E1kb`DRTIiR?XDEV<f;2[U6m[28_;7bO^6`EYXcoNDgED@E4eHQb
<GcX8HVOFjd`k;Q@AChHIP``KNB5lIjNDSdL>LH/Blj;:@?>mh::ld>:RVAoU]_`ic8<`c0<XaGBdTdH
@g`<5A;ilU6WJ1QnI5S@ieeiR735F]bE:1PiFb`ShL6h4IgR[hL4On0k8_l/5RCgLbho1>[?`o/6ookm
?_1I6^<F;XIQ68IQ=2=Z=F6ACMeNm>n>5LoITPV6HAR6HAP=A8dV;;]lJO^/dTE]/TL^7I=E__S3i?9:
Wd=U68IQ68IQk2@aCESFn>EkI9H]O_3lNcK9QI?O5CEQFc;:5WG9ZZS/^2_DILcZS_YjYeeDnYZ]6VlH
QV4HAZ/TYPW[oJAl?j^ll[K>8iO=jS9jYG@I/d;BbaLNd7EdiNmfSMKl;[]XoVmjmnhMcYDb3<<`3<=X
=M@j7<WO[=7;ffIG;1V3:G8?]3i8U?L[e^l/hIVIQV4HQV4H=E9[HWkGdF]HD/7ABZ=B[7;?NUinlEAX
YnZVHTfafV1M<YigT=/;H;EkUZf8=N_B<0c3<0bSVUY=F0]HXV9Wj:aRQGZoAQOLZ9ZQjZWRA]]WZF;1
hj`?aYO78ZeME9h>ZUMEhHEM3L<`3<<`]R5ACAS;KBaE/G:nQhEC^CFASf;MXN:F@]4A@8H^FNGnB;LG
g7?bKEEee53Y[`[Od/P`3<<`36<K4]F4GJ1RUOd`g?]a_LX_b<YZnen[F70e3=6aMeBk^kfTY7eDFeCQ
HDTFJ>FVgJbBKaR6HAR6/Af9J/;6ZdZ3cF[jZ:Z2C@Ng5_Y6aKdQ`ebQfZSbZn1S];iBWNkf]T8D;OZH
HAR6HAR68e5=6?UL_H?=JPJY^0NTiilZ8Ua7^;f]G:_R9^4NKS7d^HYL/33L8c;fUf/HQV4HA/:CZ2J<
6fZClaGV>QDgcoK3T@NZ_UA5cgC/ZV8hd]lkTPCl;eCA4K?GEFK23<<`3<>8BJ:J/8VZj>78De@<:ok2
kBDUYJ_FZUReWnAlKkX>ES5<jG?5CU:AV<mjHf782K?QB<<`3<<`HY:X9^aReO?1ISG<KV@hLXB:a?[W
E5N[H5lEBe6`H2fA/VMDheAoDcfX^T/EIRlE1Rjlo8EQ68IQ64HeRF[2R7HAZ@[?J8@oZPJ[QZ]HR=Ec
U>YSUKn9nIhZUZ7PNBaA4DdoeMg1YV4HQV4Ha_HTZPV37ZZGE?7LSZV_RXELhn4d5@^m4TdcS5f9cfM/
K>9i7CXZC7j9cYGLFGKEIhb6n^;:H;?1l3>/3L=8D1;IQ07A[RTZUZ>XSKY^HNCQ=TRcE2Ce6dI3@YBf
@WFVfm/NQ/1I5VFDff/l68KWMOk/mVZV[DYDM63RQG^_d]UQR9meo4J[`WN]80nCenKh[VJ5jZeP/d7X
Z6:Y6njnHAQ6PY;X9PanYOYU/;WCT0=V_E^S<CQ6QJTIi_JfQdF36C;W]U^=2@KY8eEMmdM]Xn;mg^[f
j^ID5K>>nImUZWVZCb;k[>/7Nj_hS7AdMSG<MUhNK=H;9_`DZWk]m[JB[N;cgN3f3<=8B<b46DK;P=]T
HDQHE;PVOQ3ifiP`7<R<hKZXS`W3G7fZNTo5K6<?]aNkC8GalkL?faFO<AHkJ/;^E?4m<8TWV_2]cPc3
B43<Q1U6bj0^4hI9hCVa6W/<4CodLmeN/=c:RBY_J?Qk/R[j5UdoE74lO3?j_j]H`3Pj=h^Qa0`E@o`<
WK;HLK`Vk3hEcbEZE1>lGZc?b7/n=]Qd4fdHg]_?k@D@VNHcL?a/5LK>`cHA>1IL3/=agT_hN2`CmWdE
4DZnfbaEm>_b_^iAlMVH`<=@lP4Zh;IWo6n/:?cn:[i7l]1>D?4jHOPNSUOifj8MYn;cTHmZ64H;`TbH
HK@<jS9QC33QlI5^Kb/5:Xik_J1R1S3Ki941TBSfQkZm[K0dBoCajB[^ZAYN5hnkAGbPlZo17BB:8m^g
Z6Z3HC[Fii_[mVZ7ig;>L4hHMkYPF8oUI?c[4cT33=[;:Xkm=o:G_2kbe@0Sb[5;gMiF<63Aaj==f66Z
eBZNanOUkQY//l@=<9>Jm@<i5YHO;/H`/Ln`Y0OCboGccnEkhNn[Z_3`klmEG0>6>LWAllm7c<Y^ZVRQ
HASea4bHHK@<jS9QA6ehW>AmCbLEaiQlP^5R`PQgRn3H]bXoPiN9:Ab;=V54MSPNcT?3Q76726o2F>h5
Ho>nRXP<DK?oZ?PoM;>Z=Wb^FhkKZae_=<>C3oPno6/a6i<KkkMC4CejDLGa;RZn7aIJWZ?b/a`In^Ca
J1=6M2cjN;@9Be6=EA5U9:Y5m8mL=Ok?gnZ<J629RV?WZGSm?jV0QI`i7SIQO^RBki][Pi4S6/HaC:Xg
EgcWg^0]D64ZNKj?::JY3<=X0IP9<hbF@K`V[<c]1A058TXD7X9SF>la5Ln=SX@A8@_S8f53g5k0E=EW
:Vo2Z41h3[Oc2^?=0hJ/=[aA[<^/PCMQHJ?9kLLh=]3]KHFeoCS>FWkAn9`f7`V;G^_?Al;2an?92O>V
ULo^hG=a;7ZX]kf:h`aS0Yn=fj@mjOJf9Do5Lgfn72J<2@Y;EDC5?1PlWQMm=a33<9XYI/8<XfE@Ga=6
dSL6k76g]bd<hO7LQS1QO[SCWl_S3DUM>F7TZO4lgU=Ma39Q;871/NQenJiBLAbcDa<=HL:8o14ihcIW
;>3<og6CO`oA>HhaNcE<]0US:@kfHje5iYo[eb[4Q34LbE1T60`I@iR=?D?F<8`6`TbHHK@<jV_2B=YV
?mJM6aSjhk5X4aI]Q6XcHCjj=TU5_QD6:Dbl/b?mNV8<YME5KBH/NZdoKRG6LB9R=N5=6;La2a>?2N?c
<ab96GYGaAdhgUCaOaQ0Ck`VS659m/?3TikXJhl9`fcMjoJf`_0UdKBVF<;3<8`M`4bHHK@<jV_2<0WT
KS7d64e=TK3X8CeV8G:l]TQH^H[WA<o:m0J^;Q?6k40RMQ]DdK<0XjW=Q4D_Z8bahWQ=Rm^2=f7AUJ0O
bZc=Q1FYN0jA:nh>`33_XI5S_E@N?e`JoOjRCIS?Ck_6kFd;Wl6o5]AU`VJj?L<`VSeV`PbSIN1=F4di
ER`A`N?QW32<0`J7A]_3lQAnaZ0gHGm@/CoKkFf5=KXh7SIWdBK<?nMl]kLEW`]EEdhHn9VD]kVmKF4i
1/`B9/O?SXc7Q7TS5Ohn0:?W5dkeYRWGkFf5cl_al6[fdBJ<b=NjH;<JOhg2A/Y?DV3IRC3A9XaQCOIS
iHCi6I0HFc0CIQR]13=QQ]4bH=HO3O7m:]J@`_AhLJL66V0N3a/DWa`oCLDB1i`3<l4aQQ2m2L?X?:gR
>?o3[3i_KU0hEhal8aYjKl8HmVB91QIJaBbaSQRVa_m_?>^44LGS]T0lWgFeF<n;MK28IReD<A<@^;/5
c`W?S_AiF=73OG`V?c_b>QFOWm`]IQWbfH3jSFDVF5j2fH^L0m?6oj3`k<Si:XbG1j?3LliAlKhhmi[8
/K09HaHUaoQ>63;ebf?hfI6MgEh0`i_n^EbKl7D8VdVRQmnX60X>`o_P/c03e32<5X2I<<=X6A3YhGI1
=<SAHPT68Sa/Qa][IP6bYUKh^NaSH]Sf9Pb8e13YlLlS_hTX3N]oQFLH/]`5YR/lhi:Tm?1k8d;4`Zdl
SibXN63f8<]On7=hHGj86P73OQaS2=CSLklHDXf6klbKCZm:EOSN[Rb6^UWU7fO68In79Cc29^`e5DKA
Pf5KY>9oR0anZ>ZWh__2m7WhW_a/E>BCiWgNFJKK2oRYJX;:?mN;jaF^Rc70/B9QA<P`b9JHKaP]13=Q
Q]5b`3@aji1Q:L@fi/TK8Y;Q`j_KN`iG4K7Q;dCWQ7VHGDOn4CNGmY4^Q^aH0l]3kQO7XUO<IgT48UQ4
N1Sb11HdIIRd?V36F<RD1F2SQaR9KTEoA/i?M:VV1DYI^IkeboSl=BGY4lgS<o?NoO8E[?F5jO?`GZ:7
59V1bV[lbBXo>i>e`:8W:F2@N@nlQ_ln<5b/IaHN:_I`GITebW^>WW00?_l/n_[EM=``S6J:VC33B3bR
IdLJQV4HCH2I<<=8?7cN4oUKQV4HAQ=Q9/``4PoFXYZ/l[<43L<`S2JPAQ?FIN@bLQ8<`c0<`c2<AR2S
I=65TLe]bBZ_jYYI]_S/c=;59fN>=9U<[DUIXiNN5>^hbF@bVGJ=/RXFWiAE^YP5WKNWLgkE[c9:5oh[
HmCROiQ<9Y?9I3:I6TjMbnKo<je`4C?;3L<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`
3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<<`3<=819:BoQlMEhKA96n4W0000019
ADi4[T9PPP08@048900001P000024<3K0@0000@00000000000000000000K@000@00003@000010000
0P0000000;l0002o040HA020QD<300000000P000080Z1[5:0000P000080L>A]:8@0000P0001R0000
30000040000Q0000200001h0000H000000000000001Q0P002`4001D0000<0000100001D0000<0000
100004H0000D0000200005A>D5060@00D@000?1C0000000000000602000:0@000000000000000000
00000642000;0@00D000030000200000L5<0000000260>h0H@8000/1000X0000H@8000/100010040
0000000000000000000000000000000000000?ooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000008P1000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000002ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ
ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZP00000@000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000`000000000000000000000
00000000000000000000000000000000000008000000000000000000000000000000000000000000
00001000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000>000000000000000000000000000000000000000000000000
0000000000200000100000000000000000000000000000000000000004@000000000@40000040000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
03nPk3nHnP0oV87hoV?hlQn>6000000000000000000000000000000000000000P000000000000000
0000000000000000000000000000<C4LMaQ7074APA4LAS734L@@0000000000000000000000000000
0000000000000000000000000000000000000000000000000000000P8`iSV880h9R30hiV>88`iQP0
00000000000000000000000000000000000008000004000000000000000000000000000000000000
030c144IP`304HH114LAQS1440000000000000000000000000000000000000000000000000000000
000000000000000000000000000082<<hhV20<0HPP>>HoR28>hH0000000000000000000000000000
0000000000200000000000000000000000000000000000000000000`<`A14H<0`1620@AP4H<`A100
00000000000000000000000000000000000000000000000000000000000000000000000000000000
020c3V>HPP20>883SV0hPS3V>000000000000000000000000000000000000000P00000@000000000
0000000000000000000000000000<34L@AS70<0A`A44A1724<L@0000000000000000000000000000
0000000000000000000000000000000000000000000000000000000P8?cSV?h0`1RinhiSho8?S_00
00000000000000000000000000000000000008000000000000000000000000000000000000000000
030000004`1001000401P00000000000000000000000000000000000000000000000000000000000
00000000000000000000000000008000000206200000H02000000000000000000000000000000000
0000000000200000100000000000000000000000000000000000000`<00060<07a00001000L00000
00000000000000000000000000000000000000000000000000000h20>00000000000000000000000
020P00080P0>600006000P000000000000000000000000000000000000000000P000000000000000
04000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000HXhPP0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000080000040000000011A5100000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000000<
8XR60000000000000000000000000000000000000000000000000000000000000000000000000000
00000000002000000000000000@R40@0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000002288QP0000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000P00000@000000004
@PR40000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000`R28`0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000080200000000000012H1100000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000002
?P^80000000000000000000000000000000000000000000000000000000000000000000000000000
00000000002000001000000000400100000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000P00000000800000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000P00000F000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000jZZZZP000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000008000005P00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000080002000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000002000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000?SkciS`i<h00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000P00000@000000A41
9TI44A00000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000026X>RaRRIX00000000000000000000000000000000000000000000000
000000000000000000000000000000000000080000000000004CI0541A4000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000PX/
8V8XVb00000000000000000000000000000000000000000000000000000000000000000000000000
0000000000200000100000014DDDEDDEL00000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000008hPPP>PP8X00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000P000000000000G00
00@00000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000002X0000P00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000008000004000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000008000000000000000000000000000000000000000000
0000000000200000000000000000000000000000000000000000000000000000@001000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000020P0020200000000000000000000000000000000000000000000000P00000@000000000
000000000000000000000000000000000000@11000D4000000000000000000000000000000000000
0000000000000000000000000000000000000002R000000000000000000000208680PXH000000000
000000000000P8P08000000000000000000008000000000000000000000000000044000000000000
00000000000@@001000000000000000000000041400@000000000000000000000000000000000000
000000000>080`<000000000000000000000Qi0R>X62000000000000000000000P2S00P000000000
000000000020000010000000000000000000@@aA@@0000000000000000000044540@@88000000000
0000000000045=45100000000000000000000000000000000000000000000026b<V0P00000000000
000000000H`8h23VPP00000000000000000000HZVHV<00000000000000000000P000000000000000
000000000@A0@@00000000000000000000011000410300000000000000000000121@4@@000000000
000000000000000000000000000000000000QV30X80000000000000000000062000j008000000000
0000000000048:08QP0000000000000000000800000400000000000000000044@400P00000000000
000000000@5000@00P00000000000000000000@@0124000000000000000000000000000000000000
0000000008iP;02000000000000000000000P8002P02000000000000000000003QX028`000000000
000000000020000000000000000000000000140@0@00000000000000000000000000000000000000
000000000004000@100000000000000000000000000000000000000000000022h001000000000000
00000000080000001P000000000000000000008000V800000000000000000000P00000@000000000
000000000450004000000000000000000000@0000004000000000000000000000@001A0000000000
00000000000000000000000000000000000088003P000000000000000000000P000000P000000000
000000000000P0028000000000000000P00808000000000000000000000000000000000000000000
00000000000000004000000000000000000000000000000000000000004000@00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000PXRPP2000001000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000006AI100000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000008IQV<0P000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000144@@0000000000000000000000000080P8080000000000000000000000020PX00000000000
0000000000020000XR00000000000002<HHS0800000400000000000000000074UADL`00000000000
00000000000@E=50000000000000000000000AE<AA55E00000000000000A14400000000000000000
000000000Xna/VV00000000000000000000001S1PR00000000000000000000039/S8VRc000000000
00000QV6HP200000000000000000000000010a4A@@00000000000000000000004440000000000000
00000000004S@44AA4000000000000014@A200000000000000000000000000>S<`]QP00000000000
00000000000JkKXP000000000000000000000n;XRIRTk00000000000006;0XH0P00000@000000000
000000000DDA0D400000000000000000000001a54V0000000000000000000001@4a5T4A400000000
000004@010000000000000000000000000023;W^>l000000000000000000000063SSh00000000000
0000000000<SS^SkkSP0000000000000000808000000000000000000000000404001000000000000
00000000000@000P000000000000000000000C00@004000000000000000000000000000000000000
000000000n0P00200000000000000000000001h0020000000000000000000003h0[X000000000000
000000000020000010000000000000000000@0000000000000000000000000001000000000000000
00000000000014000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000P000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000008000004000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000002000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000400000000000000
00000000000008000000000000000000000000000P0000000000000000000000P00000@000000000
000000000000@0000000000000000000000000000000000000000000000000000004000000000000
000000000000000000000000000000000000003P0000000000000000000000000020000000000000
00000000000000h00000000000000000000008000000000000000000000000000G00000000000000
00000000000000000000000000000000000000001`00000000000000000000000000000000000000
0000000000000000000000000000000000000000P000000000000000000000000002000000000000
00000000002000001000000000000000000000100000000000000000000000000000000000000000
00000000000000@00000000000000000000000000000000000000000000000000000000000000000
0000000000000800000000000000000000000000000000000000000000000000P000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000020000000000000
00000000000000800000000000000000000008000004000000000000000000000400000000000000
00000000000000000000000000000000000000001000000000000000000000000000000000000000
000000000000P000000000000000000000000000P000000000000000000000000000000000000000
00000000002000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000008000000000000000000000000000P0000000000000000000000P00000@000000000
000000000000@0000000000000000000000000000000000000000000000000000004000000000000
00000000000000000000000000000000000000000000000000000000000000000020000000000000
00000000000000000000000000000000000008000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000P000000000000000000000000002000000000000
00000000002000001000000000000000000000100000000000000000000000000000000000000000
000000000000000000000000000000000000000000000hR8R8R8R8R8R8R8R800080000R8R8R8R8R8
R8R8R8P000000800000028R8R8R8R8R8R8R8R000000008R8R8R8R8R8R8R8R800P0000001ogmoOgmo
OgmoOgmo@00000007gmoOgmoOgmoOgmoL00000000000000OOgmoOgmoOgmoOgm`00000000OgmoOgmo
OgmoOgmo@00000000R?oooooooooooooooo00000000Ooooooooooooooooh00000020000003oooooo
ooooooooooP00080003oooooooooooooooo0080000000Ooooooooooooooool00040001oooooooooo
ooooooP00000040000007ooooooooooooooon00010000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon0000003h000000Ooooooooooooooooh00000000oooooooo
oooooooo`0200000001oooooooooooooooo00000000Oooooooooooooooo`00000070000001oooooo
oooooooooo000000001oooooooooooooooo0000000000?oooooooooooooool0000000Ioooooooooo
ooooooP0000008000001Wooooooooooooooon00000002_ooooooooooooooon:RP0000000oooooooo
oooooooo`000@001gooooooooooooooon0000000@000007Ooooooooooooooooh00040007oooooooo
oooooooo`0000000003ooooooooooooooooZZZZZZZ_oooooooooooooooojZZZZZZZZZZZZZooooooo
ooooooooooZZZZZZZZooooooooooooooooo00000000007oooooooooooooool0000000Aoooooooooo
oooooo000000000000017oooooooooooooool000000017oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00002020820000ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh04004441040001oooooo
ooooooooooP00000003oooooooooooooooo0000000000?oooooooooooooool08002R01oooooooooo
ooooooV0j80Hj880`HP2gooooooooooooooon020V00X0?oooooooooooooool0000000000Oooooooo
oooooooo`1000A407oooooooooooooool@0@0110@P11001Oooooooooooooooo`0@0A0100Oooooooo
oooooooo`0000000003oooooooooooooooo088H0P80Ooooooooooooooooj2XR2621R>:288Soooooo
ooooooooooP2>?62203ooooooooooooooooP000000000?oooooooooooooool11A1C0@1oooooooooo
oooooo`DC4@D44@DD@A1Gooooooooooooooon0@DD@D40?oooooooooooooool0000000000oooooooo
oooooooo`<<R::307ooooooooooooooonQPXS::HKR2:P<2Ooooooooooooooooh3R38R8h0oooooooo
oooooooo`0000000001oooooooooooooooo0@a00040Ooooooooooooooood400405144040@Aoooooo
oooooooooo04050@101oooooooooooooooo0000000000?oooooooooooooool32822XH1oooooooooo
ooooooX800H002H`001P_ooooooooooooooon0H`00R60?oooooooooooooool0000000000oooooooo
oooooooo`48@40107oooooooooooooooo0d01400A14004@Ooooooooooooooooh110068@0oooooooo
oooooooo`0000000003oooooooooooooooo0`R0N0<0Ooooooooooooooooj2X02P01^2P00:1oooooo
ooooooooooP62P08S03oooooooooooooooo00000000007oooooooooooooool13<000@1oooooooooo
oooooo80000004@000007oooooooooooooool000004407oooooooooooooool0000000000oooooooo
ooooooooh2<P00207ooooooooooooooonP000000`P00000ooooooooooooooooh0P002hP0oooooooo
ooooooooh0000000003oooooooooooooooo04D000@0Ooooooooooooooooi00000010000001oooooo
ooooooooooP10000403oooooooooooooooo0000000000?oooooooooooooool08P00201oooooooooo
ooooooV0000008>000007ooooooooooooooon02000000?oooooooooooooool0000000000Oooooooo
oooooooo`00000007oooooooooooooool00000010000000Oooooooooooooooo`00000000Oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000080000003oooooo
ooooooooooP00000003oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000001oooooooooooooooo00000000Oooooooooooooooo`00000000000001oooooo
oooooooooo000000001oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP0000000000000?ooooooooooooooon00000000?ooooooooooooooon0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000001oooooo
ooooooooooP00000003oooooooooooooooo00000000007oooooooooooooool00000001oooooooooo
ooooooP00000000000007oooooooooooooool000000007oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000001oooooo
ooooooooooP00000003oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000Oooooooo
oooooooo`00000007oooooooooooooool00000000000000Oooooooooooooooo`00000000Oooooooo
oooooooo`0000000003ooooooooooooooooP0000000Ooooooooooooooooh00000000000003oooooo
ooooooooooP00000003ooooooooooooooooP000000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000001oooooooooooooooo00000000Oooooooooooooooo`00000000000001oooooo
oooooooooo000000001oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP0000000000000?ooooooooooooooon00000000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000001oooooo
ooooooooooP00000003oooooooooooooooo00000000007oooooooooooooool00000001oooooooooo
oooooo000000000000007oooooooooooooool000000007oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000ooooooooooooooooh00000000oooooooo
ooooooooh0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000001oooooo
ooooooooooP00000003oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000Oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Oooooooooooooooo`00000000Oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000003oooooo
ooooooooooP00000003oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000001oooooooooooooooo00000000Oooooooooooooooo`00000000000001oooooo
oooooooooo000000001oooooooooooooooo0000000000?ooooooooooooooon00000001oooooooooo
ooooooP0000000000000?ooooooooooooooon00000000?ooooooooooooooon0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000Ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo00000000Ooooooooooooooooh00000000000001oooooo
ooooooooooP00000003oooooooooooooooo00000000007oooooooooooooool00000001oooooooooo
oooooo000000000000007oooooooooooooool000000007oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000000000000ooooooooooooooooh00000000oooooooo
oooooooo`0000000003oooooooooooooooo40000000OoooooooooooooooiP0000000000001oooooo
ooooooooooV00000003oooooooooooooooo40000000:Z_oooooooooooooooojZZZZZZ[oooooooooo
oooooonZZZZZZZZZZZZZ_oooooooooooooooojZZZZZZZ_oooooooooooooooojZ00000000Oooooooo
ooooooooe00000007ooooooooooooooolH0000000000000OoooooooooooooooaP0000000Oooooooo
oooooooog0000000003oooooooooooooooo20000000OooooooooooooooohP0000000000003oooooo
ooooooooooR00000003oooooooooooooooo80P0000000?oooooooooooooool00000001oooooooooo
ooooooP00000000000007ooooooooooooooon00000000?oooooooooooooool0000000000oooooooo
oooooooo`00000007ooooooooooooooon00000P00080800Ooooooooooooooooh00000000oooooooo
oooooooo`0800000001oooooooooooooooo00000000Ooooooooooooooooh001010000@0@01oooooo
oooooooooo000000001oooooooooooooooo0000000000?oooooooooooooool00000001oooooooooo
ooooooP008022P01RhP0?ooooooooooooooon00000000?oooooooooooooool0200000000oooooooo
oooooooo`00000007ooooooooooooooon00100@40044300Ooooooooooooooooh00000000oooooooo
oooooooo`0000000002ZZZZZZZZZZZZZZZZ3P801X>0:ZZZZZZZZZZZZZZZX00<8PXS2888<00ZZZZZZ
ZZZZZZZZZZP3P1X00P2ZZZZZZZZZZZZZZZZ00P02000@00000000000000000000@040400000000000
000000000@B004<Q@@@0000000000000000000004001000000000000000000000000000000000000
000000001SYR8:0`000000000000000000022Zj80c<QQP0000000000000000001R8:8:2000000000
000000000080000000000000000000000004544`P1000000000000000000008801`4@0D400000000
0000000000044@414800000000000000000000000000000000000000000000`R0ZR8600000000000
000000000P^P20;X2PH0000000000000000000`ZRH>hP00000000000000000020000000000000540
0@50000012<2@10@000000000000000000020A0014@01000000000000000000012@50A0000000540
1@0000000000000000000001Znc:Ph00000<8P9X01P00000?cR8X?P000000089/006K0060000000Z
802P800000089P03<8000001Znc;P80000000P000000000000249501000000@Q1T@04000000@A8T0
@00000000@00000000@0000001EM4D3@000000AT@04@P00000241505`00000000000000000000<H/
cX6000003R82:00H000001S<RP1P000000030000000030000000<<b:08P0000032:00cR000000<H/
gXk000000080000000000000@2AA0@0000044P000100000004@AD30000000040000000040000000@
AA504000000400014@000000A2AA10000000000000000000000RY/^1P000008n00008000000<a8/`
<00000000800000000P0000000R4Rk2h00000080002S0000000RkX^2P00000020000000000000155
1@4000000@000010000000ALdD0@00000000@00000004000000014CA050000000@0000@000000155
1@3000000000000000000000V0000h0000000000080000000RRPX0P0000000000000000P00000006
>?SP60000000P00000000000^0000h0000000P0000000000005@00010000000000000000000C0000
D000000000000000000000000080000@0000000000000000005@0001000000000000000000000000
0000000000000000000002X0002P000000000000000000000000?P000?0000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000010000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000@00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000006080h20000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000@@A0P0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000022b:20P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000A14400000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000QV>H`8000004000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000004@A100000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000008iQR<20000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000144@@0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000026HIR0P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000004104@00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000882R08000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P00000@000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000003h?PS3n0?[R1n?kSn>8?SQP0
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
000AAa24I`1a4H<A74Ha`Q6440000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003^68cSP>2iPP>>ISV2<<Hh0000000000000000000000000000
0000000000800000000000000000000000000000000000000000000004@Ha440`1660@A64HIPA100
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000k0R<`h20>8H3SV?hPR3^60000000000000000000000000000000000000020000010000000000
0000000000000000000000000000007468A10H0AQP44@16284@@0000000000000000000000000000
000000000000000000000000000000000000000000000000000000001hhHS>>0P3V20hiP>H8`iSP0
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
000<1Q34A`304L<A14@AQQ3740000000000000000000000000000000000000000000000000000000
000000000000000000000000000001P3n8`oP<0ino^>hn?R7hoP0000000000000000000000000000
000000000080000000000000000000000000000000000000000000004040P140@00@@@110H040000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000H00200h3PP0000601P00000000000000000000000000000000000000000020000000000000000
000000000000000000000000000000g00<@107D@0000@04400000000000000000000000000000000
000000000000000000000000000000000000000000000000000000003h00S0>0;SP0001P00800000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
000000000@0000000400000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000020000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000P000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000008000004000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000:ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ
ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000001A0000i?P4000000000000H08000X100000000
0000000000000000H@8000/1001@0000:00007P0001/n0@000000<H0R01Q0P002`4002P0001Q0P00
2`40004040000000000000000000000000000000003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRh00?moogooOomo
ogmk<_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`0000000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl000000000000000000?mo003oOomoogooOomo00000000ogl00000
ogooOomoogl000000000000000000?moogl00000ogooOomo0000000000000?mo003oOomoogooOomo
ogooOomoogooOomo0000000000000000003oOomo00000?moogooO`00ogooOomoogooOomo00000000
00000000ogooOomo0000000000000000003oOomo00000?moogooO`000000000000000000ogooOomo
00000000003oOomo003oOomoogooO`000000000000000?moogooO`0000000?moogooOomo00000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00?moogl00000
ogooOomo003oOomoogl00000003oOomoogl00000003oO`0000000?moogooO`00003oOomoogooO`00
ogooOomo00000000ogooOomoogooOomoogooOomo00000000ogooOomo003oOomoogl00?moogooO`00
003oOomoogooOomoogl00?moogooO`00ogooOomo003oOomoogl00000003oOomoogl00?moogooO`00
003oOomoogl00000ogooOomo00000000ogooOomoogl00000ogooOomo003oOomoogl00000003oOomo
ogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooO`00ogooOomo00000?moogooOomo00000000ogooO`00003oOomoogl00000
003oOomo00000?moogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomo00000000ogooOomo
ogooO`00ogooO`00003oOomoogl00?moogooOomoogl00000ogooOomoogooOomo00000000ogooOomo
00000000ogooO`00003oOomo00000?moogooO`0000000?moogooO`00ogooOomoogooO`00ogooOomo
00000?moogooOomo00000000ogooO`00003oOomoogooO`00003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00000ogooOomoogooOomo00000?moogl00000ogooOomoogooO`00
ogooOomo003oOomoogooOomo003oOomoogl00000ogooO`00003oOomoogooOomo00000?moogooOomo
ogooOomoogl00000ogooOomoogooOomoogooOomo003oOomoogl00000ogooOomoogl00000ogooOomo
ogooOomoogooO`00ogooOomoogooO`00ogooOomo003oOomoogl00000003oOomoogl00?moogooO`00
003oOomoogooO`00003oOomoogl00000ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogl00?mo
ogooO`00003oOomoogooO`00003oOomo00000000ogooOomo00000000ogooOomo003oOomo00000?mo
ogooOomoogl00?moogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogl00000ogooOomo
003oOomoogooOomo003oOomoogooOomoogooO`0000000?moogooO`0000000?moogl00000ogooOomo
0000000000000000003oOomoogl00?moogooOomoogl00?moogooO`00ogooOomoogooO`0000000?mo
00000000ogooOomoogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
00000?moogooOomoogooO`00003oOomo00000?moogooOomoogl00?moogooO`00ogooOomoogooO`00
ogooOomo003oOomoogl00000ogooOomoogooO`00003oOomoogooOomoogooOomo00000?moogooOomo
ogooOomoogooO`00ogooOomo00000?moogooOomoogl00?moogooOomoogooOomoogl00?moogooOomo
ogl00?moogooO`00003oOomoogooOomoogooOomo003oOomoogl00000ogooOomoogooO`00003oOomo
00000?moogooOomoogl00?moogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo00000?moogl00000ogooOomoogl00000
003oOomo00000?moogooO`0000000?moogl00000ogooOomo003oOomoogooOomo003oOomoogooOomo
ogooOomoogl00?moogooOomoogooOomoogooO`0000000?moogooO`00ogooOomoogooO`00ogooOomo
ogooOomoogl00000003oOomoogl00000003oOomo00000?moogooOomoogooOomo00000000ogooOomo
003oOomoogooOomo003oOomoogl00000ogooOomoogl00000003oOomo00000?moogooO`0000000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogooOomoogl00000
ogooOomo003oOomoogl00000003oOomoogl00?moogooOomoogl00?moogooO`00003oOomoogl00000
ogooOomo00000000ogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogl00?moogooO`00
00000?moogooOomoogl00?moogooO`00ogooOomo003oOomoogooOomo003oOomoogl00?moogooO`00
ogooOomoogooO`00ogooOomo00000000ogooOomoogl00?moogooOomo003oOomoogooO`00003oOomo
ogl00000003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooO`00ogooOomoogooO`000000000000000?moogl00000003oOomoogl00000
003oOomo00000?moogooO`000000000000000000ogooOomoogooOomoogooOomo00000?moogooOomo
ogooOomoogooO`00003oOomoogl00?mo00000000ogooO`000000000000000?mo00000000ogooOomo
00000000ogooO`00003oOomoogl0000000000000ogooOomo0000000000000000ogooO`00ogooOomo
ogooO`0000000000003oOomoogl00000003oO`0000000000ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo00000?moogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooO`00
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomoogooOomoogooOomo00000?moogooOomoogl00?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000ogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
00000?moogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo00000?moogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogooOomo00000000
00000?moogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000000ogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooO`0000000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo003oOomoogooOomo
ogooOomoogooOomoogooO`0000000?moogooOomo00000?moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00000ogooOomo003oO`00ogooOomo00000000ogooOomo003oOomoogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooO`00ogl00?moogooO`00
ogooOomo003oO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomo
ogooO`00ogooOomo003oO`00ogooOomo003oOomoogl00?moogooOomo00000?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomo003oOomoogl00?moogooOomo003oOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogl00?moogooO`00ogooOomo
ogooO`00ogooOomo003oOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogl00?moogooOomo003oOomoogooOomo003oOomoogl00?moogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo00000?moogooOomo003oOomoogl00?moogooOomoogl00?moogooO`00ogooOomo
00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogl00?moogl00000ogooOomo
ogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
ogooO`0000000000003oOomoogooOomo003oO`0000000?moogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoNbkoOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmj;_moVc:L<_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomo_3;N=WX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moVbkoOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOi/^Vc;oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`0000000000003oOomoogl0000000000000ogl0000000000?moogl0000000000000ogooO`00
003oOomoogl0000000000?moogooOomo00000000ogooO`00ogooO`00003oOomo00000000ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogooOomo003oOomoogooOomoogooO`00
ogooO`00ogooO`00003oOomo003oOomoogl00000ogooO`00ogooOomo003oOomoogooOomo003oOomo
ogl00?moogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo00000?mo
003oO`00ogooOomoogooO`0000000?mo003oOomoogl00?mo00000?moogooO`00003oOomoogl00?mo
003oOomoogl00?moogl00000ogooO`00003oO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogl00?moogl00000ogl00000ogooO`00ogooOomoogooOomoogooOomo003oO`00
ogooOomo003oOomoogooOomoogooO`00ogl00?moogooO`00ogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo003oO`00ogooOomo003oO`00003oOomo
ogooO`00ogooOomo003oOomo00000?moogooO`00ogooOomo003oO`00ogooOomo003oOomo00000?mo
00000?moogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomo
ogl00?mo003oOomoogl00?mo003oOomoogl00?mo003oOomoogl00?mo003oO`00ogl00?mo003oOomo
ogl00?mo003oOomoogl00?mo003oO`00ogl00000003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomo00000000ogooOomo003oOomoogooOomo003oOomoogooOomo003oOomoogooOomo
ogooO`0000000?mo003oOomoogooOomo003oOomoogooOomoogooO`00ogooOomo003oO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?mo00000000ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo003oO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?mo003oOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooO`00ogooOomo
ogooOomo00000?moogooO`00ogooOomoogooOomoogooOomo003oOomoogooOomo003oO`00ogooOomo
ogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooO`00ogooOomo003oOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooO`00
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`0000000?mo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo00000?moogooOomoogooO`00003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogooO`0000000000ogooO`00ogooOomoogooOomo003oOomoogl00?mo
ogooO`0000000?mo003oO`00ogooOomoogooOomo00000?moogooOomoogl00?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogl00?mo003oOomoogl00000ogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogl00?moogooOomo00000?moogooO`00ogl00?moogooO`00
ogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogooOomo003oO`00
ogooOomo003oOomoogooOomoogooOomoogl00?moogooOomoogl00?moogooOomoogooO`00ogooOomo
ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomo003oO`00ogooO`00003oO`00ogooOomo003oOomo
ogooOomo003oO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo00000?mo00000?moogl00?mo
ogooO`00003oOomo003oOomo00000?moogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000ogooOomo
00000?moogooOomoogooO`00ogooOomo00000000ogooOomoogooOomoogl00?moogooOomoogl00000
003oOomo00000?mo003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000ogooOomo003oO`00ogl00?mo
003oOomo00000?moogl00000ogooOomo003oOomo00000?moogooO`00003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogl00?moogooO`00ogooOomoogooOomoogl00?moogooOomoogl00?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogl00000ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogl00?moogooOomoogooO`00ogl00?moogooOomoogooOomo003oOomoogl00?moogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogooO`00003oOomo00000?moogooOomoogl00000ogooOomoogooOomo
003oO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomoogl00?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo00000000ogl00?moogooOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooO`00ogooOomoogooO`00ogl00?moogooOomoogooOomo
ogooO`00ogooOomo003oOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogl00?moogooOomo
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomo003oO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomoogl00?moogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo
00000000ogooO`00003oOomoogooOomoogooO`00ogl00000ogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?mo003oOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000
003oOomoogooO`00003oO`00ogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogooOomo
00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogl00?mo00000000ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomo00000?moogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogooOomo003oO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogl00?moogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00000003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomo003oO`00ogooOomo003oOomoogl00?mo003oOomoogooOomo003oOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogl00?moogooO`00ogl00000ogooO`00
ogooOomoogooO`00ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogl00000ogooO`00
003oOomoogooO`00003oOomo00000?moogooO`00003oOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomoogl00?moogooOomoogl00?moogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo003oOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomoogooOomo003oOomoogooOomo003oO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oO`00ogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooO`00003oOomoogl00000ogooOomoogl00000ogooOomo
003oOomoogl00000ogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000000ogooOomo003oOomo003oOomo003oO`00
ogl00?moogooO`00ogl00?mo003oOomoogl00000003oOomo00000?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogl00?mo003oO`00ogooO`00003oO`00ogooOomo003oO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogl00?mo003oO`00ogooO`00003oOomo
ogl00?moogooO`00ogl00?moogooO`00ogooOomo003oO`00ogooOomo003oO`00ogl00?mo003oO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00
ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oO`00ogooOomo
0000000000000?mo00000?moogooO`00003oO`00003oOomo003oOomo00000?mo003oOomo00000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00000ogooOomoogooO`00
003oOomoogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000ogooO`00ogooO`00
003oO`00003oOomo003oOomoogl00000ogooO`00ogooOomo003oOomo00000?mo003oOomoogl00?mo
00000?moogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooO`00003oOomo00000?moogooOomo00000?moogl00000ogooOomo003oOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomo00000?moogooO`00ogooOomo003oOomoogl00?moogooO`00
ogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogooOomo003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomo003oOomoogl00000ogl00?moogooOomoogooOomo003oOomoogooOomo003oOomo
ogl00?moogooO`00ogl00?moogooO`00ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogl00?moogooOomoogl00?moogooO`00
ogooOomoogl00?moogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`0000000?mo003oOomoogl00000ogooO`00003oOomo
00000?moogooOomo003oO`00003oO`00003oOomoogooO`00003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00000ogl00?mo00000000ogl00000ogl00000ogl00000003oO`00ogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo0000000000000?moogooO`00ogl00000003oO`00ogooOomo
003oOomoogl00?moogl00000ogooO`00003oOomoogl00?mo003oOomo003oOomo00000000ogl00000
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooO`00ogl00000
ogooOomoogooOomo003oO`00ogooOomoogl00000ogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo003oOomo
ogl00?mo003oOomoogl00?moogooO`00ogooOomoogooOomoogl00?mo003oOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`0000000?moogooO`00ogooOomo003oO`00
ogooOomo003oOomo003oOomo00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogl00?moogooOomo
ogooOomo003oOomo00000?moogooO`00ogooOomo003oO`00003oOomo003oOomoogooOomo003oOomo
ogl00?moogooO`00ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomoogl00000ogooO`00ogl00000003oOomo00000000003oO`0000000?mo
ogooO`0000000?mo00000000003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?mo
ogooOomoogl00000003oOomoogl00000003oOomoogl0000000000000ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00003oOomo003oOomoogl00000003oOomoogl00000003oO`0000000?mo003oOomoogl00000
00000000ogl0000000000000ogl00000003oOomoogl00000003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogl00000ogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo0000000000000?mo
ogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`0000000000ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl0000000000000ogooOomo
ogooOomoogooOomo003oO`00ogl00000003oO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogoN=_moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoW3;oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;]hfNRkoOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRkN=Y`bogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogmj;_moNbjl<WX^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOi/^_C9j;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
NRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmk;_moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoNbkoOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOgX^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo_b[oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
NRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
NRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOg/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
NRjl<WX^ogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOklZogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomo/AgoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomoCaWoOomoogna7OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOk<MogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6Omo
ogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomoCaWoOomoogm?6OmoogooOdlIogooOomo
CaWoOomoogm?6OmoogooOdlIogooOomoogooOomoogooOomoogooOomoogooOomoNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOkdb_39I:SLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV
5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHV
oglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV
5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVogod8OmoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoe24g:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHV
oglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV
5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV
=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5bKoOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogod8CLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV
=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV
5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHV
oglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXg9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglg:QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV
5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHV
oglF9QLZ5RHg:QHV5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVoglF9QLZ5RHg:QHV
5bXF9_mo5RHG:QHV=bXF9QLZ5RKoOaHV5bXF9SLZ5RHG:QHVogod9OmoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomo_3;oOomoogmj;_moogooOgX^_CII;Y/bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:L<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bW3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjm<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogm?5CLZW3:L<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;[db
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9KdbVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`b
VbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:K;Y`bVbjL<Y/^W3:L<QHV
ogooOomoogooOomoogooOomoogooOomoogooOgX^003oOomoogooOomoogooOomoogooOomoogooOomo
ogmH:QHVVbjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<Y/b5R[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoW3;oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOgX^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj:Y`b
W3;N=WX^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogmj;P00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoNRkN=W/^ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmk;Y/^ogooOaHV
Vbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`^ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi/^
VbkoOomo5RJK;W/^NRjK<WX^Nbij;Y/^NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^W3;e8OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_mo
NbkoOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RH<5OmoogooOgX^ogmj;_moNRkoOomoogmj;_moNRh00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9k;Y`^NbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOgX^gSIk;_mo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bVc8g:_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogmj;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoNbkN=W/^oglg:Y/bNRjK<W/^Vc9j;Y`^O2jL;W`ZWBim:Yd^O2jL;W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:K<QHVogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoNbkoOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomogSJK<WX^=bZK;Y/bNbjK<WX^W39k;Y`bNbjL<Y`^W39l;Y`bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;WTbMCJL;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
=b[oOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^Nbjn<Y/bFBhF9W/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<W/^N2ig;Y`bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjK<QHVogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOi`bogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNbkoOgX^ogmj;_moNRkoOkdbogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRik;[hbVc9H:SLZNbjK<WX^Nbik;TUB
AUI6ETMBBE9;BTi6D49d>WLbNS9l:Yd^O2Yk;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y/b
5RKoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkN=WX^NRhF9Y/bNRik;W/^;Rh::R/^
;2X];RlZDBiC:WH^F2ij;W/^W39k;Y/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y`^N3I3GU0n
WBik;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogooOoDU
_39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W39D;RP^MbjM<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<Y/bogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOgX^
ogooOomo5RJL<Y/b_39k;Y`^A5YPKV1ZH6iPJV1ZH6YPJT1VHF94FVUBCTId?WTbW2im:Y`^NbjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`b
ogooOomoW3:K<W/^W38[:RD^9Ri6<RH^9RhU;RH^1RhW;PTZ;Bha;WH^NBjL<Y`^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNbii<V5VP79??WdZNbjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbil;UD^
ABi8;UHZW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoCaDg:UTZ2aGd9KdbNbi5FV1ZH6YPIV1ZH6J0JV1VH6YPJV1Z
H6YPJT1V@ei8CW12N3:L;W`ZNbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9k;R`^9Ri7;RL^9bhW;TLb9bi7;RL^9RhU;RD^
1RXY;RdZDbii;Y`bNbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL;WT^PfH0Oj1bCT:M;W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;YdbEBj8=ZPjB39E;YdbNbjK<W/^Vc9j;Y/bNbjK<WX^Vc:K<QHZogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogooOomo003oOomoogooOomo003oOomoogooOomoogooO`00ogooOomoogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV_3;e9HH<m26m<TEF
P6iPJX1ZH6J0JV1ZP6YPIX1ZH6Z0JV1ZP6YPJV1^@6YRHTU>M3ik;Yd^NbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<Y`b
5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y`b:bY6<RL^
Ac8W;TPb9bi7<RL^B38W;TLb9bi7<RH^9Rh5:RT^;Rig;W/^W39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;Y`^O2Ym:W`ZN39RHP1o
07nPMTa6O2ik;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?mo003oOomoogl00?moogooOomoogooOomoogooOomoogooOaHV
VbjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<W/^W39l;Y`bO2iD:TLbbCjW>TL^<bZL<WX^Nbij;Y/b
NRik;WX^Vc9j;Y`b5RKoOomo00000?moogooOomoogooOomo00000000ogl00?moogooO`00ogooOomo
ogooOomoogooOomoogl00000ogooOomo00000000ogl00?moogooO`00ogooOomoogooO`00ogooOomo
ogooOomoogooOomo00000?moogooOomoogl00000ogooOomo003oOomoogooOomoogooOomoogl00?mo
00000?mo=bZK;[dfdb5U27XZIUYPJV1ZH6IPJV1VH6YPIV1ZH6IPJV1VH6YPIV1ZH6J0JV1ZH6Y0ITIF
DCik;W`ZVbij;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W3;e9OmoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo
003oOomo00000?moogooOomoogooOomoogooOomoogooOomo003oO`00ogooOomoogooOomoogooOomo
ogooOoDUW39j;W/^Nbh/;RD^9bhW;TL^9bhW;RL^AbhW;RL^9bi7;RL^9bhW;TLb9RhU;PHZ;2iD:Y`^
O2jK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
W2il:Y/^McIb?T]:IeYRH/1f07lPO`1o`7Y:BY`^O2jK<WX^W38F9_moogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogooOomo003oOomo
ogooOomoogooOomoogooOomomRFl<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNbjL<Y`^NbiG;U<^;Ri<;RP^
R3K9>/TjZ3Y7<S8ZWC9k;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogl00?moogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomo
ogl00?moogooOomo003oOomoogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00oglh:Y`bNbjm<XH8L1eWFV1^H6J0JV1ZP6YPIX1ZH6Z0JV1V
P6YPJX1ZH6J0JV1ZP6YPJX1ZH6YPJTEFLcil;Y`^NRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogl00?moogooO`00ogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNbjL<R/Z9RhW;TPb9bi7<RL^B38W;TLb9bi8<RL^
Ac8W;TPb9bi7<RL^Ac8V;RH^;2Yg;Y`^W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjL;W`ZNbiD=Te:AEZ1KZ1fh7kPOP1o07l0O`1o07l0Ol1jB4ik;W`^Vc:K;QHV
ogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogl00000ogooOomoogooOomoogooOomo
003oOomoogooOomoogooO`00ogooOomoogooOomoogooOomooglF9Y/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`b
O2ij;S@Z;bhZ;TPbIS:W=ZLjbCZY>/TjZC[9>ZPjAS8a:Y`bNbik;WX^Vc9j;W/^NRjL<QHVogl00?mo
ogooOomoogl00?mo003oO`00ogooOomo003oOomoogl00?moogooOomoogl00?moogooOomo00000?mo
ogooOomoogl00?moogooOomoogooO`00003oOomoogl00?moogooO`0000000?moogooO`00ogl00?mo
ogooOomoogl00?moogooO`00ogooOomoogooO`00ogooOomo003oOomoogm315PZVbik;[`bCQV626IJ
H6YPJV1VH6YPIV1ZH6IPJV1VH6YPIV1ZH6IPJV1VH6YPIV1ZH6IPJV1ZH6Y0ITUBN3:M;WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`b
mBGoOomoogooOomoogooOomoogl00?moogooO`0000000?moogooO`0000000000ogooOomo00000?mo
ogooOomoogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogoe9I`bNRjK<W/^;2hV;TL^
9bhW;RL^AbhW;RL^9bi7;RL^9bhW;TL^9bhW;RL^AbhW;TL^9bhV;PHZ;bij;Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
;AWoOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bO2jM;WPbCdIUFZ1b`7h0O`1o87l0O`1o07l0O`1o
07l0O`1o07o0OTMFVS9k;Y`b5RKoOomoogooOomoogooO`00ogooOomoogooO`00ogl00?moogooO`00
ogooOomoogooO`00ogl00?moogl00000ogooOomoogooOomoogl00?moogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc:L;Y`bERi@;RT^Ic:7=/PjbC[9?/TjbCk9>/TjZC[9>/TjbC[8>VLb<2ZL<W/^
Vc9k;Y/bNRjK<Y/b>2YT2?moogooOomoogl00?mo003oOomoogl00?moogl00000ogooOomo003oOomo
ogl00?moogooOomoogl00?mo003oOomoogooOomo003oOomoogooOomo003oOomoogl00?moogooOomo
ogl00?mo003oOomoogl00?mo003oOomoogl00?moogooOomoogl00?moogooO`00ogooOomoogooO`00
ogl00?mo=bZL<WX^_3;d8D<48eJ0KV1ZP6YPJX1ZH6Z0JV1VP6YPJX1ZH6J0JV1ZP6YPIX1ZH6Z0JV1V
P6YPJX1ZH6Y3HW8nWBik;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogl00?moogooOomoogl00?mo003oOomo
ogl00?mo003oOomoogl00?moogooOomoogl00?mo003oOomoogooOomo003oOomoogooOomoogooOomo
ogooOaHVVc:K<W/^W38[:THb9bi7<RL^B38W;TLb9bi8<RL^Ac8W;TPb9bi7<RL^B38W;TLb9bi8<RL^
Ac85;RX^MbjM<W/^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`^O2Yg=T]:PVK0NP1o
07l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o`7i6DW/^W2hF9_moogooOomoogooO`00003oOomo
ogooO`00003oOomo003oOomoogl00?moogooO`00ogl00?moogooO`00ogl00?moogooOomoogl00000
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^W39k;UD^;2Y7<XHfb3[9>/TjZ3[9>ZTjbCZX>/Tj
ZC[9>ZPjbCZY>/Tjb3YU<RlZW39j;W/^NRjK<WX^W38h:_mo003oOomoogooO`00003oOomoogooOomo
003oO`00ogooOomo003oOomoogl00000ogooO`00ogl00?moogooO`00ogl00?moogl00000ogooOomo
ogl00000ogl00000003oOomoogl00?moogooOomoogl00?moogooO`00ogl00?mo003oOomoogooOomo
ogooO`00003oOomoogooOomoogl00?mooglF9Y/^Vc:K;QLV8P3RCF1V@6I0HV1V@6IPJV1ZH6YPJV1Z
H6Z0JV1VH6YPIV1ZH6IPJV1VH6YPIV1ZH6J0JV1Z@6I<AY`^Nbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogl00000
003oOomoogl00?moogooOomoogl00000ogooO`00ogooOomo003oOomoogl00?moogooO`00ogooOomo
00000000ogooOomoogooOomoogooOomomBFL<WX^Nbik;Rd^1RXX;PLZ9bh5:RH^1BhV;RH^9bhW;TLb
9bhW;RL^AbhW;RL^9bi7;RL^9bhW;TLb9Bh7:U<^W39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Yd^NC9]BX5Zh7h0Ob1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o87n0KW92NbjL<QHV
ogooOomoogooOomoogl00?moogooOomo00000?moogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<W/^WC9F;R`^AS:X>/Tj
bCk9>/TjbC[9>ZTjbC[9>/TjZC[9>/TjbCZY>/TjbC[8>TL^MBik;Y/bNRjK<W/^Vc:K<_mo@PCoOomo
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomo003oO`00ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomoogooOomoogooOomo
ogooOomo003oOomoogooOomoogooOomoogl00?moogooOomoogl00?moogooOaHVW39k;Y`b>2Y21?8Y
Ucie=WHjM3Yb@Tm2K4i9DTEJ@F9PIV1ZH6iPJX1ZH6Z0JV1VP6YPJX1ZH6J0JV1ZP6YPJV1ZBTjL;W/^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo003oO`00ogooOomoogooOomo
ogl00?moogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNBih;WP^
N39F;WH^DbiA;Rh^;2h8:RL^9BhV;RH^Ac8W;TLb9bi8<RL^Ac8W;TPb9bi8<RH^9RiB;YdbNbjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9k:W`^D3iSH/1j07l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o
07l0O`1o87n0KU4nOBZK<Y/^5RKoOomoogooOomoogl00000ogooOomoogl00?moogooO`00ogooOomo
ogooOomoogl00?moogooOomoogl00?mo003oO`00ogooOomoogl00000ogooOomoogooOomoogooOaHV
Vbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;W`^NRh^:TLbYcK9>ZTjbCZY>/TjZ3[9>ZTjbCZX>/TjZC[9>ZPjbCZY>/TjZC[8>RL^EBil;W/^
NRjK<WX^Nbij;Y`b=b[oO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogl00000ogooOomo
00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogooOomo
003oOf@4=bZK;W/^VbiH:R40mRFM;Y`^O2ZL;W`ZWBil:W`^NRih=U<jKTI8DT9N@6IPJV1ZP6YPIV1Z
H6IPJV1VH6YPIV1ZH6IPJTY>W2ik;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^W3;e9OmoogooOomoogooOomoogl00000ogooOomo00000?moogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomo00000?moogooOomoogooOomo
ogooOoDUW39j;Y/bNRjK;W/^W39k;Y`bO2jL<W`^W39k;WX^ERiC;RdZ:Bh5:RD^9Ri7<RL^9bhW;TL^
9bhW;RL^AbhV;PH^DRZL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9l;WTbBDjPMP1o87l0O`1o07l0O`1o
07l0O`1o07l0O`1o07l0Ob1o07l0O`1o87n0LU12OBZK<W/^W38F9_moogooOomoogooOomo003oOomo
ogooO`00ogooOomoogl00?moogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<W`^EBhY;XLfbC[9?/TjbCZY>/TjbC[9>ZTjbC[9>/TjZC[9>/Tj
bCZY>/TjbC[9>TH^E2jL;Y/bNRjK<W/^Vc9j;Y/bVc9H:T84ogooOomoogooOomo00000?mo003oOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooO`00ogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogl00?moogooOomooglF9Y`bNRjl<QHZ8P@F9[`bNbjK<WX^Vc9k;Y/bNbjK<W/^
WBil:Y`^NC9c?T]>Hei0IV1^H6Z0JV1ZP6YPIX1ZH6Z0JV1ZH6Y=AYd^NbjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L<QHVogooOomoogooOomoogooO`00
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooO`00ogooOomo
ogl00?moogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<W`^
W39j;WH^;bXY;PD^9RhW;TPb9bi7<RL^B38W;TLb9RhV;UD^W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9l:WHf
A5kPOP1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o87l0O`1oh7h0O`1o87n0LTi6O2ZK;WX^NbjK;QHV
ogooOomoogooOomo00000?moogooOomo003oOomoogl00?moogooOomoogooOomoogl0000000000?mo
ogooOomoogooOomoogooO`00003oOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjK;W`^<BhV;ZPjbC[9>ZPjbCZY>/Tj
Z3[9>ZTjbCZX>/TjbC[9>/PjbCZY>/TjZ3[9>TH^Dbil;W/^NRjK<WX^Nbij;Y/bNRjL<SLZogl00?mo
ogooOomoogl00?mo003oO`00ogooOomoogooOomoogooOomoogooOomoogl00?mo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00003oO`0000000?moogooOomoogl00?mo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogl00?moogooOomoogooOaHVVbjK<Y/^mBDR15P^
Nbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;W`ZWBii;W8nAe90IT1ZH6YPIV1ZH6IPJV1VH6YPJT1V
DSjM;WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`b
mBGoOomoogooOomoogooOomo00000?moogooOomoogl00?mo003oOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomo003oOomoogl00000ogooOomoogooOomoogooOomoogoe9I`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y/^O2jL<WT^E2h/:RL^1BXW;RL^AbhW;RL^9bi7;RH^22Yh;Y`b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9m:W@jHVH0O`1o07l0O`1o07l0O`1o07l0Ob1o07lPO`1oh7jPMX5^I5j1KP1o
87nPMTe:O2ZK<W/^Vc9j;Y`b5RKoOomoogooOomoogooO`00ogooOomoogl00000ogooO`00003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOoHU
_39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<W/^
;biV</TnbC[9>/TjbCZY>/TjbC[9>ZTjbCk9>/TnZ3ZW>VLbJ38X;XPfbC[9?THbDRjL;Y/bNRjK<W/^
Vc9j;Y/bNbjK<Y/bogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<W/^_CI_6HD8Vc:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y`^O2ZL;WDj
BU90HV1^H6Z0JV1VP6YPJX1ZH6Y4GWXbW2ij;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9l;Y`bMbh^;PHZ
9RhW;TLb9bi8<RL^B38U;Rh^W2jK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9l:WDfHFH0O`1o07l0O`1o07l0O`1o07l0O`1o
h7k0NV5VIeY<AW<nF2ih<V=R87nPNT]:O2ZK;WX^Nbij;Y/bVbhF9TdEogooOomoogooOomoogl00?mo
ogooO`00003oOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo
ogooOomoogooOomoogooOomo5RJK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;W/^;biV</TjZC[9>ZPjbCZY>/TjZ3[9>/TjbCZ7=VLfAbi;;RhZDbiG;U@^
Ac;Y?VHb<2il;W/^NRjK<WX^Nbij;Y/bNRik;WX^W38F9_mo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
00000?moogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoCaDF:Y/^Nbjl<ZL<;1Fm<WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W2il:WDjAe90JV1ZP6YPIV1ZH6J0JT1ZCTIl:Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<_DUogooOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo00000000ogooOomo
003oOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRjL<W`^MRh;:PD^9Ri7;RL^9bhW;TLb1RYf;W/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9RdIogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9l;WPb@V80O`1o
07l0O`1o07l0O`1o87l0Ol1jHFYYEU4nN3Ik;Yd^O2jM;WT^Pf[0OTUBNbZL<WX^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomo003oOomoogl00?mo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<W`^DBiV</TnZC[9>/TjbCZY>/TjbC[9?ZPj
QcI8;Rd^<RYh;W/^W39l;YdbEBj7=VHf;bil;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:K<QHZogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW3:L<SLZ@`AH;Y/b
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bO2jL;U12@f9PJX1ZH6J0JV1Z
P6Y3FYXbNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<Y`b
5RKoOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L;Y`bDRhX;RH^B38W;TPb9bhV;RhZ
W39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9k;W`^AU;POP1o07l0O`1o07l0O`1o07nPLVENCd9h<W`ZWBik;Y/^NRik;W/^NC90HTMF
NbjL;WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOaHV
VbjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;W`^EBi6;/Tj
ZC[9>ZPjbCZY>/TjbCZW>THb:bha:WP^NbjL<W/^Nbij;Y/bNbiE;R@^CRik;Y/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;Y`b5RKoOomo00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooO`0000000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<WX^QPR@7I`bVc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;W/^WBig<TMF@6Z0JV1VH6YPJV1VDSZL;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W3;e9OmoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NbjM<UL^:RX5;TLb9bhW;RH^:2ih;Y/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Yd^D3k0NR1o07l0O`1o07lPO`1o`7YUFW8nNRjM;W`^
Vc9j;Y/bNbjK<WX^W2ig=TUBNC:L;WX^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomomRFl<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<W/^Vc8Z;/PjbC[9>/TjbC[9>/XnZ3YW<R`ZEBik;YdbNbjK<W/^Vc9j;Y/bNbjL<U@^
;2ik;Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglG9WX^jQ2A7I`bVc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9j;Y`^Nbi[CT1VP6YPIX1ZH6Y/BW`ZVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W39j;Rd^9Bi7<RL^B386;WD^O2jK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WXZNbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NBiSHP1o07l0O`1o
07lPOl1jHf9@?W/^O2ZK;WX^Nbij;Y/bNRik;WX^Vc9j;WXbNRjL;WX^Nbij;Y/bNRik;WX^Vc:K;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Nbij:W/^NRjK<WX^Nbij;Y/bNRik;WX^W38a:VHfbC[9>ZPjbC[9>/TjIS8Z;U@ZW39l;W/^
NRjK<WX^Nbij;Y/bNRik;W/^NBii;Y/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogm?5CLZNRiI;Y`bVc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL;W`ZCDY0IV1Z
@6IPJTMBW2ij;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`bNbh];PDZ9bhW;RH^
<BZL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^^cZK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bO2Y`@/1j87l0O`1o07l0Oh1bBdii;Yd^NbjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNbjL<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:K<[/jNRjK<W/^Vc9j;Y/bNbjK<WX^W39j;TT^Z3[9>/Tj
bC[9>ZPj9biA;W/^WC9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<Y/b5R[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<W/^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vbil:Va>H6ZTKV1ZIEYk;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjL<W/^CBi9=TPb9Bi@;Y`^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRik;WX^Nbij;Y/bNRik;WX^Vbij;W/^NRik;WX^NbjnKaa;FRYk;WX^Vc9j;W/^
NRik;WX^Nbij;Y/bNRik;WX^Vc9j;W/^Nbik;TEF07l0O`1o07l0Of5VDSil:W`^NRjK<WX^Nbij;Y/^
NRik;WX^Nbij;W/^NRik;WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRik;WX^Nbij;Y/bNRik;WX^Nbij;W/^NRik;WX^Nbij;W/^NRik;WX^NbiJ:Qa;_Vmk;WXZNbij;Y/b
NRik;WX^Nbil;U@^IS;9>ZPfbC[9>XLf2RYG;W`^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;W/^NRik;WX^Nbij;W/^NRjK<WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vbij;W/^
NRjK<WX^Nbij;W/^NRik;WX^Nbij;W/^NRik;WX^Nbij;Y`^FB[@F[UoP6hSFW/^NbjK<WX^Nbij;W/^
NRik;WX^Vc9j;W/^NRjK;WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRik;WX^Nbij;W/^NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRik;WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK;WX^Nbij;Y/bNRik;WX^Nbjl?[acB38U:RhZW39j;Y/bNRik;WX^Vbij;W/^
NRik;WX^Nbij;W/^NRik;WX^Nbij;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;W/^
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/^NRZK<WX^Nbij;Y/bNRYk;W/bNbij;Y/bNbik;WX^Vc9j;W/^NRjK<WX^
Nbij;]mco4Yj:WX^Nbik;Y/bNRYk;W/bNbij:Y/bNbik;WX^Vc9k;W/^NRjL;UHbP6X0O`1o07oPOT=N
MSIm:Y/bNRik;W/^Vc9j:Y/bNRjK<WX^Vc9j;W/^NRjK;WX^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRik;WXZVc9j;W/^Nbik;UXZVc9j;W/ZNRjK<WX^Nbij;Y/bNRjK<WX^
Vc9j;W/Z74_OLgXZVc9j:W/^NbjK<UXZVc9k;W`Z;RZW>/TjbC[9>XLf;BYj;W`^Vc9j:Y/bNc9k;WX^
Vc9j;Y/bNbjK<WX^Vc9k;W/^NRjK<W/^Vc9j;Y/bNRik;WX^Vbij;Y/bNRjK<W/^Vc:K<_moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Nbij:Y/bNRik:W/^NbiJ:Y/bNRik:WX^Vc9j;W/^NRjK<WX^Vc9j;Y/bNRik:_e2
ngmPJTAJNRYk;W/^Vc9J:Y/^Nbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRZK;W/bNbij;Y/bNRjK<W/^
Vc9j;Y/bNbik;WX^Vc9k;Y/bNRjK;WX^Nbij;Y/^NRjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRYk;W/^NbiJ:Y/bNbik:WX^Vc9j:Y/^NRjK;WX^Vc9j;W/^NRjK<WX^Nbij:]e2gWLX<PDZ
;RYl;Y/bNbik;WX^Vc9j:W/^NRjK<WX^Vc9j;Y/bNRjK<WX^Nbij;Y/bNRik;W/^Nbij;Y/bNbik;WX^
Vc9j;W/^NRjK<W/^Vc9j;Y/^NRik;WX^Vbik;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;W/^NRiMFkmcgg=mHk/jFRKlBYi[_fmnHk/f
FR[L?UeOVc9J:Qe??EMk;UXZGE_lBWXZWV]nHiiW_folBWX^NRZk>WiS_fnNJoa6FRZK<WeOg3iJ:Y/b
OV>l>U/V]dJENmQoegm/Ob9JfDYOEgX^FRXMBeeKNRij:SeG_W<mDeXZNbjJ<Yi[WVNoJii[_fnk>W/^
NRik;WX^Vc9j;W/^NRjK<Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
Vbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRik:[/n_V^oLkm_74mk;WXbOV>nKkm_
74]k;WXZGE_lAWXZNS9nHk/jNRZk>WiSNRklB[icGUnnKiiWVc9k;WXZ?E>nKkm_GE];<XHb<5=eGfHb
3BHMCeiKNRYj:SeG_VnoKgiW^cYj:WiOfd9j:WX^OV>k?WXZ^cZoKii[^cYj:W/^Vc:NIii[_f^NJeeK
NRZK;WX^Nbij;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOdlE5RZK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Nbjk>Yi[_g>oKceCNbij;WiO_VnoKaa?NbiJ:UeK
74mk:WX^OV>k?WXZVcInHgX^oD:jOe5gVGNNIi/fNRiJ:Qe?WVnoKeeOVc9J9_a6GEmk;UXZo4YMFg/^
FRXmDki__fnNIm`nFRYNGoa6NRYj;WiOfd9j:Y/fWf^nKk`nNRYk:_a6_fnNIkm_WV]NGgX^Nbij;W/^
NRjK<WX^Nbij;Y/bNRik;WX^W3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/bFRZk>WiSgg>nKeeKNRik;SeG_fnNJceGNRYk:QaC?E=J:W/^
GEolAUXZVcImHi/b^ckOMcIKVFmkIk`jFRYj:_a6_fnNKgiSVcIj:[/nOV=j;W/Zfd9NGgX^Nb[lB[m_
WV^OJm]2FRXmEae?FRYk;UeKo4YJ9Y/fOVNoLm/nNRYj;Y/bGEnoJii[_f]MGi/bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RH]6OmoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNRZNImmk
7D_L@WiS?E>l?_mo?E>k=YmW_fmk:_a6og]k;W/ZGE^oKgXZNbjoKeiKFRJoLmmgo4HLBomo^cik;[mc
WVNk=SeCog^l>WX^og_lAW/ZVc;oOm`nNbkOLk1o9Gm7OlaVEc8nCmmcNRYk:UeKgg=J9[`joglMCk/j
Vc9j;Y/^WV_oOoa6o4KlAY/fNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRik;]`n
ogmnGoa2o4ZOJi/fWVNoLk`no4KoOoa6FRZoKeeGFRJK=]mgo4IJ9_a6og^K<_a6ogmMFk`j_VnOJeXV
7DooOoa:^cZoLgISQS9CFkU_3BYk:UiO_fmJ8SeCggOL@[/j7D^k>W/^ggLMCeXZVc;oNoa6FRInHkm_
g3jK<Y/bNbjK<[/n7DooOoa:^cZK<W/^Vc9j;Y/bVc8F:_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^Nbjk>_moOVOl@_a:
WV^k>WiOggOL?]a2og/MCeXVWV]nGeXZVc;ONoe6FRKL?_mkVc;L@_moDg>8GYiW_fmJ9_a6oglMCk/j
_f^NIeXV74ooMgX^NbXmDmmcFRHMComko4Jk>_e:^cik:]mc?EMJ9Y/bggLMCcXRGUoOLm`nVcJK;WXZ
g4;oOiiWg4;mB]a2Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L<QHVogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjl>_mkWf_L@_e:WVOL?SeG
og_L?]a2ggLmEeXRWVMnHg/ZNRkOMae?NbZK=_moVcJl?_moWVM;=UISgg=k;[/noglMCk`jOV>oKeXZ
o4[ONi/bFRXMCmmcNb[L@_moo4Jl>_a6g49J9[m_GE]k:WXZgg<mDeXV7E?oNm`n^cIj;Y/bNbkL?_a6
oglMDk`nNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bFR[L@_mog3iJ9WXZFRYj:UeK_f]J9WXZNS;oNk/jg4:oLi/bFRIMFgiWNRYJ:[m_
?E=J:[mc7Dlj8UXVWV]MFi/fog^K<WXZFRJNJeeKNbZoLoa6FRZK=]mg^c[M?]ao`7XPOh1^DSYL8Qe?
_Vmk;UXV?ENNJeXZ^ckOMgXbNbYj;W/^NRik;YiWOUmJ9WXZNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK;UXZ_V^NIeXVFRYj:UXZ^cKONma2FRIJ9UeKWV]J9[m_75=J:Y/bggOK?UXV
g4;OMgX^o4ZoLg/^FRKL?]mkVc:NIgiO>R9J:[`joW_8>U9KO6Mi:U/VGU^NIeXV_VmMEeXVVc9j:W/^
NRjoLoa:NRYj;]mgg49J9WiWGE]J9W/^NRik;WX^NRZk>_mkVc9k:WX^Nbij;Y/bNRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVVbjK<WX^Nbij;Y/b
NRik;WX^Vc9J:YiW_Vmj:UXZNRYJ:Y/bggOlAUXVFRHmDkm_FRJNJeeKFRYj;]mgg49J:[/jggMj;]a2
gg=8DP1F^c[oNi/fOEmnIeXVNRZK=_mkVc8MBkicNbiJ:SeCWV]J9YiWOUmJ:Y/bNRik;UXZ_g<LCgXZ
NRjoLoa:FRImHgiO>R9k;WX^NbiJ:]a2ggOL@SXRNbij;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRik;WX^Vc9j;W/^
NRij:UeKggMJ:WXZFRYj:WX^ggLLBeXVFRHMCkmcFRYnHgiSFRIk;[mc7DmJ9Y/fggNk=[/jog^K<^LQ
;2koNk/jGU^NJeXVFRZK=]mk^ckL@]mgNRiJ:_a:_g=J9WiSOVMj:WX^Nbij:W/ZWV]MFeXVNbjNJceC
>R9NFiiWFRIj;Y/bNRik;UXZVc;OMm`nFRJK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbik:SeGogMj;Y/^NRjK<UXZOV=nHg/ZNRjK;]mg
o4KL@]mcNRik:SeGWVMJ:W/^WV]MEeXVgg?lAW/ZFRJNIgiOg3kOMi/bNRij:WiSWVMj:]mgg49k:Y/b
og^k>_e6oGnfOkEoVW>oJi/b74noKgXZNRXmEkm_FRKL@]mg^cIj;Y/bNRjK<WX^VbjoLgiOFRZK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOoHU
_39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc;OMae?FRZK<WX^Nbjk>_mk^cYk;UXZ
?E>oKg/ZWV/mDeXVVcKOLma2FRKlA]mgVc;lB[m_NRYk;[/fog^k=[m[?E=k:WX^_3KoNnY245>oJg/Z
NbYMFkm[FRJoLkmcWf^NIkmc?E=k:[mcoDYJ:Y/bggOlAUXVWVMMFg/ZNbjK<WX^Vc9j:]`nog^l>WX^
Vc9j;Y/bNbjK<Y/b=b[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/^gg<mEeXZVc9j;W/^Vc;oNm/nNbiJ:Qe?_g=k:YiW
GU]J9Y/bggOl@UXVg3kOMi/bg4;NNf9VHejK<_mk^cZNIeeKNbYj;Y/fggOL?_a:gg=j:W/Z7E>oKeXV
_f_OLim[WVNoKceGNbZoKceCFRYk;[m_7DmJ9WiSOUmk:W/^Vc9j;Y/bFRKlB_mog3ij:Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<WXZ_fmMFg/ZNbjK<WX^Vc;OMoa6FRYk;]a2og]j;WiSOUmk:WXZ
gg<LCgXZVcKoNi/fg3kOMgHb9BY>;]mgo49MGgiSFRZK<W/^ggOL@_a6gg>K<UXZ7DnoLg/ZOV?OMiiW
Wf^nKgiOFRJoJceGNbYj:[m_7E=J9UeK_f]J:Y/bNbjK<WX^VbjK=]mgg49k;W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;UXZGE^nKgX^
NRjK<WX^NRXLDmmgFRYJ9[/jognK=]a2og^k>STNGUoOMg/^FRJoLceCFRZnLeeK>R9J:[i_?EMj<_mo
^ciJ9UXZgg<mEgXZggLmDcTRVcKoNk/j_3[mOn9nA5[L@_moNRhMCmmgVc8i8UiOWV]J9[/jggMj;WXZ
NRjK<WX^Nc9J:[/fog_lAUXZVc9j;W/^NRjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK<_mo
g4Ij:WX^Vc9j;W/^ggLMCcTRFRInIiiWFRJoKgeOFRIj<_mo74lj8]a2og]j:_a:gg^K=STRo4KONg/^
GEnoJeXVFRKmA_ioIRkCC]mgVc8i8WiSWVMJ9WiWOV=J9WXZWVmMFeXVggLmEeXRVS;oNm/n>R9nHeeK
>B9k;WX^Vc9j;WX^^ckoNi/fNbij;Y/bNRik;WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoCaDF:Y/^Nbij;Y/bNRik;WX^Vc9j;W/^NRkOMoa:NRYj;Y/b
NRik;[mc?ELi8UXVGEnoKcXRWV^NIeXVNRkoOaeC>R:k?_mkNRkM@]eo0glPF]`nog^K<SeG_g=J9UXV
g4;oOgX^o4[ONi/f>AiMFii[FRIMGiiWFRYj:Yi[OV=J9[mcGEmJ9WX^og_lASXRGEmnGcTRNbij;Y/b
NRik;UXVGENnLg/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^NbjoLceGFRIk;WX^NbiJ:[m_
GE]J9SXRGENoLeXVGEnoKeXVNR[OMeiO>R:k>_mkVcJk>_moSci3:VhfognK=Qe?gg=k;STR^c[oNk/j
fd;oOk/j>R8LCkmcFRIMFii[NRYJ9WiSWVMJ9Yi[WVMJ9WXZ_g<MCcTNGE^NIeXVNRYk<WX^Vc9j:Y/f
ggOL@UXZNbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^NbXLComkNRjK<W/^Vc9j;Y/b_fnoJceGogMnHeXZg4;oOii[GU_oNkm[WVMnHomo
g3ij:[mcggMnGgiSog^K=W/ZGEOoNceG_f_OMi/fNRkoMmmgGUnnKmmcNbik:UaSeGodG]m_GE]J9Qe?
ognNIeiKoglMCgX^OV?oNgiOo4Ik;W/^Vc9j;Y/bFRINGii[Nbik;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bgg/mDeXVVc9k;Y/^FRXMComkGU]nHomo^cij:Yi[og]NGim[gg>oJeeK
ggMnHeXVo4[oOii[GU_oNgiOFRJl>]mgWVLmEomo<EL89Q]?ognNIeiKoglMBeXVg3kOMeiGGE_OMi/f
NbkOLomgGEnoKmmcVbkLA]mg_fmMEi/fVbik;Y/^FRKL?_mk^cYj;Y/bNbjK<WX^Vc:K<QHZogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39j;Y/bNbjK<WX^
Vc9k;Y/bNRik;[mcGU]J9Y/bNbjK;UXZoD[oNeiOGEooOma2FRJNIomoOUnNImmg_fmMGmmcWVMk:]a2
oWoFOe=cggNNHeXZVcKOLii[?EOoNeeOFRHLBomoWVMNFomo?E=J9[`jgg=NFceGog^k?W/Z_fooNeeO
Wf_OMi/bg3kOLkmcGENk>W/^NbjK<WX^Vbik;_mko4Yk;W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<Y`b
5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9J:[m_OV=J:WX^Vc9j;W/^g4;oNeiOGUooNae;FRInHomkWV=nHomkWV]nHkm__fmJ:]e2ogniKeAK
^gNOJg/^NRjoLii[?EOOMiiSFRKlA_mo_f]MFomo?EMk:Y/fgg=MFceGggOlAUXV_f_oNgiSOV?oOi/f
g3joKomg?EOL?WX^Vc9k;W/ZVc;oNma2Nbij;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j:[/fogolBSXRNRYj:Y/fNRZK<Qa?GUolBW/^
NRZk>]a2g3iMFae;FR[lBUeKg49J:W/^o4Jk>QaCGE^k>W/^NRij;_a6GUlmDi/fNRZK<_a6^cXmDeeG
VcIk;W`ZCDK:JUeOoDYk;UXZ_3kL@]a2?E/LBgXZVc9MGomoGE_lAWXZNbij;Y/bFRYJ9Qa?og]j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
VbjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bFRINGkmcNbYJ9UXZNRjK<UXZg49MFeeK
^cYj:WX^o4Jk>Qe??E^k=YXbGE/mDi/bFRZk>]a2g3iMFae?NRik;UXZVcHmDeiOfT86:RhZgSkK@]a2
GE_lBWXZNbiJ:[`n?EMMFk/jNbij;_a6^cXmDceG^cYJ:_a6gg>oKceCVcIj;W/^VcHMCk/nog^K=W/^
NRik;WX^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<UXZGEOOMg/^FRIJ:WX^Vc9J:]`n?EMMFk/nNRYj;_a6
^cXMCeeK^cYj;UeK?ENL<UXZRUY7OdIoDW<MCg/^NbiJ:Y/b?E=NGoa6Nbij:[`ng4;L?UeK7D]j;W/^
FRZk>SeGGE^k>W/^NRklA[/j7E<mEk/jFR[L@[mcgg<mDk/jNRYk;WX^NbiJ9UXV_g=MFeXVNbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;W/^NRjK<WX^Nbij;WXZ74ooOiXbFRYJ9W/^Vc9k:[/jGEMMFma2FRYk;]a2g3klAUeK
^cYk;SeC?ENK=W`^NC;>A/]2M5ofDY`bNRik;WXb?E=MFae?NRik;[/jo4Jk>UeK74mk;WX^NRjK=UeG
?E_L@UXZNbkL@[/jo4YNFk/jFRZk>[mcggLmEk/jNbij;Y/b74nk>[mcg49J:Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bFRXmEomo
GE/LBkm[?EMk:WX^NbYJ:W/ZNRjK<WX^Nbij:W/ZNRZK<WXZNbYj:Y/bNRik;WX^NbYJ:W/^NbjK<WX^
NbiJ:W/ZNRjK<W/^Nbij;W/ZFRYk;WX^WBi=AR1VDCYm:WX^Vc9j;W/^NRYk:UXZVc9j:[`j_VnK<WXZ
Vc9j;Y/bOV=NFaa;og]nHg/^NRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomomRFl<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbik;Y/b
ggNnKae??ENoLk/fNbij:W/ZFRYk;WX^Vc9j:W/^FRYk:WX^NbiJ:W/ZNRjK<WX^Nbij;W/ZFRZK<W/^
Vc9j;W/ZNbYi:PHZ:Rik;W/^NRYk:WXZVc9j;Y/bNRik:UXZNbik;Y/bNRYk;WXZNbYj;Y/bFRInGceC
FRIj;Y/bNRjK<WiSggOoOk`jNRjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y`bNbjK<WX^Vc9k;Y/bNRjK<W/^Nbij;]mc_flMCceC
gg>k>W/^NRYk:UXZNbij;Y/bNRYk;UXZNbYj;W/^FRYk:W`ZBdjPNP1o07mSGUXVVbik;Y/bNRik:UXZ
NbYj;Y/bNRik;WXZNbYj:Y/bNRjK<WX^NbYJ:W/^NbjK<WXZNbij:W/ZNRZK<UXVGU/mEeXVNRjK<WXZ
o4JnJae?GE_oOma2Nbij;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbik;Yi[ggLMCceC_fol@WXZ
NbiJ:W/ZNRZK<WX^Nbij;W/^FRYk;W/^NbYJ:Y`^Nbh/:VHbbCZ5<RhVO2jK<W/^NbiJ:W/ZNRZK;WX^
Vbij:W/^FRYk:W/^Vc9j;W/^FRYk:WXZVc9k;W/^NRYk;UXZNbij;U/Z?E=nHeXRVbik;Y/bNRiNGmmc
ogoL@W/^NbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRik;UXZo4YnIkm_?E^K=WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9l:Ti6@6Y6FW/^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK=WX^Nbij;Y/bNR[L@WiS_flmFi/bNRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
CAGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^NbjK<UeKWV^NIoa6Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjK;WT^22X5:U<^O2jK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/bVc9j;W/^NRjK<WX^NR[lBWiSVS9k;WX^Vc9j;W/^NRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogm?5AHZVbik;WX^Vc9j;W/^
NRjK<WX^Nbij;W/^NS9MFii[WV_lBW/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL;W`ZC4ZPMR1o
07l0OfMFO2ij;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^NbjK<Y/bNRik;WX^Nbij;SeCWV^NJoa6NRij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc8mDki[WVLMCgX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`bNbh]:VHfbCZY>XLf
<2ZL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRjK<Y/bNbij;W/^NRik;UXZo4InHk/jNRYk;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
;AWoOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9J:W/^NRYk:WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Yd^CDIPKT1ZL49m:Y/bNbjK<WX^Vc9k;Y/bNRjK<WX^Vc9j;Y/bNbjK<WXZNbij:W/ZNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;W/^FRYk;WXZNbij;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<W/^NC88:RHb2BZJ<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vbij;Y/bNRjK<W/^Vc9j;W/^NRZK<WX^
Vc9k;Y/bNRjK<Y/b5R[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbik;UXZNbij:W/ZNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjM;W/^BTjPMR1o07lPOl1nK4im:Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNRjK<WX^Vc9k;Y/bFRYk;WXZNbij;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9j;W/ZNRYk;WXZVc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y`bNRh/;VHfjCk9>/TnIS9E;Y`^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vbik;Y/bNRjK<W/^Vc9j:W/^NbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^O2Y^AT1ZH6Y1GWLfO2Yk;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9i;RP^9RhV;RdZW39k;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NbjM:ULbAUK0NR1o07l0O`1oX7IB>Y`^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK;WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbik;YdbEbXZ;XHfbCjX>/Tjb3Y8;UP^Vbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjM;U12H6YPJV1^AEZJ<W`^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;WXb2BY7<RL^9Rha:YdbNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bO2ZL;U0nPVKPOR1o07l0O`1o
07mTGWXbNbjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9l;Y`b<RY8;ZLfbSk9>/TjbCZW>Rh^
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<W`ZLci0IX1ZH6IPJTIBNS9l:W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
Vbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRh[;RH^9bhV;PH^
<RZL<W/^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOdlE5RZK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9k;WXbNC:K;WX^Nbij;Y/bNRik;WX^Vc9j;Y`^
O2Yd>TIFX7H0Ob1o07l0O`1o87nPMTm2O2ZK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^W3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<W/^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^W39l;UH^
:bYV<ZPjbCZX>/TjZC[9>RL^Ebik;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W2ig=V5RH6Z0JV1ZH6i6EWTbO2ZK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjL<RhZ9RhW;TPb9bhV;S0ZW39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bVc8F:_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/^BDie>W`^
Vc9j;Y/bNbjK<WX^W2im:Y`^E3IYEX1^07l0Ob1o07l0O`1o87l0OfANNRjL<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L<QHVogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38_:WLbNbjK<WX^
Vc9k;Y/bNRjK<Y`^W39F;Rh^Ac:X>/TjbCk9>/TjZC[:?XLf;Ril;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;Y/^A5IPJV1VH6YPIV1Z
A5Ye>WdZNbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<W`^Dbh5:TLb9bhW;RH^9Rh]:WX^O2jK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVVbjK<WX^Nbij;Y/b
NRik;WX^Vc9k;W`^BDiPJWHfW2ij;Y/bNRjL;W`ZWBiH;U4nAUJPL^1n87l0O`1o07l0O`1o07l0Oh1^
DcZM;WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRik;WX^Vc9j;W/^
NRjK<WX^W38`:PH^EbjL;WX^Vc9j;Y/^O2jL<WX^EBh/:TLbQcK9>/TjbCZX>/TjZC[9>ZLf:2iI;Y`b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bOBY^AT1ZP6YPJX1ZH6YPKT5RKdIk;Yd^NbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOoHU
_39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W39i;RP^9bi7<RL^
B38W;RH^2BYe;Y`^W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<Y/bogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<W/^Vc9j;Y/bNbjK<WX^Vc9k;Yd^Bd[0OZ1^McIm:Yd^OBZL;WPbLSi9CX9VX7H0O`1o
87l0O`1o07l0O`1o07lPOj1jCT:M;W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^WC8a:VHfB39h;W`^W3:L;Y`bNRiF;RlZBRiW<ZPjbC[9?ZTj
bC[9>/TjZC[9?/PjAc9E;YdbNRjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRil;WPb@F9PJV1ZH6IPJV1VH6Y0ITIFE3ZL;W`ZVbij;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y`b;RXU;RL^AbhW;RL^9bhV;PDZ;RiH;Y`bNbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoCaDF:Y/^Nbij;Y/bNRik;WX^Vc9j;WdZCDJPMR1oPFiE<WPb
DSY=BTMFPVZPM^1n07lPO`1o07l0O`1o07l0O`1o07l0Ol1jBTZL;W/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^W38b:TLbb3Y8<ULZNRiF:U8^
;BY:;TH^QcJX>/TjZC[9>ZTjbCZX>/TjZC[9>ZPjAS8b:Y`bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9RdIogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^WBi=AV1ZH6Z0JV1Z
P6YPIX1ZH6Y0ITQBMSYl;Yd^NbjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbii;PLZAc8W;TLb9bi8<RL^Ac8U;RL^;bii;W`^
W39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:K<QHZogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39j;Y/bNbjK<WX^
Vc9k;Yd^CT:PMP1o87n0KV=RPF[0M/1n07l0Ob1o07l0O`1o07l0O`1o07l0O`1o87l0Oj1jBdZL;W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<Y`b
5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
WC9D:TLbb3[9?TPb:bi9;VPbIS:X>/PjbCk9>/TjbC[9>ZTjbC[9>/TjZC[9?/PjAc8a:YdbNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9k;WXbA5YPJV1VH6YPIV1ZH6IPJV1ZH6Y0HTQBDcYj<W`ZW2ik;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
VbjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;W`^DRh5:TL^
9bi7;RL^9bhW;TL^9RhU;PLZ;RiE;W/^O2jL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJK;Y/bNRik;WX^Vc9j;YdZD3j0LP1o07l0O`1o07l0O`1o87l0O`1o07l0O`1o07l0O`1o
07l0O`1o87l0Oh1bCDIl;W/^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;W/^NRjK<WX^W39E:TL^Z3[9>ZTjZCZW=/PjbC[9>ZTjbCZY>/TjZ3[9>ZTjbCZX>/Tj
ZC[9>ZLfAbhc:Y`bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;Y/^5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bO2Yf>T5RP6iPIX1ZH6Z0JV1VP6YPJX1ZH6YPJTAJ
KDYd>Y/bO2ZM;W/^W39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomomRFl<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9l;Rh^1Bi8<RL^Ac8W;TPb9bi7<RL^Ac8U;RH^:RYA;UH^Vc9l;YdbNbjK<W/^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc8g:_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y`bNbjK<WX^Vc9k;Yd^DSZ0KP1o07l0O`1o07l0O`1o
07l0O`1o07l0O`1o07l0O`1o07l0O`1o87oPOV=VDSZM;W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<WX^WC9F;TP^Z3[9>ZTjbC[9>/TjZC[9>/Tj
bCZY>/TjbC[9>ZTjbC[9>/TjbC[9?XHf:RiF;YdbNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<W`ZLSi0HV1Z
H6IPJV1VH6YPIV1ZH6IPJV1VH6Y0JT1VA5Y;CU4nMcIj;W`^O2ZM;W`ZW2ik;Y`^Nbik;W/^Vc:K;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y/^NRh/;PDZAbhW;TL^9bhW;RL^AbhW;TL^
9bhV;PDZ1Rh9:Rl^DbYg;WT^W39l;Y`bO2jL<W/^Vbik;Y/bNbik;WX^Vc9j;W/^NRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogm?5AHZVbik;WX^Vc9j;YdZ
DcZ1JP1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o07n0KTYBF3:M;WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^W39G;RP^
YcK9>ZTjbCZX>/TjZC[9>ZPjbCZY>/TjZ3[9>ZTjbCZX>/TjbCZW>TH^;bii;Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9m:W92@69PKV1ZP6YPJX1ZH6J0JV1ZP6YPIX1ZH6YPJV1ZH6Y1HTANB59]BU12
Lcie=WPfNC9j<WTbVS9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<WX^
;2h5;TLb9bi7<RL^B38W;TLb9bi8<RL^Ac8W;TLb9BhV;PLZ:Bh/:Tl^<BiD;UD^Mbih;WTbNBij<W/^
Vc9k;Y/bNRjK<Y/b5R[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<WX^Vc9k;Y`^E3Z2JP1o87l0O`1o07l0O`1o07l0O`1o07l0O`1o07l0O`1o07lPOn1n
X7I6FW@jO2ZL;WX^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^W39G;TT^Yc[9?ZTjbC[9>/TjZC[9>/TjbCZY>/TjbC[9>ZTjbC[9>/TnYcIW<R`^
ERil;Y`bNRjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bO2Yc?T9NH6YPIV1ZH6IPJV1VH6YPIV1Z
H6IPJV1VP6YPIV1ZH6YPJT1ZH6Y0IV1V@692GT=J@ei6DW/^W2hF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^W2ij;Rh^1BXW;RL^AbhW;RL^9bi7;RL^9bhW;TL^9bi7;RL^Ac8V;RH^
9BhV;PDZ9Rh6:RL^1bX6:RdZW39j;W/^NRjK<WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NbY9CZ1j87l0O`1o07l0O`1o07l0O`1o
07l0O`1o07l0Ob1o07oPOX1^IeYA>W/^O2ZK;WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbik;Rl^AC;9?ZTjbCZX>/TjZC[9>ZPjbCZY>/Tj
Z3[9>/TjbCZX>XLfAbh/;S@ZNbil;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WdZ
McI6EV1ZH6Z0JV1ZP6YPIX1ZH6Z0JV1VP6YPJX1ZH6J0JV1ZP6YPJX1ZH6Z0JV1ZP6iPKT=NNRjl<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y`bO2iA;PHZ9S8W;TLb9bi8<RL^
Ac8W;TPb9bi7<RL^B38W;TLb9bi8<RL^Ac8W;TLb9bi7<RD^;Bil;Y/bNRjK<W/^Vc:K<_moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39k;Y/bNRjL<WX^
BE:PNR1o07l0O`1o07l0O`1o07lPO`1o87l0On1nX7J3IT]>MCYk;Yd^NbjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNRh];VHb
jCk9>/TjZC[9>/TjbCZY>/TnbC[9?/PjZ3YV<TTb;RYf;W/^W39k;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9l:W/^CDI1IT1ZH6YPIV1ZH6IPJV1VH6YPIV1ZH6IPJV1VH6YPIV1Z
H6IPJV1VH6YPIV1ZA5Yk<Y/^5RI=5OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
Vbik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;W`^Mbh::RD^9Ri7<RL^9bhW;TL^9bhW;RL^AbhW;RL^9bi7;RL^9bhW;TL^9bhW;RL^9Rh/:Y`^
NRjK<WX^Nbij;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOdlE5RZK;W/^NRjK<WX^W2ik:T]:X7HPO`1o07l0O`1o07l0On1n`7Z0LVARBDiB?WT^WBil:W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^W3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDUW39j;Y/bNRjK;W/^;RiV</TjZC[9>ZPjbC[8>/PjQcJ7=TLbBBh]:U<^FBjL<W/^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<Y/^5RH]6OmoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNbjM;WHfBE90IV1^H6Z0JV1V
P6YPJX1ZH6J0JV1ZP6YPIX1ZH6Z0JV1VP6YPJX1ZH6YTGWX^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L;Y/bDRhY;PD^Ac8W;TPb9bi7<RL^B38W;TLb9bi8<RL^
Ac8W;TPb9bi7<RL^B38V;Rd^O2jK<W/^Vc9j;Y/bVc8F:_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y`bNRjK<W/^Vc9j;Y`bO2Y=BZ1f87l0Ob1o`7J2JVEN
JE9?@WDjNBjM;W`ZW2ik;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc:L<QHVogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJK<Y/bNbjK<WX^W39l;S0^AS;9?/TjbCZ8=TPbBRi=;S4Z
ERii;Y`bO2jL<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^W38F9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y`bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^W2il:W<nAe90IV1ZH6YPIV1ZH6IPJV1VH6YPIV1ZH6IPJV1VH6YPIV1ZH6IPJT=JNbjL;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NbjL<WT^DBh8:RD^
9Bi7;RL^AbhW;RL^9bi7;RL^9bhW;TL^9bhW;RL^AbhW;RH^;2ZL<WX^Nbij;Y/bNRjL<QHVogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVVbjK<WX^Nbij;Y/b
NRik;W`ZCdJ0LP1o07n1KU@fO2il:Yd^O2Yk;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;Y`b
mBGoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRik;WX^Vc9j;Y/^
O2ha;TH^bC[9>TPb=BYk;W/^W39k;Y/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^NbjK;QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bO2ZL;WDjJdi2GV1ZH6Z0JV1ZP6YPIX1ZH6Z0JV1V
P6YPJX1ZH6J0JV1ZA5Yj;[`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOoHU
_39k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^W39l;YXbDRh[;PHZ9RhV;TLb9bi8<RL^Ac8W;TPb9bi7<RL^B38W;TLb9Rh];W`^
Vc9j;Y/bNbjK<Y/bogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<W/^Vc9j;Y/bNbjK<WX^Vc9m:U12P6hPOh5^McIl:Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoW3:K<WX^Vc9k;Y/bNRjK<Y`^Dbi6;/PnB39h;W`^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;W/^W2il:WTb
D499DT9N@6I0JV1ZH6YPJV1ZP6YPIV1ZH6IPJV1VH6Y4FW/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNbjL<W/^Mbh`:R/^1bXV;PD^9RhV;TLb
9bi7;RL^AbhW;RL^9bhV;R`ZW2ij;Y/bNRik;WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoCaDF:Y/^Nbij;Y/bNRik;WX^Vc9j;W/^OBYB?X1^P6iF<Y`^
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Vc9j;W/^NRjK<WX^Nbil;U@^9Ri7<UL^W39j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bVbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomooglg:Y/^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNbjM;W`^NC9c?Ve:AeI3GT1RH6YPJV1ZH6Z0KV1ZP6YPKT=NNRjL<QHV
ogooOomoW3;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9l;YdbNbih<U<^Cbh[:RP^1RhV;RD^9RhV;RH^9Ri7<RD^;2il;Y/bNbjK<WX^Vc:K<QHZogooOi/b
_3;oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHVW39j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<WdZLci2GWHjO2jK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<Y`b
5RKoOomoVbjK<_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/bVc9k;Y/bNRjK<W/^
Vc9j;Y/bW2iE;PLZMc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<QHV
ogooOomoNRkoOomoogooOomoogooOomoogooOomo003oOomoogooOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOaHVW39j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;Y`^O2Yl;WTbMSYB>Vm6
BdY9DTIBAEI4FTANAe9k;Y/^5RIH:Y/b_C:L<WX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmH:SLZ
VbjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<W/^W39l;Y/bF2if;U<^DBh^:Rd^2bX[;PTZ:2X^:Y`b
NRik;WX^Vc9j;Y/b5RII;W/^gSJL<_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOcLV>2ZK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbil:WDjMc9k;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Vc;e9GX^Vbjn=W/^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOaLVW39j;W/^NRjK<WX^Nbij;Y/bNRik;W`^MbiH;Y/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;W/^=bYI:[`b_C:K<WX^ogmj;_moNRkoOgX^ogmJ:_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoognL<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<W/^W39l;Yd^O2ZM;W`ZW2ij;YXbNS:J<WX^W38F9_moNbkoOkdbogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJL<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjL<W`^
W3:L;Y`bO2jK<WX^VS9j;Y/bNbjK<WX^Vc9k;Y/bVc;oOomoognK;]hfogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomooglG9Y`bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bO2jK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<_moogooOi/b_CKoOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoognK<Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^W38F9_moNbjm<W/^ogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;Y/^Nbik;W/^Vc:K;QHV
ogooOomoogmj:_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomooglF9Y/^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbik;Y/bNRik;WX^Vc9j;W/^NRjL<QHVogooOomo
VbkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl/4AHZVbik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y`b
mBGoOomoogmk;_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogoe9I`bNRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc:K;QHV
ogooOg/^ogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W39j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<Y/b5R[oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo5RJL<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bW38F9_moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHVVc:K<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomo5RJL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo5RJK;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^W38F9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomooglF9Y/^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRjL<_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBFL<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^
NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/b
NRik;WX^Vc9j;W/^NRjK<WX^Nbij;Y/bNRik;WX^Vc9j;W/^VbhF9_moogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogof9K`bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc:K<SLZogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOaHVW39k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<Y/b
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOi`bVc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^
Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^
Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjK<W/^Vc9j;Y/bNbjK<WX^Vc9k;Y/bNRjL<QHV
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOaHV_3:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<Y`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOaHV
W3:K<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;[`b5RKoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogl00?mo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00003oOomoogl00?mo00000000ogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOdlE=bZL<Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;Y/bNbjK<Y/^_3;e9OmoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOoDU_3:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/b
VbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/bNbjK<Y/^Vc9k;Y/bVbjK<W/^Vc:K;Y/b
NbjK<Y/^Vc9k;Y/bVbjK<Y`b5RKoOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomomBEI;UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZNRke8OmoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomomBEj;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBhF9_moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogooOomoogl00000
ogooOomoogooOomoogooOomoogooOomooglF9WX^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBij;_DUogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomomBEJ;UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZ
FBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZFBiI:UT^FBYI;UTZNRke9OmoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoognb7OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mognb7Omo
ogooOomoogl00000003oOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooO`00
003oO`00ogooOomoogooO`0000000?moogooOomoogooOomoogooOk8MognA7Omo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOm8QogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogooO`00ogooOomo003oOomoogooOomo
003oO`00ogooOomo003oOomoogl00000ogooOomoogl00?moogooO`00ogooOomoogooO`00ogooOomo
ogooO`00ogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo
/QgoOomoogooOomoogooOomoogl00000003oOomoogooOomoogooOomoogooO`00003oO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoognb8OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7Omo
TAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo
/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7OmoTAgoOk4MognA7Omo/AgoOi4Mogna7Omo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogmj;_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogl00?moogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooO`00003oOomo
003oOomoogooO`00ogl00?moogooOomoogl00?moogooOomoogl00?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00000
003oO`00ogooO`00003oOomoogl00?moogooO`00ogooOomoogooO`00ogl00?moogooOomoogooOomo
00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomoogl00?mo003oO`00ogl00?mo00000000ogl00?moogooO`00ogooOomo
ogooOomoogooOomo00000?moogl00000ogooO`00003oOomo003oOomoogooO`00003oOomoogooO`00
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
003oOomoogl00?moogooO`00ogooOomoogooO`00ogl00?moogooO`00ogooOomoogooO`00ogl00?mo
ogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomo003oO`00ogooOomo003oOomoogooOomo003oOomo00000?moogooOomo
003oOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooO`0000000?moogooOomoogooOomo003oOomoogl00?moogooOomoogooOomoogooOomo
ogl00?mo003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogl00?moogooOomoogooOomo003oOomo
ogooOomoogooO`00ogooOomo003oOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo00000?moogooOomo003oOomoogl00?moogooOomoogooOomo
003oO`00ogl00?mo003oOomoogl00?moogooO`00ogooOomoogooOomo00000?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomo
003oO`0000000?mo003oOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooO`00ogl00000
003oO`00ogooOomoogooOomoogl00?mo003oOomoogooOomoogl00000ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomo003oO`00ogl00?mo
003oOomoogl00?moogl00000ogooOomoogooO`0000000?mo00000000ogooOomo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oO`00ogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomo003oO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogl00?mo
ogooO`00003oOomoogooOomoogl00?moogl00?moogooOomoogooOomoogooO`00ogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomoogooOomoogl00?moogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogl00?moogl00?moogooOomoogooOomo003oO`00ogooOomoogooOomoogl00?moogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oO`00ogooOomo003oOomoogooOomoogooOomo
ogooOomoogooO`00ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oO`00ogl00?mo
0000000000000?mo00000?moogl00000ogooO`00ogl00?mo003oOomoogooOomo00000000ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00003oOomoogooO`00ogooOomo003oOomoogooOomoogooO`00ogooO`00003oO`00ogooOomo
ogooOomoogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`000000000000000?moogl00000
003oOomoogl00?moogooO`00ogooOomo003oO`00ogooOomoogooO`0000000000003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooO`00ogooO`00003oO`00003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogl00000ogl00000ogooOomoogooOomo
ogooOomoogooOomoogooOomo00000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oO`00ogl00?mo
ogooO`00ogooOomoogooOomoogooOomoogooOomoogl00?mo003oOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooO`00ogooO`00003oOomoogooOomoogooOomoogooOomo
ogooOomoogl00000ogooO`00003oOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oO`00ogl00?mo
0000000000000?mo00000?moogl00000ogooO`00ogl00000003oOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomo003oOomoogooO`00ogooO`00ogooOomo003oO`00ogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo003oOomoogooO`00ogooOomoogooO`00
003oOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogl00?moogooO`00ogooO`00ogooOomo003oOomo003oOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogl00?mo003oO`00ogl00000003oO`00ogooOomo003oOomoogl00?mo003oOomo
ogooOomoogl00000ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00003oOomo003oOomo
ogl00?moogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00?moogooOomo003oOomoogooOomoogooO`00ogooOomo003oO`00ogooOomoogooOomo
ogooOomo003oO`0000000?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00000ogooOomo003oO`00003oOomo
00000?moogl00000003oO`00ogooOomoogooOomo00000?moogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000003oOomoogl00?mo
ogooO`00ogooOomoogooOomoogl00?moogooO`00ogl00?moogooOomoogooOomoogooOomoogooOomo
ogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00003oOomoogl00000ogooO`00003oOomo003oOomoogl00?mo
003oOomoogooOomoogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogooO`00003oOomo00000?moogl00?mo
ogooO`00ogl00?moogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000
ogooOomoogl00?moogooO`00ogl00?moogooOomoogooOomoogooOomoogooOomo00000?moogl00000
003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00000ogooOomo003oO`00003oOomo
00000?mo00000000003oO`00ogooOomo00000000ogl00000ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogl00?moogl00?moogooO`00ogl00?moogooO`00ogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomo003oOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogl00?moogooOomoogl00?moogooO`00ogl00?mo003oOomoogooOomoogl00000ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogl00?moogooO`00ogl00?moogooO`00ogooOomo003oO`00ogooOomoogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00
ogooOomoogl00?moogl00?moogooO`00ogl00?moogooO`00ogooOomoogooO`00ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogl00?mo003oO`00ogooO`00003oO`00003oOomo003oO`0000000?mo
ogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo0000000000000?moogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00003oOomo00000?moogooO`00ogooO`00ogooOomo003oO`00003oOomo00000?moogooOomo
ogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogl00?moogooOomo003oOomo003oOomoogl00?mo00000000ogl00000
ogooOomoogl00?mo00000000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogl00?mo003oOomoogl00000ogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogl00?mo00000000ogl00000003oO`00ogooOomo003oO`0000000?mo
ogooOomoogl00?mo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo003oO`00ogooOomo003oO`00
ogooOomoogooO`00ogl00?moogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogl00000003oOomo00000?mo003oOomo
ogl00?mo003oOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogl00?moogl00000
ogl00?moogooO`00ogooOomoogooOomoogooOomo003oO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo003oO`00ogooOomo003oO`00
ogooOomoogooO`00ogl00?moogooOomoogooOomoogl00000ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomo00000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000000ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogl00?mo
003oOomoogl00?mo003oOomoogooOomo003oO`00ogooOomoogooOomoogooOomo003oOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?mo
ogooO`0000000?moogooO`0000000000003oOomoogl00000003oOomoogooOomoogooOomo00000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oO`0000000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000000ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oO`00ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogl00000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?mo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo003oO`00ogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?mo003oO`00ogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?mo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`0000000000003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooO`0000000000ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOgX^
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomoogooOomo
ogooO`00ogooOomoogooOomoogooOomo00000000ogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogl00?moogooOomoogl00?moogooOomoogl00?moogooO`00ogooOomoogooOomo003oOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogl00?mo00000?moogl00?moogooO`00ogl00?mo
ogooOomoogl00?moogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00
ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogooO`00003oOomo00000?moogooO`0000000?moogl00000ogooOomo00000?moogooOomo
ogooOgX^ogooO`00ogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomoogl00?moogooO`00
ogooOomoogooO`00ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo00000000ogooO`00
003oOomoogooO`00003oOomoogl00?moogooO`00003oOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomo003oOomoogooOomo003oOomoogl00?moogooOomoogl00?moogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomo00000?moogl00000ogooOomoogl00000ogooO`00
003oOomoogl00?moogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooO`00
ogooOomoogooOomoogooOomo003oOomoogl00?moogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooO`00ogooOomoogooO`00ogooOomoogooOomoogl00?mo003oOomoogl00?moogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogmj;_moogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl0000000000000ogooOomoogooO`0000000000003oOomoogooOomo
003oOomoogl00000ogooOomoogl000000000000000000?moogooOomoogooOomoogooO`0000000000
003oO`00ogl00000003oOomoogl00?moogooOomoogooO`000000000000000?moogooO`0000000000
00000000ogl00000003oOomoogl000000000000000000?moogooO`0000000?moogooO`00ogooOomo
ogooO`0000000000003oOomoogl00000003oOomoogooO`00003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooO`00ogl00?moogooO`00
00000?moogooO`00ogooOomoogl00?moogooOomo003oOomoogl00000ogooO`0000000?moogooOomo
ogooOomoogooO`0000000?moogooO`00ogooOomo003oOomoogl00000ogooOomoogooO`00003oOomo
ogl00?moogooO`00ogooOomo00000000ogooOomo003oOomoogl00000ogooOomo00000?moogooO`00
00000?moogooOomo003oOomoogooO`00ogooOomo00000?moogooOomo003oOomoogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogl00000003oO`0000000?moogooOomo00000?moogooO`00ogooOomo00000?moogl00000
003oOomoogl00000003oOomoogooOomoogooO`0000000?moogooOomoogl00?mo00000000ogooO`00
003oOomoogooOomo003oOomoogooOomoogooO`0000000?moogooO`0000000?moogl00000ogooO`00
003oOomoogl00000003oOomo00000?moogooOomoogl00?moogooO`00003oOomoogooO`00003oOomo
ogl00000ogooOomo00000000ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogl00?moogooOomoogl00000ogooOomo
00000?moogooO`00ogooOomo003oOomoogooOomo003oOomoogooOomoogooOomo00000?moogooOomo
ogooOomoogooO`00ogooOomo00000?moogooOomo00000?moogooOomoogooOomoogl00?moogooOomo
ogl00?moogooO`00ogooOomo00000?moogooOomo003oOomoogl00000ogooOomoogl00000ogooO`00
003oOomoogooOomoogl00?moogooO`00ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo00000000ogl00000
ogooOomoogooOomo003oOomoogl00?moogooO`00003oOomo00000?moogooOomo00000000ogooOomo
ogooOomoogl00?moogooOomoogooOomoogooO`0000000?moogooO`00ogooOomoogl00000ogooOomo
ogooOomoogl00000003oOomoogl00000003oOomo00000?moogooO`000000000000000000ogooOomo
003oOomoogooOomo003oOomoogl00?moogooOomoogl00000003oO`0000000?moogooOomo00000?mo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOgX^
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomo00000000ogooOomo003oOomoogooOomo00000?moogooO`00ogooOomoogl00?moogooO`00
ogooOomoogooO`00ogooOomoogooOomoogl00000ogooOomoogooOomoogooOomoogl00?moogooO`00
003oOomoogooO`00003oOomoogooOomoogooOomo003oOomoogooOomo003oOomoogl00?moogooOomo
ogooOomoogooO`00ogooOomo00000?moogooOomoogl00?moogooO`00ogooOomoogooOomo003oOomo
ogl00?moogooOomoogl00?moogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooO`0000000000ogooOomo00000000ogooOomoogl00000ogooOomo
003oOomoogl00000ogooO`0000000?moogooO`0000000?moogooOomoogooOomo003oOomoogooOomo
ogooOomoogl00000003oOomo00000?moogooOomoogl00?moogooOomoogooOomo00000000ogooOomo
00000000ogooO`00003oOomoogooOomoogooO`0000000?moogl00000ogooOomoogooO`00ogooOomo
00000?moogooOomo00000000ogooO`00003oOomoogl00000003oOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogooOomoogooO`00
003oOomoogooO`00ogooOomoogl00000ogooOomo003oOomoogl00?moogooO`0000000?moogooOomo
ogooOomoogl00000ogooOomoogooOomoogooOomo003oOomoogl00000003oOomoogooO`00003oOomo
ogl00?moogooO`00ogooOomoogooO`00ogooOomo003oOomoogl00?moogooOomoogl00?moogooO`00
003oOomoogooO`00003oOomoogooO`00ogooOomoogl00000ogooOomo00000000ogooOomo003oOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00
003oOomoogooOomoogooOomoogl000000000000000000?moogooO`00ogooOomo00000?moogooOomo
0000000000000000003oOomoogooOomoogooO`00003oOomoogooOomoogooOomo00000000ogooO`00
0000000000000?mo0000000000000000003oO`0000000?moogooO`0000000?mo00000000ogooOomo
0000000000000?moogooO`0000000000003oOomoogl00?moogooOomo0000000000000000ogooOomo
0000000000000000003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomo
003oOomoogooOomoogooOomoogooO`00ogooOomo003oOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogl00?moogooOomoogl00?moogooOomoogl00?moogooOomo
ogooOomoogooO`00ogooOomoogooO`00ogooOomoogooOomoogl00000ogooOomoogooOomoogooOomo
ogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00000ogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl00?moogooOomoogooOomoogooOomoogooOomo00000000ogooOomo
ogooOomoogl00000003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00000?moogooOomoogooOomoogooOomoogooO`00
003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
00000?mo00000000ogooOomoogooOomoogooOomoogooOomoogooO`00003oOomoogl00?moogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomo00000000ogl00?mo003oOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomo003oOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogl0000000000000ogooOomoogooOomoogooOomoogooOomoogooOomo
003oOomoogl00000ogooOomoogooOomoogooO`0000000?moogooOomoogooOomoogooO`00ogl00000
003oOomoogl00000003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00003oOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooO`00ogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoNRkoOomo003oOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOgX^ogooO`00ogooOomoNRkoOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo003oOomoogooOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_mo
NRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moNRkoOgX^ogmj;_moogl00?moogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooO`00ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomoogooOomo
ogooOomoogooOomoogooOomoogooOomoogooOomo00160000500000P0001DCU1@1`400280000<0000
ooooodH0002H0000S00004E=AR/T@00030000000000Z@000900001P00000080o000000000000080o
00000000000Z@000900001P00000080o000000000000080o00000000000V@000400000@000000000
240211P0000<00000Q30f`000003000@=40200`000000000C00006@00000000000000602000:0@00
00000000001Q0P002`4002T0ZP00000000000000P3l0000000000000P3l000000000000000000000
000000000000000000000280000<0000ooooodH0000L0000400004E=AR/2@00030000000000>0000
50000000000@00005000
\>"], "Graphics",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 ImageSize->{813.1666666666666, 354.80867665418225`},
 ImageMargins->
  0,ExpressionUUID->"8f2306ad-5625-47f7-a1ac-e154bbd3b84b"]], "Text",
 CellChangeTimes->{
  3.7131590143340616`*^9, {3.713178719905802*^9, 3.7131787371961412`*^9}, {
   3.7131825355943503`*^9, 3.7131825355983505`*^9}, {3.713201770781247*^9, 
   3.7132017736779633`*^9}},ExpressionUUID->"9b44f3c6-478b-42bd-a790-\
f55ad4ab1336"],

Cell[CellGroupData[{

Cell["Overall System Balances", "Subsection",
 CellChangeTimes->{{3.713185682951949*^9, 
  3.7131856875367255`*^9}},ExpressionUUID->"c7d389b9-7bfd-4441-bd6b-\
17901b883976"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isothermReplacement", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox[
       RowBox[{"n", "[", "x_", "]"}], "1"], ",", 
      SubscriptBox[
       RowBox[{"n", "[", "x_", "]"}], "2"]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"isotherm", "/.", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["c", "y_"], "\[RuleDelayed]", 
        SubscriptBox[
         RowBox[{"c", "[", "x", "]"}], "y"]}], "}"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.713201953259486*^9, 
  3.7132019563616624`*^9}},ExpressionUUID->"621db57f-61dd-443c-b0b1-\
8cbbf1f0bbcd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox[
     RowBox[{"n", "[", "x_", "]"}], "1"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], " ", 
      SubscriptBox[
       RowBox[{"c", "[", "x", "]"}], "1"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       SubscriptBox[
        RowBox[{"c", "[", "x", "]"}], "1"]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       SubscriptBox[
        RowBox[{"c", "[", "x", "]"}], "2"]}]}]]}], ",", 
   RowBox[{
    SubscriptBox[
     RowBox[{"n", "[", "x_", "]"}], "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "2"], " ", 
      SubscriptBox[
       RowBox[{"c", "[", "x", "]"}], "2"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       SubscriptBox[
        RowBox[{"c", "[", "x", "]"}], "1"]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       SubscriptBox[
        RowBox[{"c", "[", "x", "]"}], "2"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132019582588367`*^9, 3.7132103924937496`*^9, 
  3.713212318514927*^9, 3.713213978391222*^9, 
  3.713354370447037*^9},ExpressionUUID->"40fca006-104e-4152-9f00-\
7547cda7ebea"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assertions about the separation", "Subsubsection",
 CellChangeTimes->{{3.7131904718831377`*^9, 
  3.7131904813193274`*^9}},ExpressionUUID->"2c1bb97f-d8f8-478d-8147-\
26e82528d2d4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["flow", 
   RowBox[{"comp_", ",", "zone_"}]], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["m", "zone"], "*", 
    SubsuperscriptBox["c", "comp", "zone"]}], "-", 
   RowBox[{"Refresh", "[", 
    SubsuperscriptBox["n", "comp", "zone"], "]"}]}]}], "\[IndentingNewLine]", 
 SubscriptBox["flow", 
  RowBox[{"1", ",", "\"\<I\>\""}]]}], "Input",
 CellChangeTimes->{{3.713182558668332*^9, 3.7131825785461607`*^9}, {
  3.71318295575062*^9, 3.71318296925163*^9}, {3.7131862505272512`*^9, 
  3.7131862581126766`*^9}, {3.7131949706051893`*^9, 
  3.713195037241495*^9}},ExpressionUUID->"dd5ab8dd-ba60-4374-a768-\
a103e9c609f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["c", "1", "\<\"I\"\>"], " ", 
   SubscriptBox["m", "\<\"I\"\>"]}], "-", 
  SubsuperscriptBox["n", "1", "\<\"I\"\>"]}]], "Output",
 CellChangeTimes->{
  3.713186258930763*^9, 3.7131869015476*^9, 3.7131869852493653`*^9, 
   3.7131904112438436`*^9, 3.7131917173971863`*^9, 3.7131933194421062`*^9, 
   3.7131934661233473`*^9, 3.71319497474625*^9, {3.713195018644256*^9, 
   3.71319503776847*^9}, 3.7131988103574004`*^9, 3.7131995282889338`*^9, 
   3.7131998361399765`*^9, 3.713200349587015*^9, 3.7132007017611647`*^9, 
   3.713210392505251*^9, 3.713212318532426*^9, 3.713213978405722*^9, 
   3.71335437046704*^9},ExpressionUUID->"dc18f801-fc5e-4aa1-84b8-\
7ef151dfe9bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"separationConstraints", "=", 
  RowBox[{"(", GridBox[{
     {
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"1", ",", "\"\<I\>\""}]], "\[Equal]", "0"}], 
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"2", ",", "\"\<I\>\""}]], "\[Equal]", "0"}]},
     {
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"1", ",", "\"\<II\>\""}]], "\[Equal]", "0"}], 
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"2", ",", "\"\<II\>\""}]], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["m", "3"], "-", 
           SubscriptBox["m", "2"]}], ")"}]}], 
        SubsuperscriptBox["c", "2", "\"\<F\>\""]}]}]},
     {
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"1", ",", "\"\<III\>\""}]], "\[Equal]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["m", "3"], "-", 
          SubscriptBox["m", "2"]}], ")"}], 
        SubsuperscriptBox["c", "1", "\"\<F\>\""]}]}], 
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"2", ",", "\"\<III\>\""}]], "\[Equal]", "0"}]},
     {
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"1", ",", "\"\<IV\>\""}]], "\[Equal]", "0"}], 
      RowBox[{
       SubscriptBox["flow", 
        RowBox[{"2", ",", "\"\<IV\>\""}]], "\[Equal]", "0"}]}
    }], ")"}]}]], "Input",
 CellChangeTimes->{{3.713186279487664*^9, 3.713186323262861*^9}, {
  3.7131864712069654`*^9, 3.7131864918949203`*^9}, {3.7131866440722785`*^9, 
  3.7131867017929316`*^9}},ExpressionUUID->"27a2d3f4-8d1d-4f29-8eb6-\
9ad8ce32cede"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "1", "\<\"I\"\>"], " ", 
        SubscriptBox["m", "\<\"I\"\>"]}], "-", 
       SubsuperscriptBox["n", "1", "\<\"I\"\>"]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "2", "\<\"I\"\>"], " ", 
        SubscriptBox["m", "\<\"I\"\>"]}], "-", 
       SubsuperscriptBox["n", "2", "\<\"I\"\>"]}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "1", "\<\"II\"\>"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}], "-", 
       SubsuperscriptBox["n", "1", "\<\"II\"\>"]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "2", "\<\"II\"\>"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}], "-", 
       SubsuperscriptBox["n", "2", "\<\"II\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "\<\"II\"\>"], "-", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "1", "\<\"III\"\>"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}], "-", 
       SubsuperscriptBox["n", "1", "\<\"III\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["m", "\<\"II\"\>"]}], "+", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "2", "\<\"III\"\>"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}], "-", 
       SubsuperscriptBox["n", "2", "\<\"III\"\>"]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "1", "\<\"IV\"\>"], " ", 
        SubscriptBox["m", "\<\"IV\"\>"]}], "-", 
       SubsuperscriptBox["n", "1", "\<\"IV\"\>"]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "2", "\<\"IV\"\>"], " ", 
        SubscriptBox["m", "\<\"IV\"\>"]}], "-", 
       SubsuperscriptBox["n", "2", "\<\"IV\"\>"]}], "\[Equal]", "0"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.713195041181196*^9, 3.713195059879284*^9}, 
   3.713198810377898*^9, 3.713199528326433*^9, 3.7131998361714783`*^9, 
   3.713200349618515*^9, 3.713200701795167*^9, 3.7132103925177507`*^9, 
   3.7132123185539265`*^9, 3.7132139784237213`*^9, 
   3.7133543704855785`*^9},ExpressionUUID->"10dfae59-f31a-48e0-a3db-\
045647f2b902"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All Mass Balance Equations", "Subsubsection",
 CellChangeTimes->{{3.713186189572278*^9, 
  3.7131861982179527`*^9}},ExpressionUUID->"33f7d274-cc70-4a75-8686-\
8a83eee71bf8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massBalances", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "3"], "-", 
        SubscriptBox["m", "4"]}], ")"}], 
      SubsuperscriptBox["c", "1", "\"\<R\>\""]}], "==", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "3"], "-", 
        SubscriptBox["m", "2"]}], ")"}], 
      SubsuperscriptBox["c", "1", "\"\<F\>\""]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "1"], "-", 
        SubscriptBox["m", "2"]}], ")"}], 
      SubsuperscriptBox["c", "2", "\"\<E\>\""]}], "==", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "3"], "-", 
        SubscriptBox["m", "2"]}], ")"}], 
      SubsuperscriptBox["c", "2", "\"\<F\>\""]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["n", "1", "\"\<RS\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "1", "\"\<RS\>\""]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "4"], "+", "\[Eta]"}], ")"}], 
      SubsuperscriptBox["c", "1", "\"\<R\>\""]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "3"], "+", "\[Eta]"}], ")"}], 
      SubsuperscriptBox["c", "1", "\"\<R\>\""]}], "\[Equal]", 
     RowBox[{
      RowBox[{
       SubscriptBox["m", "3"], 
       SubsuperscriptBox["c", "1", "\"\<III\>\""]}], "-", 
      SubsuperscriptBox["n", "1", "\"\<III\>\""], "+", 
      SubsuperscriptBox["n", "1", "\"\<RS\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "1", "\"\<RS\>\""]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["n", "1", "\"\<\[Gamma]\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "2"], "+", "\[Eta]"}], ")"}], 
      SubsuperscriptBox["c", "1", "\"\<\[Alpha]\>\""]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["n", "2", "\"\<ES\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "2", "\"\<ES\>\""]}]}], "==", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "1"], "+", "\[Eta]"}], ")"}], 
      SubsuperscriptBox["c", "2", "\"\<E\>\""]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["n", "2", "\"\<ES\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "2", "\"\<ES\>\""]}]}], "==", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "2"], "+", "\[Eta]"}], ")"}], 
       SubsuperscriptBox["c", "2", "\"\<E\>\""]}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["m", "2"], 
         SubsuperscriptBox["c", "2", "\"\<II\>\""]}], "-", 
        SubsuperscriptBox["n", "2", "\"\<II\>\""]}], ")"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["n", "2", "\"\<\[Gamma]\>\""], "+", 
      RowBox[{"\[Eta]", "*", 
       SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "==", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "3"], "+", "\[Eta]"}], ")"}], "*", 
      SubsuperscriptBox["c", "2", "\"\<\[Beta]\>\""]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.713187210426819*^9, 
  3.713187478035986*^9}},ExpressionUUID->"079127fe-3444-47a6-a011-\
e298a471b9a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "\<\"III\"\>"], "-", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["m", "\<\"II\"\>"]}], "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "\<\"I\"\>"], "-", 
       SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["m", "\<\"II\"\>"]}], "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"RS\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"R\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      SubscriptBox["m", "\<\"III\"\>"], " ", 
      SubsuperscriptBox["c", "1", "\<\"III\"\>"]}], "+", 
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "-", 
     SubsuperscriptBox["n", "1", "\<\"III\"\>"], "+", 
     SubsuperscriptBox["n", "1", "\<\"RS\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"\[Gamma]\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"\[Alpha]\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"E\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", 
        SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
      SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "-", 
     RowBox[{
      SubscriptBox["m", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["c", "2", "\<\"II\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"\[Gamma]\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"\[Beta]\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713186201247198*^9, 3.7131869016565995`*^9, 3.7131869854118643`*^9, 
   3.713187478874668*^9, 3.7131877073178463`*^9, 3.713190410884842*^9, 
   3.713190491766708*^9, 3.713191717451187*^9, 3.7131933194931097`*^9, 
   3.713193466172347*^9, {3.713194721772403*^9, 3.71319474160544*^9}, 
   3.7131950613584766`*^9, 3.7131988104033976`*^9, 3.7131995283634357`*^9, 
   3.7131998362094812`*^9, 3.7132003496575136`*^9, 3.7132007018371677`*^9, 
   3.713210392532752*^9, 3.7132123185814266`*^9, 3.7132139784467225`*^9, 
   3.7133543705075784`*^9},ExpressionUUID->"4468a370-c5a8-4898-b9a8-\
a3d4de387496"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"explanations", "=", 
    RowBox[{"{", 
     RowBox[{
     "\"\<All of Component 1 leaves in the raffinate\>\"", ",", 
      "\"\<All of component 2 leaves in the extract\>\"", ",", " ", 
      "\"\<Component 1 balance on zone 4\>\"", ",", 
      "\"\<component 1 balance on zone 3\>\"", ",", 
      "\"\<component 1 balance on zone 2\>\"", ",", 
      "\"\<component 2 balance on zone 1\>\"", ",", 
      "\"\<component 2 balance on zone 2\>\"", ",", 
      "\"\<component 2 balance on zone 3\>\"", ",", 
      "\"\<The net flow through zone 1 is zero\>\"", ",", 
      "\"\<The net flow through zone 1 is zero\>\"", ",", 
      "\"\<The net flow of component 1 through zone 2 is zero\>\"", ",", 
      "\"\<The net flow of component 2 through zone 2 is equal to the feed \
rate of component 2\>\"", ",", 
      "\"\<The net flow of component 1 through zone 3 is equal to the feed \
rate of component 1\>\"", ",", 
      "\"\<The net flow of component 2 through zone 3 is zero\>\"", ",", 
      "\"\<The net flow through zone 4 is zero\>\"", ",", 
      "\"\<The net flow through zone 4 is zero\>\""}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"completeBalanceEquations", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"massBalances", "~", "Join", "~", 
      RowBox[{"Flatten", "[", "separationConstraints", "]"}]}], ",", 
     "Reals"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"Length", "[", "completeBalanceEquations", "]"}], "]"}], ",", 
      "completeBalanceEquations", ",", "explanations"}], "}"}], "]"}], ",", 
   " ", 
   RowBox[{"Alignment", "\[Rule]", "Left"}], ",", " ", 
   RowBox[{"Frame", "->", "All"}], ",", " ", 
   RowBox[{"Background", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lighter", "[", "LightGray", "]"}], ",", "None"}], "}"}], 
       "}"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.713187795259011*^9, 3.7131878373627577`*^9}, {
  3.7131880178277054`*^9, 3.7131880746781874`*^9}, {3.713188191767767*^9, 
  3.7131883570706053`*^9}, {3.7131885020504675`*^9, 3.7131885027396345`*^9}, {
  3.713189415998562*^9, 3.713189490968899*^9}, {3.713189909506931*^9, 
  3.7131899227682133`*^9}},ExpressionUUID->"14c808c9-ed70-4078-af94-\
a6d1c55554df"],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "\<\"III\"\>"], "-", 
         SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["m", "\<\"II\"\>"]}], "+", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", 
        "1", "\<\"F\"\>"]}]}], "\<\"All of Component 1 leaves in the \
raffinate\"\>"},
    {"2", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "\<\"I\"\>"], "-", 
         SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["m", "\<\"II\"\>"]}], "+", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", 
        "2", "\<\"F\"\>"]}]}], "\<\"All of component 2 leaves in the \
extract\"\>"},
    {"3", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "1", "\<\"RS\"\>"]}]}], "\<\"Component 1 balance on zone 4\"\>"},
    {"4", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Eta]", "+", 
          SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "+", 
       SubsuperscriptBox["n", "1", "\<\"III\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "\<\"III\"\>"], " ", 
        SubsuperscriptBox["c", "1", "\<\"III\"\>"]}], "+", 
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "1", "\<\"RS\"\>"]}]}], "\<\"component 1 balance on zone 3\"\>"},
    {"5", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "1", "\<\"\[Alpha]\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "1", "\<\"\[Gamma]\"\>"]}]}], "\<\"component 1 balance on zone 2\"\>"},
    {"6", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "2", "\<\"ES\"\>"]}]}], "\<\"component 2 balance on zone 1\"\>"},
    {"7", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Eta]", "+", 
          SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "+", 
       SubsuperscriptBox["n", "2", "\<\"II\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["m", "\<\"II\"\>"], " ", 
        SubsuperscriptBox["c", "2", "\<\"II\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "2", "\<\"ES\"\>"]}]}], "\<\"component 2 balance on zone 2\"\>"},
    {"8", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "2", "\<\"\[Beta]\"\>"]}], "\[Equal]", 
      RowBox[{
       RowBox[{"\[Eta]", " ", 
        SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
       SubsuperscriptBox["n", 
        "2", "\<\"\[Gamma]\"\>"]}]}], "\<\"component 2 balance on zone 3\"\>"},
    {"9", 
     RowBox[{
      SubsuperscriptBox["n", "1", "\<\"I\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "1", "\<\"I\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"I\"\>"]}]}], "\<\"The net flow through zone 1 is zero\"\>"},
    {"10", 
     RowBox[{
      SubsuperscriptBox["n", "2", "\<\"I\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "2", "\<\"I\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"I\"\>"]}]}], "\<\"The net flow through zone 1 is zero\"\>"},
    {"11", 
     RowBox[{
      SubsuperscriptBox["n", "1", "\<\"II\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "1", "\<\"II\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"II\"\>"]}]}], "\<\"The net flow of component 1 through zone \
2 is zero\"\>"},
    {"12", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["n", "2", "\<\"II\"\>"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["m", "\<\"II\"\>"], "-", 
          SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "2", "\<\"II\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"II\"\>"]}]}], "\<\"The net flow of component 2 through zone \
2 is equal to the feed rate of component 2\"\>"},
    {"13", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["n", "1", "\<\"III\"\>"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["m", "\<\"II\"\>"]}], "+", 
          SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "1", "\<\"III\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"III\"\>"]}]}], "\<\"The net flow of component 1 through \
zone 3 is equal to the feed rate of component 1\"\>"},
    {"14", 
     RowBox[{
      SubsuperscriptBox["n", "2", "\<\"III\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "2", "\<\"III\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"III\"\>"]}]}], "\<\"The net flow of component 2 through \
zone 3 is zero\"\>"},
    {"15", 
     RowBox[{
      SubsuperscriptBox["n", "1", "\<\"IV\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "1", "\<\"IV\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"IV\"\>"]}]}], "\<\"The net flow through zone 4 is zero\"\>"},
    {"16", 
     RowBox[{
      SubsuperscriptBox["n", "2", "\<\"IV\"\>"], "\[Equal]", 
      RowBox[{
       SubsuperscriptBox["c", "2", "\<\"IV\"\>"], " ", 
       SubscriptBox[
        "m", "\<\"IV\"\>"]}]}], "\<\"The net flow through zone 4 is zero\"\>"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxBackground->{"Columns" -> {{Automatic}}, "Rows" -> {{
        RGBColor[0.9, 0.9, 0.9], None}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.713186214059441*^9, 3.7131869018090987`*^9, 3.7131869855588665`*^9, 
   3.7131877187059593`*^9, {3.7131880307541714`*^9, 3.7131880752680197`*^9}, 
   3.713188239530734*^9, {3.7131882937735963`*^9, 3.713188357576968*^9}, 
   3.713188503545254*^9, 3.7131894404786987`*^9, 3.713189491606289*^9, 
   3.7131899237395678`*^9, 3.7131904110688424`*^9, 3.7131904950179777`*^9, 
   3.713191717664689*^9, 3.71319331970961*^9, 3.7131934663663483`*^9, 
   3.713194861033343*^9, 3.7131950628082848`*^9, 3.713198810604903*^9, 
   3.713199528609437*^9, 3.7131998364399805`*^9, 3.713200349902517*^9, 
   3.7132007020636687`*^9, 3.713210392738767*^9, 3.7132123188019295`*^9, 
   3.7132139786577415`*^9, 
   3.7133543706830916`*^9},ExpressionUUID->"ffcc23ca-a7a9-4510-b055-\
73462da83869"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All of component 1 is removed in the raffinate", "Subsubsection",
 CellChangeTimes->{{3.713185732924873*^9, 
  3.7131857516550407`*^9}},ExpressionUUID->"561bfc08-ebb9-4bb1-8234-\
f3464921b4fa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cRsolution", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"completeBalanceEquations", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    SubsuperscriptBox["c", "1", "\"\<R\>\""]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713185718576807*^9, 3.713185721946944*^9}, {
   3.7131858714124904`*^9, 3.7131858860842967`*^9}, {3.7131860258661375`*^9, 
   3.7131860262176776`*^9}, {3.713189660041274*^9, 3.7131896633988905`*^9}, 
   3.713189929673423*^9, {3.7132278105590935`*^9, 
   3.713227814162136*^9}},ExpressionUUID->"22913af9-55e2-4c0a-9b5c-\
99ef3f780068"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "1", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "\<\"II\"\>"], "-", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], 
      RowBox[{
       SubscriptBox["m", "\<\"III\"\>"], "-", 
       SubscriptBox["m", "\<\"IV\"\>"]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7131858905884204`*^9, 3.713186026613758*^9, 
  3.713186901823097*^9, 3.713186985584367*^9, 3.713189664225634*^9, 
  3.7131904111003428`*^9, 3.7131905234508314`*^9, 3.7131917176881905`*^9, 
  3.7131933197331085`*^9, 3.713193466390349*^9, 3.713195066523441*^9, 
  3.7131988106284018`*^9, 3.713199528636937*^9, 3.7131998364679804`*^9, 
  3.7132003499300184`*^9, 3.7132007020961666`*^9, 3.713210392753768*^9, 
  3.7132123188224306`*^9, 3.7132139786752443`*^9, 3.713227814947641*^9, 
  3.7133543707070923`*^9},ExpressionUUID->"ac8ccedd-c525-4fd8-b0b0-\
265301306297"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["All of component 2 is removed in the extract", "Subsubsection",
 CellChangeTimes->{{3.7131860415822554`*^9, 
  3.713186053050171*^9}},ExpressionUUID->"4632290e-8320-41c7-849a-\
b848e259915f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cEsolution", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"completeBalanceEquations", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", 
    SubsuperscriptBox["c", "2", "\"\<E\>\""]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7131860755166054`*^9, 3.713186098906197*^9}, {
   3.7131896746361947`*^9, 3.7131896765290174`*^9}, 3.713189931495698*^9, {
   3.7132277988468604`*^9, 
   3.7132278041158967`*^9}},ExpressionUUID->"c2aed495-c3ee-4f42-b669-\
ca668b00a89b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "2", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["m", "\<\"II\"\>"], "-", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
       SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
      RowBox[{
       SubscriptBox["m", "\<\"I\"\>"], "-", 
       SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7131860995758677`*^9, 3.713186901841218*^9, 
  3.713186985611868*^9, 3.7131896767892165`*^9, 3.7131904111318407`*^9, 
  3.7131905246227117`*^9, 3.713191717709692*^9, 3.7131933197556086`*^9, 
  3.7131934664108477`*^9, 3.713195067629527*^9, 3.7131988106479*^9, 
  3.713199528660937*^9, 3.713199836493479*^9, 3.7132003499545155`*^9, 
  3.7132007021206694`*^9, 3.71321039276427*^9, 3.7132123188419304`*^9, 
  3.7132139786907415`*^9, 3.713227805078403*^9, 
  3.7133543707206707`*^9},ExpressionUUID->"d164771b-b25d-406c-99a0-\
a1988f70d48e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Equations 1,2,3,4,6,7 allow us to solve for ",
 Cell[BoxData[
  SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]],
  CellChangeTimes->{
   3.713186214059441*^9, 3.7131869018090987`*^9, 3.7131869855588665`*^9, 
    3.7131877187059593`*^9, {3.7131880307541714`*^9, 3.7131880752680197`*^9}, 
    3.713188239530734*^9, {3.7131882937735963`*^9, 3.713188357576968*^9}, 
    3.713188503545254*^9, 3.7131894404786987`*^9, 3.713189491606289*^9},
  ExpressionUUID->"958d6a75-c689-4e05-983c-aef7a913dd21"],
 " and ",
 Cell[BoxData[
  SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]],
  CellChangeTimes->{
   3.713186214059441*^9, 3.7131869018090987`*^9, 3.7131869855588665`*^9, 
    3.7131877187059593`*^9, {3.7131880307541714`*^9, 3.7131880752680197`*^9}, 
    3.713188239530734*^9, {3.7131882937735963`*^9, 3.713188357576968*^9}, 
    3.713188503545254*^9, 3.7131894404786987`*^9, 3.713189491606289*^9},
  ExpressionUUID->"c98d27ec-0083-4975-97be-6ac193e147c4"]
}], "Subsubsection",
 CellChangeTimes->{{3.713189828250346*^9, 
  3.713189878324066*^9}},ExpressionUUID->"edf4f579-0969-4a2e-bda5-\
ea956faa8ad5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eliminate", "[", 
   RowBox[{
    RowBox[{"completeBalanceEquations", "[", 
     RowBox[{"[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "7"}], "}"}],
       "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "1", "\"\<R\>\""], ",", 
      SubsuperscriptBox["c", "2", "\"\<E\>\""]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Thread", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox[
        RowBox[{"n", "[", "x_", "]"}], "1"], ",", 
       SubscriptBox[
        RowBox[{"n", "[", "x_", "]"}], "2"]}], "}"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"isotherm", "/.", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "y_"], "\[RuleDelayed]", 
         SubscriptBox[
          RowBox[{"c", "[", "x", "]"}], "y"]}], "}"}]}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "1", "\"\<III\>\""], "==", 
        SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "2", "\"\<II\>\""], "==", 
        SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "2", "\"\<III\>\""], "==", "0"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "1", "\"\<II\>\""], "==", "0"}]}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eliminate", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "1", "\"\<RS\>\""], ",", 
      SubsuperscriptBox["c", "2", "\"\<ES\>\""]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"c\[Gamma]Values", " ", "=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], ",", 
      SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}], "}"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.7131957562242804`*^9, 3.7131957712033854`*^9}, 
   3.713195865079878*^9, {3.7131959573987885`*^9, 3.7131960820206428`*^9}, {
   3.7131961786147738`*^9, 3.7131961933595276`*^9}, {3.7131963032627306`*^9, 
   3.7131963601545324`*^9}, {3.7131964425636063`*^9, 
   3.7131965350002356`*^9}, {3.7131967730197077`*^9, 
   3.7131968836033134`*^9}, {3.7132004802404933`*^9, 
   3.7132004898227544`*^9}, {3.713200719372386*^9, 3.7132007517420626`*^9}, {
   3.713201053167153*^9, 3.713201129199258*^9}, {3.7132011853305693`*^9, 
   3.713201204386859*^9}},ExpressionUUID->"2d78b9bf-14ae-4715-b479-\
13807b33ca13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["m", "\<\"III\"\>"], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["m", "\<\"III\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "1"]}], "+", 
             SubscriptBox["m", "\<\"III\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}]]}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], "-", 
        SubscriptBox["m", "\<\"II\"\>"], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             SubscriptBox["m", "\<\"II\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["m", "\<\"III\"\>"], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["m", "\<\"III\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "1"]}], "+", 
             SubscriptBox["m", "\<\"III\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}]]}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], "-", 
        SubscriptBox["m", "\<\"II\"\>"], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             SubscriptBox["m", "\<\"II\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["m", "\<\"III\"\>"], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["m", "\<\"III\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "1"]}], "+", 
             SubscriptBox["m", "\<\"III\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}]]}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], "-", 
        SubscriptBox["m", "\<\"II\"\>"], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             SubscriptBox["m", "\<\"II\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["m", "\<\"III\"\>"], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["m", "\<\"III\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "1"]}], "+", 
             SubscriptBox["m", "\<\"III\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["m", "\<\"III\"\>"]}]]}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], "\[Rule]", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "2"], "-", 
        SubscriptBox["m", "\<\"II\"\>"], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             SubscriptBox["m", "\<\"II\"\>"], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7131958658936305`*^9, 3.7131960267216053`*^9, {3.7131960606112485`*^9, 
   3.713196082991218*^9}, 3.713196147505384*^9, {3.713196184431856*^9, 
   3.7131961941916704`*^9}, {3.713196286266528*^9, 3.7131963115013094`*^9}, {
   3.7131963466009235`*^9, 3.7131963608054523`*^9}, {3.713196445008336*^9, 
   3.713196535787755*^9}, {3.7131967751312995`*^9, 3.7131967984744043`*^9}, {
   3.713196856770195*^9, 3.7131968842074003`*^9}, 3.713198810841901*^9, 
   3.713199528708936*^9, 3.713199836590479*^9, 3.7131999594800596`*^9, 
   3.7132003500015154`*^9, {3.7132004749648447`*^9, 3.713200490629704*^9}, {
   3.7132007021641674`*^9, 3.7132007524502897`*^9}, 3.713201087705196*^9, 
   3.713201129849186*^9, {3.7132011921182833`*^9, 3.7132012141414523`*^9}, 
   3.7132104039596543`*^9, 3.7132123298568754`*^9, 3.713213989691572*^9, 
   3.713354381394014*^9},ExpressionUUID->"87192d21-c6a4-4452-88d5-\
bc42fcff03da"]
}, Open  ]],

Cell[TextData[{
 "Which of these four solutions is correct?  Each one has the form of a \
quadratic formula.  Since we have selected ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "2"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "8546ff81-ec55-4587-abed-1d89be8550f5"],
 " to be the more strongly adsorbed component, we should expect that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["c", "1", "\[Gamma]"], ">", 
    SubsuperscriptBox["c", "2", "\[Gamma]"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f952edec-dbbd-481b-bda4-8c73ff86a593"],
 " because it will be more readily released from the solid phase in zone 2.  \
We will therefore restrict our attention to the third solution, where ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "1", "\[Gamma]"], TraditionalForm]],ExpressionUUID->
  "094fc5d8-2382-4886-a243-33f75a8eff0a"],
 " has the positive root term, while the ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "2", "\[Gamma]"], TraditionalForm]],ExpressionUUID->
  "7d4ff82a-af0c-4016-b3df-4206ebbdc836"],
 " has the negative root."
}], "Text",
 CellChangeTimes->{{3.7132013166261806`*^9, 
  3.713201618948762*^9}},ExpressionUUID->"94fb2f88-6c4c-46d1-81bb-\
0b1dc5a2131f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c\[Gamma]Value", " ", "=", " ", 
  RowBox[{"c\[Gamma]Values", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713201665505598*^9, 
  3.7132016768303347`*^9}},ExpressionUUID->"f6f7583a-39c9-4dcd-904f-\
8d2ed009cad4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "-", 
      SubscriptBox["m", "\<\"III\"\>"], "-", 
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["m", "\<\"II\"\>"], " ", 
       SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["b", "1"], " ", 
       SubscriptBox["m", "\<\"III\"\>"], " ", 
       SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["m", "\<\"III\"\>"], "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["b", "1"], " ", 
      SubscriptBox["m", "\<\"III\"\>"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "2"], "-", 
      SubscriptBox["m", "\<\"II\"\>"], "+", 
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["m", "\<\"II\"\>"], " ", 
       SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
      RowBox[{
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["m", "\<\"III\"\>"], " ", 
       SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "2"], "-", 
           SubscriptBox["m", "\<\"II\"\>"], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["b", "2"], " ", 
      SubscriptBox["m", "\<\"II\"\>"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132016777555733`*^9, 3.713210404087163*^9, 
  3.713212329922877*^9, 3.7132139897635717`*^9, 
  3.713354381454012*^9},ExpressionUUID->"0f158ee6-80f0-4fce-87a8-\
295495fbff6c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use Equation 8 in conjunction with the \[Gamma] solutions to find an \
equation for ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "2", "\[Beta]"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "96e35b8b-f0fd-4e10-ad63-9836fffc51b8"]
}], "Subsubsection",
 CellChangeTimes->{{3.713189828250346*^9, 3.713189878324066*^9}, {
  3.7132018236593113`*^9, 
  3.713201874677941*^9}},ExpressionUUID->"a84a31c8-d1ab-49f7-836c-\
475d9dd648e9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"completeBalanceEquations", "[", 
      RowBox[{"[", "8", "]"}], "]"}], "/.", "isothermReplacement"}], "/.", 
    "c\[Gamma]Value"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{"%", ",", 
    SubsuperscriptBox["c", "2", "\"\<\[Beta]\>\""]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.713201888111566*^9, 3.7132019283858385`*^9}, {
   3.713201969808177*^9, 3.7132020936884356`*^9}, 
   3.713202145415249*^9},ExpressionUUID->"59b7b9f3-f6c4-4282-a6ed-\
e5b8e9f95b15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "2", "\<\"\[Beta]\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SubscriptBox["b", "2"], " ", 
       SubscriptBox["m", "\<\"II\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"III\"\>"]}], ")"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "2"], "-", 
        SubscriptBox["m", "\<\"II\"\>"], "+", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["m", "\<\"II\"\>"], "-", 
             SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
           SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}]}], 
            ")"}], "2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           SubscriptBox["m", "\<\"III\"\>"]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["m", "\<\"II\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["m", "\<\"III\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubsuperscriptBox["m", "\<\"II\"\>", "2"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["m", "\<\"III\"\>"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["m", "\<\"II\"\>"]}], "+", 
                 SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
               SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["m", "\<\"II\"\>"], " ", 
                  SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
                 RowBox[{
                  SubscriptBox["m", "\<\"III\"\>"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubsuperscriptBox["m", "\<\"III\"\>", "2"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["m", "\<\"II\"\>"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["m", "\<\"II\"\>"], "-", 
                 SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
               SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "2"], "-", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["m", "\<\"III\"\>"], " ", 
                  SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
                 RowBox[{
                  SubscriptBox["m", "\<\"II\"\>"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}]}], 
                ")"}], "2"]}]]}]}], ")"}]}]}], ")"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.713201920581608*^9, 3.7132019292748146`*^9}, 
   3.7132019710217333`*^9, {3.713202010245445*^9, 3.713202038804865*^9}, {
   3.7132020759700623`*^9, 3.713202094411508*^9}, 3.7132021457542567`*^9, 
   3.713210405664274*^9, 3.7132123314889126`*^9, 3.7132139913031106`*^9, 
   3.713354382856536*^9},ExpressionUUID->"f2ac7c9d-aba1-4b10-a378-\
7c98a99e3615"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use Equation 5 in conjunction with the \[Gamma] solutions to find an \
equation for ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "1", "\[Alpha]"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "703b8b0e-dc2f-47df-b90a-8d55beb5e1c1"]
}], "Subsubsection",
 CellChangeTimes->{{3.7132021624526997`*^9, 
  3.7132021887824926`*^9}},ExpressionUUID->"6d3fe41f-1698-444e-be01-\
d19644da1229"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"completeBalanceEquations", "[", 
      RowBox[{"[", "5", "]"}], "]"}], "/.", "isothermReplacement"}], "/.", 
    "c\[Gamma]Value"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{"%", ",", 
    SubsuperscriptBox["c", "1", "\"\<\[Alpha]\>\""]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.713202201416407*^9, 
  3.713202218904667*^9}},ExpressionUUID->"922e5107-1bf6-4f51-983d-\
12b78a2d7199"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "1", "\<\"\[Alpha]\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SubscriptBox["b", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Eta]", "+", 
         SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
       SubscriptBox["m", "\<\"III\"\>"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "1"], "-", 
        SubscriptBox["m", "\<\"III\"\>"], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["m", "\<\"III\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["m", "\<\"II\"\>"]}], "+", 
             SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
           SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "-", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["m", "\<\"II\"\>"], " ", 
              SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["m", "\<\"III\"\>"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}]}], 
            ")"}], "2"]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["m", "\<\"II\"\>"], " ", 
           SubscriptBox["m", "\<\"III\"\>"]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["m", "\<\"II\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["m", "\<\"III\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubsuperscriptBox["m", "\<\"II\"\>", "2"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["b", "1"], " ", 
               SubscriptBox["m", "\<\"III\"\>"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["m", "\<\"II\"\>"]}], "+", 
                 SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
               SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "1"], "-", 
                 RowBox[{
                  SubscriptBox["b", "1"], " ", 
                  SubscriptBox["m", "\<\"II\"\>"], " ", 
                  SubsuperscriptBox["c", "1", "\<\"F\"\>"]}], "+", 
                 RowBox[{
                  SubscriptBox["m", "\<\"III\"\>"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ")"}]}]}], 
                ")"}], "2"]}]]}], "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["m", "\<\"II\"\>"], " ", 
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubsuperscriptBox["m", "\<\"III\"\>", "2"], " ", 
            SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["m", "\<\"III\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["b", "2"], " ", 
               SubscriptBox["m", "\<\"II\"\>"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["m", "\<\"II\"\>"], "-", 
                 SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
               SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "2"], "-", 
                 RowBox[{
                  SubscriptBox["b", "2"], " ", 
                  SubscriptBox["m", "\<\"III\"\>"], " ", 
                  SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], "+", 
                 RowBox[{
                  SubscriptBox["m", "\<\"II\"\>"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ")"}]}]}], 
                ")"}], "2"]}]]}]}], ")"}]}]}], ")"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7132022031619444`*^9, 3.7132022193306937`*^9}, 
   3.713210407121377*^9, 3.713212332960432*^9, 3.7132139927322035`*^9, 
   3.713354384170452*^9},ExpressionUUID->"19993fcf-8552-4b26-97e7-\
7bdced75a6fa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use Equation 6 in conjunction with the \[Gamma] solutions to find an \
equation for ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "2", "ES"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "9b07b0b5-0c48-43a9-8ebf-e4645f9b5514"]
}], "Subsubsection",
 CellChangeTimes->{{3.7132022841840453`*^9, 
  3.7132023070503583`*^9}},ExpressionUUID->"5936bf7f-0c89-4f31-9184-\
46c71e3b9ffb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"completeBalanceEquations", "[", 
   RowBox[{"[", "6", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"esSol", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "/.", "cEsolution"}], ",", 
    SubsuperscriptBox["c", "2", "\"\<ES\>\""]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.713202340936827*^9, 3.7132023472572765`*^9}, {
   3.713227791071808*^9, 3.7132277911343074`*^9}, {3.713227823063696*^9, 
   3.7132278407833166`*^9}, 3.7132279004588585`*^9, {3.713227947988827*^9, 
   3.7132279604390354`*^9}, {3.713228726066157*^9, 3.7132287287468476`*^9}, {
   3.7132295326737366`*^9, 3.713229561667616*^9}, {3.713230024387534*^9, 
   3.713230065554818*^9}, {3.713235992991764*^9, 
   3.7132359944862256`*^9}},ExpressionUUID->"c6e41285-c762-4e30-bff8-\
483f151e914a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "2", "\<\"ES\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Eta]", "+", 
           SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["m", "\<\"II\"\>"], "-", 
           SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
         SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
        RowBox[{
         SubscriptBox["m", "\<\"I\"\>"], "-", 
         SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
       SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], "\[Eta]"]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7132023480896635`*^9, 3.7132104073643937`*^9, 3.7132123331729345`*^9, 
   3.7132139929697065`*^9, 3.7132278256632137`*^9, 3.7132279609995403`*^9, 
   3.7132287296294923`*^9, {3.713229557485632*^9, 3.7132295624775763`*^9}, {
   3.713230025744048*^9, 3.7132300661664543`*^9}, 3.7132359954302425`*^9, 
   3.7133543842194495`*^9},ExpressionUUID->"c9d0e8b5-1278-4cef-984a-\
15e51ec32f4b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 7: Construct the Solution", "Section",
 CellChangeTimes->{{3.713124401574875*^9, 3.7131244019468746`*^9}, {
  3.713151942940961*^9, 3.713151963709821*^9}, {3.713158067576443*^9, 
  3.713158067664444*^9}, {3.7131940470474806`*^9, 
  3.7131940470894814`*^9}},ExpressionUUID->"0c2254e1-cb18-42a6-9031-\
74a1f6c01679"],

Cell[CellGroupData[{

Cell["Describe the constraints imposed by the different zones", "Subsection",
 CellChangeTimes->{{3.713153022429165*^9, 
  3.713153054060163*^9}},ExpressionUUID->"62f10351-db33-4a53-9155-\
7f0da29e68cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"\[Mu]", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "zone"], "-", 
        SubscriptBox["\[Theta]", "1"]}], ")"}]}], 
     RowBox[{"\[Psi]", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], 
         SubscriptBox["\[Theta]", "1"]}]}], ")"}]}]], "\[Equal]", 
    FractionBox[
     RowBox[{"1", "-", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], " ", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
       SubscriptBox["\[Theta]", "1"]}]}], 
     RowBox[{"\[Psi]", "+", 
      RowBox[{
       SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
       SubscriptBox["\[Theta]", "1"]}]}]]}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["m", "zone"], "\[Equal]", 
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[Mu]", " ", 
         SubscriptBox["\[Epsilon]", "p"]}]}], 
       RowBox[{"\[Mu]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7132071138079348`*^9, 3.713207117752221*^9}, {
  3.713207190578126*^9, 3.713207229607707*^9}, {3.7132072851676254`*^9, 
  3.7132073681705585`*^9}},ExpressionUUID->"c7a6c5f7-fb66-4978-b135-\
33fc28de4ea2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.713207196189952*^9, 3.713207274061154*^9, {3.7132073137671585`*^9, 
   3.71320736872458*^9}, 3.713210407471402*^9, 3.713212333231936*^9, 
   3.7132139930722094`*^9, 3.71321904619209*^9, 
   3.71335438423645*^9},ExpressionUUID->"19dd0071-f724-4d6e-92bd-\
20c160699766"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"velocity", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"\[Mu]", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "zone"], "-", 
       SubscriptBox["\[Theta]", "1"]}], ")"}]}], 
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], 
        SubscriptBox["\[Theta]", "1"]}]}], ")"}]}]], "/.", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "\[Rule]", 
    RowBox[{"eigenvalues", "[", "isotherm", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.713207529596711*^9, 3.713207529671212*^9}, {
  3.7132076384024286`*^9, 3.713207670831457*^9}, {3.7132077815917053`*^9, 
  3.713207791796599*^9}, {3.7132080146000385`*^9, 
  3.7132080230062375`*^9}},ExpressionUUID->"87849216-a8be-448c-b6cb-\
f14f48718cad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "1"], "+", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "+", 
       SubscriptBox["m", "zone"]}], ")"}]}], 
    RowBox[{"\[Psi]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}], "-", 
           SqrtBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SubscriptBox["a", "1"], " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["a", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "1"], "+", 
          SubscriptBox["a", "2"], "+", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}], "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "1"], " ", 
                   SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "2"], " ", 
                   SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubscriptBox["c", "1"]}], "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "+", 
       SubscriptBox["m", "zone"]}], ")"}]}], 
    RowBox[{"\[Psi]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"], "+", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubscriptBox["c", "1"]}], "+", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            SubscriptBox["b", "2"], " ", 
            SubscriptBox["c", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SubscriptBox["a", "1"], " ", 
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubscriptBox["c", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["a", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "1"], " ", 
                    SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["a", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "2"], " ", 
                    SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
          ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7132076627099543`*^9, 3.7132076714991384`*^9}, 
   3.7132077861857285`*^9, 3.7132080236335115`*^9, 3.7132104075089045`*^9, 
   3.7132123332764425`*^9, 3.71321399317371*^9, 3.713219046259092*^9, 
   3.7133543842544565`*^9},ExpressionUUID->"6d2abfd5-788e-44f4-be74-\
24216be388e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"velproportion", "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["m", "zone"], "-", 
    SubscriptBox["\[Theta]", "1"]}], "/.", 
   RowBox[{
    SubscriptBox["\[Theta]", "1"], "\[Rule]", 
    RowBox[{"eigenvalues", "[", "isotherm", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7132189170183263`*^9, 
  3.7132189290619664`*^9}},ExpressionUUID->"f34511ca-90f7-4e79-97dc-\
3c651f775046"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "+", 
    SubscriptBox["m", "zone"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["c", "1"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["c", "2"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["a", "1"], " ", 
          SubscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "1"], " ", 
             SubscriptBox["c", "1"]}], "+", 
            RowBox[{
             SubscriptBox["b", "2"], " ", 
             SubscriptBox["c", "2"]}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubscriptBox["c", "1"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubscriptBox["c", "2"]}]}], ")"}]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "1"], " ", 
           SubscriptBox["c", "1"]}], "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubscriptBox["c", "2"]}]}], ")"}], "2"]}]]}], "+", 
    SubscriptBox["m", "zone"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713218930756529*^9, 3.713219046297093*^9, 
  3.713354384274456*^9},ExpressionUUID->"3773bf25-09d4-46bc-bd11-\
4b362c4b55ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zone I", "Subsubsection",
 CellChangeTimes->{{3.713157783470209*^9, 
  3.71315778605821*^9}},ExpressionUUID->"9c55c054-8ece-4b1e-8b76-\
a8faac1e15e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"velocities", "[", "1", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velocity", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "1"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713208992444585*^9, 3.7132090123278265`*^9}, 
   3.713227317586942*^9},ExpressionUUID->"d5c37761-98b8-4e7a-8586-\
e8179dba66c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "1"], "-", 
       SubscriptBox["m", "\<\"I\"\>"]}], ")"}]}], 
    RowBox[{"\[Psi]", "+", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["a", "1"]}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "2"], "-", 
       SubscriptBox["m", "\<\"I\"\>"]}], ")"}]}], 
    RowBox[{"\[Psi]", "+", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["a", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.713208998523901*^9, 3.713209012888009*^9}, 
   3.7132104076189127`*^9, 3.713212333349437*^9, 3.7132139932892103`*^9, 
   3.713219046434095*^9, 3.713227318157447*^9, 
   3.713354384314455*^9},ExpressionUUID->"393caa4a-00c7-435d-ab5f-\
a23e276f8d5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"proportions", "[", "1", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velproportion", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "1"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7132189567656612`*^9, 3.7132189751291113`*^9}, {
  3.7132271326671495`*^9, 3.713227154029177*^9}, {3.7132272310128064`*^9, 
  3.7132272385461965`*^9}},ExpressionUUID->"b50608b8-4d69-4d1d-a179-\
96a0473ac6b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "1"]}], "+", 
    SubscriptBox["m", "\<\"I\"\>"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "2"]}], "+", 
    SubscriptBox["m", "\<\"I\"\>"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132272391138506`*^9, 
  3.713354384353464*^9},ExpressionUUID->"92c4df23-e5c3-49b9-8692-\
4e0c6f012f3e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"proportions", "[", "1", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"velproportion", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["m", "zone"], "\[Rule]", 
         SubscriptBox["m", "1"]}], ",", 
        RowBox[{
         SubscriptBox["c", "2"], "\[Rule]", 
         SubsuperscriptBox["c", "2", "\"\<ES\>\""]}], ",", 
        RowBox[{
         SubscriptBox["c", "1"], "\[Rule]", "0"}]}], "}"}]}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["a", "1"], "<", 
        SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", "esSol"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7132286445923743`*^9, 3.713228652156496*^9}, {
  3.7132287456306963`*^9, 3.7132287588786917`*^9}, {3.7132292752434845`*^9, 
  3.713229296436795*^9}, {3.713230188350901*^9, 3.7132302201158285`*^9}, {
  3.7132302680235367`*^9, 3.713230268351734*^9}, {3.7132311748353195`*^9, 
  3.7132312076446204`*^9}},ExpressionUUID->"f5616047-24e4-4e94-9413-\
9f87f92c50e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["m", "\<\"I\"\>"], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "2"], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Eta]", "+", 
                  SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["m", "\<\"II\"\>"], "-", 
                  SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
                SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
               RowBox[{
                SubscriptBox["m", "\<\"I\"\>"], "-", 
                SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
              SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], 
           "\[Eta]"]}], ")"}]}], "-", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           FractionBox[
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Eta]", "+", 
                   SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["m", "\<\"II\"\>"], "-", 
                   SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
                 SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
                RowBox[{
                 SubscriptBox["m", "\<\"I\"\>"], "-", 
                 SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
               SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], 
            "\[Eta]"]}], ")"}], "2"]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox[
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Eta]", "+", 
                  SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["m", "\<\"II\"\>"], "-", 
                  SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
                SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
               RowBox[{
                SubscriptBox["m", "\<\"I\"\>"], "-", 
                SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
              SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], 
           "\[Eta]"]}], ")"}], "2"]}]]}], ",", 
    RowBox[{
     SubscriptBox["m", "\<\"I\"\>"], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "-", 
       FractionBox[
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         SubscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Eta]", "+", 
               SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["m", "\<\"II\"\>"], "-", 
               SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
             SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
            RowBox[{
             SubscriptBox["m", "\<\"I\"\>"], "-", 
             SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
           SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], "\[Eta]"], 
       "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "1"]}], "+", 
           SubscriptBox["a", "2"], "+", 
           FractionBox[
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             SubscriptBox["b", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Eta]", "+", 
                   SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["m", "\<\"II\"\>"], "-", 
                   SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
                 SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
                RowBox[{
                 SubscriptBox["m", "\<\"I\"\>"], "-", 
                 SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
               SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], 
            "\[Eta]"]}], ")"}], "2"]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox[
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Eta]", "+", 
                  SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["m", "\<\"II\"\>"], "-", 
                  SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
                SubsuperscriptBox["c", "2", "\<\"F\"\>"]}], 
               RowBox[{
                SubscriptBox["m", "\<\"I\"\>"], "-", 
                SubscriptBox["m", "\<\"II\"\>"]}]], "+", 
              SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}], ")"}]}], 
           "\[Eta]"]}], ")"}], "2"]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7132286551563067`*^9, 3.7132287487872353`*^9, 3.713228781551895*^9, {
   3.7132292850169244`*^9, 3.713229300894849*^9}, 3.7132296572326703`*^9, {
   3.7132301965085573`*^9, 3.7132302260918474`*^9}, 3.713230288972103*^9, {
   3.713231191342498*^9, 3.7132312113438053`*^9}, 
   3.713354385864535*^9},ExpressionUUID->"7ef713d9-1717-4ed1-8d8b-\
a0a0747cd3fd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zone II", "Subsubsection",
 CellChangeTimes->{{3.6735386017255225`*^9, 3.6735386035163746`*^9}, {
  3.6735386942139287`*^9, 3.673538696098835*^9}, {3.713156614326826*^9, 
  3.7131566145048275`*^9}},ExpressionUUID->"9bfd4512-e56c-4d43-8086-\
a7b84a224f50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"velocities", "[", "2", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velocity", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "2"]}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713208059100623*^9, 3.713208062015377*^9}, {
   3.7132080952126956`*^9, 3.7132082191479855`*^9}, 
   3.713227346896553*^9},ExpressionUUID->"c7c089dc-d899-41ca-ad82-\
5a0ca6d40e92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["m", "\<\"II\"\>"]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["b", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["b", "2", "2"], " ", 
         SubscriptBox["m", "\<\"II\"\>"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], 
        "-", 
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "2"], " ", 
            SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "+", 
        SqrtBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "2"], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], 
              ")"}]}]}], ")"}], "2"]]}], ")"}]}], 
     RowBox[{"\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["a", "2"]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["b", "2"], " ", 
         SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["b", "2", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], 
        "+", 
        RowBox[{
         SubscriptBox["a", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["v", "*"], "+", 
           RowBox[{
            SuperscriptBox["v", "*"], " ", 
            SubscriptBox["b", "2"], " ", 
            SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "2"], "-", 
             RowBox[{
              SubscriptBox["a", "1"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "2"], " ", 
                 SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], 
               ")"}]}]}], ")"}], "2"]]}]}], ")"}]}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "2"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["m", "\<\"II\"\>"]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["b", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"], " ", 
        SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["b", "2", "2"], " ", 
        SubscriptBox["m", "\<\"II\"\>"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "2"], " ", 
           SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "2"], "-", 
           RowBox[{
            SubscriptBox["a", "1"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "2"], " ", 
               SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}],
           ")"}], "2"]]}], ")"}]}], 
    RowBox[{"\[Psi]", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", 
        SubscriptBox["a", "2"]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["b", "2"], " ", 
        SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["b", "2", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], "+", 
       RowBox[{
        SubscriptBox["a", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["v", "*"], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["b", "2"], " ", 
           SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", 
        SqrtBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "2"], "-", 
            RowBox[{
             SubscriptBox["a", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "2"], " ", 
                SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], 
              ")"}]}]}], ")"}], "2"]]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7132081471822214`*^9, 3.7132081892652607`*^9}, 
   3.7132082205990653`*^9, 3.7132082925660934`*^9, 3.7132104078574314`*^9, 
   3.7132123336024404`*^9, 3.7132139935767145`*^9, 3.713219046726098*^9, 
   3.71322734819406*^9, 
   3.7133543863065944`*^9},ExpressionUUID->"27263ccd-c2a6-4826-896f-\
5a53d81dc301"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"proportions", "[", "2", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velproportion", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "2"]}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", 
        SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7132190138808503`*^9, 3.7132190411120195`*^9}, 
   3.7132273547531056`*^9},ExpressionUUID->"cefb5790-0c5e-4214-8909-\
7f035b387fd1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["m", "\<\"II\"\>"], "-", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "-", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "2"], "-", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}], 
         ")"}], "2"]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}], 
       "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["m", "\<\"II\"\>"], "-", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "+", 
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       SubscriptBox["b", "2"], " ", 
       SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "2"], "-", 
          RowBox[{
           SubscriptBox["a", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "2"], " ", 
              SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}], 
         ")"}], "2"]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "2"], " ", 
          SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}]}], ")"}], 
       "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132190468480997`*^9, 3.7132273556381135`*^9, 
  3.7133543865156174`*^9},ExpressionUUID->"0b41c796-0a4e-4ee1-a935-\
e820b6427564"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zone III", "Subsubsection",
 CellChangeTimes->{{3.6735386017255225`*^9, 3.6735386035163746`*^9}, {
  3.6735386942139287`*^9, 3.673538696098835*^9}, {3.713156603758753*^9, 
  3.713156607724783*^9}},ExpressionUUID->"b0b0c44d-cd44-4dea-9129-\
b0e2483d7174"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"velocities", "[", "3", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velocity", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "3"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7131531129771175`*^9, 3.7131531201834855`*^9}, {
   3.713153221921895*^9, 3.7131532364600706`*^9}, {3.7131532982026787`*^9, 
   3.713153299139406*^9}, {3.7131564891644506`*^9, 3.713156493181978*^9}, {
   3.713156748880848*^9, 3.7131567660179663`*^9}, {3.713208238945672*^9, 
   3.7132082895681763`*^9}, 
   3.713227359157686*^9},ExpressionUUID->"d30fc2b9-dc51-4703-89eb-\
887d200a770f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "1"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["m", "\<\"III\"\>"]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["b", "1"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["b", "1", "2"], " ", 
         SubscriptBox["m", "\<\"III\"\>"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], 
        "-", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "1"], " ", 
            SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "+", 
        SqrtBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], 
              ")"}]}]}], ")"}], "2"]]}], ")"}]}], 
     RowBox[{"\[Psi]", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SubscriptBox["a", "1"]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["b", "1"], " ", 
         SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["b", "1", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], 
        "+", 
        RowBox[{
         SubscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["v", "*"], "+", 
           RowBox[{
            SuperscriptBox["v", "*"], " ", 
            SubscriptBox["b", "1"], " ", 
            SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["v", "*"], " ", 
         SqrtBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "1"], "-", 
             RowBox[{
              SubscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "1"], " ", 
                 SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], 
               ")"}]}]}], ")"}], "2"]]}]}], ")"}]}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "1"], "+", 
       SubscriptBox["a", "2"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["m", "\<\"III\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        SubscriptBox["b", "1"], " ", 
        SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["b", "1"], " ", 
        SubscriptBox["m", "\<\"III\"\>"], " ", 
        SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["b", "1", "2"], " ", 
        SubscriptBox["m", "\<\"III\"\>"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], "+", 
       SqrtBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "1"], "-", 
           RowBox[{
            SubscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "1"], " ", 
               SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}],
           ")"}], "2"]]}], ")"}]}], 
    RowBox[{"\[Psi]", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", 
        SubscriptBox["a", "1"]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["b", "1"], " ", 
        SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["b", "1", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"], ")"}], "2"]}], "+", 
       RowBox[{
        SubscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["v", "*"], "+", 
          RowBox[{
           SuperscriptBox["v", "*"], " ", 
           SubscriptBox["b", "1"], " ", 
           SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["v", "*"], " ", 
        SqrtBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "1"], "-", 
            RowBox[{
             SubscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "1"], " ", 
                SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], 
              ")"}]}]}], ")"}], "2"]]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7131532286216855`*^9, 3.7131532371904945`*^9}, 
   3.7131533024171004`*^9, 3.713156494424985*^9, 3.7131567673759737`*^9, 
   3.7131824977666936`*^9, 3.7131827478606296`*^9, 3.713186901919216*^9, 
   3.713186985769375*^9, 3.713190411495846*^9, 3.7131917179811897`*^9, 
   3.7131933200521092`*^9, 3.713193466723352*^9, 3.713198816353938*^9, 
   3.7131995294984455`*^9, 3.7131998373344865`*^9, 3.713200350689026*^9, 
   3.7132007030396767`*^9, {3.713208278879256*^9, 3.713208290021783*^9}, 
   3.713210408108447*^9, 3.713212333858444*^9, 3.713213993846719*^9, 
   3.7132190471186037`*^9, 3.713227360112192*^9, 
   3.713354386877962*^9},ExpressionUUID->"f4903c3a-8ef4-4eda-8a46-\
e01b00db008c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"proportions", "[", "3", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velproportion", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "3"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", 
        SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.71321902455615*^9, 3.7132190391754675`*^9}, 
   3.713227362188205*^9},ExpressionUUID->"c05c2045-1356-4ec6-8df3-\
80198e670dbe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["m", "\<\"III\"\>"], "-", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "+", 
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "-", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}], 
         ")"}], "2"]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}], 
       "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["m", "\<\"III\"\>"], "-", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "1"], "+", 
      SubscriptBox["a", "2"], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       SubscriptBox["b", "1"], " ", 
       SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
      SqrtBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "1"], "-", 
          RowBox[{
           SubscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "1"], " ", 
              SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}]}]}], 
         ")"}], "2"]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "1"], " ", 
          SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}]}], ")"}], 
       "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713219047283107*^9, 3.713227362785709*^9, 
  3.713354387052475*^9},ExpressionUUID->"0dc61f90-4454-49c9-bf0d-\
65ec983b63f1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zone IV", "Subsubsection",
 CellChangeTimes->{{3.7131577979292107`*^9, 
  3.713157799579712*^9}},ExpressionUUID->"db6e6759-a83e-4b25-b6ee-\
95ac57f9e5b8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"velocities", "[", "4", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velocity", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "4"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7132090170807323`*^9, 3.7132090236969786`*^9}, 
   3.713227366011734*^9},ExpressionUUID->"8f11f128-bc46-46ab-9068-\
a258b6f66f0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "1"], "-", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}]}], 
    RowBox[{"\[Psi]", "+", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["a", "1"]}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "p"]}], ")"}], " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "2"], "-", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}]}], 
    RowBox[{"\[Psi]", "+", 
     RowBox[{
      SuperscriptBox["v", "*"], " ", "\[Psi]", " ", 
      SubscriptBox["a", "2"]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.7132090239180274`*^9, 3.7132104082449565`*^9, 
  3.713212333910945*^9, 3.713213994049221*^9, 3.7132190474916077`*^9, 
  3.7132273663912344`*^9, 
  3.7133543871254964`*^9},ExpressionUUID->"830c1f06-664a-46c0-93f4-\
d36d467f724a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"proportions", "[", "4", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"velproportion", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["m", "zone"], "\[Rule]", 
        SubscriptBox["m", "4"]}], ",", 
       RowBox[{
        SubscriptBox["c", "2"], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["c", "1"], "\[Rule]", "0"}]}], "}"}]}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "1"], "<", 
       SubscriptBox["a", "2"]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7132190327212834`*^9, 3.7132190360483027`*^9}, 
   3.7132273698397593`*^9},ExpressionUUID->"1e78af48-2f16-4ffa-a176-\
c962fdc8dfb3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "1"]}], "+", 
    SubscriptBox["m", "\<\"IV\"\>"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "2"]}], "+", 
    SubscriptBox["m", "\<\"IV\"\>"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132190476066103`*^9, 3.71322737025426*^9, 
  3.713354387159009*^9},ExpressionUUID->"091dfab3-43ed-493a-a1a0-\
72d09626872a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 8: Plot the region of complete separation", "Section",
 CellChangeTimes->{{3.713210486571615*^9, 3.713210492765633*^9}, {
  3.7132217714410057`*^9, 
  3.713221782659738*^9}},ExpressionUUID->"ba86ed3f-586a-4c4d-8c6f-\
e2ad20b44fb3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotRegion", "[", 
   RowBox[{"r_", ",", "a1_", ",", "a2_", ",", "label_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"RegionPlot", "[", 
      RowBox[{"r", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["m", "2"], ",", 
         RowBox[{"a1", "/", "2"}], ",", 
         RowBox[{"a2", "+", 
          RowBox[{"a1", "/", "2"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["m", "3"], ",", 
         RowBox[{"a1", "/", "2"}], ",", 
         RowBox[{"a2", "+", 
          RowBox[{"a1", "/", "2"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{"label", ",", "Large", ",", "Black"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            SubscriptBox["m", "2"], ",", "Large", ",", "Black"}], "]"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{
            SubscriptBox["m", "3"], ",", "Large", ",", "Black"}], "]"}]}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Bold", ",", "Black"}], "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], "//", 
   "Quiet"}]}]], "Input",
 CellChangeTimes->{{3.7132201697429695`*^9, 3.7132201732148323`*^9}, 
   3.713220255672767*^9, {3.713220426147803*^9, 3.7132204738740096`*^9}, 
   3.7132206102619543`*^9, {3.7132206790854464`*^9, 3.71322067968902*^9}, {
   3.7132252067464933`*^9, 
   3.7132252070714064`*^9}},ExpressionUUID->"3242b91d-4c0c-4d86-bda5-\
8b1aa115f45e"],

Cell[CellGroupData[{

Cell["Langmuir", "Subsection",
 CellChangeTimes->{{3.7132193866089883`*^9, 
  3.7132194021366034`*^9}},ExpressionUUID->"b1c75432-baa5-47b8-af33-\
9daa5fda6e47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"values", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "1"], "\[Rule]", "1"}], ",", 
        RowBox[{
         SubscriptBox["a", "2"], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubscriptBox["b", "1"], "\[Rule]", "0.1"}], ",", 
        RowBox[{
         SubscriptBox["b", "2"], "\[Rule]", "0.2"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<F\>\""], "\[Rule]", "3"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<F\>\""], "\[Rule]", "3"}]}], 
       "}"}]}], ",", "results2", ",", "results3", ",", "set1", ",", "set2", 
     ",", "set3", ",", "set4", ",", "constraints", ",", "optimum", ",", 
     "overallReg", ",", "location"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"results2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "2", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"results3", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "3", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"set1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results2", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results2", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results3", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results3", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set3", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "2"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"set4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "1"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"constraints", "=", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"set1", "&&", "set2", "&&", "set3", "&&", "set4", "&&", 
        RowBox[{
         SubscriptBox["m", "3"], "\[GreaterEqual]", 
         SubscriptBox["m", "2"]}]}], "//.", "values"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"location", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1.1", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}], ",", 
        RowBox[{"0.9", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}]}], "}"}], "/.", "values"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"optimum", "=", 
     RowBox[{"FindMaximum", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["m", "3"], "-", 
          SubscriptBox["m", "2"]}], ",", "constraints"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "3"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "2"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}]}], "}"}], "/.", 
        "values"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"overallReg", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"plotRegion", "[", 
        RowBox[{"constraints", ",", 
         SubscriptBox["a", "1"], ",", 
         SubscriptBox["a", "2"], ",", 
         "\"\<Langmuir Region of\\nComplete Separation\>\""}], "]"}], "/.", 
       "values"}], "//", "Quiet"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"overallReg", ",", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"location", ",", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["m", "2"], ",", 
               SubscriptBox["m", "3"]}], "}"}]}], "}"}], "]"}], "/.", 
          RowBox[{"optimum", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"\"\<Optimal point at \\n\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["m", "2"], ",", 
                  SubscriptBox["m", "3"]}], "}"}], ",", "3"}], "]"}], "/.", 
              RowBox[{"optimum", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", "location", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
          "]"}]}], "}"}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.71321052304011*^9, 3.7132105982452593`*^9}, {
   3.7132106412229495`*^9, 3.7132106719179516`*^9}, {3.7132107505410557`*^9, 
   3.713211034601261*^9}, {3.713211075695417*^9, 3.7132112151294622`*^9}, {
   3.7132112591600018`*^9, 3.7132112612361584`*^9}, {3.713211960832994*^9, 
   3.7132121567642155`*^9}, {3.7132122077345033`*^9, 
   3.7132122257337627`*^9}, {3.713212350008083*^9, 3.7132123662358637`*^9}, {
   3.713212396451017*^9, 3.713212414608677*^9}, {3.713212482357136*^9, 
   3.7132125415704193`*^9}, {3.7132125829700804`*^9, 
   3.7132126088133645`*^9}, {3.713212643360848*^9, 3.7132126968914776`*^9}, {
   3.713212740810562*^9, 3.7132127601915236`*^9}, {3.7132128101864023`*^9, 
   3.713212841797994*^9}, {3.7132129432220397`*^9, 3.7132130554739738`*^9}, {
   3.7132132008415785`*^9, 3.713213207570712*^9}, {3.713213243760844*^9, 
   3.713213273646042*^9}, {3.7132133714760046`*^9, 3.7132134051705756`*^9}, {
   3.7132137072058825`*^9, 3.7132137985607767`*^9}, {3.7132138594357595`*^9, 
   3.713213866274764*^9}, {3.713214057417972*^9, 3.7132140637576313`*^9}, {
   3.7132140958321953`*^9, 3.7132141201759863`*^9}, {3.7132142003936906`*^9, 
   3.713214214014885*^9}, {3.713214252102813*^9, 3.7132143264619093`*^9}, {
   3.7132143608655667`*^9, 3.713214362607955*^9}, 3.7132143943954716`*^9, {
   3.7132144482297926`*^9, 3.71321444962806*^9}, {3.7132144803303056`*^9, 
   3.7132145453666725`*^9}, {3.7132186626419535`*^9, 3.713218713530896*^9}, {
   3.713218836737592*^9, 3.713218875827533*^9}, {3.713219129772863*^9, 
   3.713219171569045*^9}, {3.7132192089510155`*^9, 3.7132192115338955`*^9}, {
   3.713219287037033*^9, 3.7132192882368135`*^9}, {3.7132193446073265`*^9, 
   3.713219346075502*^9}, {3.7132196475900555`*^9, 3.7132196640576262`*^9}, {
   3.7132202394707155`*^9, 3.7132203056793823`*^9}, {3.713220342473565*^9, 
   3.713220367236586*^9}, {3.7132204835869875`*^9, 3.7132205023711367`*^9}, {
   3.7132207454785147`*^9, 3.7132208975857325`*^9}, {3.7132209365017233`*^9, 
   3.713221018989929*^9}, {3.7132212219943266`*^9, 3.713221255047592*^9}, {
   3.7132212975102835`*^9, 
   3.7132214487627354`*^9}},ExpressionUUID->"22d31372-8dac-4c76-b47b-\
65300052425a"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJy9fHtcTdn7f9KF5JZIRDJJiRSmifCkRBORXCJyaVImkUhEmhK5RCIRuaQR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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnAf8l9MXx7/P/KKM7K2UNNEQZZWVQhGiSEqllD2jUMpelewdMlJ2EslM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          "]], PolygonBox[CompressedData["
1:eJw1mQn4VlMXxd977zn3oiiUJEPJPESkQUgqiVAkESEVhQqpJJk1CFEkISKS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          "]]}]}, {}, {}, {}, {}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwl2HfcjmUYxvFHiFRWCUlGtKeG9k6UlvYWEQ0jIu2hoiFSRApZoYyktEQl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       "]]}}], {
    ArrowBox[{{1.6500000000000001`, 1.35}, {0.7581646795151337, 
     1.161223729693926}}], 
    InsetBox["\<\"Optimal point at \\n{0.758, 1.16}\"\>", \
{1.6500000000000001, 1.35}, {-1, 1}]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  BaseStyle->{FontFamily -> "Arial"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
       SubscriptBox["m", "3"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
       SubscriptBox["m", "2"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[Bold, 
    GrayLevel[0]],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotLabel->FormBox[
    StyleBox["\"Langmuir Region of\\nComplete Separation\"", Large, 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->NCache[{{
      Rational[1, 2], 
      Rational[5, 2]}, {
      Rational[1, 2], 
      Rational[5, 2]}}, {{0.5, 2.5}, {0.5, 2.5}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.713220316975443*^9, {3.7132203561246033`*^9, 3.713220375570259*^9}, 
   3.713220510996586*^9, 3.713220626847958*^9, {3.713220838857235*^9, 
   3.7132208774919357`*^9}, 3.713221027401394*^9, {3.7132213434339437`*^9, 
   3.713221457359146*^9}, 
   3.7133543952231073`*^9},ExpressionUUID->"2ef6cc5f-b030-431e-acf8-\
2ad7381676eb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixed (M1) Langmuir", "Subsection",
 CellChangeTimes->{
  3.7132194069535666`*^9},ExpressionUUID->"fc15a711-eaae-4765-9acb-\
4be9c0ad95ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"values", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "1"], "\[Rule]", "1"}], ",", 
        RowBox[{
         SubscriptBox["a", "2"], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubscriptBox["b", "1"], "\[Rule]", "0.1"}], ",", 
        RowBox[{
         SubscriptBox["b", "2"], "\[Rule]", 
         RowBox[{"-", "0.2"}]}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<F\>\""], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<F\>\""], "\[Rule]", "2"}]}], 
       "}"}]}], ",", "results2", ",", "results3", ",", "set1", ",", "set2", 
     ",", "set3", ",", "set4", ",", "constraints", ",", "optimum", ",", 
     "overallReg", ",", "location"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"results2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "2", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"results3", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "3", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"set1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results2", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results2", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results3", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results3", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set3", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "2"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"set4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "1"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"constraints", "=", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"set1", "&&", "set2", "&&", "set3", "&&", "set4", "&&", 
        RowBox[{
         SubscriptBox["m", "3"], "\[GreaterEqual]", 
         SubscriptBox["m", "2"]}]}], "//.", "values"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"location", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1.1", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}], ",", 
        RowBox[{"0.9", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}]}], "}"}], "/.", "values"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"optimum", "=", 
     RowBox[{"FindMaximum", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["m", "3"], "-", 
          SubscriptBox["m", "2"]}], ",", "constraints"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "3"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "2"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}]}], "}"}], "/.", 
        "values"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"overallReg", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"plotRegion", "[", 
        RowBox[{"constraints", ",", 
         SubscriptBox["a", "1"], ",", 
         SubscriptBox["a", "2"], ",", 
         "\"\<Mixed (M1) Region of\\nComplete Separation\>\""}], "]"}], "/.", 
       "values"}], "//", "Quiet"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"overallReg", ",", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"location", ",", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["m", "2"], ",", 
               SubscriptBox["m", "3"]}], "}"}]}], "}"}], "]"}], "/.", 
          RowBox[{"optimum", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"\"\<Optimal point at \\n\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["m", "2"], ",", 
                  SubscriptBox["m", "3"]}], "}"}], ",", "3"}], "]"}], "/.", 
              RowBox[{"optimum", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", "location", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
          "]"}]}], "}"}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.71321052304011*^9, 3.7132105982452593`*^9}, {
   3.7132106412229495`*^9, 3.7132106719179516`*^9}, {3.7132107505410557`*^9, 
   3.713211034601261*^9}, {3.713211075695417*^9, 3.7132112151294622`*^9}, {
   3.7132112591600018`*^9, 3.7132112612361584`*^9}, {3.713211960832994*^9, 
   3.7132121567642155`*^9}, {3.7132122077345033`*^9, 
   3.7132122257337627`*^9}, {3.713212350008083*^9, 3.7132123662358637`*^9}, {
   3.713212396451017*^9, 3.713212414608677*^9}, {3.713212482357136*^9, 
   3.7132125415704193`*^9}, {3.7132125829700804`*^9, 
   3.7132126088133645`*^9}, {3.713212643360848*^9, 3.7132126968914776`*^9}, {
   3.713212740810562*^9, 3.7132127601915236`*^9}, {3.7132128101864023`*^9, 
   3.713212841797994*^9}, {3.7132129432220397`*^9, 3.7132130554739738`*^9}, {
   3.7132132008415785`*^9, 3.713213207570712*^9}, {3.713213243760844*^9, 
   3.713213273646042*^9}, {3.7132133714760046`*^9, 3.7132134051705756`*^9}, {
   3.7132137072058825`*^9, 3.7132137985607767`*^9}, {3.7132138594357595`*^9, 
   3.713213866274764*^9}, {3.713214057417972*^9, 3.7132140637576313`*^9}, {
   3.7132140958321953`*^9, 3.7132141201759863`*^9}, {3.7132142003936906`*^9, 
   3.713214214014885*^9}, {3.713214252102813*^9, 3.7132143264619093`*^9}, {
   3.7132143608655667`*^9, 3.713214362607955*^9}, 3.7132143943954716`*^9, {
   3.7132144482297926`*^9, 3.71321444962806*^9}, {3.7132144803303056`*^9, 
   3.7132145453666725`*^9}, {3.7132186626419535`*^9, 3.713218713530896*^9}, {
   3.713218836737592*^9, 3.713218875827533*^9}, {3.713219129772863*^9, 
   3.713219171569045*^9}, {3.7132192089510155`*^9, 3.7132192115338955`*^9}, {
   3.713219287037033*^9, 3.7132192882368135`*^9}, {3.7132193446073265`*^9, 
   3.713219346075502*^9}, {3.7132196475900555`*^9, 3.7132196640576262`*^9}, {
   3.7132202394707155`*^9, 3.7132203056793823`*^9}, {3.713220342473565*^9, 
   3.713220367236586*^9}, {3.7132204835869875`*^9, 3.7132205023711367`*^9}, {
   3.7132207454785147`*^9, 3.7132208975857325`*^9}, {3.7132209365017233`*^9, 
   3.713221018989929*^9}, {3.7132212219943266`*^9, 3.713221255047592*^9}, {
   3.7132212975102835`*^9, 3.7132214487627354`*^9}, {3.7132214998654165`*^9, 
   3.713221528961375*^9}},ExpressionUUID->"5ba29db7-2527-4d2d-85bd-\
ab7e37c3d600"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1nX1cjNn7x9tWHhLZtBGRbFKykWwb0ZXIJiKRiEQim0i0eUrKQx4ikWgl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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVnQX4FdXzxu/dvXd3sbsLxUZU7ABBBBMRFQNRQhGUUEFUFFRQUEBFxA7s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          "]], PolygonBox[CompressedData["
1:eJwtmXnYVlMXxs/7nufZ55Dm0iTNmjSpREmSoVGmChVNSJKi+AyZfYWSqJTS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          "]]}]}, {}, {}, {}, {}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwl13f8j2UbxvGv7NGwsmVEQ0uaKmkqGqJFKpUiFQ0jKqSnnRCeEgktGnhU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       "]]}}], {
    ArrowBox[{{1.6500000000000001`, 1.35}, {1.222222306684039, 
     1.7777776939521208`}}], 
    InsetBox["\<\"Optimal point at \\n{1.22, 1.78}\"\>", \
{1.6500000000000001, 1.35}, {-1, 1}]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  BaseStyle->{FontFamily -> "Arial"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
       SubscriptBox["m", "3"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
       SubscriptBox["m", "2"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[Bold, 
    GrayLevel[0]],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotLabel->FormBox[
    StyleBox["\"Mixed (M1) Region of\\nComplete Separation\"", Large, 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->NCache[{{
      Rational[1, 2], 
      Rational[5, 2]}, {
      Rational[1, 2], 
      Rational[5, 2]}}, {{0.5, 2.5}, {0.5, 2.5}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.713221515588443*^9, 3.7132215386829185`*^9}, 
   3.7133544023047223`*^9},ExpressionUUID->"fcbc5ae1-7e0c-4d86-a8c5-\
f868df906fcf"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mixed (M2) Langmuir", "Subsection",
 CellChangeTimes->{{3.71321940980497*^9, 
  3.7132194119923515`*^9}},ExpressionUUID->"c1ca0ca4-c8dc-45ce-9d63-\
51a40e557da1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"values", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "1"], "\[Rule]", "1"}], ",", 
        RowBox[{
         SubscriptBox["a", "2"], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubscriptBox["b", "1"], "\[Rule]", 
         RowBox[{"-", "0.1"}]}], ",", 
        RowBox[{
         SubscriptBox["b", "2"], "\[Rule]", "0.2"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<F\>\""], "\[Rule]", "1"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<F\>\""], "\[Rule]", "1"}]}], 
       "}"}]}], ",", "results2", ",", "results3", ",", "set1", ",", "set2", 
     ",", "set3", ",", "set4", ",", "constraints", ",", "optimum", ",", 
     "overallReg", ",", "location"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"results2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "2", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"results3", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "3", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"set1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results2", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results2", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results3", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results3", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set3", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "2"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"set4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "1"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"constraints", "=", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"set1", "&&", "set2", "&&", "set3", "&&", "set4", "&&", 
        RowBox[{
         SubscriptBox["m", "3"], "\[GreaterEqual]", 
         SubscriptBox["m", "2"]}]}], "//.", "values"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"location", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1.1", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}], ",", 
        RowBox[{"0.9", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}]}], "}"}], "/.", "values"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"optimum", "=", 
     RowBox[{"FindMaximum", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["m", "3"], "-", 
          SubscriptBox["m", "2"]}], ",", "constraints"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "3"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "2"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}]}], "}"}], "/.", 
        "values"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"overallReg", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"plotRegion", "[", 
        RowBox[{"constraints", ",", 
         SubscriptBox["a", "1"], ",", 
         SubscriptBox["a", "2"], ",", 
         "\"\<Mixed (M2) Region of\\nComplete Separation\>\""}], "]"}], "/.", 
       "values"}], "//", "Quiet"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"overallReg", ",", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"location", ",", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["m", "2"], ",", 
               SubscriptBox["m", "3"]}], "}"}]}], "}"}], "]"}], "/.", 
          RowBox[{"optimum", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"\"\<Optimal point at \\n\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["m", "2"], ",", 
                  SubscriptBox["m", "3"]}], "}"}], ",", "3"}], "]"}], "/.", 
              RowBox[{"optimum", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", "location", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
          "]"}]}], "}"}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.71321052304011*^9, 3.7132105982452593`*^9}, {
   3.7132106412229495`*^9, 3.7132106719179516`*^9}, {3.7132107505410557`*^9, 
   3.713211034601261*^9}, {3.713211075695417*^9, 3.7132112151294622`*^9}, {
   3.7132112591600018`*^9, 3.7132112612361584`*^9}, {3.713211960832994*^9, 
   3.7132121567642155`*^9}, {3.7132122077345033`*^9, 
   3.7132122257337627`*^9}, {3.713212350008083*^9, 3.7132123662358637`*^9}, {
   3.713212396451017*^9, 3.713212414608677*^9}, {3.713212482357136*^9, 
   3.7132125415704193`*^9}, {3.7132125829700804`*^9, 
   3.7132126088133645`*^9}, {3.713212643360848*^9, 3.7132126968914776`*^9}, {
   3.713212740810562*^9, 3.7132127601915236`*^9}, {3.7132128101864023`*^9, 
   3.713212841797994*^9}, {3.7132129432220397`*^9, 3.7132130554739738`*^9}, {
   3.7132132008415785`*^9, 3.713213207570712*^9}, {3.713213243760844*^9, 
   3.713213273646042*^9}, {3.7132133714760046`*^9, 3.7132134051705756`*^9}, {
   3.7132137072058825`*^9, 3.7132137985607767`*^9}, {3.7132138594357595`*^9, 
   3.713213866274764*^9}, {3.713214057417972*^9, 3.7132140637576313`*^9}, {
   3.7132140958321953`*^9, 3.7132141201759863`*^9}, {3.7132142003936906`*^9, 
   3.713214214014885*^9}, {3.713214252102813*^9, 3.7132143264619093`*^9}, {
   3.7132143608655667`*^9, 3.713214362607955*^9}, 3.7132143943954716`*^9, {
   3.7132144482297926`*^9, 3.71321444962806*^9}, {3.7132144803303056`*^9, 
   3.7132145453666725`*^9}, {3.7132186626419535`*^9, 3.713218713530896*^9}, {
   3.713218836737592*^9, 3.713218875827533*^9}, {3.713219129772863*^9, 
   3.713219171569045*^9}, {3.7132192089510155`*^9, 3.7132192115338955`*^9}, {
   3.713219287037033*^9, 3.7132192882368135`*^9}, {3.7132193446073265`*^9, 
   3.713219346075502*^9}, {3.7132196475900555`*^9, 3.7132196640576262`*^9}, {
   3.7132202394707155`*^9, 3.7132203056793823`*^9}, {3.713220342473565*^9, 
   3.713220367236586*^9}, {3.7132204835869875`*^9, 3.7132205023711367`*^9}, {
   3.7132207454785147`*^9, 3.7132208975857325`*^9}, {3.7132209365017233`*^9, 
   3.713221018989929*^9}, {3.7132212219943266`*^9, 3.713221255047592*^9}, {
   3.7132212975102835`*^9, 3.7132214487627354`*^9}, {3.713221555883034*^9, 
   3.7132215632539105`*^9}, {3.713221681802963*^9, 
   3.713221685096037*^9}},ExpressionUUID->"aa51520f-5934-4ac1-b33b-\
32c9521d6705"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJylnXlYTe33/xOJRCQyRCJREYlEaaVEQsgQmZMiEZ5kSiQyRDJEJBL1JBpE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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxVnHf81tP7x+/7/b7f45MR2TIqZVYoI5soUSFlZkUhsxCZZYfsRLakKGRn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          "]], PolygonBox[CompressedData["
1:eJwtmXnATlXXxm/nPGefc1NSNFBSSYUyVhQiDRRFhlKGTCWESoOxSEJmSqER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          "]]}]}, {}, {}, {}, {}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwl2Hf4lnMfh/E7GvbIaJCGmdWgUkmSlPYUSdGmPZUmIakQDVJklK1FmYUi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       "]]}}], {
    ArrowBox[{{1.6500000000000001`, 1.35}, {0.9090909930399647, 
     1.8181817331200276`}}], 
    InsetBox["\<\"Optimal point at \\n{0.909, 1.82}\"\>", \
{1.6500000000000001, 1.35}, {-1, 1}]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  BaseStyle->{FontFamily -> "Arial"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
       SubscriptBox["m", "3"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
       SubscriptBox["m", "2"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[Bold, 
    GrayLevel[0]],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotLabel->FormBox[
    StyleBox["\"Mixed (M2) Region of\\nComplete Separation\"", Large, 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->NCache[{{
      Rational[1, 2], 
      Rational[5, 2]}, {
      Rational[1, 2], 
      Rational[5, 2]}}, {{0.5, 2.5}, {0.5, 2.5}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.713221574096364*^9, 3.7132216936342063`*^9, 
  3.713354409860304*^9},ExpressionUUID->"1c811dad-971c-49bd-82da-\
debaabdb477a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Anti-Langmuir", "Subsection",
 CellChangeTimes->{{3.7132194187356777`*^9, 
  3.713219423800644*^9}},ExpressionUUID->"9ef93d29-10f8-4f62-ad5e-\
465ef4a736fa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"values", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["a", "1"], "\[Rule]", "1"}], ",", 
        RowBox[{
         SubscriptBox["a", "2"], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubscriptBox["b", "1"], "\[Rule]", 
         RowBox[{"-", "0.1"}]}], ",", 
        RowBox[{
         SubscriptBox["b", "2"], "\[Rule]", 
         RowBox[{"-", "0.2"}]}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<F\>\""], "\[Rule]", "2"}], ",", 
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<F\>\""], "\[Rule]", "2"}]}], 
       "}"}]}], ",", "results2", ",", "results3", ",", "set1", ",", "set2", 
     ",", "set3", ",", "set4", ",", "constraints", ",", "optimum", ",", 
     "overallReg", ",", "location"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"results2", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "2", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"results3", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"proportions", "[", "3", "]"}], "/.", "c\[Gamma]Value"}], 
      "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"set1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results2", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results2", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", "results3", "]"}], "<", "0"}], "&&", 
      RowBox[{
       RowBox[{"Max", "[", "results3", "]"}], ">", "0"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"set3", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "2"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"set4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], "\[Element]", 
         "Reals"}], "&&", 
        RowBox[{
         SubscriptBox["c", "1"], "\[GreaterEqual]", 
         SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "/.", 
       RowBox[{
        RowBox[{"intercepts", "[", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"constraints", "=", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"set1", "&&", "set2", "&&", "set3", "&&", "set4", "&&", 
        RowBox[{
         SubscriptBox["m", "3"], "\[GreaterEqual]", 
         SubscriptBox["m", "2"]}]}], "//.", "values"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"location", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1.1", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}], ",", 
        RowBox[{"0.9", "*", 
         FractionBox[
          RowBox[{
           SubscriptBox["a", "1"], "+", 
           SubscriptBox["a", "2"]}], "2"]}]}], "}"}], "/.", "values"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"optimum", "=", 
     RowBox[{"FindMaximum", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["m", "3"], "-", 
          SubscriptBox["m", "2"]}], ",", "constraints"}], "}"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "3"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["m", "2"], ",", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "1"], "+", 
              SubscriptBox["a", "2"]}], "2"]}], "}"}]}], "}"}], "/.", 
        "values"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"overallReg", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"plotRegion", "[", 
        RowBox[{"constraints", ",", 
         SubscriptBox["a", "1"], ",", 
         SubscriptBox["a", "2"], ",", 
         "\"\<Antilangmuir Region of\\nComplete Separation\>\""}], "]"}], "/.",
        "values"}], "//", "Quiet"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"overallReg", ",", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Arrow", "[", 
           RowBox[{"{", 
            RowBox[{"location", ",", 
             RowBox[{"{", 
              RowBox[{
               SubscriptBox["m", "2"], ",", 
               SubscriptBox["m", "3"]}], "}"}]}], "}"}], "]"}], "/.", 
          RowBox[{"optimum", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"\"\<Optimal point at \\n\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"NumberForm", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  SubscriptBox["m", "2"], ",", 
                  SubscriptBox["m", "3"]}], "}"}], ",", "3"}], "]"}], "/.", 
              RowBox[{"optimum", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", ",", "location", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
          "]"}]}], "}"}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.71321052304011*^9, 3.7132105982452593`*^9}, {
   3.7132106412229495`*^9, 3.7132106719179516`*^9}, {3.7132107505410557`*^9, 
   3.713211034601261*^9}, {3.713211075695417*^9, 3.7132112151294622`*^9}, {
   3.7132112591600018`*^9, 3.7132112612361584`*^9}, {3.713211960832994*^9, 
   3.7132121567642155`*^9}, {3.7132122077345033`*^9, 
   3.7132122257337627`*^9}, {3.713212350008083*^9, 3.7132123662358637`*^9}, {
   3.713212396451017*^9, 3.713212414608677*^9}, {3.713212482357136*^9, 
   3.7132125415704193`*^9}, {3.7132125829700804`*^9, 
   3.7132126088133645`*^9}, {3.713212643360848*^9, 3.7132126968914776`*^9}, {
   3.713212740810562*^9, 3.7132127601915236`*^9}, {3.7132128101864023`*^9, 
   3.713212841797994*^9}, {3.7132129432220397`*^9, 3.7132130554739738`*^9}, {
   3.7132132008415785`*^9, 3.713213207570712*^9}, {3.713213243760844*^9, 
   3.713213273646042*^9}, {3.7132133714760046`*^9, 3.7132134051705756`*^9}, {
   3.7132137072058825`*^9, 3.7132137985607767`*^9}, {3.7132138594357595`*^9, 
   3.713213866274764*^9}, {3.713214057417972*^9, 3.7132140637576313`*^9}, {
   3.7132140958321953`*^9, 3.7132141201759863`*^9}, {3.7132142003936906`*^9, 
   3.713214214014885*^9}, {3.713214252102813*^9, 3.7132143264619093`*^9}, {
   3.7132143608655667`*^9, 3.713214362607955*^9}, 3.7132143943954716`*^9, {
   3.7132144482297926`*^9, 3.71321444962806*^9}, {3.7132144803303056`*^9, 
   3.7132145453666725`*^9}, {3.7132186626419535`*^9, 3.713218713530896*^9}, {
   3.713218836737592*^9, 3.713218875827533*^9}, {3.713219129772863*^9, 
   3.713219171569045*^9}, {3.7132192089510155`*^9, 3.7132192115338955`*^9}, {
   3.713219287037033*^9, 3.7132192882368135`*^9}, {3.7132193446073265`*^9, 
   3.713219346075502*^9}, {3.7132196475900555`*^9, 3.7132196640576262`*^9}, {
   3.7132202394707155`*^9, 3.7132203056793823`*^9}, {3.713220342473565*^9, 
   3.713220367236586*^9}, {3.7132204835869875`*^9, 3.7132205023711367`*^9}, {
   3.7132207454785147`*^9, 3.7132208975857325`*^9}, {3.7132209365017233`*^9, 
   3.713221018989929*^9}, {3.7132212219943266`*^9, 3.713221255047592*^9}, {
   3.7132212975102835`*^9, 3.7132214487627354`*^9}, {3.7132216012227736`*^9, 
   3.7132216086004763`*^9}, {3.713221658662225*^9, 
   3.7132216606068573`*^9}},ExpressionUUID->"df583ce9-45df-42e4-973e-\
8eb223da2e72"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyVnXtcTNv//2ciOcnlJJITKYlEhJOI1lYiEYlEJBKRiE5CErlERSIlEolI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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnXfc1tMbx+/n/n7v73hIdqKkkkrISmSTbBHJSEZWdkYhikJmVsbP3mXv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          "]], PolygonBox[CompressedData["
1:eJwtmgncVtMWxs/XOe+7z1FIKWQMpVJpwC1pIM1zRLNmqaSBBrc0ESGEUMJF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          "]]}]}, {}, {}, {}, {}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwl2Hf8T+UfxvFPdjQ0yC8aNoWUSgnZu2EmDSNCWaWhQbukaCtNSikpJSLa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       "]]}}], {
    ArrowBox[{{1.6500000000000001`, 1.35}, {1.5523431830394714`, 
     2.298437717527727}}], 
    InsetBox["\<\"Optimal point at \\n{1.55, 2.3}\"\>", \
{1.6500000000000001, 1.35}, {-1, 1}]}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  BaseStyle->{FontFamily -> "Arial"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      StyleBox[
       SubscriptBox["m", "3"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}, {
     FormBox[
      StyleBox[
       SubscriptBox["m", "2"], Large, 
       GrayLevel[0], StripOnInput -> False], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  FrameTicksStyle->Directive[Bold, 
    GrayLevel[0]],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Medium,
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotLabel->FormBox[
    StyleBox["\"Antilangmuir Region of\\nComplete Separation\"", Large, 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->NCache[{{
      Rational[1, 2], 
      Rational[5, 2]}, {
      Rational[1, 2], 
      Rational[5, 2]}}, {{0.5, 2.5}, {0.5, 2.5}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7132216199532337`*^9, 3.713221675846176*^9, 
  3.7133544170493455`*^9},ExpressionUUID->"d7bcb09d-6e88-4f29-972b-\
d434a257fd60"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 9: Construct a nice GUI", "Section",
 CellChangeTimes->{{3.7132217856742744`*^9, 
  3.7132217951500063`*^9}},ExpressionUUID->"bc6efc2d-c464-4983-91c0-\
3c7d6b9b8aec"],

Cell[CellGroupData[{

Cell[BoxData["completeBalanceEquations"], "Input",
 CellChangeTimes->{{3.7132265459724903`*^9, 
  3.7132265505349855`*^9}},ExpressionUUID->"fbf00256-1b1f-4469-a5dc-\
6616ea37b690"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "\<\"III\"\>"], "-", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["m", "\<\"II\"\>"]}], "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["m", "\<\"I\"\>"], "-", 
       SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["m", "\<\"II\"\>"]}], "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"IV\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"RS\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", 
        SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
      SubsuperscriptBox["c", "1", "\<\"R\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"III\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      SubscriptBox["m", "\<\"III\"\>"], " ", 
      SubsuperscriptBox["c", "1", "\<\"III\"\>"]}], "+", 
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"RS\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"RS\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "1", "\<\"\[Alpha]\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "1", "\<\"\[Gamma]\"\>"]}], "+", 
     SubsuperscriptBox["n", "1", "\<\"\[Gamma]\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"I\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Eta]", "+", 
        SubscriptBox["m", "\<\"II\"\>"]}], ")"}], " ", 
      SubsuperscriptBox["c", "2", "\<\"E\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"II\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"ES\"\>"]}], "+", 
     RowBox[{
      SubscriptBox["m", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["c", "2", "\<\"II\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"ES\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Eta]", "+", 
       SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
     SubsuperscriptBox["c", "2", "\<\"\[Beta]\"\>"]}], "\[Equal]", 
    RowBox[{
     RowBox[{"\[Eta]", " ", 
      SubsuperscriptBox["c", "2", "\<\"\[Gamma]\"\>"]}], "+", 
     SubsuperscriptBox["n", "2", "\<\"\[Gamma]\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "1", "\<\"I\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "1", "\<\"I\"\>"], " ", 
     SubscriptBox["m", "\<\"I\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "2", "\<\"I\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "2", "\<\"I\"\>"], " ", 
     SubscriptBox["m", "\<\"I\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "1", "\<\"II\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "1", "\<\"II\"\>"], " ", 
     SubscriptBox["m", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["n", "2", "\<\"II\"\>"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["m", "\<\"II\"\>"], "-", 
        SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
      SubsuperscriptBox["c", "2", "\<\"F\"\>"]}]}], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "2", "\<\"II\"\>"], " ", 
     SubscriptBox["m", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["n", "1", "\<\"III\"\>"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["m", "\<\"II\"\>"]}], "+", 
        SubscriptBox["m", "\<\"III\"\>"]}], ")"}], " ", 
      SubsuperscriptBox["c", "1", "\<\"F\"\>"]}]}], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "1", "\<\"III\"\>"], " ", 
     SubscriptBox["m", "\<\"III\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "2", "\<\"III\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "2", "\<\"III\"\>"], " ", 
     SubscriptBox["m", "\<\"III\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "1", "\<\"IV\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "1", "\<\"IV\"\>"], " ", 
     SubscriptBox["m", "\<\"IV\"\>"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["n", "2", "\<\"IV\"\>"], "\[Equal]", 
    RowBox[{
     SubsuperscriptBox["c", "2", "\<\"IV\"\>"], " ", 
     SubscriptBox["m", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7132254655175886`*^9, 3.713226551655772*^9, 
  3.7133544171053457`*^9},ExpressionUUID->"d0f3096c-1206-494d-99d1-\
0cd64509f0d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make a nice plot function", "Subsection",
 CellChangeTimes->{{3.7132249989254193`*^9, 
  3.7132250026033196`*^9}},ExpressionUUID->"48736850-18ec-4851-bed6-\
d60350596d60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"createPlot", "[", 
   RowBox[{
   "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "cf1_", ",", "cf2_"}], 
   "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"values", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["a", "1"], "\[Rule]", "a1"}], ",", 
         RowBox[{
          SubscriptBox["a", "2"], "\[Rule]", "a2"}], ",", 
         RowBox[{
          SubscriptBox["b", "1"], "\[Rule]", "b1"}], ",", 
         RowBox[{
          SubscriptBox["b", "2"], "\[Rule]", "b2"}], ",", 
         RowBox[{
          SubsuperscriptBox["c", "1", "\"\<F\>\""], "\[Rule]", "cf1"}], ",", 
         RowBox[{
          SubsuperscriptBox["c", "2", "\"\<F\>\""], "\[Rule]", "cf2"}]}], 
        "}"}]}], ",", "results2", ",", "results3", ",", "set1", ",", "set2", 
      ",", "set3", ",", "set4", ",", "constraints", ",", "optimum", ",", 
      "overallReg", ",", "location"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"results2", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"proportions", "[", "2", "]"}], "/.", "c\[Gamma]Value"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"results3", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"proportions", "[", "3", "]"}], "/.", "c\[Gamma]Value"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"set1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", "results2", "]"}], "<", "0"}], "&&", 
       RowBox[{
        RowBox[{"Max", "[", "results2", "]"}], ">", "0"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"set2", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", "results3", "]"}], "<", "0"}], "&&", 
       RowBox[{
        RowBox[{"Max", "[", "results3", "]"}], ">", "0"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"set3", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""], "\[Element]", 
          "Reals"}], "&&", 
         RowBox[{
          SubscriptBox["c", "2"], "\[GreaterEqual]", 
          SubsuperscriptBox["c", "2", "\"\<\[Gamma]\>\""]}]}], "/.", 
        RowBox[{
         RowBox[{"intercepts", "[", 
          RowBox[{"{", 
           RowBox[{
            SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
            SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"set4", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""], "\[Element]", 
          "Reals"}], "&&", 
         RowBox[{
          SubscriptBox["c", "1"], "\[GreaterEqual]", 
          SubsuperscriptBox["c", "1", "\"\<\[Gamma]\>\""]}]}], "/.", 
        RowBox[{
         RowBox[{"intercepts", "[", 
          RowBox[{"{", 
           RowBox[{
            SubsuperscriptBox["c", "1", "\"\<F\>\""], ",", 
            SubsuperscriptBox["c", "2", "\"\<F\>\""]}], "}"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "/.", "c\[Gamma]Value"}]}],
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"constraints", "=", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"set1", "&&", "set2", "&&", "set3", "&&", "set4", "&&", 
         RowBox[{
          SubscriptBox["m", "3"], "\[GreaterEqual]", 
          SubscriptBox["m", "2"]}]}], "//.", "values"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"location", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1.1", "*", 
          FractionBox[
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"]}], "2"]}], ",", 
         RowBox[{"0.9", "*", 
          FractionBox[
           RowBox[{
            SubscriptBox["a", "1"], "+", 
            SubscriptBox["a", "2"]}], "2"]}]}], "}"}], "/.", "values"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"optimum", "=", 
      RowBox[{"FindMaximum", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["m", "3"], "-", 
           SubscriptBox["m", "2"]}], ",", "constraints"}], "}"}], ",", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["m", "3"], ",", 
             FractionBox[
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               SubscriptBox["a", "2"]}], "2"]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["m", "2"], ",", 
             FractionBox[
              RowBox[{
               SubscriptBox["a", "1"], "+", 
               SubscriptBox["a", "2"]}], "2"]}], "}"}]}], "}"}], "/.", 
         "values"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"overallReg", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"plotRegion", "[", 
         RowBox[{"constraints", ",", 
          SubscriptBox["a", "1"], ",", 
          SubscriptBox["a", "2"], ",", 
          "\"\<Langmuir Region of\\nComplete Separation\>\""}], "]"}], "/.", 
        "values"}], "//", "Quiet"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"overallReg", ",", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Arrow", "[", 
            RowBox[{"{", 
             RowBox[{"location", ",", 
              RowBox[{"{", 
               RowBox[{
                SubscriptBox["m", "2"], ",", 
                SubscriptBox["m", "3"]}], "}"}]}], "}"}], "]"}], "/.", 
           RowBox[{"optimum", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], " ", ",", "\[IndentingNewLine]", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"\"\<Optimal point at \\n\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"NumberForm", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   SubscriptBox["m", "2"], ",", 
                   SubscriptBox["m", "3"]}], "}"}], ",", "3"}], "]"}], "/.", 
               RowBox[{"optimum", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], 
            "\[IndentingNewLine]", ",", "location", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
           "]"}]}], "}"}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.71321052304011*^9, 3.7132105982452593`*^9}, {
   3.7132106412229495`*^9, 3.7132106719179516`*^9}, {3.7132107505410557`*^9, 
   3.713211034601261*^9}, {3.713211075695417*^9, 3.7132112151294622`*^9}, {
   3.7132112591600018`*^9, 3.7132112612361584`*^9}, {3.713211960832994*^9, 
   3.7132121567642155`*^9}, {3.7132122077345033`*^9, 
   3.7132122257337627`*^9}, {3.713212350008083*^9, 3.7132123662358637`*^9}, {
   3.713212396451017*^9, 3.713212414608677*^9}, {3.713212482357136*^9, 
   3.7132125415704193`*^9}, {3.7132125829700804`*^9, 
   3.7132126088133645`*^9}, {3.713212643360848*^9, 3.7132126968914776`*^9}, {
   3.713212740810562*^9, 3.7132127601915236`*^9}, {3.7132128101864023`*^9, 
   3.713212841797994*^9}, {3.7132129432220397`*^9, 3.7132130554739738`*^9}, {
   3.7132132008415785`*^9, 3.713213207570712*^9}, {3.713213243760844*^9, 
   3.713213273646042*^9}, {3.7132133714760046`*^9, 3.7132134051705756`*^9}, {
   3.7132137072058825`*^9, 3.7132137985607767`*^9}, {3.7132138594357595`*^9, 
   3.713213866274764*^9}, {3.713214057417972*^9, 3.7132140637576313`*^9}, {
   3.7132140958321953`*^9, 3.7132141201759863`*^9}, {3.7132142003936906`*^9, 
   3.713214214014885*^9}, {3.713214252102813*^9, 3.7132143264619093`*^9}, {
   3.7132143608655667`*^9, 3.713214362607955*^9}, 3.7132143943954716`*^9, {
   3.7132144482297926`*^9, 3.71321444962806*^9}, {3.7132144803303056`*^9, 
   3.7132145453666725`*^9}, {3.7132186626419535`*^9, 3.713218713530896*^9}, {
   3.713218836737592*^9, 3.713218875827533*^9}, {3.713219129772863*^9, 
   3.713219171569045*^9}, {3.7132192089510155`*^9, 3.7132192115338955`*^9}, {
   3.713219287037033*^9, 3.7132192882368135`*^9}, {3.7132193446073265`*^9, 
   3.713219346075502*^9}, {3.7132196475900555`*^9, 3.7132196640576262`*^9}, {
   3.7132202394707155`*^9, 3.7132203056793823`*^9}, {3.713220342473565*^9, 
   3.713220367236586*^9}, {3.7132204835869875`*^9, 3.7132205023711367`*^9}, {
   3.7132207454785147`*^9, 3.7132208975857325`*^9}, {3.7132209365017233`*^9, 
   3.713221018989929*^9}, {3.7132212219943266`*^9, 3.713221255047592*^9}, {
   3.7132212975102835`*^9, 3.7132214487627354`*^9}, {3.7132224301974883`*^9, 
   3.7132224704177675`*^9}, 
   3.7132225230733824`*^9},ExpressionUUID->"e25f2702-8283-43fb-8d14-\
d0f62bf2ddd1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make the dynamic components", "Subsection",
 CellChangeTimes->{{3.713225007837698*^9, 
  3.7132250128032217`*^9}},ExpressionUUID->"f1061b6d-66a0-4804-b911-\
03c42c4d8160"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "=", "0.2"}], ",", 
     RowBox[{"b1", "=", "0.1"}], ",", 
     RowBox[{"cf2", "=", "3"}], ",", 
     RowBox[{"cf1", "=", "3"}], ",", 
     RowBox[{"update", "=", "0"}], ",", 
     RowBox[{"a1", "=", "1"}], ",", 
     RowBox[{"a2", "=", "2"}], ",", 
     RowBox[{"plot1", "=", 
      RowBox[{"Text", "[", "\"\<No Plot Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot2", "=", 
      RowBox[{"Text", "[", "\"\<No Plot Yet\>\"", "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Triangle Theory Applied to the Langmuir Isotherm\>\"", ",", 
            "Bold", ",", "Large"}], "]"}], "]"}], ",", "SpanFromLeft"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"Dynamic", "[", "a2", "]"}]}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Dynamic", "[", "a1", "]"}], ",", "30"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \
\(2\)]\)\>\"", ",", 
            "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \
\(2\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Riffle", "[", 
          RowBox[{"#", ",", "SpanFromLeft", ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}], ",", "2"}], "}"}]}], "]"}], "&"}], "@", 
        RowBox[{"Inner", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Labeled", "[", 
            RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Manipulator", "[", 
             RowBox[{
              RowBox[{"Dynamic", "[", "cf1", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "10"}], "}"}], ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
              RowBox[{"AppearanceElements", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                 "\"\<StepRightButton\>\""}], "}"}]}], ",", 
              RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Manipulator", "[", 
             RowBox[{
              RowBox[{"Dynamic", "[", "cf2", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "10"}], "}"}], ",", 
              RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
              RowBox[{"AppearanceElements", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                 "\"\<StepRightButton\>\""}], "}"}]}], ",", 
              RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Feed Concentration 1\>\"", ",", 
             "\"\<Feed Concentration 2\>\""}], "}"}]}], ",", 
          "\[IndentingNewLine]", "List"}], "\[IndentingNewLine]", "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Button", "[", 
          RowBox[{
          "\"\<Generate Triangle Theory Plots\>\"", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"plot1", "=", 
            RowBox[{"createPlot", "[", 
             RowBox[{
             "a1", ",", "a2", ",", "b1", ",", "b2", ",", "cf1", ",", "cf2"}], 
             "]"}]}], "\[IndentingNewLine]", ",", 
           RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}], ",", 
         "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Dynamic", "[", "plot1", "]"}], ",", " ", "SpanFromLeft", 
         ",", 
         RowBox[{"Dynamic", "[", "plot2", "]"}], ",", "SpanFromLeft"}], 
        "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "2"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.7132221641077385`*^9, 3.7132221649669533`*^9}, {
  3.713222204595378*^9, 3.7132223489120674`*^9}, {3.7132223911929417`*^9, 
  3.7132223928702106`*^9}, {3.713222566668933*^9, 3.7132226024254737`*^9}, {
  3.7132226374934826`*^9, 3.7132226395057983`*^9}, {3.713222673964061*^9, 
  3.713222731910654*^9}, {3.7132228656785765`*^9, 3.7132229091441045`*^9}, {
  3.7132229398801823`*^9, 3.7132230026773357`*^9}, {3.7132230379589396`*^9, 
  3.713223093916134*^9}, {3.7132232752782507`*^9, 3.7132232877570305`*^9}, {
  3.7132233737121773`*^9, 3.7132233810850983`*^9}, {3.7132234338375206`*^9, 
  3.7132234647359056`*^9}, {3.713223989225457*^9, 3.71322399072958*^9}, {
  3.7132240373293867`*^9, 
  3.7132240624827657`*^9}},ExpressionUUID->"9612cab4-1445-4f45-afbf-\
da4835733401"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 0.5, $CellContext`cf1$$ = 
  0.5, $CellContext`update$$ = 0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 
  2.0000000000094587`, $CellContext`plot1$$ = Graphics[{
    GraphicsComplex[CompressedData["
1:eJx1nXtYTNv/xxOKdOQkkhOpk8glwjdRp08kEiURTi6RiETqJCKRiERyj0gi
EoVIJPeoSESiIrklqpnuTdNcfsvzeM/umfr55/289pqZ9v583nvtddlr0XX1
clymqKCg0FNFQeGXxvvMKLysUU3y+u3q9dFe7m0V5Xo1WuFGadxxsLzi8y4j
t5RXqdbIPg/G58Dyiu+f8Po6MdGF+z4Y3wfje2B5xe8VJk096ZnM/R4YvwfG
74HxO2B5xe/35iU1De1cK/t9MH4fjN8H4/fB+F2wvL5Zni8uDebTrOEajhVz
a2V/H4y/D8bfB+Pvg/H3wfj7YPxdsLzifCI8/S8lJHDnA8b5gHE+YJwPGOcD
xvmAcT5gnAdYXnF+zy+WKHmIufMD4/zAOD8wzg+M8wPj/MA4PzDOD4zzAssr
zlelwmqJoUOd7HzBOF8wzheM8wXjfME4XzDOF4zzBeN8wThPsLzi/KcMuXC7
PJY7fzDOH4zzB+P8wTh/MM4fjPMH4/zBOH8wzh+M8wbLK65n+8ruveMbuOsB
43rAuB4wrgeM6wHjesC4HjCuB4zrAeN6wLgeMK4DLK+4vgfx/611t6mXXR8Y
1wfG9YFxfWBcHxjXB8b1gXF9YFwfGNcHxvWBcX1gXBdYXnG9ku/vnhpEcdcL
xvWCcb1gXC8Y1wvG9YJxvWBcLxjXC8b1gnG9YFwvGNcLxnWC5RXXbzbIYmBZ
FXf9YFw/GNcPxvWDcf1gXD8Y1w/G9YNx/WBcPxjXD8b1g3H9YFw/GNcNltf5
5V2nupbwaMPyM1viLBtk8QEjPmDEB4z4gBEfMOIDRnzAiA8Y8QEjPmDEB4z4
gBEfMOIDRnzAiA8YcQHLK+KVEtelyO0gFy8w4gVGvMCIFxjxAiNeYMQLjHiB
ES8w4gVGvMCIFxjxAiNeYMQLjHiBES8w4gSWV8Sv9uvqMfplXPzAiB8Y8QMj
fmDED4z4gRE/MOIHRvzAiB8Y8QMjfmDED4z4gRE/MOIHRvzAiB8YcQPLK+I5
Qv91+BfTRlk8wYgnGPEEI55gxBOMeIIRTzDiCUY8wYgnGPEEI55gxBOMeIIR
TzDiCUY8wYgnGPEEI45geUV8PZea/ogN4+ILRnzBiC8Y8QUjvmDEF4z4ghFf
MOILRnzBiC8Y8QUjvmDEF4z4ghFfMOILRnzBiC8Y8QUjrmB5RbwvxJ60ci3h
4g1GvMGINxjxBiPeYMQbjHiDEW8w4g1GvMGINxjxBiPeYMQbjHiDEW8w4g1G
vMGINxjxBiPeYMQZLK+If9knxWhd4yZZ/MGIPxjxByP+YMQfjPiDEX8w4g9G
/MGIPxjxByP+YMQfjPiDEX8w4g9G/MGIPxjxByP+YMQfjPiDEXewvCIff+uu
EJQGc/kAIx9g5AOMfICRDzDyAUY+wMgHGPkAIx9g5AOMfICRDzDyAUY+wMgH
GPkAIx9g5AOMfICRDzDyAUY+wMgDWF6Rn8WLnzvGFHD5ASM/YOQHjPyAkR8w
8gNGfsDIDxj5ASM/YOQHjPyAkR8w8gNGfsDIDxj5ASM/YOQHjPyAkR8w8gNG
fsDIDxh5Acvrp5V06Ispj06eGpXoYiiQ5Q+M/IGRPzDyB0b+wMgfGPkDI39g
5A+M/IGRPzDyB0b+wMgfGPkDI39g5A+M/IGRPzDyB0b+wMgfGPkDI39g5A+M
/IGRN7C8Ip9FJUeVdQK4fIKRTzDyCUY+wcgnGPkEI59g5BOMfIKRTzDyCUY+
wcgnGPkEI59g5BOMfIKRTzDyCUY+wcgnGPkEI59g5BOMfIKRTzDyCUYewfKK
/Gr2Fy8pyeXyC0Z+wcgvGPkFI79g5BeM/IKRXzDyC0Z+wcgvGPkFI79g5BeM
/IKRXzDyC0Z+wcgvGPkFI79g5BeM/IKRXzDyC0Z+wcgvGPkFI69geUW+Zy90
TT+p2yzLNxj5BiPfYOQbjHyDkW8w8g1GvsHINxj5BiPfYOQbjHyDkW8w8g1G
vsHINxj5BiPfYOQbjHyDkW8w8g1GvsHINxj5BiPfYOQbjHyDkWewvCL/+09k
9l7oy+UfjPyDkX8w8g9G/sHIPxj5ByP/YOQfjPyDkX8w8g9G/sHIPxj5ByP/
YOQfjPyDkX8w8g9G/sHIPxj5ByP/YOQfjPyDkX8w8g9G/sHIPxh5B8sr/JBb
PMxbO5PzAxh+AMMPYPgBDD+A4Qcw/ACGH8DwAxh+AMMPYPgBDD+A4Qcw/ACG
H8DwAxh+AMMPYPgBDD+A4Qcw/ACGH8DwAxh+AMMPYPgBDD+A4Qcw/ACGD8Dy
Cn90++vAs2ItocwfYPgDDH+A4Q8w/AGGP8DwBxj+AMMfYPgDDH+A4Q8w/AGG
P8DwBxj+AMMfYPgDDH+A4Q8w/AGGP8DwBxj+AMMfYPgDDH+A4Q8w/AGGP8Dw
Bxj+AMMXYHmFX2ycmwZGeXJ+AcMvYPgFDL+A4Rcw/AKGX8DwCxh+AcMvYPgF
DL+A4Rcw/AKGX8DwCxh+AcMvYPgFDL+A4Rcw/AKGX8DwCxh+AcMvYPgFDL+A
4Rcw/AKGX8DwCxh+AcMnYHmFf3YcW7DV+R7nHzD8A4Z/wPAPGP4Bwz9g+AcM
/4DhHzD8A4Z/wPAPGP4Bwz9g+AcM/4DhHzD8A4Z/wPAPGP4Bwz9g+AcM/4Dh
HzD8A4Z/wPAPGP4Bwz9g+AcM/4DhHzD8A4ZvwPLqXuH70e1gFT1896BIS71F
5i8w/AWGv8DwFxj+AsNfYPgLDH+B4S8w/AWGv8DwFxj+AsNfYPgLDH+B4S8w
/AWGv8DwFxj+AsNfYPgLDH+B4S8w/AWGv8DwFxj+AsNfYPgLDH+B4S8w/AWG
v8DwFxi+Assr/CbVHPS/QjfOb2D4DQy/geE3MPwGht/A8BsYfgPDb2D4DQy/
geE3MPwGht/A8BsYfgPDb2D4DQy/geE3MPwGht/A8BsYfgPDb2D4DQy/geE3
MPwGht/A8BsYfgPDb2D4DQy/geE3MPwGhs/A8gr/mc/dsy8ylfMfGP4Dw39g
+A8M/4HhPzD8B4b/wPAfGP4Dw39g+A8M/4HhPzD8B4b/wPAfGP4Dw39g+A8M
/4HhPzD8B4b/wPAfGP4Dw39g+A8M/4HhPzD8B4b/wPAfGP4Dw39g+A8M/4Hh
PzB8B5ZX+Mn/SM2PuSoimZ/A8BMYfgLDT2D4CQw/geEnMPwEhp/A8BMYfgLD
T2D4CQw/geEnMPwEhp/A8BMYfgLDT2D4CQw/geEnMPwEhp/A8BMYfgLDT2D4
CQw/geEnMPwEhp/A8BMYfgLDR2B5Rb5uvJkzSXMhly8w8gVGvsDIFxj5AiNf
YOQLjHyBkS8w8gVGvsDIFxj5AiNfYOQLjHyBkS8w8gVGvsDIFxj5AiNfYOQL
jHyBkS8w8gSWV8SnTiM9uuAyFx8w4gNGfMCIDxjxASM+YMQHjPiAER8w4gNG
fMCIDxjxASM+YMQHjPiAERewvOJ8Rs7WbT6sKJadDxjnA8b5gHE+YJwPGOcD
xvmAcR5gecX3Vx8MmeXkxH0fjO+D8T2wvKI84VVFokY8dxz8/+n3P2d2yRf+
/6o/84brQTtJG10S8dcdxxhOo19s1VSv47S4e5l3nrVUpn3sp+VERHLqtPeK
gUMFp5PVt4WoWVTLdPvM76W5EZyqnxs3L6aAT/cjppuFf6luoyiXvLh62M6k
po2ifLyaZrVqaE0bRfkG+wDbnOKaNory63s/nQ0zqm2jaB+Ca3MmS22DODVS
vfSvSj6nntP+vJ5tUCfT+N1+3UP9OY0c5HVG15hPZdnFK2xy6tooyvW6Tnik
rFPfRlG+2OZcv0zv+jaK8hM7u20IyahvoygverL2lbVmQxuVvd/wm3srFQzr
7MHpbGuznRnpnEZsj/kUrNYo09xHnc2tXDntf+EsLzaMRyodVx1RTGlsoyi3
mfiy+oFyUxtF+fag/00Lcm5qoyh/eP94nGViUxtFuUT6619TG0X/AGxOy5zv
OQpkuiHw6fXAOE5v3BmhZiHgtFZ0aKXYtlmmZ4cUjdMvq6KR5sJH6Seb2yjK
PTe59A+obm6jKE9Iy9hgZiVsoygvazZ8LTwsbKMo1x+3b3haubCNon8EXryh
fqe/WYtMo1P//WwazmlR411zQSmn+H0w4guW+es34/4C9zHRP5o6WiRT3Idg
3Gdg3Gdg3Gdg3Gdg3Gfg2etCa/xCOIWvwTJf43Pw92+Gr8HwNRg+Bh+4zptm
UsgpfASGj8DwERg+AsM3YPgEnFs361zDULFMkTcw4g5WHX1LISWQU5w3GL8L
tvHpP983j1P8Dlj+cyFXg1NG60tkKn/8YXW5Wp0fp3jugBVG2nskZ3Nq7nUt
w1tbKtONSX10jL04vVG12b/6AafwG/pVYPSrwOhXgdGvAqNfBT+jnQ1GOxuM
djYY7Www2tm4X9BOBqMdCEY7EIx2IBjtQNyPaMeB0Y4Do90ERrsJLD9eDN/I
3n/7zbLnw2+Wvf/2mxE33H/oj4LRHwWjPwpGf1T+fpbvn8C3svdRfrPsfZTf
LHsf5TfL3keRu3/l28+4D9B+BqP9DEbcZffj77jL36/y7U/cR7Jxid+M85C/
H+Xbf/L3H9p1uI/Qfnund0NRQaFapr5KyhctE/n07R+b3GKtWhLuNG98oMwn
lfVvWw4rNtDWrj4TrFx5NOLKckOHiiZSCju/JyO9imb/aJijki+krGkTR3X2
YH46P3C5TU6L7PcSJs/rGd/QQoXjP4wtdKuj7zvurHa3Yf3La3n3HGMaSf+x
XpZBFOuvDH0yJae4mZZ02qVXViWS/U60VVVAnCU7fzendSEZIire5vjW7SCL
zxedIZ09xNTnYaqxfhmLT8yMcVauEjpgua0sNozTkaXXDyqmsPrkw1Qxe5DL
FMehL7Z8t3Qtaato367W6ct7oCyVqeq96VG6xpwmLNpiE+TM6VTJ1YbSYE6/
n/waa5nIacg/mg4xBZxiPAjtYeSlt+tfC+85crz+YfllF8NqWb2JetKpQ789
X0wlsjjgulBf4ntQfF7+e/9fHPE7iAvORzZP/dt38Ju/3o7tGemsn7PkZ0mw
mkTmUzA+h+tAHnE+8CmuQz4P8v0G2frw34zzm3V6a2pgHFffo90gW//3m1GO
dgTKwSaZpx2CnFn9Pd96ZFo593m0M2Trs34zPm8WlbDb36xO9nnUW/g8GJ/f
UKT2zTSce36gHYL6FYxytEtk7yv+5nSbt1GKKez5cDh/oW8e93m0W/B5MD6/
OH/czdH6jbLPo10je//pN+PzJ3ueUq/z455PaNfIxtd/M8rRzkE5eOJT1e/B
aqy9n7s0zCiN+zzaQfg8GJ/f8Uf2tyrVZtnn0U7C58H4/MPpRpaJLtzzD+1b
PN/AKEe7CeVg1Herletulse2yPx2vYO9ik4AV5+uurdZa6FvjYxVXK48ST/J
cbzk83/amRxPie6lG1BdI/PDiZb1H7TUOX+gHkX9HCFQnaK5sF7GIyKp3i+E
4+djfU4XXObY8+1Ze5PCeln+HoxR7pYv5Pwi+c9z2UG7Rll9n2J8wjfPuknG
s/NydY29OK5d2+FFRCTH+3uMCah+0CSLd9nqI6bhX7h8/Z3YcsDOpFn2/Cjy
GBobZiSUsb/KohkVcznWTIgQ2QZxfGPqowsJCULZ9eD5gvoA7Q2wbLz6d72A
cjDKMa6AcrBsvLz0258WAlbPle2+r6wjko0z4PNgfN5oa597J3VrZJ9/rjPN
U2zLMcYh8H0wvg/f4PPwDdglXT3Y+V6t7HkKn4AxboD2EhjtJYwboBwsG8+d
V3QsdXQ97RhY3TfTWyQbR8Dnwfg8fIjPw4dgjDPg+2B8Hz7F5+FTMHyK9gJ8
Csa4ANpvYLSbMC6AcrBs/PO3r9HOwDgBPg/G5+F7fB6+B2PcAN8H4/toR+Hz
uTOOFVzWEMgY9wnaQ4srF1ephnKMfr+sHfib0Z5Evx/lYJSjn49yMMrRrpOe
SXthrcnaV7sGd/IQc4x6Et8H4/v7B8+/mm3QIvv8yKy9iwwdOIYP0L4Fox0L
H6Odh/tZts/T73YRVLYfzO/7GvWwfH2M/hwY/RLUJ+ifgdE/Q/2G/hYY/S3U
T+g/gdF/Qv2K+grPUzDqdzDaB+AH2qVvhIe5+x39JTDaJWD0n2Tt7d/tEDD6
U2C0E3A/ob8ERrsAjP6TrP3+ux0ARn8KjP4R/IvnMBj9JbA07OBxz2SO0X8C
o3+E/gHuK/QP0P9BuxPHoTiOdivaq1D4EO1SeUU7ForvoT0rW+/1u35H+wD5
xPgWysGo/9EuQH2P8SncJ2DUn+inob5Euwv1Dxhx8uQ/C2YNKVl9I5u3/H0/
4jwRX9k41+9yMOIk+7u/71f5cSXZ7/6OO+oBxA39EtyvuI/xHAbL73uH8hrL
a24luZziOJ7LYPl971CO5zUUx/FcBsvvc4dyPK+hOI68guX3sUM58g3FcYx7
guX3pUM5+u1Q+XkJsPw+cijX25w4OMqTU/l5DLD8Pm8oR3sEKj/vAZbfdw3l
aL9A5edJwPL7nqEc7WIojqPdA5bfZwzlvTdOPBCZyimOo10Elt/HC+Wzbp2v
nKvCKY6jnQSW3xcL5Wg/QXEc7SSw/L5SKEf7CYrjqCfA8vswoRz1B1R+ngcs
vy8RyqfcMJ/j5MSp/LwQWH5fHpRvbzh9RSOeU/l5JLD8PjQoR/sQKj/vBJbf
ZwXlaE9CcRzjgGD5fUNQjvEsKI6jHQqW3/cC5RtqTfqq1zXKFMfRTgXL79OA
cvTToDiOditYfh8BlKM9K2vX/j6OditYfl07ytGehcrPm4Hl11GjHM8jqPw8
G1h+nS7KLxgZl+RGcCo/LweWX/eJcvRTofLzeGD5dYMoR3sdiuOYpwHLrzND
Odr3UByXjRP/Zvl1SCjH+CkUx9EvAMuvS0E5+uFQHEe/ASy/LgHl6KdDcRz9
CrD8e+goR38DKj8PCZZ/rxjl6G9A5ectwfLvhcrmxdzvdwv151R+nhMs/x4f
yjFeDZWf1wTLv6eFcrTzoPLzlGD594RQjvYXVH7eESz/3gzKZf3e3yo/jyib
d5R7rwXlaM9BcRztQ7QjoTiO9iHajVCMl6Kdgv4a2icoRzsE5Wh/oBztDJSj
fYFytCNk/cPf7QeMf+I5h/4gnm8ox3MM5Xh+oRzPKZTj+YRyPIdk/c/fzx+M
Z6KeRH8T9aNsfv13PYhy1H8oRz2HctRvKEc9Juvf/q6/MP6J+wz9WdxfKMd9
hHLcP+iXy/fDMR4v387HcXlFex7jb/KK9jrG1+QV7XGMn8kr2tsYd5VXtKe3
f9i4ycyqrcKP6J/LK/yI/rm8wo/on8sr/Ih5AXlFezVFax0JStsq2qMYz5NX
tDcxXievaE9iPE5e0V680FvlQsPQtor7pczJq2NKYFvF/YLxB3nF/YLxB3nF
/YLxB3lFe6zIsdPq5Oy2ivaW5oGVmd7aTW0U7SmMD8or2ksY/5NXtIcwviev
uJ+77ZOM9HJvq7ifMS8ir7ifMQ8ir7ifMd4ir2hvYLxFXtGeMH8mqB/aWdhG
0V7AuL28oj2AcXt5xfMe44vyivoG44fyivoG8zDyiucxxjPkFc9bjIPJK56n
GMeSVzwvMS4lr3geYtxJfpwJ40lgjEfJj2vKj1stP3I92eUHX1Yu2//re8WG
ENbPP5HWd/G9jdzzsyDrpa/7Cu55ef+fK4VCJ+75WKn5U1xqxT0PMT4ZMmDT
OUvW79Mzd7ho+Ybbr3eBrdL98ofcfrST733TD7jC7a/qc0xnqms0tz8o5uMS
/mXZZv2A+Ds7Gh+M4J5vn5+ZdfPoxz3Pciz/WitW4Z5fgr5Oh74IqmTPK8zH
vTxwrEMKaxca0e0JVru559UKO+85Feu555PjQ4fbgcu49T+711UJS3ty8zsY
r8sakXXMs9V6jDj/x8c81bn1GD77Jl9I6Mutxwi3iF4h1uPWY3juilohHsKt
xyh8mf3WbTT3Pv4y3rp1IW7c+/ifPQa8uezJvY9/53q/N5d9uffxh4inTdLc
zL2Pf86/8YzlDu798G0j/Wv8bnDvh/f4dGqC613u/fDNhrlXsp9w74fb0oz7
yi+498Pf8tf1qCvg3p9u7ONzzLML9/70SyeHfgE9uPenT6zKG5bWh3t/+nzZ
pRZbXTHl3z18X1naImvXIa76VSv2fJnHve+89talh+nruPZj759Rn0zvimm4
3bucCAH3/jHeD7jf5/k95RkSuun5Jrt4nLTNe8YdtPdqBzhISWFQ77qhh9u+
d2y67+7JgigpKdUX+plVtH0P+azBzgI3pheCFexzNvHprtkQYemsWlo7cOYL
g1V8ev9s7GG76Foa0dnkmF0Bjz773hoUZd5AjedC+sY/5pFi58yHyjsbKCVk
1dfckTzqkmTj5DRQQAGD05cZDuCRgcWc6gdeAjLrcnqEQ1gVDfv+dpta9xZS
TKi5krCxiqav/9YvYF4LdbL6787oNB7lWhmctRS0kEPR17xibz6ZvGye5dRB
RGeX7vsZe7SWnuZ4blOzFZGv4qPd/nW1tGCYWZbBLBFVVn3a5jyDtVvf1S+z
WSCiWoHLHqNXDVQ7OKmxlNVTHl8Dt6sZNZLRG/dDinEiijDJzCkObaQ+5bbb
1JJE1H24W27Eima69PXOlexGEY3Zcqn3woxmOtIUE10gZX+vyZAX28CnQz9C
zcKNqmnttwBtdYtq0qad1apMz52P0Kwr5VPaS7OguLBqStL/7JfH2nXOgZW2
OUy/PVwWH5bLpyGnXL8Ef6ymgrlNllY5fCpJrXqSXl5NP5dOyYv4Uk1H7syM
C2Oa5HbDsOwOn2xHrA2sNqyhLl0WeRxM5VOnU6dU861raPCZS0MdTGooX3RD
asvU7fOfIWqhNdTDXNtZhWms7vrS3OIast8UdD2bacni9+PDWb24O62seyhT
o74/4gpavb+tHTPhsF1QLWU1T1tpw3Tex3N81fxa6jTu6iNlpsINLuP0Hdj1
6WmttNGsoyP9VW1zDOpo4obe/TOZDjN84uprxq6n67MkF986erXQ+2yYfx0F
pm7aEMJ01aSoOlVDPjm8q+lhkVVHCwqH7ckwYNdTE1Dvl1dHPU4WSGxz6ii9
sfSVNdMxZRW+7n34tGaF9GKCej2Fhx5M0VDn0+B3Ruw66mn6e7N/VXTqSfC/
ycM7M9391+lr2d71ZLLu4s4Mpk+clbqHZtSTz/Uen4OZdjq+aoUNq8ev1K0z
t2J6Pap/zdxW73NbFr58qOzRQJWjio8oMg3sY9IvM72BhvhY1jxgulV4aHtc
Ao9K5scfUVRopLS5UetD1Bpp+dW4aUFMkxNaEhsO85iPnd9rLWwkwRGFV9au
jXS2WuWcJdOaxy8twoN55PtnkIXgSiN9dnZ9ax3Eo8FDVPWM0xppTMGyYZ1T
Gql0xFoFBaZp7rr3y314dOh0OKu+G0mjW7bCEU8e2f95191Gs4l8ej0Lyfj1
HrjXG+d7TJNmj/wU7NxEzknjUwKZVh48bGaV2ESRVafULJgOfi08rKggoPxh
rHfJnj/j+802L2z1fvdy9cXVDxwFpO7pkZHONHbmY9ugOAHZX3zRP4CpUsDT
Fwad2fUdHpuRXi6g0oghcZYCAe35OcbfjKnpMONmv+oqGhzwo2u+dTNpv9wn
ldo2U5bh8ddCpuunKO1WK6mi47Y9PJOPNdOK90f1MouryH5p1IyK2GZyVmv4
997JZlJaKR2extTyx5xuHs+r6GZRP2Wdr810fI9kmmZmFfnY2rHrENIRe+fr
gdXNNDHebZc/0/y997pbWAlp6/fsz6ZMezzXXyk+LKR0gxH/CJjaq+5+lM6e
k8Jlh46mMr0fHbrTudX73run8fsFmLWQSVxzjR/TrN2zN5iFt5Dv10XTTZju
EUv7xruw68t9UuOXx+qrp7deCUtb6MrfGecamP7VO2uQ8YsqGtAh67F3Jesf
zu20z38ZjyJ19lWq1rfQxK46w9PYc5DnatghhWknu2lxYY3VlO8/cHjaABHd
jXrzp8XgGnrXwaZn/EARTSpK6585oYZeDf2ru8Vg9nyr6uessr2GMjSGdkgx
EtFLhQ42mntraNuk8ZQ4gj3fBk3xdn9XQyMX/rtWeyz7O3Z7j6f+XUsl6zac
DrMQUYDv60fKXrUUHn70ldBaRIE223f6h4hoSGz4fF+me95/7Jgyqp5+nv55
JdtHRK5f0+bfc62nOX9Gj/BaLyLtjgbDOwfWU2Ra18+mG0U02/zisdS79aQ6
xLBn/FYRKX7YKrHNrieejsaq5CBWv3bMHBSl0UDRpqNP6IaKqP+QP2ZWuDTQ
9JmOzyMiRHTJYdZGs4sNJFrpLZEeFVH6zh+fTAtFtOJTXcpoptejdR8qs/6F
61HFN5dZ+9L+kulC35PM7zF7Onpks/g8dq+Ym8ae91d0lXRy2O//6u42N1Gy
1Hlq0CsWn1/NxM4Cup9lOTb8tYg8x81MznYQkGuaYv3QYhGdu3X6ssYJAbn5
a86M+Swik9Lv79y+M/8fMNmm9lNEgif25oKhYjo74N8edUyPT+gqlb4V0iTR
8/Vmf7HndJc/a/0ahZSr/+qTaX8x5dTEjNI3aaHxqxVmxhiIqdN+s9lO1EJD
ilWLtAaLScMn+5DijhaaN+5r3dD/iclE6fqR1EAxfXa565HMtEvC2fm+LC/a
90zNBZ5iUt1U9cKaxXH2cCe9smAx+VhrMd+Jqf+pvx97M40P46vHDxHTmqJt
vAevxHRle+A0E30JLSjZpWPMNDBztH1FppgcFqx5mD5cQpWPvsQ1+Ekosh/P
v5rpnFFRmQZDJVTrlSeWenHvUf57dfawtF0Suq82ekzhGO798+3rTwgO75aQ
xYXjQWo3JDSk41SFlGwJFSyYlX+Zae9V66J0b0noZ73BOKsi1l7RvuikcpZ7
b3L5xCRnX20pqZ+4aeTFdGT924bSnlKy+Rl+UHEga4cE9UwZ7SUlh+J+oUZM
kwekNZSuktJE8/U2QT5SKr2/Qa3ugZT29A3+UsX0nZOfsy/TQzt2RHo+lNKg
ebFTOygoWEJN5yW4+Lb6/8Q8/rVXONLO+++5tvquhq3mU8Hvmt6r5rdaj+V3
VC1tdDvzrp4/56iFMj1h90R7YQa/zfyq6u7Q9HKmGmMnuh9stX4rucBXo66d
edgEw/SVNkwNGxw/aSXz28y32mTzesczdfQ7/8Cx1Xqv6l5Fa5LbmZctW6Gb
odxq3jWky2xvd6bhKara6q3Wgw1zomzvduZl9eND+me2mnd9OOXWMwOmOfXe
fnmt1ot5HDr7t3E787Loj6EfprCzv0EZ0y5j3r6MaLWe7NzrroHV7czLRhvM
fG3dat7V/Enw1jimk/8zH+rQar3ZV3Wvd5fbmZctWnZjeOdW864bO/8ocmO6
Lfn0DrVW69MGOOaP8mpnXrZP3F+7MlrNu96YZP8/fab3a5RKc1utZ1u0f9xe
o3bmZWd/3fo5mGl1UfA0zXbWS9QHX9v3pdV8LFg00nN8eKv1ccdfRn+vamfe
9sDfZeZWv+ZpX7S4l/Tnt5mfHfmoz89YpuPX5h2ya7We7p1ap4mJ7czj5rpO
O6rI9LLfrmFRqvw287VrFAMnuTL1u2zCV221/k5jxsoTnu3M66rGXql50Gre
NmHCl2hdptd5UVNzWq3PcwzPbRzazryuzade04NazduWb7VpLmVaPbzD2bBW
6/fCn4+eWdHOvC767+i3699PnBXD1Gj1coltq/V9OarHLia0M6/70KVUQaHV
vK2rVD3JhanHpWfzVFqt/+syXdLZo515XYVT1vPvtZq3jbbY0EXn1/+3UjHy
Wnar9YKTw5YuNmxnXte8JCElsNW87fvNH1xLmH4dcuSP0FbrC7c9zUorb2de
d2O/Hj0smPotuHUksp31NX3uTLxzstV8LljPo8XdptV6xftdjXrFtzPve2PB
Og/x9UaKdzC+5uLPazO/O0d0XnMh00UXFj9UbrW+UWRz0Mu9nXng+qiijHSm
/xPcWa/tzmsz33vA7A8f7V//n0H5Y+3MVushx+8SZBu0My88sph0AlrN+77c
6JNTzPTdoKHrQ1qtl/TLXKhf1s688Jq+cf5mreZ9VdPeGkT92v/dPSLPutV6
yutKjwLj2pkXxngPxhtsm82DnJk6nmsY2lmBmxeuth5c6NbOvHB5pJdRWqt5
3xDT2GKtX/tZf3MOyWi1HtNox97R+u3MC+u/y9/l32reN2O9skkh0xz9+6XB
rdZvemTU7v3Szrywq+b4L6at5n0VUj0jIn/tr+s20Myq1XrP+I7zymPbmReO
nnPqHwFT0QfeJ6121mNZNOb9nNtqPhg8+czuw4rTuN/5OvHORNd25o3fH+4U
mcrU6NVySenrqjbzwxv/N9Za89f+np/5/Aet1pvqbdM7qdvOPHKfNytr/Zje
9q97ePJBVZv54pu+J04VML2v62Qb1Gp96qIHO5tK25lXnqPxYrpJq3nj+msd
hId/7f+3OO2sZav1qycUqmbGtDOvfGDWmPMNreaNR9Utn+3EdHyMjlTaan3r
O3K85NLOvDLGBzFetWZUTpLGr/27Pm7/916r9a+9t6Qq6bQzr6z6SjLft9W8
8SVv4675TK/3/3ktsNX6WMe72ktK2plXtv3T7cboVvPG5VeOLD34a7+chTO6
W7RaTxshDrp9sp155RCH7B51pdz6gzLv491Cf7TQisurn3svaLsezzlf6b+8
Gm597SQf51H6Stx8s0F1yx3HX++nn7y+Qtxq/W6O+fdeC9uZl87YZ7Qq+df6
vC7DCoQp3HpctHPm2PmODTfj1vONPuo9NtxKRLc6Lj0QOZd73xzP8cClKavd
F3Pz164jlvRR/7U/yHutR+mt1v+qBExfq93OPLfCi4OPvZluNZ6S5NJcLzsu
+3/XHtWdsdzLrf+r6abXM/6wiHZm7Aj1j+LW86EeTiwcU6SVzM2Hx6x54pPH
NP6vLf0CWq0Pnnz76tPidubNLbo36xgzTbqXbq35D7ceEPXQJNOzW5w/cusF
e9gP3Bf5XUS+VTFLSkq49X+y9d7231JGd+LGR98nDn0e8et9buev681arR/e
Luw9MKqdefiNdos2Vg/l1hOucMhXSDESk+J1s//ynNqu/9W75vDYezo3H9+3
KmKQA1O941NfCVutH74/LmCLs1Pbefubex7lX2ZqdKNymY0vtz4xQDBjXUg+
tz4R5/3ELTXUKEFMkg2fCrVa7UvR+7j3avfB3PyHUrjK2PD/uPVk+F2DQ2Mv
unSQ0CRJVU7ETe59W9OL8x6mr+bWjaHfFlGyw0v7PNcPm/d4fXjkd9ZPPOVX
KJTyZarYeCVSUaH6/z2+7X5JXnEwXzaO2GWiRr+FJTzZuFr4o6krStj9h3Em
Dest11zY/Ypxl1fWtl7JGtUUeGq2VSLT7jsuZ3uzfll6ya2TnkynZ2joG7N+
laCfjmAo010dNwZWs36RycLtjhVMn0z8+O4y69f4nPhxKYGp4rZJo71YP+VK
sb2yR/Kv/s+wO6P38OnsY+e5Tl1ryfLBhb1G7P6s7Ht9iSHTAAW18ip2fw5x
1kovZ5pGvhMTWT9h+bHA3vFMGwMLT3iydv/Zd1/WujMdc9eiaShrx5dqTn1m
wHSt+MzMCtbu7j83aWAZ0yTzrpcSWLvZ+UjPrXFMf25ao+Txa53zmw1FbkwH
33692JC1Y/M1SsboM/U7uqRLShmPsiQ/tqvV1pOb0PR2OWunqs+22veFaey4
6F7x7P61Pxj/I5ZpyYaOa93Z/bvn1R+TXJlq31zx1IC1C7P+/C9al+m8puf6
ZaydpzTznaCU6RGT0VviWLtsYsQ/s2KYvloXWejG2lVbX8QmujDtkSIerc/a
Rendu3TRYTq93jX8C2vnCO1Wu5YwFfU5OstkAo94Y/2Ts4uaaPforPJY1o4x
2fsq/STTJz7DrVxZu8Q3Z6zmQqadkg+c1GX395VuJ721mVrWNDWVsvubZ6uY
U8w0cORCxxjWDhiy290gimma18NLLuy5vSI7Z6szU0HSIGWdX+uwu4wq1mI6
hrdnSQl7bn6ecvR/hUx9htfePsmeg/13ivZFMt12PCc6NaqK1L27lAY/ElKS
59zeC9lzbsGTJT/nMq28mL5Wmz23IjtnTtJkOrhC91kxu/8LJg07VcA0asWa
bdVLqsgvxay7RVYLLR+yc2AUe86ob9/ffJjpZ4nZlYQDfPJ5eqdHnaKI/IYN
7xv/nE+X/q14WtyZ1bsGbkFxzLcDvryf4MqeD7ErK7c4M3V41DjLieng8jgS
OHDzD7wuk/7TPlFHPZpu7/mylH1fU+m85eY66u5a9j6X1f+l8TOLtFi9vkdx
QZIG0y5DZ0zW3Mvay3ZxE1yTRBQ587CX+7tG6rQ8wycvRURnXSqqH6Q20h5v
8+bDrL7WLr8xppDVw08nPOiSz3S88guRbXYzZQzestpdQUxZw3sZRGkIyXdC
dHSBspjUkzaM9KptpoKQ8d1CWf3qPEh7XySrN5WCDJYeZNr4M2RfZCZ7rkvD
ZjlZi6kg/Ryrv1rI4981e77YiKl0nPe+SGURKVUrJWnME9OR5UE/5rJ6cNL9
sDuOTE11Hg9yuC0it6zP+lEnxOTjFNFYWieiFXkBV7JviGnwuXdnLD+IyDLj
TWedS2LKjyuz0mT13lZptaY60yG3TiyzWcy0cnxjKV9MuwK/6UcdElOX5XP3
23WXkN/wDw4x4WJyUF03756KhHp8mxZdwOrFuxZzfPKYZmnwDTsznWjfZ4Kr
vYTs9a8KDttJSLj5dk7Er318BpgOcpgvIdcHxwSHD0ho99Les5xYPWl6Z8Ag
B6aL5nRsLD0oIVHD/85Y3pFQVuymRI06CfmKdgSpMS0SPlSrK2PfP2uhYyyV
UKfPpcr51lJKNqsozmWq8rfpQkNLKV0SHgzxnyalibqTXQ9GSom30cEknOme
tCsuJUekdPbTN1Or41IKXHwx3bFCSsPSUiLsmCZZPs61ZioqjAp0ruDGs4Rd
Z7iLpVKC4jjma1Gfop7GOgv8Pub5sO4bv+N87bJh5xQJKf2RJpZel1DjP/W6
Zacl5LltXWedLAkJHD8XuJVI6NylygQXprFbdiZqvGTx2TIl/3Ile66IFaIL
3nLrkrEuetScfE93gYSO1Gpsz1CW0qTpOvPuMR2V97bATSyh+NULOuuoS8nk
wBRjfWMpfa6Y2ZkFlMwt/hdqNERK78ktUcOUW1ce/kjrk6mFlPKNN5YEO0tp
a9j25ECm+cpmxvpzGKc8cilZJCWfvEthX4KlNGBoqksJ02qlPc6+QVKKbXgb
YRfCrUNflOaQE7FLSj28P5paJUrp7tMfqhZMi/Il10dfklL98qcRdklSutJD
vSy2QEoLPLTTTjItU/Go9mNqsDbjcnardeuPY73V6gq4uCLODheOxnjW8mXr
tnr39SgL5vPJdvpxuyDbagqf8UFxWgWfBrPuvNbCagp2jXSqaOLT55eSuU4D
ufXt2xX6b3FexeL+nM8uS0zj/3AaZ+UoofC/HwsOq0tI+6OvjrELt05c1z2L
nY+ELEfZqcd35fYHwbpxhXV85fy+UrJdnOTpvoLbLwTr9j3sznypcpWS4M4a
M8F9bv8QrNtPPlKYa31ZSjGHv1i7GlaTPb9Ka6Eht24f86Eox7qWwHxNvTJT
CQ0z0mssNeXGm3F/ohzr3zGejTjgOL6v7Wv7wtpVQk+fzz5j6cq1dzC+jXKs
50/vuTkgLkxCK1bvdIgJ49pJuP9RjvX+GC/H7+I4vo/6Q36dPu4ntLcwPo77
TX49P+oX3G+4jzC+Lr/vAO5H53m1lq53ueOor+T3CcD9Bx9g/B33Jz6H9wlQ
n+H+xH2I8Xv8Do7L7t/fx+e+VFhmM0xKXoOv+1frcp9DfYm/A7/hfoYPMf6P
+x2fw/sMqE9xv+O+xvwBfgfHUR/g+LBRuY5O66R0WG35PeUt3OdQX+PvwO+o
H3AfYP4B9Qc+h3oW9TnqD9QTmL/A7+A46hcc9+23N7X8oZSmvEuPsGv1/fHp
G8P9W/iy93REu+xZO0FMY1oG6JX14/aXsDD/ati5L+MhfMHhI9w6PeHx3uca
StlzefBdTXULbr+JHl90L7pM4HycGTPgSvYTzkcXtEoSXFg9su2fFDNBNeer
rWUTonRncvnJ6aaVaXCRi0dAcF6GYylfNn9i5LRfs66ET+qGBy0Fh6ppcfcl
D096c/tPJK+1bhnqxadONuFb48JqqSKlKsTZhdt/4vOAS/oBznzK32V7PLWc
48EjLJ+kMy4Y8ryiajq3/8SJqFPGnW35tHaH4Saz0XWkkadun2PNp+m9a7vl
W9eRYmflHvnjuf0nrhc8cfUdxycTV701yaydVrbvyB86Odx+E6a1GycnZrP+
TVC/JBffBvIe+/er4lvcfhMrYj95ia/zSPigMNM7j+PpK17U+TFecElxrNd5
br8JvX5vAkLO8ujQ3ZvxDX810nFHm2N2MTzymRE0LtyokXaFmM93OsztNzF+
niix4SCPFkRdjfJc3kief+bMizHg9pe4+9+V/Ub6PLJPu1SstVBATTfn9Vuo
we0vwftb83agGo/6t6xoGJrGsc/pRbrGjD8PN91W3YHbXyI+WiVLWVpFaU1T
Ci53aqYB+Zu/5gqr6MiuHu42ms3UvYvPuQJ+lWx87n6hcbMfr4q25ltmG8xo
ptoDHc7qBnH7SUxq+Pb+cmAV+dSZdc23bqHN48NXlKzh9pPwjZuupOBRRZPG
CPTKYjk+UlRlXxHLvW+9een2pQeruP3VbP07/5fXwO2vdrfYu0hLwq0nfblP
6aX1WG7/NPN3YyiRuP3Tbs7+GF0whds/7XD0++iCGdz+aR2+q3S3mMetN93b
KfWiSyi3P5pzX9PbJ/dz+6OVP13ULfRYq/3Reu7dWH2a2x9Nz7D7bqMEbj1q
0uS0QQ7F3P5nuYrGSw9+4fY/O09q32MruP3P0K6W7X/2p/IofZGIi+Ozyy+s
x3LrU7W1hr4S7uDGMfpsGNXR47WYpnf6UWD9nU8KS1TrHnixdmPzlrTA59x+
k3elVsOiCviyfvmGjWPH6T/h06G+kneXO9WQRheTFwa3uf0nqy8nOFU8YPfb
xScrbTRrKCJlkcfBFD45NzU+M5hRQ5KAXmPS4rn9KAcs/nOLWSKfJlZuC3b2
5fjQgQ2XXRib3sw4+CWW3d8hMx0rYmtoyt+jW4bG8cl39ZM1ycdqaPDcGfNi
jnD7VxYVddqTcYJP78uXuJXcrSGHHhviwyL5lOY/pMEvr4ZWrBh6Z3Q4u57V
HVk7uZa6Pw4OCDnE/p74dVedrzV0vM+BsmB/dv6zUz5oLWQ+MXtV4vYfnwxS
H/NV/WvpaZZALd+NT0fM3P82TqslR79mtXxXPlUevPs5+FEtdf36PMbTkU9K
KuE71LrX0asd/fUyJ7DvH48aEDCvjhZtSumsMJjb33JSkP96beZXjCtIWjy3
xw3g081Ze5U8quroeOiqvvG9uP0u/YxLYzy12d//6nRUUaGeeo89lKLRg09b
R4Y0l46tp+0S2y1mHbn9L899mvw0XZlPyweqX9VYyHHaM2V2ffV0d5ywxE3M
6qd7pVviwurp+dkVkxOlPDp+zumE57Z6Snq3/YxuDY9bf7lg/FvrJh4p6tXs
jzxfTwX7E+tU63hUknxLzzitnng/FndJKWf1ybkDj9PL6+nQ5FuZynwe3TRZ
OrYwp54GHM807pzPoyN7J7H6t4EepisPKXvO7t/q2f0ylzSQg63RfKd7PErz
bXSoiG2gd02M7/BI/bldD4tLDbRvWcfKqks8GmbV71p2YwPNU5692uYE+/7r
IfYmExrpq+inQ9A2bj/Np4qXH55k9QPGRbZvjn1hsImd7x7tMfoFjTSg2+ll
hmu5/TVFyb0qq/zY3+/3LSO9vJFO3MxWOOLBo7Mrew2KGtBEKlu3Pk1fyO23
OWxpQC8LVx7tWXS6JNea45JOR1XyGU+6PWJI2VwWD4FXootvE80yiN5v5Myj
ux+/ZhusaqIxzmm82Gnc/pxlH7z0MmfyyGD+1nuOEU20oOcXi3A7HnWqtGHx
aCLfVUdmmVix6/moy54nTdQ3i6ceOpX9Pa9at4MpTXTuL3FAiBE7/yevTcON
BGRj8c8698E8Wmv41TbIVkAFz5aeK9DiUWnijsC4MAEt8nc7V6DJIxOlD/8I
Dgmo13fTsV7KPHIIuFQa/FFAJbtCb2Y3VtFa1bRN1YbN5BE44ITiB27/Toft
X//QYfUxxnVUpG/7xr+pIsUnF5eU3G2mc3sKriQ85fbz3DZm2livvCoqneNb
65fXTHrjpdM0H1fR09izs526Cimiw41eFje5/T2Tv15dfC+9iq4cHakaasRx
JwsDdn1Cemq+bJ17Mns+GEuLtBYKqfD86/eXr1fR1z6+TaWzhJRWzB+nf47b
D9TTJW61zaUqmn5IrUrVX0ifD/XZrRZfRYMHvtscFyYkYeWz6NSTVZTe5+oA
4zQhxUzVX6Ryll3PhaADdtFCGnZyVJZyKDt/qetyG80Wyr3nc798WxUdcv1v
g9noFlpgd6xmri87v+8aLB4t9FXI2KeKFpDnquTNLSS0tG32Y+dz9vSFqUE/
W8j2W1Go2iIehV/fMza8roXWSI6naIhYvrpduBbY0kJbza4ad+7NpzUx6lez
Rdx+Pt13FU9w7S4iQTeD0IxW72vzdtRWzR1fTS/1grapsfJy6V3HCpdq8rP5
/rT4TxGp/s82MWFiNVncutWjrju3H9CwsaM7pPQWUf9Fa/Ii1lZT8sSLO/17
iijwkqlm/A7WbzOLuRbYS0S+Bp0DzC5Wk8ESJZGtlojG7DzQ4BddTYNzTkik
mtz+QV2DRnZI6S+iyKl7s71zqonHcxsYpc3+/utAS8FL9vdm3/taxfiSz9Wq
ucJqctsw54SuLrefUMGRqz3qDER0vDljpY12Db33LOm1UF9ErzKa/6c/p4bs
w8btNhrC7R9Ua931pfWv99/6Lj3p6V5Ds8PizAVDRSTsPTGw+moNjY/WZvkR
UeWaUenlf9QS78b5+b7m7Pk8ftWT9JW1NMdqU7dQa3Z+UVpVc1m9Pv78jY4e
duz3CqOXH3xcS+WxU2fG2LPreeDSO75zHf2892ZM4WwR7Rr6PclFl9XzKcMo
cS63v9CCxOTV7itEpG455JnBxTraVvF2ltMyES3if+qX+aCOLK447It0F5Hj
gn1KHt/rqPzzm1lOq0Q0eKU9X7WwjgS+2U+LV3L7EWU2lL7PXcvaCwd8etYp
1TOfpE1wXcOup9fgKZp/1FNlltd9ZS8ROdw+MrZwTD193nnpZrkPtz/RJJ8w
c8EGEW00X7PWfV49Hf8UXuPnJyK/Pz5uiYuop5zj+841bOL2I9JN32Uu2Coi
laXXj6WeqScbYaJe2WYRHTB9Oiumsp4SQnoNMN4hou7GXbK8bRroJ/HGWYWL
6P0LsxU2Zxso4FT6Fuej7Pw+PKzzY/W08C/3j8GnWPvotvNiQ4VGujnNr19A
DDufTl37ZbJ6O35MSI+6cyIK+ONMfMP8Ropd9G+30Avc/kVaekunBqWJ6OYu
tV7x3xpJsWX4Wu1UEYU/W5IvFDfSpbAht0/eEpHBhuLI1L+bKDnwyxnLOyLK
uTp6XHjPJvLbrvM99ja331HZ2K/z7j0UUWnR3IW+E5qo8o8/FxneZ+2k2vNi
26lN5Hx2aqXqAxGld9VfH+LVRENOJjwtbrUfkm+5yoWEp8y/fXgGUYeaqMud
Ff0CskTk+mZBkPOzJjpkGLix+jm331HpyHF91F8zv9IYh4qPTXTzzU77ihci
GuUboWs8SEAGodPvK78VkfOTdyvF2wSsfz4iSaNURC+vNi0pKRHQdJsf00x+
sPNLm5iQMKqZVjRZdgutYfd/R8uEhPHNZDI/Z5xVrYgSSne9Fm5upt49FpsL
BCIaMGdXrd8R1m5fc3mQQwu3P9J4t+WPvVXFZJ9w9OfcAULy/WLQR72rmBYV
hf+cO15IAWPm7vTvJial29tPFbgIWXv94BZnNTHd9L863speSBY9u98++Qe3
v5LzgA8KKRpiyol9s8gwQEjXT0iN9dXFpNcyrH/ADiHVO/ZP0ugppkOfnmYZ
XBTSANVrV7J7i2lXn29FWglCeunzXiGlN7cfk/HC29sztFm5/Yar2S9ZPW9h
ui6kr5gmB5/YbaTUQo7RRnNUBnD7Lymk2u30HySmE6mD37n91UL1GlXxCXpi
6k0LulusaKGyvqFbnEdw+yttD/2nxm+5mNKD1+yLVBPRla0dmw87i0l1f9e/
Mlm9s8H09AtrVzGZmg/okMLu+/Bj2+44rhXL5q/Q/8a4Fsa/LP/Xu+6BYzVV
hg/ITG+1bgnzWyjHuiasH5CND/4+ju+X5NvE6AZU026jWb7ardaJYj0ByuX3
d0J7WsNj1OTEU9x+TxaTPD0O7m273xPah8cr3PcbCXmy968yHp9O0WDtOfn9
n9DeGbD65PvLs7n9oGynvFU4MrHtflB4fp/jvRpkfJnbH+pllup0zZPc/lC6
Bw9MsFLkUd+hUfeV+S208u21/UZ9Wf/7fqe7jtUtFKJv+TX3Co+evPub/6CJ
2z+q1IP/tLi5hc5455h4TWH9g5qJA4yl3P5RSVvXFmkpsvrKcnlswccaShrU
nf+A9QclVZLhnSU1NNIkf3HJeFb/rprpl2dWS3t6HlohtmR517Ce6zS1lkrs
6/bbTWTPP96pwVGHamnMdXHfzKnc/lPRH0+da5gmIsVeZTMrPtbS5xzt6SYz
uf2n+i6wVdJhz4sDZsM2mQ2to4hvZpvj5nH7TwnipijpLGD3q6vP2TA/9nyQ
OCdpLGbPL+WvZ8L6NpDvDdHDdNbfNLhiWTl3fAOdG1q5PWOPiJ6e05zk6tdA
XXo/65J/gPUXC0J6xe9ooNmTut0YfYjVr036U3NeNlCO66v3ua32s7qre0av
7CSr/2zXvtfSbqSz9pVnLM9w+1lNe5Xtkxcnor7P7he6ubP6+Y8OHVISuP2s
UvsKPpkmiSi+RqljSjLr3xoMGKWfLKLJJ69bazoJ6IS6xdhw1p/tUvej1s9P
QG4xJxaXlIjo7q7X/wiuCOjd3ab8y19FdERrpHbmAwFp3Lq9366MPT+L/grJ
UG2mh3lFD9OrRKRv6Wet+QfHeK9IaezpMYV8EX322hGs1p3bDyt5efoa93nN
tPZnc93QBm4/ra5TNtpXNIlo4l7FyNQzzdS/o9bAKBG3n1bBgpaFhgpiennN
ht0OzZTzl+kclU5iWnDj59eqEy20p/ZrfMJ4MWUc3DYz5hxrh6Uu/Fplzu1P
/CF+irnAUkxBB3rOdkrh9ouad/n0zXKWlx6r8zINwtjnK+eeDosWUcb8fhLp
Pm6/rrW+5iO8jorp6YnAGr9z3P5djZVveQ/Yc2HycUX2PBRTpzl2q93Z8eTL
cye4tloHifkzlOP7eL8c7w3gOL4f27Clb2a6mBxm7OY9aLXuEu+XoxzrMt2+
/SORsnq0ZGmXa4FvxFTrVqYeb83iEnM3SvcT917Ey7+OeyT/YJ9bn62QYs+t
7/Sb8CI+YaOYAjqaLS6RiGni4eRMA3acx0uP0i3j3nPAfB7K8X28/47zxHF8
v3TMN98QNQntCefbBKlx84P4XYyDohzzCnhfHt+X38/spe/wxSUG3H7tp9Xz
nFTGSOjInZ8VqoXcfr2Yb8S8BuYdMD+B9yew/grvT2A9Et6fwPocvD+B9SoP
7s4LVSvhk56K68wYJeaj1Ukj01i9Pmz9vY4e7LkWGSp8qMyvp0b157OcWPts
Q86ZbIOhArqxc/MIL+ajhPUF9hXfmT/VvSa4srxMrul5NHUpa3dpihI1Nojp
4R6PEV7sOX9j3Bv9qAyxbPwH72P01UgSluay/sbqm7nFTOfN6ukUo1tDnRL7
GUYxxbgNnj+v8j501cmsocCh5R+0mHb/08qtRKuW0j3sTAuZTneIv3vSs5YE
F5IPRDLdte8PrYX3asnkh2bVXKZPcn3+01avI5/Bm6doMlXs/u55sVsdXXH/
fLrAjRs/wfsYlnb/DI5KraPKc1NEh5kG7Ind5qxST0PKLs1xYopxDzzvGlVW
jy28XE9n3dZ3y2c6xvbV/kjFBio9837ZQaZrQ8dWznVqoP5fJtx3ZJqUdWKy
ZnwDOeud76vO9Key4umCX/tYLFFdl8d08BT3lsN2jZQf4/0iwo4bf8D7GG4h
OU5OMY2kXlpg6MA09rHxFY26RrLXMd+uxhTjBni+ak8SuR2MbKKsk0rjwpnO
C15yz/HXvuMfVh20Y3rk4RMtdQsBTdTOq1Jl+qrDMN+8CAFtnW9ik8O0x4T9
uRFfBJR+PCo2jOn0rY2DHUyaSVioILY14frveB9j9735wWqhrD2ptXyuCtMn
kvsfcoubyXfes6vZTNHvxvPccnPYAbsgIfEKDi+3YRqYXl2pmi+kIb1b7isz
TWtxmpJj0EIrnBazdlULCcbfPh3m30JnDz1eF8J0zMYBItucFvr8eshLa6Y+
t3bMUdFh/dCeEUM6M00S/LyS7S2iBY4N2zOYVo516BbK2uGR+50/BjMdvD5l
mY2mmApe3htnxTSrd7l6PKt3fdfWlsUyXX6j733lX/uo9Bh4SJFpQOQbd7GP
hM6VGy2zOSsh9YI1n0ytJJS/auR+uyAJBfhusguKq6YhuTt0A5imXSs9bymo
puV/VGwyY9pYa62oMK2Gzk53KBDa1tCYURcX3DtZQ6VhKSPTmK717pEaWF1D
/Z/1DfNnmnRl3Z8WVrXkrLL1mynTn/yiVeLDtaxf/I0ETDFvgfkMtzVxAwJ+
7ZOddbnej2lsosoms/A6slfuNcOEaUml1xthaR3tmbzxQgNT7WFvRqSNrqes
HR87pjCdt2r8bv+QelJ6PGmRL9MjCae+mhbW08ROCTdHM331oxMJhjbQViu1
nuwBST0MPY6lBjZQ+jbf1clMMU+B+Yvd58fYm+g3kkkH0jNm+qTsWHyDXyP5
Wp4NqGbayUCqmJLdSFe2dH17manlMreFvtpNxLu7xtiLaeDZ7NTRv/pPktdh
RkzTvhip1z1oohX/jCurYirQO+SZrCGgswHRlolMx7g2P/F2F9Dn2x2jPJli
XgLzFUmljzZVs/bBgvG5MyqYVuoYFlx2aaZI/9EJCUwHu4SP9Epmz/ObkZ08
mC6Prttt1FlI6gLxIkOmsR/mfauaKySHsUtvlTMt1b5Liaz/sccvq2c8U+0F
fx/3FLP+RsrwNe5MnaN21Q91aCGlhgNZBkwxD4H5icr0/OjU4Crq013tQ255
C+VrzbqQ0NBCW/9buDmOaY9/b3b0sGHtnuSHb92Y2kf2W2TI2mHCmkGj9Jnu
frvtZjlrt5ga793zhWnjrbdTg1xb6N3MM/vtjMT0f32iJRs=
     "], {{{
        EdgeForm[], 
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Opacity[0.3]], 
        GraphicsGroup[{
          Polygon[CompressedData["
1:eJxVnXf8V+P7x9/v9znvc95ve4/sJCRCQyVZJSEVIVkpmdkjsiNERshKZERk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           "]], 
          Polygon[CompressedData["
1:eJwtmXkcTsUXxl/e+87MRUkqJUqLlCVJpagohFQqFaWiQkmiol2oEClEopBW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           "]]}]}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        Line[CompressedData["
1:eJwl2Hf8lmMbx/E77aVpS7JSJCEkKi0ZlZaGkCKVlFkRFSIpm8ceFZoqoyml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         "]]}}}], {
     Arrow[{{1.6500000000000001`, 1.35}, {0.9173487727387872, 
      1.7438618718003749`}}], 
     Text[
     "Optimal point at \n{0.917, 1.74}", {1.6500000000000001`, 1.35}, {-1, 
      1}]}}, {ImageSize -> Medium, DisplayFunction -> Identity, AspectRatio -> 
    1, Axes -> {False, False}, AxesLabel -> {None, None}, 
    AxesOrigin -> {Automatic, Automatic}, 
    BaseStyle -> {FontFamily -> "Arial"}, DisplayFunction :> Identity, 
    Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
       Style[
        Subscript[$CellContext`m, 3], Large, 
        GrayLevel[0]], None}, {
       Style[
        Subscript[$CellContext`m, 2], Large, 
        GrayLevel[0]], None}}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    FrameTicksStyle -> Directive[Bold, 
      GrayLevel[0]], GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], 
    Method -> {
     "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
      "AxesInFront" -> True}, PlotLabel -> 
    Style["Langmuir Region of\nComplete Separation", Large, 
      GrayLevel[0]], PlotRange -> {{
       Rational[1, 2], 
       Rational[5, 2]}, {
       Rational[1, 2], 
       Rational[5, 2]}}, PlotRangeClipping -> True, PlotRangePadding -> {{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}}, 
    Ticks -> {Automatic, Automatic}}], $CellContext`plot2$$ = Text[
  "No Plot Yet"]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Triangle Theory Applied to the Langmuir Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "feb9ee65-ab87-48ba-a5d3-1a47ef2f222d"],
       Text[
        Style[
        "Triangle Theory Applied to the Langmuir Isotherm", Bold, Large]]], 
      "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], "\[SpanFromLeft]", 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {259., {39., 15.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], "\[SpanFromLeft]"},
     {
      ButtonBox["\<\"Generate Triangle Theory Plots\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = \
$CellContext`createPlot[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`cf1$$, $CellContext`cf2$$]),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{432., {250., 255.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{78., {3., 15.}}], "\[SpanFromLeft]"}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 CellChangeTimes->{3.713223241383704*^9, 3.7132232896068115`*^9, 
  3.713223383218844*^9, 3.7132234661310496`*^9, 3.713223992065814*^9, 
  3.713224063571741*^9, 
  3.7133544171598816`*^9},ExpressionUUID->"a9ae6dad-056e-4dfe-b849-\
368b803cdc95"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1762, 1348},
WindowMargins->{{319, Automatic}, {Automatic, 0}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "kd" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "KroneckerDeltaSeq"], "notation" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "eb" -> 
  SubscriptBox["\[Epsilon]", "b"], "ep" -> SubscriptBox["\[Epsilon]", "p"], 
  "phase" -> FractionBox[
    SubscriptBox["\[Epsilon]", "p"], 
    RowBox[{"1", "-", 
      SubscriptBox["\[Epsilon]", "p"]}]], "ns" -> 
  SubsuperscriptBox["n", "i", "ss"], "cs" -> 
  SubsuperscriptBox["c", "i", "ss"]},
Magnification:>1.2 Inherited,
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 241, 4, 121, "Title", "ExpressionUUID" -> \
"d64e7edc-5dca-405e-919b-43567e913504"],
Cell[824, 28, 165, 3, 42, "Subtitle", "ExpressionUUID" -> \
"1a9c401d-e6ca-4da5-be73-c2aa9aa5ef56"],
Cell[CellGroupData[{
Cell[1014, 35, 257, 4, 88, "Section", "ExpressionUUID" -> \
"2d7153d8-72bd-4358-af3f-3bd99ee7b74d"],
Cell[1274, 41, 2534, 58, 148, "Text", "ExpressionUUID" -> \
"388760df-8334-4667-a50b-5f312b37b6db"],
Cell[3811, 101, 640, 13, 59, "Text", "ExpressionUUID" -> \
"7b8a40a8-c9b6-48b4-a315-859a2f763e43"],
Cell[CellGroupData[{
Cell[4476, 118, 380, 10, 52, "Input", "ExpressionUUID" -> \
"7f6b36a2-775e-49e9-8162-4d8094502003"],
Cell[4859, 130, 628, 11, 48, "Output", "ExpressionUUID" -> \
"7f2f912e-776a-4986-9a80-78f55a17d8b3"]
}, Open  ]],
Cell[5502, 144, 518, 14, 36, "Text", "ExpressionUUID" -> \
"7d1243a4-4dc2-4bd0-9c6b-fa6b4d54e86a"],
Cell[6023, 160, 638, 13, 81, "Text", "ExpressionUUID" -> \
"95a5935a-d2fd-4c0d-a52c-9a38198ed1dd"],
Cell[6664, 175, 712, 11, 48, "Input", "ExpressionUUID" -> \
"f269ec12-eabb-412a-8d8c-4126a0962bb5"],
Cell[7379, 188, 4001, 88, 1049, "Input", "ExpressionUUID" -> \
"1db33f99-6061-4533-9bd0-be12dcbfc7d0"],
Cell[11383, 278, 7183, 162, 849, "Input", "ExpressionUUID" -> \
"78080e82-5fa1-4e6a-9cd1-2627706bb684"],
Cell[18569, 442, 489, 11, 36, "Text", "ExpressionUUID" -> \
"55b7bde2-942e-4cd2-8efe-9604f196893a"],
Cell[19061, 455, 1221, 27, 251, "Input", "ExpressionUUID" -> \
"0b034b46-b216-471d-b36c-1a557508e683"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20319, 487, 275, 4, 88, "Section", "ExpressionUUID" -> \
"27e42881-72c9-4446-b3fb-93671a9bffaf"],
Cell[20597, 493, 172, 3, 62, "Subsection", "ExpressionUUID" -> \
"5aaaad89-f065-4d8c-bd8b-dde2cc9c9774"],
Cell[CellGroupData[{
Cell[20794, 500, 214, 4, 61, "Subsection", "ExpressionUUID" -> \
"2cf22b89-24bd-4b08-a0af-62d793cf704d"],
Cell[CellGroupData[{
Cell[21033, 508, 1069, 23, 68, "Input", "ExpressionUUID" -> \
"0658c780-1a73-460f-92fe-84e48b417fb7"],
Cell[22105, 533, 1777, 35, 70, "Output", "ExpressionUUID" -> \
"afa1dc0e-4702-453e-ab3f-73b16a5e6d8f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23919, 573, 679, 21, 72, "Input", "ExpressionUUID" -> \
"2c5e0843-a842-4161-8bd4-631ec685fb1f"],
Cell[24601, 596, 1349, 36, 70, "Output", "ExpressionUUID" -> \
"25a99625-2ca7-43b6-860a-5f8a43819825"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25987, 637, 681, 21, 102, "Input", "ExpressionUUID" -> \
"b03b973d-067d-4810-a562-ce42df7d9a36"],
Cell[26671, 660, 1974, 44, 70, "Output", "ExpressionUUID" -> \
"6a797084-956a-4c3f-ada2-1f117530a8ad"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28694, 710, 160, 3, 62, "Subsection", "ExpressionUUID" -> \
"bcaa0f8e-d803-445e-8175-b47071461acd"],
Cell[CellGroupData[{
Cell[28879, 717, 920, 24, 211, "Input", "ExpressionUUID" -> \
"bd2017da-d06c-4f07-945f-1fc32ec02ae7"],
Cell[29802, 743, 2098, 45, 70, "Output", "ExpressionUUID" -> \
"9bcf4eb0-eed2-4db3-a188-f4e6200d5c29"]
}, Open  ]],
Cell[31915, 791, 2176, 50, 316, "Text", "ExpressionUUID" -> \
"45dea960-689b-43fd-a127-e315f71eec4e"],
Cell[CellGroupData[{
Cell[34116, 845, 899, 24, 408, "Input", "ExpressionUUID" -> \
"88425244-ddd9-4c21-b47b-d4b8478e23d6"],
Cell[35018, 871, 1704, 29, 70, "Output", "ExpressionUUID" -> \
"455c6185-7f8a-4f58-a923-02383fc9e459"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36771, 906, 220, 4, 61, "Subsection", "ExpressionUUID" -> \
"5d9c660f-35ba-437b-b7ba-9b184672f31e"],
Cell[36994, 912, 243, 4, 50, "Text", "ExpressionUUID" -> \
"4e2ad624-4d16-45ef-b7a0-ec9e706fcab1"],
Cell[CellGroupData[{
Cell[37262, 920, 281, 4, 68, "Input", "ExpressionUUID" -> \
"eb9add44-9484-4a24-8cfc-31284dfcbf53"],
Cell[37546, 926, 2105, 45, 70, "Output", "ExpressionUUID" -> \
"44b7bfec-296f-43c1-87dd-260f98e5b263"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39688, 976, 392, 7, 68, "Input", "ExpressionUUID" -> \
"c18c2cd9-de12-4593-9ea9-cae1ba426603"],
Cell[40083, 985, 1818, 51, 70, "Output", "ExpressionUUID" -> \
"69f14e82-49ec-4ce7-b832-54095d256bf6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41938, 1041, 196, 4, 68, "Input", "ExpressionUUID" -> \
"d04c16b7-2455-4867-987a-0e5b630f90a0"],
Cell[42137, 1047, 3403, 90, 70, "Output", "ExpressionUUID" -> \
"315e52fd-fe9c-43d7-a9cb-a8dd326d81dd"]
}, Open  ]],
Cell[45555, 1140, 627, 16, 54, "Text", "ExpressionUUID" -> \
"ff19589d-df2a-44fa-a501-32e10ac17f73"],
Cell[CellGroupData[{
Cell[46207, 1160, 752, 20, 104, "Input", "ExpressionUUID" -> \
"829ddd87-ab17-4e25-ac2d-9db27fb5d662"],
Cell[46962, 1182, 10507, 293, 70, "Output", "ExpressionUUID" -> \
"953e99ad-bfac-415d-b64c-8a55f0c69050"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[57530, 1482, 230, 4, 70, "Section", "ExpressionUUID" -> \
"ff80a2b1-8068-489e-9928-37f7cafae5d9"],
Cell[57763, 1488, 329, 7, 35, "Text", "ExpressionUUID" -> \
"850117d9-9090-440d-8474-0e6759d84599"],
Cell[CellGroupData[{
Cell[58117, 1499, 176, 3, 44, "Subsection", "ExpressionUUID" -> \
"f1f9b472-3829-480f-8cbc-869b3892fd59"],
Cell[58296, 1504, 538, 10, 50, "Text", "ExpressionUUID" -> \
"8ffc406c-2914-49b1-b6b5-7d26c66168cc"],
Cell[CellGroupData[{
Cell[58859, 1518, 775, 15, 104, "Input", "ExpressionUUID" -> \
"0a621afe-d894-4d29-8ed6-21c2e5c5128a"],
Cell[59637, 1535, 5521, 145, 70, "Output", "ExpressionUUID" -> \
"f8e86bdd-299f-4b22-b9b9-0654d0e3c24c"]
}, Open  ]],
Cell[65173, 1683, 930, 20, 88, "Text", "ExpressionUUID" -> \
"09926698-e4b8-479d-9125-6924b6cba820"],
Cell[CellGroupData[{
Cell[66128, 1707, 895, 22, 105, "Input", "ExpressionUUID" -> \
"8cfaee93-93cc-49f1-9e81-cea7cb87bb72"],
Cell[67026, 1731, 3912, 104, 70, "Output", "ExpressionUUID" -> \
"b639dc1c-3811-41f7-9782-b41325bc20ee"]
}, Open  ]],
Cell[70953, 1838, 261, 6, 50, "Text", "ExpressionUUID" -> \
"a9f39401-71a6-466f-94df-5677106d3cae"],
Cell[CellGroupData[{
Cell[71239, 1848, 1363, 37, 104, "Input", "ExpressionUUID" -> \
"263085bb-d70f-42e9-a9ee-f4199378c6b5"],
Cell[72605, 1887, 8371, 243, 70, "Output", "ExpressionUUID" -> \
"52456bd8-236f-4d90-9017-afe688afbbea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81013, 2135, 284, 4, 61, "Subsubsection", "ExpressionUUID" -> \
"0ef3c32a-2e66-411b-a06f-2693e51c5bf5"],
Cell[CellGroupData[{
Cell[81322, 2143, 119, 1, 1858, "Input", "ExpressionUUID" -> \
"bca9d8fa-2a58-4852-9330-ded82d0d4903"],
Cell[81444, 2146, 4632, 133, 70, "Output", "ExpressionUUID" -> \
"ccd169f9-26b6-42c2-82c7-cdaca7bd6e32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86113, 2284, 190, 4, 1858, "Input", "ExpressionUUID" -> \
"ab60a5a2-4db6-459b-9fc9-6237365892f5"],
Cell[86306, 2290, 6488, 183, 70, "Output", "ExpressionUUID" -> \
"ba25bd37-ab54-46f8-a1d7-df5ee3297c10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92831, 2478, 199, 4, 1858, "Input", "ExpressionUUID" -> \
"dbddcb24-cf6a-4682-8b63-a22cfdc85002"],
Cell[93033, 2484, 7668, 223, 70, "Output", "ExpressionUUID" -> \
"72c688ee-66c8-422b-8382-adb6ed62ffe4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100738, 2712, 194, 4, 1858, "Input", "ExpressionUUID" -> \
"df0e4580-cc97-4c5e-94a6-cfb140eda709"],
Cell[100935, 2718, 15710, 425, 70, "Output", "ExpressionUUID" -> \
"04dd525c-6dec-448b-82d5-0749e9454dc1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[116694, 3149, 186, 3, 60, "Subsubsection", "ExpressionUUID" -> \
"6ed1adf5-a56a-498c-88fb-fdefac071c31"],
Cell[CellGroupData[{
Cell[116905, 3156, 178, 4, 1858, "Input", "ExpressionUUID" -> \
"5b105114-bb30-43cf-af33-6f5d4afa930a"],
Cell[117086, 3162, 9815, 277, 70, "Output", "ExpressionUUID" -> \
"4b7a73e7-9f66-4922-b446-590330e7d5d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126938, 3444, 227, 4, 1858, "Input", "ExpressionUUID" -> \
"d1eb5706-9e7a-4742-8858-c8b05b95e929"],
Cell[127168, 3450, 12875, 363, 70, "Output", "ExpressionUUID" -> \
"b00e1454-ef64-44c9-89ca-5739c5bd2278"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140080, 3818, 233, 4, 1858, "Input", "ExpressionUUID" -> \
"a3ca0518-7825-4d92-a0af-960f15988063"],
Cell[140316, 3824, 7890, 231, 70, "Output", "ExpressionUUID" -> \
"1ba37dae-8776-47ed-8323-930c0de8651f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148243, 4060, 231, 4, 1858, "Input", "ExpressionUUID" -> \
"d2072a2f-64a6-4536-82cf-10d7abd6e5f4"],
Cell[148477, 4066, 28102, 738, 70, "Output", "ExpressionUUID" -> \
"478213a7-256a-4a8d-97a0-1ced7274a146"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[176640, 4811, 212, 4, 43, "Subsection", "ExpressionUUID" -> \
"5eab965c-f748-48bc-9b18-3c446daeb560"],
Cell[CellGroupData[{
Cell[176877, 4819, 345, 6, 43, "Subsubsection", "ExpressionUUID" -> \
"a8368a19-35d4-4cc4-bdf2-754ae7074754"],
Cell[CellGroupData[{
Cell[177247, 4829, 308, 7, 1858, "Input", "ExpressionUUID" -> \
"61785d16-741b-4798-aad8-763c0b9cb647"],
Cell[177558, 4838, 1329, 19, 70, "Output", "ExpressionUUID" -> \
"f83e7e21-f9ad-4cc3-937b-9bedb0fddeb9"]
}, Open  ]],
Cell[178902, 4860, 355, 7, 1430, "Text", "ExpressionUUID" -> \
"20584ea3-8488-43e2-8811-b4c63daa70b7"],
Cell[CellGroupData[{
Cell[179282, 4871, 842, 21, 1858, "Input", "ExpressionUUID" -> \
"02994375-aa0a-488f-8914-4d9a13be513a"],
Cell[180127, 4894, 1667, 28, 70, "Output", "ExpressionUUID" -> \
"30699dbb-e42c-45ce-9118-3b7db1d4a0eb"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[181843, 4928, 222, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"bcbf2a1c-689a-4255-9d57-5e19fbe0f9e0"],
Cell[182068, 4935, 824, 22, 35, "Text", "ExpressionUUID" -> \
"ab0922be-1e38-4fdf-975b-db330cf31d7a"],
Cell[CellGroupData[{
Cell[182917, 4961, 982, 25, 88, "Input", "ExpressionUUID" -> \
"64f4eb82-7e35-4ef1-867a-40af77c9f6ac"],
Cell[183902, 4988, 1862, 38, 48, "Output", "ExpressionUUID" -> \
"32a2ba22-aac0-4700-8e88-646445c600b4"]
}, Open  ]],
Cell[185779, 5029, 168, 3, 35, "Text", "ExpressionUUID" -> \
"5bb4a008-7b31-44fd-8204-7636b0a63a6b"],
Cell[CellGroupData[{
Cell[185972, 5036, 672, 16, 121, "Input", "ExpressionUUID" -> \
"257308ea-080b-46fc-b935-08cd7592e14d"],
Cell[186647, 5054, 4867, 132, 81, "Output", "ExpressionUUID" -> \
"82c1a51e-b318-4fc1-afc8-b20525038a8d"]
}, Open  ]],
Cell[191529, 5189, 354, 7, 35, "Text", "ExpressionUUID" -> \
"37c2eab0-5a54-4b18-9ee7-cee788ae1c47"],
Cell[CellGroupData[{
Cell[191908, 5200, 726, 18, 73, "Input", "ExpressionUUID" -> \
"a76a4270-cc1c-4d21-8248-95d54f6cef5b"],
Cell[192637, 5220, 1565, 45, 48, "Output", "ExpressionUUID" -> \
"6ddabef7-86b4-4626-93a3-96eb2df6fa2a"]
}, Open  ]],
Cell[194217, 5268, 233, 6, 35, "Text", "ExpressionUUID" -> \
"a52dcc1e-9e6a-40fd-9235-b36b412d5de1"],
Cell[CellGroupData[{
Cell[194475, 5278, 358, 10, 48, "Input", "ExpressionUUID" -> \
"d01f532d-bd99-4025-a047-a8255754f61d"],
Cell[194836, 5290, 984, 24, 48, "Output", "ExpressionUUID" -> \
"18b3189e-e795-41b4-815d-2fa13a13db1b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195857, 5319, 199, 4, 48, "Input", "ExpressionUUID" -> \
"14e2efdc-b372-49e7-b1be-617bb07a0a0f"],
Cell[196059, 5325, 1450, 38, 50, "Output", "ExpressionUUID" -> \
"8f8619f2-4fef-4f3f-9b61-16e154d25839"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197546, 5368, 362, 10, 48, "Input", "ExpressionUUID" -> \
"30bcf909-fb31-4e87-a5e6-bdf1a13f6026"],
Cell[197911, 5380, 1880, 39, 50, "Output", "ExpressionUUID" -> \
"0c235560-ee86-42c7-bd1f-b4661088bbc6"]
}, Open  ]],
Cell[199806, 5422, 254, 6, 35, "Text", "ExpressionUUID" -> \
"a5da4552-9a11-4a70-95e0-14b75c83dce6"],
Cell[CellGroupData[{
Cell[200085, 5432, 388, 8, 48, "Input", "ExpressionUUID" -> \
"45e19b01-4555-4958-86fc-6591d95fef34"],
Cell[200476, 5442, 1180, 18, 48, "Output", "ExpressionUUID" -> \
"4ed28ad6-a986-4cf7-9da5-28ec3fbb226c"]
}, Open  ]],
Cell[201671, 5463, 541, 12, 58, "Text", "ExpressionUUID" -> \
"1ce335cf-fb24-47fe-92ff-0f965d748ed2"],
Cell[CellGroupData[{
Cell[202237, 5479, 2107, 69, 67, "Input", "ExpressionUUID" -> \
"91f7e226-a668-46df-9e90-e772f6b4b0fb"],
Cell[204347, 5550, 532, 9, 48, "Output", "ExpressionUUID" -> \
"fe0607e8-8b69-410c-9e49-4cad77f1b78f"]
}, Open  ]],
Cell[204894, 5562, 196, 3, 35, "Text", "ExpressionUUID" -> \
"ad3c239d-1dfb-435e-a7c5-5d3bfd470643"],
Cell[205093, 5567, 2768, 80, 91, "Input", "ExpressionUUID" -> \
"f9b5754e-ed46-444a-a281-24e06aff528e"],
Cell[207864, 5649, 1047, 28, 35, "Text", "ExpressionUUID" -> \
"c3ce975d-f2c3-40e9-88b3-df07ac86c733"],
Cell[CellGroupData[{
Cell[208936, 5681, 525, 13, 48, "Input", "ExpressionUUID" -> \
"1d0c751c-2078-4c37-a011-11530c2021d4"],
Cell[209464, 5696, 1339, 36, 50, "Output", "ExpressionUUID" -> \
"bfaa7369-27a9-43c9-b305-8b8d5d768b75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210840, 5737, 506, 14, 48, "Input", "ExpressionUUID" -> \
"771fba96-30f9-432d-ba9c-26fd7008b21c"],
Cell[211349, 5753, 1347, 36, 50, "Output", "ExpressionUUID" -> \
"0a1f857d-1506-460e-902a-5715e8891445"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212733, 5794, 278, 7, 48, "Input", "ExpressionUUID" -> \
"429dae3f-cedf-4986-a741-c7041b35c3b6"],
Cell[213014, 5803, 2516, 62, 50, "Output", "ExpressionUUID" -> \
"30253b3a-6834-4ef5-b44a-eeeb21cb8e84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215567, 5870, 570, 13, 48, "Input", "ExpressionUUID" -> \
"1f6fc38b-fd42-42ff-9b16-b3a93fef9a55"],
Cell[216140, 5885, 2377, 52, 70, "Output", "ExpressionUUID" -> \
"b3e499aa-51b6-4bb9-829c-2b2ecad56199"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[218566, 5943, 244, 6, 43, "Subsubsection", "ExpressionUUID" -> \
"5744268e-01bf-4a93-b401-ccdf07523f55"],
Cell[218813, 5951, 615, 11, 82, "Text", "ExpressionUUID" -> \
"fefa719c-d51f-414c-92f4-ca2cde285932"],
Cell[CellGroupData[{
Cell[219453, 5966, 1032, 24, 110, "Input", "ExpressionUUID" -> \
"04fa6ee3-88dd-4085-be15-fc72628c955d"],
Cell[220488, 5992, 1808, 41, 70, "Output", "ExpressionUUID" -> \
"ffc92542-522a-4fd5-9568-a5e737b7b567"]
}, Open  ]],
Cell[222311, 6036, 796, 17, 82, "Text", "ExpressionUUID" -> \
"cf22eaef-8d02-4a40-b578-d62092725545"],
Cell[CellGroupData[{
Cell[223132, 6057, 1760, 49, 180, "Input", "ExpressionUUID" -> \
"1791ad09-9677-4574-ae5d-6e0e5adf963e"],
Cell[224895, 6108, 836, 13, 70, "Output", "ExpressionUUID" -> \
"237403cb-234d-40ac-b4dd-dd5c85f5f9b3"]
}, Open  ]],
Cell[225746, 6124, 451, 13, 50, "Text", "ExpressionUUID" -> \
"6b38c918-a6c8-4b84-98b9-42d6c9234c63"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[226246, 6143, 187, 3, 44, "Subsection", "ExpressionUUID" -> \
"460486db-e41d-4899-862e-762ab23219a1"],
Cell[226436, 6148, 1534, 46, 63, "Text", "ExpressionUUID" -> \
"ee82a2f6-91a2-4804-aa0e-65b6e735e4f7"],
Cell[CellGroupData[{
Cell[227995, 6198, 828, 20, 87, "Input", "ExpressionUUID" -> \
"77327ac2-5166-4e9a-b8f7-178e9253cb51"],
Cell[228826, 6220, 1397, 24, 70, "Output", "ExpressionUUID" -> \
"76afab34-2600-4671-8f65-9b7014b0997f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230260, 6249, 690, 18, 87, "Input", "ExpressionUUID" -> \
"01dcd7f1-81e5-4ecc-b862-f68c4893f579"],
Cell[230953, 6269, 1327, 23, 70, "Output", "ExpressionUUID" -> \
"0ec93cc2-ca01-440f-abe5-aa38db243ae2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[232329, 6298, 208, 3, 43, "Subsection", "ExpressionUUID" -> \
"6afe0d6b-3e26-48f8-9753-f177842c47a2"],
Cell[232540, 6303, 451, 9, 42, "Text", "ExpressionUUID" -> \
"828c04a0-8b9e-4d92-9e5e-353a10c194f5"],
Cell[232994, 6314, 242, 6, 42, "Text", "ExpressionUUID" -> \
"b8889d31-b223-4cba-a272-c7139bb44fbf"],
Cell[CellGroupData[{
Cell[233261, 6324, 382, 9, 57, "Input", "ExpressionUUID" -> \
"60053013-bf5c-4e3d-b3da-613207cce74f"],
Cell[233646, 6335, 2751, 71, 70, "Output", "ExpressionUUID" -> \
"ca6eb648-2f63-4337-8170-79a91d4f7623"]
}, Open  ]],
Cell[236412, 6409, 508, 14, 42, "Text", "ExpressionUUID" -> \
"b41757ac-277b-4913-bb7e-676a0020f915"],
Cell[CellGroupData[{
Cell[236945, 6427, 521, 12, 57, "Input", "ExpressionUUID" -> \
"efff9b38-3a5c-478f-947e-1f7c6109ffec"],
Cell[237469, 6441, 8954, 242, 70, "Output", "ExpressionUUID" -> \
"d1f5ab5d-b610-4b57-ba51-ac01edeb1a05"]
}, Open  ]],
Cell[246438, 6686, 790, 20, 42, "Text", "ExpressionUUID" -> \
"18166f69-6fe5-4afa-b3ba-8cd6f71359ae"],
Cell[CellGroupData[{
Cell[247253, 6710, 578, 15, 57, "Input", "ExpressionUUID" -> \
"cfd14147-f468-4af7-abae-9cc75694f486"],
Cell[247834, 6727, 1203, 17, 70, "Output", "ExpressionUUID" -> \
"e58cc4ff-59b9-455d-a27f-6609d54e513b"]
}, Open  ]],
Cell[249052, 6747, 705, 17, 42, "Text", "ExpressionUUID" -> \
"b5d33196-460e-43a3-b723-53e3aa859de6"],
Cell[CellGroupData[{
Cell[249782, 6768, 926, 27, 116, "Input", "ExpressionUUID" -> \
"979d7df4-0a9a-4331-862d-26527dfb092f"],
Cell[250711, 6797, 533, 9, 70, "Output", "ExpressionUUID" -> \
"22c9962b-da7e-498a-ab41-6ab4ed53960e"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[251305, 6813, 187, 3, 88, "Section", "ExpressionUUID" -> \
"148d8a72-9aa6-4ce0-ab7e-87dd4ee25032"],
Cell[251495, 6818, 346, 7, 35, "Text", "ExpressionUUID" -> \
"68a1ae69-d67b-4b2c-b6bc-c80dcd7dfaa2"],
Cell[251844, 6827, 1024, 20, 81, "Text", "ExpressionUUID" -> \
"6e8f6cab-fa93-45e3-a451-43537ab7041f"],
Cell[CellGroupData[{
Cell[252893, 6851, 207, 3, 44, "Subsection", "ExpressionUUID" -> \
"b6304fa1-2305-4c90-a2a7-ab01f9c666dc"],
Cell[CellGroupData[{
Cell[253125, 6858, 200, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"990acbf6-15ab-446d-8e44-f2df21d71527"],
Cell[253328, 6863, 846, 18, 58, "Text", "ExpressionUUID" -> \
"5c4d0683-ed81-4bcd-bccd-381cde0e704d"],
Cell[CellGroupData[{
Cell[254199, 6885, 1516, 32, 48, "Input", "ExpressionUUID" -> \
"3045945b-2f49-4328-86aa-c864df92dcc0"],
Cell[255718, 6919, 1632, 29, 63, "Output", "ExpressionUUID" -> \
"b615a96b-2a5c-4cd5-ad6f-01df6fa169ad"]
}, Open  ]],
Cell[257365, 6951, 340, 11, 35, "Text", "ExpressionUUID" -> \
"362004c2-c211-4b74-ae73-84066d47b191"],
Cell[CellGroupData[{
Cell[257730, 6966, 725, 21, 48, "Input", "ExpressionUUID" -> \
"2628d335-6941-411c-9ebd-783a2cc23340"],
Cell[258458, 6989, 1484, 26, 63, "Output", "ExpressionUUID" -> \
"06c33caa-e0b9-4e1a-809a-422e9d17c163"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[259991, 7021, 225, 5, 43, "Subsubsection", "ExpressionUUID" -> \
"85aca3a0-61ab-4add-8cc0-e2075abae5d6"],
Cell[260219, 7028, 512, 15, 36, "Text", "ExpressionUUID" -> \
"ab839c3b-d2c7-4514-9b45-908396a1420c"],
Cell[CellGroupData[{
Cell[260756, 7047, 899, 24, 48, "Input", "ExpressionUUID" -> \
"1f76264d-e392-4722-a365-0c021f101b3d"],
Cell[261658, 7073, 12827, 347, 247, "Output", "ExpressionUUID" -> \
"1dd1c605-3aa6-4433-88c1-838f4bfca764"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274522, 7425, 798, 23, 48, "Input", "ExpressionUUID" -> \
"92feb9f0-44d9-4802-8cce-6184630f308e"],
Cell[275323, 7450, 1110, 23, 68, "Output", "ExpressionUUID" -> \
"fbd02054-9201-4e22-a164-5482281e4632"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[276482, 7479, 384, 11, 43, "Subsubsection", "ExpressionUUID" -> \
"818c22db-707d-4613-a6c3-0675acdf07b9"],
Cell[CellGroupData[{
Cell[276891, 7494, 1007, 27, 121, "Input", "ExpressionUUID" -> \
"178bdfb5-6264-4d5a-b675-09b038576bdf"],
Cell[277901, 7523, 10118, 282, 247, "Output", "ExpressionUUID" -> \
"48144dd9-6654-4d6a-9896-92838d85f029"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[288080, 7812, 233, 5, 44, "Subsection", "ExpressionUUID" -> \
"618f4f33-0c7e-4a51-9af6-e957586d7fa7"],
Cell[CellGroupData[{
Cell[288338, 7821, 841, 25, 97, "Input", "ExpressionUUID" -> \
"ed8440be-6f5c-4d9d-a044-f0e1290df08a"],
Cell[289182, 7848, 3458, 99, 80, "Output", "ExpressionUUID" -> \
"7c79e9e4-2cb2-4c08-9c90-38dfd49e0b6f"]
}, Open  ]],
Cell[292655, 7950, 241, 6, 35, "Text", "ExpressionUUID" -> \
"dfcaa602-ff66-48b0-8a28-f43d17a4eeec"],
Cell[CellGroupData[{
Cell[292921, 7960, 1833, 39, 73, "Input", "ExpressionUUID" -> \
"cd4e4923-6130-4f50-9e64-1efec812e54f"],
Cell[294757, 8001, 5672, 144, 148, "Output", "ExpressionUUID" -> \
"30916735-bb67-496e-ad13-5c15275c271e"]
}, Open  ]],
Cell[300444, 8148, 201, 3, 35, "Text", "ExpressionUUID" -> \
"98c66410-34a5-4747-a6c4-838ec234f77a"],
Cell[CellGroupData[{
Cell[300670, 8155, 855, 25, 73, "Input", "ExpressionUUID" -> \
"ecf030f8-37cd-4353-a49c-9585af89f1e1"],
Cell[301528, 8182, 8765, 225, 219, "Output", "ExpressionUUID" -> \
"44294e02-9447-4fb5-b18f-066f69de3a10"],
Cell[310296, 8409, 7990, 218, 219, "Output", "ExpressionUUID" -> \
"8d73fa0e-d646-43cb-bd07-cc15cceefd7f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[318335, 8633, 259, 6, 44, "Subsection", "ExpressionUUID" -> \
"9da6dc2f-7177-4b8d-b956-bf54bfa114f8"],
Cell[CellGroupData[{
Cell[318619, 8643, 182, 3, 104, "Subsubsection", "ExpressionUUID" -> \
"f43563ca-3f48-4f95-b60d-68ed9a1aa370"],
Cell[CellGroupData[{
Cell[318826, 8650, 1152, 29, 238, "Input", "ExpressionUUID" -> \
"c60af8b5-0b3b-4056-90b8-6e334f30da2c"],
Cell[319981, 8681, 2340, 58, 70, "Output", "ExpressionUUID" -> \
"43b8b054-40ac-4831-8a42-87f067563756"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322358, 8744, 718, 21, 177, "Input", "ExpressionUUID" -> \
"f296f86d-ea39-4d43-8cea-06260d7c210d"],
Cell[323079, 8767, 2233, 58, 70, "Output", "ExpressionUUID" -> \
"1967aa8d-b89e-4cf3-99a9-5e4335409af9"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[325361, 8831, 200, 3, 103, "Subsubsection", "ExpressionUUID" -> \
"3a2af8f7-92a9-4e32-9d05-17b0d63f15d1"],
Cell[325564, 8836, 399, 12, 86, "Text", "ExpressionUUID" -> \
"28688462-2a5c-4826-8286-3a93d47e0b33"],
Cell[CellGroupData[{
Cell[325988, 8852, 991, 25, 177, "Input", "ExpressionUUID" -> \
"fb2525b5-2e52-487b-811b-076ba6ada001"],
Cell[326982, 8879, 2565, 65, 70, "Output", "ExpressionUUID" -> \
"5a2aab5e-679f-4ec8-81ed-08c3f3d1ea46"]
}, Open  ]],
Cell[329562, 8947, 453, 13, 86, "Text", "ExpressionUUID" -> \
"bb3f3691-5921-42b6-8299-2c1e4bb1b74e"],
Cell[CellGroupData[{
Cell[330040, 8964, 742, 21, 177, "Input", "ExpressionUUID" -> \
"7554b372-16e3-4fa8-947e-ad5cc1337457"],
Cell[330785, 8987, 2443, 64, 70, "Output", "ExpressionUUID" -> \
"09af1a63-ea03-44a1-9334-12debf5f5ac4"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[333289, 9058, 526, 15, 43, "Subsection", "ExpressionUUID" -> \
"4ad15631-d690-416e-ab2c-fd878248ace7"],
Cell[333818, 9075, 310, 7, 35, "Text", "ExpressionUUID" -> \
"1b16dba1-9747-40a5-9559-83b6ca642335"],
Cell[CellGroupData[{
Cell[334153, 9086, 624, 19, 48, "Input", "ExpressionUUID" -> \
"a269fe5c-734b-4ecd-a3e2-fcd89047ec66"],
Cell[334780, 9107, 1604, 37, 75, "Output", "ExpressionUUID" -> \
"37db6f40-94d8-412b-ad4f-22b0634f64fe"]
}, Open  ]],
Cell[336399, 9147, 232, 5, 35, "Text", "ExpressionUUID" -> \
"177eb6bd-524c-4fde-8902-169932584f3f"],
Cell[CellGroupData[{
Cell[336656, 9156, 872, 22, 121, "Input", "ExpressionUUID" -> \
"500bc4c4-2c81-4c83-a229-95b8c88d4555"],
Cell[337531, 9180, 1627, 32, 195, "Output", "ExpressionUUID" -> \
"a92c73e2-d580-4ee0-979f-511805965109"]
}, Open  ]],
Cell[339173, 9215, 365, 7, 35, "Text", "ExpressionUUID" -> \
"6ad57263-85c9-4b0a-b09b-19e8af5d514f"],
Cell[CellGroupData[{
Cell[339563, 9226, 1379, 39, 169, "Input", "ExpressionUUID" -> \
"370d796a-12f8-4aab-b63f-c312b8f16e25"],
Cell[340945, 9267, 10056, 273, 160, "Output", "ExpressionUUID" -> \
"58373512-5589-40f3-a7d6-ded2152f924e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[351050, 9546, 290, 5, 44, "Subsection", "ExpressionUUID" -> \
"adeaa360-ce3b-44f4-b51e-013d8446efa1"],
Cell[351343, 9553, 306, 4, 35, "Text", "ExpressionUUID" -> \
"dd2fe69c-9c13-4790-ae1d-d48745c5b139"],
Cell[CellGroupData[{
Cell[351674, 9561, 1373, 37, 145, "Input", "ExpressionUUID" -> \
"a0030ff4-e7f3-4dd1-aa78-5bad2be46aca"],
Cell[353050, 9600, 9969, 272, 169, "Output", "ExpressionUUID" -> \
"9472f181-ae1e-4b30-827d-d23f74038e8e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[363080, 9879, 294, 4, 88, "Section", "ExpressionUUID" -> \
"863d1b5d-e0f7-490f-ad74-6461686b857d"],
Cell[363377, 9885, 1013, 22, 82, "Text", "ExpressionUUID" -> \
"18c9f9e1-ca6d-4b4b-96f1-c22945e326a7"],
Cell[CellGroupData[{
Cell[364415, 9911, 377, 7, 44, "Subsection", "ExpressionUUID" -> \
"a54dd1c0-8c40-4faa-969d-571a12333e6b"],
Cell[364795, 9920, 310, 6, 50, "Text", "ExpressionUUID" -> \
"ded25316-b5f8-40c3-86fa-4f1c797c0e92"],
Cell[365108, 9928, 1372, 31, 104, "Input", "ExpressionUUID" -> \
"21395e4c-0b38-452c-bf6d-3d05aa5210f4"]
}, Closed]],
Cell[CellGroupData[{
Cell[366517, 9964, 212, 3, 43, "Subsection", "ExpressionUUID" -> \
"9959928f-a4ee-4e94-8c79-656a4c5238bb"],
Cell[366732, 9969, 614, 16, 55, "Text", "ExpressionUUID" -> \
"db34ce8f-982c-4ba0-a664-c72be0b25589"],
Cell[CellGroupData[{
Cell[367371, 9989, 465, 15, 73, "Input", "ExpressionUUID" -> \
"b15f6124-9d47-44ff-8ead-c9ea376f8ea6"],
Cell[367839, 10006, 910, 19, 70, "Output", "ExpressionUUID" -> \
"6f58b117-2c86-49cb-90ad-afdac174dd01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368786, 10030, 2275, 37, 73, "Input", "ExpressionUUID" -> \
"895d846d-4c2a-488c-b856-690c2c88b048"],
Cell[371064, 10069, 18677, 507, 70, "Output", "ExpressionUUID" -> \
"03fc7750-d90d-46ba-9459-1e60fcb3a1c3"]
}, Open  ]],
Cell[389756, 10579, 1005, 22, 84, "Text", "ExpressionUUID" -> \
"f9eb51fc-9ca8-4580-807a-bccb37c7c5d7"],
Cell[CellGroupData[{
Cell[390786, 10605, 1191, 28, 74, "Input", "ExpressionUUID" -> \
"4edd9d03-5b58-45b6-9601-d380655a856b"],
Cell[391980, 10635, 40417, 1107, 70, "Output", "ExpressionUUID" -> \
"d8a398dc-6577-4b0e-9bb1-cbf90392f536"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[432446, 11748, 333, 7, 43, "Subsection", "ExpressionUUID" -> \
"26ab9ce1-1e73-405c-9e4d-9ffdfb61c247"],
Cell[432782, 11757, 252, 6, 35, "Text", "ExpressionUUID" -> \
"b4caf3ef-999e-40e2-8c6a-95ebb9321d46"],
Cell[CellGroupData[{
Cell[433059, 11767, 178, 3, 48, "Input", "ExpressionUUID" -> \
"84c1e16a-f3ef-42ba-b093-cdf9d8eb24c1"],
Cell[433240, 11772, 885, 20, 68, "Output", "ExpressionUUID" -> \
"a5f9bf36-6cf3-4dbb-af8c-f5c2547e72a7"]
}, Open  ]],
Cell[434140, 11795, 1107, 30, 58, "Text", "ExpressionUUID" -> \
"147f09c6-676a-400f-a336-058cdf54682b"],
Cell[CellGroupData[{
Cell[435272, 11829, 183, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"475e4810-07d1-4f2d-94b8-b3b92c3c96b4"],
Cell[435458, 11834, 700, 16, 69, "Text", "ExpressionUUID" -> \
"373311c1-8891-4845-b45f-8abdce0739a7"],
Cell[CellGroupData[{
Cell[436183, 11854, 1483, 43, 60, "Input", "ExpressionUUID" -> \
"37719ca1-c44c-440e-ad3d-4f223ae2ac69"],
Cell[437669, 11899, 2006, 53, 70, "Output", "ExpressionUUID" -> \
"7f74995e-f604-45d0-89f3-35edfc7c51db"]
}, Open  ]],
Cell[439690, 11955, 322, 7, 42, "Text", "ExpressionUUID" -> \
"346c400f-e393-4346-a53a-69da24809e95"],
Cell[CellGroupData[{
Cell[440037, 11966, 1379, 40, 60, "Input", "ExpressionUUID" -> \
"32e888c4-f7d2-4492-8b22-b1897be3a35d"],
Cell[441419, 12008, 945, 16, 70, "Output", "ExpressionUUID" -> \
"578baf0f-b542-4030-a346-3e4c635633cd"]
}, Open  ]],
Cell[442379, 12027, 436, 12, 42, "Text", "ExpressionUUID" -> \
"5de18a9e-cfe3-4a0c-8233-a78634af34e3"]
}, Closed]],
Cell[CellGroupData[{
Cell[442852, 12044, 184, 3, 42, "Subsubsection", "ExpressionUUID" -> \
"ec00283a-c418-4f59-b611-04a579f4cfdb"],
Cell[443039, 12049, 201, 3, 42, "Text", "ExpressionUUID" -> \
"015e9bd7-d78a-4b82-918e-1742690f8e78"],
Cell[CellGroupData[{
Cell[443265, 12056, 1437, 43, 60, "Input", "ExpressionUUID" -> \
"53dded53-6e75-43a8-9fcb-2716778c2192"],
Cell[444705, 12101, 1813, 48, 70, "Output", "ExpressionUUID" -> \
"39bab57a-07df-40fd-9258-580a8d818068"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446555, 12154, 1258, 38, 60, "Input", "ExpressionUUID" -> \
"3df94447-f02e-489e-af7d-10e81a3eceaf"],
Cell[447816, 12194, 797, 14, 70, "Output", "ExpressionUUID" -> \
"2b77d10f-0669-4991-871b-cec2268b01ac"]
}, Open  ]],
Cell[448628, 12211, 1774, 50, 91, "Text", "ExpressionUUID" -> \
"b78b3a5d-7f6f-4921-ac45-670b45b01848"],
Cell[CellGroupData[{
Cell[450427, 12265, 1464, 43, 60, "Input", "ExpressionUUID" -> \
"4f25f2e8-604d-41b4-a366-01ace6e36f28"],
Cell[451894, 12310, 1814, 48, 70, "Output", "ExpressionUUID" -> \
"d3a73a5c-89f8-4d0a-a635-bc0300490d3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453745, 12363, 1136, 35, 60, "Input", "ExpressionUUID" -> \
"89877c96-ac1c-457e-9b14-bb83068774e3"],
Cell[454884, 12400, 789, 13, 70, "Output", "ExpressionUUID" -> \
"c54a8dda-55f0-4764-b56f-a85541739669"]
}, Open  ]],
Cell[455688, 12416, 405, 11, 42, "Text", "ExpressionUUID" -> \
"f547f943-b6ea-4dba-becb-ad101f9a6cdf"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[456142, 12433, 289, 6, 44, "Subsection", "ExpressionUUID" -> \
"6408adf2-bd4a-4988-ab2d-f0f8be6c2876"],
Cell[CellGroupData[{
Cell[456456, 12443, 183, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"86b891a1-838d-4268-ad68-c3ad549e65eb"],
Cell[CellGroupData[{
Cell[456664, 12450, 6029, 138, 176, "Input", "ExpressionUUID" -> \
"f3ff24d7-88ef-424c-b208-fc3977b839c9"],
Cell[462696, 12590, 2591, 40, 70, "Output", "ExpressionUUID" -> \
"d3e481de-55a7-4ee0-a72f-1d94afd8bd2d"]
}, Open  ]],
Cell[465302, 12633, 2330, 54, 112, "Text", "ExpressionUUID" -> \
"3d2e3c1b-87b1-40a6-84f7-69596b234068"],
Cell[CellGroupData[{
Cell[467657, 12691, 1667, 49, 117, "Input", "ExpressionUUID" -> \
"657c0860-4e1c-4ac1-8604-f3b530fd95dd"],
Cell[469327, 12742, 2399, 64, 70, "Output", "ExpressionUUID" -> \
"c2cba35f-0bd9-4de3-81f1-254b31402bf2"]
}, Open  ]],
Cell[471741, 12809, 1465, 31, 43, "Text", "ExpressionUUID" -> \
"ec577f88-ea2d-4aa1-a852-5a462514846a"],
Cell[CellGroupData[{
Cell[473231, 12844, 3639, 99, 75, "Input", "ExpressionUUID" -> \
"68cefbe9-bd8f-4d2f-b253-287a6f6dc90e"],
Cell[476873, 12945, 2204, 58, 70, "Output", "ExpressionUUID" -> \
"9f793ce1-253a-4628-be11-6a3fca0fdc09"]
}, Open  ]],
Cell[479092, 13006, 499, 14, 43, "Text", "ExpressionUUID" -> \
"622b2619-5593-482b-b1bb-884d464091c0"]
}, Closed]],
Cell[CellGroupData[{
Cell[479628, 13025, 232, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"d8a92a96-9054-4ae1-bf8e-fb69e0dc3754"],
Cell[479863, 13031, 346, 7, 42, "Text", "ExpressionUUID" -> \
"30fab4ce-c0e8-4bd9-88e1-240e8de16344"],
Cell[CellGroupData[{
Cell[480234, 13042, 2410, 70, 88, "Input", "ExpressionUUID" -> \
"49bb56fb-0de5-4c63-b6ab-6f67fe366e74"],
Cell[482647, 13114, 763, 13, 70, "Output", "ExpressionUUID" -> \
"44d50836-97e9-43f3-967d-c49637ad241a"]
}, Open  ]],
Cell[483425, 13130, 204, 3, 42, "Text", "ExpressionUUID" -> \
"58731ffe-1480-4479-888d-fb441f630f2e"],
Cell[CellGroupData[{
Cell[483654, 13137, 1593, 46, 88, "Input", "ExpressionUUID" -> \
"d9477aa6-82e0-40b0-ad12-ee31208f35e7"],
Cell[485250, 13185, 791, 12, 70, "Output", "ExpressionUUID" -> \
"5148ed7f-76cc-424c-b154-51cc1e83d37d"]
}, Open  ]],
Cell[486056, 13200, 358, 7, 42, "Text", "ExpressionUUID" -> \
"176c7bb0-8a3b-40f7-9051-6ae58f352930"],
Cell[CellGroupData[{
Cell[486439, 13211, 255, 7, 57, "Input", "ExpressionUUID" -> \
"5ae15cec-f4ad-4da5-9ec5-0fa5aca33317"],
Cell[486697, 13220, 592, 10, 70, "Output", "ExpressionUUID" -> \
"e9e4264f-c113-49b8-a93e-60802009b73b"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[487350, 13237, 172, 3, 44, "Subsection", "ExpressionUUID" -> \
"cf5439b0-2c74-4496-854d-fb2959ea80db"],
Cell[CellGroupData[{
Cell[487547, 13244, 632, 20, 48, "Input", "ExpressionUUID" -> \
"86f068e3-0589-43c4-8b1a-4f0d0022c563"],
Cell[488182, 13266, 943, 24, 48, "Output", "ExpressionUUID" -> \
"8e8182c3-8ff9-4721-8d8c-40c1036cb6dc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489186, 13297, 222, 4, 88, "Section", "ExpressionUUID" -> \
"12ab9af5-0498-4136-8690-cacd96426887"],
Cell[489411, 13303, 519907, 6424, 442, "Text", "ExpressionUUID" -> \
"9b44f3c6-478b-42bd-a790-f55ad4ab1336"],
Cell[CellGroupData[{
Cell[1009343, 19731, 173, 3, 44, "Subsection", "ExpressionUUID" -> \
"c7d389b9-7bfd-4441-bd6b-17901b883976"],
Cell[CellGroupData[{
Cell[1009541, 19738, 652, 20, 51, "Input", "ExpressionUUID" -> \
"621db57f-61dd-443c-b0b1-8cbbf1f0bbcd"],
Cell[1010196, 19760, 1242, 40, 68, "Output", "ExpressionUUID" -> \
"40fca006-104e-4152-9f00-7547cda7ebea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1011475, 19805, 186, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"2c1bb97f-d8f8-478d-8147-26e82528d2d4"],
Cell[CellGroupData[{
Cell[1011686, 19812, 657, 16, 78, "Input", "ExpressionUUID" -> \
"dd5ab8dd-ba60-4374-a768-a103e9c609f2"],
Cell[1012346, 19830, 722, 14, 50, "Output", "ExpressionUUID" -> \
"dc18f801-fc5e-4aa1-84b8-7ef151dfe9bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1013105, 19849, 1621, 48, 117, "Input", "ExpressionUUID" -> \
"27a2d3f4-8d1d-4f29-8eb6-9ad8ce32cede"],
Cell[1014729, 19899, 2832, 80, 52, "Output", "ExpressionUUID" -> \
"10dfae59-f31a-48e0-a3db-045647f2b902"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1017610, 19985, 179, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"33f7d274-cc70-4a75-8686-8a83eee71bf8"],
Cell[CellGroupData[{
Cell[1017814, 19992, 3692, 110, 259, "Input", "ExpressionUUID" -> \
"079127fe-3444-47a6-a011-e298a471b9a4"],
Cell[1021509, 20104, 4065, 109, 80, "Output", "ExpressionUUID" -> \
"4468a370-c5a8-4898-b9a8-a3d4de387496"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025611, 20218, 2524, 56, 241, "Input", "ExpressionUUID" -> \
"14c808c9-ed70-4078-af94-a6d1c55554df"],
Cell[1028138, 20276, 7970, 213, 435, "Output", "ExpressionUUID" -> \
"ffcc23ca-a7a9-4510-b055-73462da83869"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036157, 20495, 199, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"561bfc08-ebb9-4bb1-8234-f3464921b4fa"],
Cell[CellGroupData[{
Cell[1036381, 20502, 592, 12, 52, "Input", "ExpressionUUID" -> \
"22913af9-55e2-4c0a-9b5c-99ef3f780068"],
Cell[1036976, 20516, 1079, 24, 71, "Output", "ExpressionUUID" -> \
"ac8ccedd-c525-4fd8-b0b0-265301306297"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1038104, 20546, 197, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"4632290e-8320-41c7-849a-b848e259915f"],
Cell[CellGroupData[{
Cell[1038326, 20553, 494, 11, 52, "Input", "ExpressionUUID" -> \
"c2aed495-c3ee-4f42-b669-ca668b00a89b"],
Cell[1038823, 20566, 1050, 24, 71, "Output", "ExpressionUUID" -> \
"d164771b-b25d-406c-99a0-a1988f70d48e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1039922, 20596, 1116, 22, 43, "Subsubsection", "ExpressionUUID" -> \
"edf4f579-0969-4a2e-bda5-ea956faa8ad5"],
Cell[CellGroupData[{
Cell[1041063, 20622, 2762, 74, 163, "Input", "ExpressionUUID" -> \
"2d78b9bf-14ae-4715-b479-13807b33ca13"],
Cell[1043828, 20698, 14855, 376, 507, "Output", "ExpressionUUID" -> \
"87192d21-c6a4-4452-88d5-bc42fcff03da"]
}, Open  ]],
Cell[1058698, 21077, 1277, 31, 70, "Text", "ExpressionUUID" -> \
"94fb2f88-6c4c-46d1-81bb-0b1dc5a2131f"],
Cell[CellGroupData[{
Cell[1060000, 21112, 266, 6, 48, "Input", "ExpressionUUID" -> \
"f6f7583a-39c9-4dcd-904f-8d2ed009cad4"],
Cell[1060269, 21120, 3503, 94, 80, "Output", "ExpressionUUID" -> \
"0f158ee6-80f0-4fce-87a8-295495fbff6c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1063821, 21220, 481, 12, 43, "Subsubsection", "ExpressionUUID" -> \
"a84a31c8-d1ab-49f7-836c-475d9dd648e9"],
Cell[CellGroupData[{
Cell[1064327, 21236, 613, 15, 77, "Input", "ExpressionUUID" -> \
"59b7b9f3-f6c4-4282-a6ed-e5b8e9f95b15"],
Cell[1064943, 21253, 6105, 152, 143, "Output", "ExpressionUUID" -> \
"f2ac7c9d-aba1-4b10-a378-7c98a99e3615"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1071097, 21411, 435, 11, 43, "Subsubsection", "ExpressionUUID" -> \
"6d3fe41f-1698-444e-be01-d19644da1229"],
Cell[CellGroupData[{
Cell[1071557, 21426, 537, 14, 77, "Input", "ExpressionUUID" -> \
"922e5107-1bf6-4f51-983d-12b78a2d7199"],
Cell[1072097, 21442, 5988, 151, 143, "Output", "ExpressionUUID" -> \
"19993fcf-8552-4b26-97e7-7bdced75a6fa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1078134, 21599, 429, 11, 43, "Subsubsection", "ExpressionUUID" -> \
"5936bf7f-0c89-4f31-9184-46c71e3b9ffb"],
Cell[CellGroupData[{
Cell[1078588, 21614, 816, 16, 77, "Input", "ExpressionUUID" -> \
"c6e41285-c762-4e30-bff8-483f151e914a"],
Cell[1079407, 21632, 1142, 29, 88, "Output", "ExpressionUUID" -> \
"c9d0e8b5-1278-4cef-984a-15e51ec32f4b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1080622, 21669, 328, 5, 88, "Section", "ExpressionUUID" -> \
"0c2254e1-cb18-42a6-9031-74a1f6c01679"],
Cell[CellGroupData[{
Cell[1080975, 21678, 203, 3, 44, "Subsection", "ExpressionUUID" -> \
"62f10351-db33-4a53-9155-7f0da29e68cd"],
Cell[CellGroupData[{
Cell[1081203, 21685, 1620, 49, 77, "Input", "ExpressionUUID" -> \
"c7a6c5f7-fb66-4978-b135-33fc28de4ea2"],
Cell[1082826, 21736, 324, 6, 48, "Output", "ExpressionUUID" -> \
"19dd0071-f724-4d6e-92bd-20c160699766"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1083187, 21747, 889, 25, 75, "Input", "ExpressionUUID" -> \
"87849216-a8be-448c-b6cb-f14f48718cad"],
Cell[1084079, 21774, 8848, 252, 136, "Output", "ExpressionUUID" -> \
"6d2abfd5-788e-44f4-be74-24216be388e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1092964, 22031, 405, 11, 48, "Input", "ExpressionUUID" -> \
"f34511ca-90f7-4e79-97dc-3c651f775046"],
Cell[1093372, 22044, 3807, 117, 81, "Output", "ExpressionUUID" -> \
"3773bf25-09d4-46bc-bd11-4b362c4b55ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1097216, 22166, 156, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"9c55c054-8ece-4b1e-8b76-a8faac1e15e5"],
Cell[CellGroupData[{
Cell[1097397, 22173, 757, 22, 48, "Input", "ExpressionUUID" -> \
"d5c37761-98b8-4e7a-8586-e8179dba66c1"],
Cell[1098157, 22197, 1170, 35, 68, "Output", "ExpressionUUID" -> \
"393caa4a-00c7-435d-ab5f-a23e276f8d5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1099364, 22237, 843, 23, 48, "Input", "ExpressionUUID" -> \
"b50608b8-4d69-4d1d-a179-96a0473ac6b3"],
Cell[1100210, 22262, 401, 13, 48, "Output", "ExpressionUUID" -> \
"92c4df23-e5c3-49b9-8692-4e0c6f012f3e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1100648, 22280, 1172, 30, 77, "Input", "ExpressionUUID" -> \
"f5616047-24e4-4e94-9413-9f87f92c50e4"],
Cell[1101823, 22312, 6427, 172, 188, "Output", "ExpressionUUID" -> \
"7ef713d9-1717-4ed1-8d8b-a0a0747cd3fd"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1108299, 22490, 261, 4, 43, "Subsubsection", "ExpressionUUID" -> \
"9bfd4512-e56c-4d43-8086-a7b84a224f50"],
Cell[CellGroupData[{
Cell[1108585, 22498, 862, 24, 52, "Input", "ExpressionUUID" -> \
"c7c089dc-d899-41ca-ad82-5a0ca6d40e92"],
Cell[1109450, 22524, 5983, 170, 97, "Output", "ExpressionUUID" -> \
"27263ccd-c2a6-4826-896f-5a53d81dc301"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115470, 22699, 820, 23, 52, "Input", "ExpressionUUID" -> \
"cefb5790-0c5e-4214-8909-7f035b387fd1"],
Cell[1116293, 22724, 2178, 69, 86, "Output", "ExpressionUUID" -> \
"0b41c796-0a4e-4ee1-a935-e820b6427564"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1118520, 22799, 260, 4, 43, "Subsubsection", "ExpressionUUID" -> \
"b0b0c44d-cd44-4dea-9129-b0e2483d7174"],
Cell[CellGroupData[{
Cell[1118805, 22807, 1068, 27, 52, "Input", "ExpressionUUID" -> \
"d30fc2b9-dc51-4703-89eb-887d200a770f"],
Cell[1119876, 22836, 6323, 173, 97, "Output", "ExpressionUUID" -> \
"f4903c3a-8ef4-4eda-8a46-e01b00db008c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1126236, 23014, 815, 23, 52, "Input", "ExpressionUUID" -> \
"c05c2045-1356-4ec6-8df3-80198e670dbe"],
Cell[1127054, 23039, 2127, 67, 86, "Output", "ExpressionUUID" -> \
"0dc61f90-4454-49c9-bf0d-65ec983b63f1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1129230, 23112, 160, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"db6e6759-a83e-4b25-b6ee-95ac57f9e5b8"],
Cell[CellGroupData[{
Cell[1129415, 23119, 759, 22, 48, "Input", "ExpressionUUID" -> \
"8f11f128-bc46-46ab-9068-a258b6f66f0c"],
Cell[1130177, 23143, 1151, 35, 68, "Output", "ExpressionUUID" -> \
"830c1f06-664a-46c0-93f4-d36d467f724a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1131365, 23183, 767, 22, 48, "Input", "ExpressionUUID" -> \
"1e78af48-2f16-4ffa-a176-c962fdc8dfb3"],
Cell[1132135, 23207, 424, 13, 48, "Output", "ExpressionUUID" -> \
"091dfab3-43ed-493a-a1a0-72d09626872a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1132632, 23228, 245, 4, 88, "Section", "ExpressionUUID" -> \
"ba86ed3f-586a-4c4d-8c6f-e2ad20b44fb3"],
Cell[1132880, 23234, 1965, 47, 241, "Input", "ExpressionUUID" -> \
"3242b91d-4c0c-4d86-bda5-8b1aa115f45e"],
Cell[CellGroupData[{
Cell[1134870, 23285, 160, 3, 44, "Subsection", "ExpressionUUID" -> \
"b1c75432-baa5-47b8-af33-9daa5fda6e47"],
Cell[CellGroupData[{
Cell[1135055, 23292, 8775, 210, 673, "Input", "ExpressionUUID" -> \
"22d31372-8dac-4c76-b47b-65300052425a"],
Cell[1143833, 23504, 47352, 802, 534, "Output", "ExpressionUUID" -> \
"2ef6cc5f-b030-431e-acf8-2ad7381676eb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1191234, 24312, 145, 3, 44, "Subsection", "ExpressionUUID" -> \
"fc15a711-eaae-4765-9acb-4be9c0ad95ee"],
Cell[CellGroupData[{
Cell[1191404, 24319, 8850, 211, 807, "Input", "ExpressionUUID" -> \
"5ba29db7-2527-4d2d-85bd-ab7e37c3d600"],
Cell[1200257, 24532, 51986, 877, 70, "Output", "ExpressionUUID" -> \
"fcbc5ae1-7e0c-4d86-a8c5-f868df906fcf"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1252292, 25415, 168, 3, 43, "Subsection", "ExpressionUUID" -> \
"c1ca0ca4-c8dc-45ce-9d63-51a40e557da1"],
Cell[CellGroupData[{
Cell[1252485, 25422, 8900, 212, 807, "Input", "ExpressionUUID" -> \
"aa51520f-5934-4ac1-b33b-32c9521d6705"],
Cell[1261388, 25636, 55811, 941, 70, "Output", "ExpressionUUID" -> \
"1c811dad-971c-49bd-82da-debaabdb477a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1317248, 26583, 163, 3, 43, "Subsection", "ExpressionUUID" -> \
"9ef93d29-10f8-4f62-ad5e-465ef4a736fa"],
Cell[CellGroupData[{
Cell[1317436, 26590, 8931, 213, 807, "Input", "ExpressionUUID" -> \
"df583ce9-45df-42e4-973e-8eb223da2e72"],
Cell[1326370, 26805, 59813, 1006, 70, "Output", "ExpressionUUID" -> \
"d7bcb09d-6e88-4f29-972b-d434a257fd60"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1386244, 27818, 180, 3, 88, "Section", "ExpressionUUID" -> \
"bc6efc2d-c464-4983-91c0-3c7d6b9b8aec"],
Cell[CellGroupData[{
Cell[1386449, 27825, 180, 3, 48, "Input", "ExpressionUUID" -> \
"fbf00256-1b1f-4469-a5dc-6616ea37b690"],
Cell[1386632, 27830, 5589, 158, 106, "Output", "ExpressionUUID" -> \
"d0f3096c-1206-494d-99d1-0cd64509f0d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1392258, 27993, 177, 3, 44, "Subsection", "ExpressionUUID" -> \
"48736850-18ec-4851-bed6-d60350596d60"],
Cell[1392438, 27998, 9159, 216, 673, "Input", "ExpressionUUID" -> \
"e25f2702-8283-43fb-8d14-d0f62bf2ddd1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1401634, 28219, 177, 3, 44, "Subsection", "ExpressionUUID" -> \
"f1061b6d-66a0-4804-b911-03c42c4d8160"],
Cell[CellGroupData[{
Cell[1401836, 28226, 8745, 193, 817, "Input", "ExpressionUUID" -> \
"9612cab4-1445-4f45-afbf-da4835733401"],
Cell[1410584, 28421, 72945, 1311, 915, "Output", "ExpressionUUID" -> \
"a9ae6dad-056e-4dfe-b849-368b803cdc95"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

