(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    452184,      10662]
NotebookOptionsPosition[    427662,      10066]
NotebookOutlinePosition[    432729,      10169]
CellTagsIndexPosition[    432686,      10166]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Standing Wave Design - Ideal Langmuir", "Title",
 CellChangeTimes->{{3.706963901015277*^9, 3.706963917889349*^9}, {
  3.713336670750559*^9, 
  3.7133366707705584`*^9}},ExpressionUUID->"ed01b458-61fa-4d99-ac4d-\
a1e3f1e77b60"],

Cell[CellGroupData[{

Cell["Step 1: Define the Problem Notation", "Section",
 CellChangeTimes->{{3.7069639650830946`*^9, 
  3.706963974809104*^9}},ExpressionUUID->"64a4e308-567b-49f3-9c40-\
eafbfc332c20"],

Cell[TextData[{
 "In this section, we \
\[OpenCurlyDoubleQuote]symbolize\[CloseCurlyDoubleQuote] some variables so \
that we can use them later.  By default, if we enter a variable with a \
subscript (e.g. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "36252514-941e-4a5e-8895-0ed1182851d3"],
 ") Mathematica sees Subscript[a,1] instead of a regular symbol like a1.  So \
when you try to assign a value to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "7cccaf37-83e1-43dc-9957-2e1ad77ade90"],
 " (e.g. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "6"}], TraditionalForm]],ExpressionUUID->
  "c16c83f0-a931-43fc-ac9a-36b2a50348b9"],
 "), Mathematica instead says to itself:\n\[OpenCurlyDoubleQuote]the user \
wants to assign a value to Subscript[a,1].  I will add Subscript[_, 1] = 5 to \
the set of things I know about a.\[CloseCurlyDoubleQuote]\nWhen Mathematica \
does this, it is referred to as a \[OpenCurlyDoubleQuote]DownValue\
\[CloseCurlyDoubleQuote] of the symbol a.\nUsing the Symbolize, function lets \
us tell Mathematica not to interpret ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "ecbb0117-3069-4818-a396-0a505293d427"],
 " as a Subscript function, and so we avoid the use of DownValue.  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "392c2751-62df-465d-827e-5b13a7148baf"],
 " is treated as its own symbol and is no longer connected to the \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] symbol.  That way, when we \
say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "5"}], TraditionalForm]],ExpressionUUID->
  "0a284276-da21-46d7-99e6-f2d927ec645c"],
 " all Mathematica does is assign the value of 5 to the symbol ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "755dd16d-d00b-491c-96c4-f1aec4472e24"],
 " without any kind of DownValue."
}], "Text",
 CellChangeTimes->{{3.706697811970934*^9, 3.7066978572260523`*^9}, {
  3.706698028311755*^9, 3.706698138056162*^9}, {3.706698490209321*^9, 
  3.70669854546424*^9}, {3.7066988160465307`*^9, 3.7066988308940997`*^9}, {
  3.7067079136585436`*^9, 3.7067079851555705`*^9}, {3.7067080312762012`*^9, 
  3.706708071022498*^9}, {3.7067081321651993`*^9, 3.7067082954546*^9}, {
  3.7067083365748663`*^9, 3.706708366015239*^9}, {3.714240242436672*^9, 
  3.7142402704766397`*^9}},ExpressionUUID->"53e94bd3-e81c-4894-96c9-\
29043d3a0b68"],

Cell[TextData[{
 "In most cases, the difference between DownValues and values is not \
important.  Algebra and calculus generally work fine with either, and you do \
not need to worry about the difference.  The one area where the difference \
does matter is ",
 StyleBox["lexical scoping",
  FontSlant->"Italic"],
 ".  For example, if you want to temporarily assign a value to a variable \
like this:"
}], "Text",
 CellChangeTimes->{{3.706708370614149*^9, 3.7067084080783415`*^9}, {
  3.7067084449173512`*^9, 3.7067084752317624`*^9}, {3.7067085299593534`*^9, 
  3.706708533151581*^9}, {3.714240283659686*^9, 
  3.7142402852275596`*^9}},ExpressionUUID->"31fb755a-cc65-4f0e-8aae-\
deb062cdca1f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", " ", 
   RowBox[{"Evaluate", "[", 
    SuperscriptBox["a", "2"], " ", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706708477171032*^9, 3.7067084894642897`*^9}, {
  3.706708550313186*^9, 
  3.7067085573213086`*^9}},ExpressionUUID->"8f8ef682-bc38-4d4c-af6f-\
745ca10b7703"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{
  3.713338979959713*^9, 3.713341287505271*^9, 3.7133463649184294`*^9, 
   3.71334683411222*^9, 3.7133470071005573`*^9, 3.7133471301795588`*^9, 
   3.7133474305006313`*^9, 3.7133475595981255`*^9, 3.713348619810763*^9, 
   3.713349910039451*^9, 3.7133503612607813`*^9, 3.7133529521733017`*^9, 
   3.713353067057189*^9, 3.7133531396832247`*^9, 3.7133532843052497`*^9, 
   3.713354874728448*^9, 3.7133612260792503`*^9, 3.7133615222710114`*^9, 
   3.713365356087522*^9, 3.713369184797988*^9, 3.7134243664504085`*^9, 
   3.7134261309211655`*^9, 3.7134563636430097`*^9, 3.7134644337951756`*^9, 
   3.71348408704692*^9, 3.7135121277261877`*^9, 3.713517720333322*^9, 
   3.7135997691907434`*^9, 3.7136022021805196`*^9, 3.713602795219641*^9, 
   3.71378156779574*^9, 3.713781855312926*^9, 3.7137867993737087`*^9, 
   3.7138922660574803`*^9, 3.713910407008621*^9, 3.713910663791442*^9, 
   3.7140707361542625`*^9, 3.7140709138976135`*^9, 3.714071072343934*^9, 
   3.7141278967887626`*^9, 3.7141362873625994`*^9, 3.714142769807407*^9, 
   3.7142100882317066`*^9, 3.7142109875262785`*^9, {3.7142160486444454`*^9, 
   3.714216070311226*^9}, 3.71424057986576*^9, 
   3.71434016023984*^9},ExpressionUUID->"c6ee60db-e8ec-4fc1-898d-\
1528ad48206d"]
}, Open  ]],

Cell[TextData[{
 "Mathematica\[CloseCurlyQuote]s scoping construct \
\[OpenCurlyDoubleQuote]With\[CloseCurlyDoubleQuote] can only create temporary \
",
 StyleBox["values,",
  FontSlant->"Italic"],
 " not ",
 StyleBox["DownValues.",
  FontSlant->"Italic"],
 "  So if we want to use these constructs, we need to use Symbolize."
}], "Text",
 CellChangeTimes->{{3.7067085051628046`*^9, 3.7067085982239428`*^9}, {
  3.706964031058267*^9, 3.706964033479744*^9}, {3.7142402964111743`*^9, 
  3.714240298203142*^9}},ExpressionUUID->"839c5116-e256-4c10-92c0-\
fbece89ea0aa"],

Cell[TextData[{
 "It is also possible to force Mathematica to say the following\n\
\[OpenCurlyDoubleQuote]the user wants to assign a value to Subscript[a,1].  I \
will add Subscript[a, 1] = 5 to the set of things I know",
 StyleBox[" about the Subscript function",
  FontWeight->"Bold"],
 ".\[CloseCurlyDoubleQuote]\nWhen Mathematica does this, 5 is called a \
\[OpenCurlyDoubleQuote]upvalue\[CloseCurlyDoubleQuote] of the symbol \
Subscript."
}], "Text",
 CellChangeTimes->{{3.7067080753723607`*^9, 3.7067081294614725`*^9}, {
  3.7067083297584944`*^9, 3.706708331542101*^9}, {3.7142403126425653`*^9, 
  3.714240314010646*^9}},ExpressionUUID->"0ff5e4fa-f9fb-4f1f-b955-\
25c031b10434"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.655654009881259*^9, 3.6556540709341335`*^9}, {
  3.6556541286705556`*^9, 3.6556541386071386`*^9}, {3.6556541826824427`*^9, 
  3.655654184784837*^9}, {3.65565422925277*^9, 3.6556542656382427`*^9}, {
  3.6556543549254217`*^9, 3.6556543753579626`*^9}, {3.6556545287943487`*^9, 
  3.6556545683435383`*^9}, {3.6556552151106796`*^9, 3.655655243548979*^9}, {
  3.6556559648318224`*^9, 3.6556559758281126`*^9}, {3.6556625350770884`*^9, 
  3.6556625553416767`*^9}, {3.6556636806921215`*^9, 
  3.655663711748703*^9}},ExpressionUUID->"ba626c86-ac46-47e4-8dc8-\
8d5f7f809b82"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["r", "p"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Particle", " ", "Radius"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "p"]},
    "NotationTemplateTag"], "]"}], 
  RowBox[{"(*", 
   RowBox[{"Effective", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "m"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Molecular", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["A", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Column", " ", "Cross", " ", "Section"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["L", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Column", " ", "Length"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["t", "sw"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Switching", " ", "Time"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7009332717595787`*^9, 3.700933287443512*^9}, {
  3.7069760577434387`*^9, 3.7069760882452564`*^9}, {3.706976265001667*^9, 
  3.706976327755203*^9}, {3.7069775917314825`*^9, 3.7069776050564218`*^9}, {
  3.7133453064566894`*^9, 3.71334533454174*^9}, {3.71335083265457*^9, 
  3.713350834501753*^9}, {3.713368226641759*^9, 3.713368226826703*^9}, {
  3.713886462695323*^9, 3.7138864668864493`*^9}, {3.7141281120744886`*^9, 
  3.714128123915663*^9}},ExpressionUUID->"3a099395-8913-48de-b810-\
ef550bb54ac5"],

Cell[BoxData[{
 RowBox[{GridBox[{
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "+"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "-"]},
       "NotationTemplateTag"], "]"}]}
   }], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", " ", 
  TemplateBox[{SubscriptBox["y", "target"]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.700682475232301*^9, 3.700682485722865*^9}, 
   3.700682643795794*^9, 3.7009481377110014`*^9, 3.7009500313826027`*^9, {
   3.7133026447441673`*^9, 3.713302647881256*^9}, {3.713348436173435*^9, 
   3.7133484487422404`*^9}},ExpressionUUID->"d7c7f4c0-c5f8-47cc-bcc4-\
c9d7fc419dac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
      TemplateBox[{SubscriptBox["x", "s"]},
       "NotationTemplateTag"], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<x\>\"", "\[Rule]", 
        RowBox[{"ToString", "[", "x", "]"}]}], ",", 
       RowBox[{"\"\<s\>\"", "\[Rule]", 
        RowBox[{"ToString", "[", "s", "]"}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "a", ",", "b", ",", "c"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Activate", "[", "%", "]"}], "//", "Quiet"}], ";"}]}], "Input",
 CellChangeTimes->{{3.700682298492797*^9, 3.700682344910399*^9}, 
   3.700682645594619*^9, {3.706971022656542*^9, 3.7069710372036867`*^9}, {
   3.713886498514454*^9, 3.71388653158484*^9}, {3.713886703550462*^9, 
   3.7138867036524887`*^9}, {3.713886899002289*^9, 3.713886935184613*^9}, {
   3.713887161722721*^9, 3.7138872331508417`*^9}, {3.7140708607149396`*^9, 
   3.7140708700167265`*^9}, {3.7140709607985344`*^9, 
   3.7140709721672974`*^9}, {3.7140710183429203`*^9, 
   3.7140710359227424`*^9}},ExpressionUUID->"f5b532f4-4de4-4997-9144-\
c9ef8b66d02e"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["q", "A"]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["q", "B"]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["a", "A"]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["a", "B"]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["b", "A"]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["b", "B"]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["c", "A"]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubscriptBox["c", "B"]},
        "NotationTemplateTag"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7138872168417816`*^9, 3.713887233814706*^9}, 
   3.7138922665575604`*^9, 3.71391040788369*^9, 3.71391066422898*^9, 
   3.7140707377325525`*^9, 3.7140708708292007`*^9, 3.7140709147570796`*^9, {
   3.71407097458932*^9, 3.714070995535798*^9}, 3.7140710372978053`*^9, 
   3.7140710736686926`*^9, 3.7141278980232687`*^9, 3.714136288284613*^9, 
   3.714142770985953*^9, 3.714210089558977*^9, 3.7142109880352783`*^9, {
   3.7142160491739445`*^9, 3.714216071415228*^9}, 3.7142405808632307`*^9, 
   3.7143401610620847`*^9},ExpressionUUID->"d1f12ddb-69ed-40d7-a26b-\
6baeea1690df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
      TemplateBox[{SubsuperscriptBox["c", "component", "x"]},
       "NotationTemplateTag"], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<x\>\"", "\[Rule]", 
        RowBox[{"\"\<\\\"\>\"", "<>", 
         RowBox[{"ToString", "[", "x", "]"}], "<>", "\"\<\\\"\>\""}]}], ",", 
       RowBox[{"\"\<component\>\"", "\[Rule]", 
        RowBox[{"ToString", "[", "c", "]"}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<s\>\"", ",", "\"\<s*\>\"", ",", "\"\<p\>\"", ",", "\"\<F\>\"", 
        ",", "\"\<R\>\"", ",", "\"\<E\>\""}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Activate", "[", "%", "]"}], "//", "Quiet"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7009477447394514`*^9, 3.7009478256140194`*^9}, {
   3.700948031117095*^9, 3.7009480372573547`*^9}, {3.7009482672419186`*^9, 
   3.700948271782887*^9}, 3.700950072397784*^9, {3.706978020590043*^9, 
   3.70697806331144*^9}, {3.713346210600847*^9, 3.7133462450694036`*^9}, {
   3.7138865738509507`*^9, 3.7138866249325924`*^9}, {3.713886665480054*^9, 
   3.713886682579504*^9}, {3.713910378795965*^9, 3.713910379889861*^9}, {
   3.7139106070685387`*^9, 
   3.7139106106002183`*^9}},ExpressionUUID->"88170bbe-01ee-44b2-85f5-\
5cdf48e680ef"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"s\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"s\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"s*\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"s*\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"p\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"p\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"F\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"F\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"R\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"R\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"E\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"E\""]},
        "NotationTemplateTag"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.713910611397171*^9, 3.7139106642914877`*^9, 3.7140707378731956`*^9, 
   3.7140709148352118`*^9, 3.71407107374683*^9, 3.714127898085749*^9, 
   3.714136288362705*^9, 3.7141427711709723`*^9, 3.714210089692977*^9, 
   3.714210988145281*^9, {3.7142160492879443`*^9, 3.7142160715272264`*^9}, 
   3.7142405809852247`*^9, 
   3.714340161149086*^9},ExpressionUUID->"50f4a91c-2148-40fd-9781-\
2d71be60c96a"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"toNumericQ", "[", "any___", "]"}], ":=", 
  RowBox[{"NumericQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toStringQ", "[", "any___", "]"}], ":=", 
  RowBox[{"StringQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["x_", "i_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{SubscriptBox[
      RowBox[{"x_", "[", 
        TemplateBox[{
          RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}], 
      "i_"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SuperscriptBox["x_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{RowBox[{"x_", "[", 
       TemplateBox[{
         RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.713336229988531*^9, 3.7133362378482275`*^9}, {
  3.7133379022738476`*^9, 3.713337902766363*^9}, {3.7138867914125266`*^9, 
  3.7138868039245224`*^9}},ExpressionUUID->"3dfd05d9-ad20-49be-ac4d-\
b2bff679cd45"],

Cell[TextData[{
 "Add some convenience shortcuts.  Now, to type in ",
 Cell[BoxData[
  SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]],
  CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
    3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
    3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
    3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
    3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
    3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
    3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
    3.7069706345688634`*^9, 3.706970785055435*^9}},ExpressionUUID->
  "955fe48c-2812-4d4f-9717-eaebfbca3e5b"],
 ", we only need to press [esc] d 1 [esc]"
}], "Text",
 CellChangeTimes->{{3.7069708724437337`*^9, 
  3.7069709086295853`*^9}},ExpressionUUID->"40a18de7-32e1-465d-bca5-\
5928c3b00b56"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]}
   }], ";"}]], "Input",
 CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
   3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
   3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
   3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
   3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
   3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
   3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
   3.7069706345688634`*^9, 3.706970785055435*^9}, {3.7069766810891023`*^9, 
   3.7069767108198867`*^9}},ExpressionUUID->"903971f3-e12d-43b9-9364-\
be8a356e2a53"],

Cell[BoxData[{
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ep\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<eb\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<et\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<feed\>\"", "\[Rule]", 
   TemplateBox[{SuperscriptBox["f", "\"F\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<des\>\"", "\[Rule]", 
   TemplateBox[{SuperscriptBox["f", "\"D\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ext\>\"", "\[Rule]", 
   TemplateBox[{SuperscriptBox["f", "\"E\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<raff\>\"", "\[Rule]", 
   TemplateBox[{SuperscriptBox["f", "\"R\""]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6726802841433578`*^9, 3.6726802928288794`*^9}, {
   3.672755271908722*^9, 3.6727552869558325`*^9}, {3.6727767324017215`*^9, 
   3.672776745104333*^9}, {3.7069704528909445`*^9, 3.7069705068199396`*^9}, {
   3.706970606368145*^9, 3.706970607027779*^9}, {3.7069767220443125`*^9, 
   3.7069767502680197`*^9}, {3.713337473752632*^9, 3.713337483785607*^9}, 
   3.7133376380505476`*^9, {3.713350841178546*^9, 3.713350845169429*^9}, {
   3.7138867792653313`*^9, 3.713886779916895*^9}, {3.7138868242222996`*^9, 
   3.713886865186973*^9}},ExpressionUUID->"e250de69-62f7-4604-a02a-\
ad4570996a35"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Define The Key Terms", "Section",
 CellChangeTimes->{{3.7069734825274553`*^9, 
  3.7069735032030835`*^9}},ExpressionUUID->"81cb6831-dc10-4571-8c85-\
777c460dc4d5"],

Cell[CellGroupData[{

Cell["Isotherm Definition", "Subsection",
 CellChangeTimes->{{3.67746618373181*^9, 
  3.6774661870844564`*^9}},ExpressionUUID->"23dfa824-aa7e-4bd6-8cb0-\
66ab78b6f783"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isotherm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "A"], "\[Rule]", " ", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["c", "A"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}], " ", ",", 
    RowBox[{
     SubscriptBox["q", "B"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["c", "B"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6774661967728624`*^9, 3.6774662432648315`*^9}, {
  3.706970980944528*^9, 3.7069709973843966`*^9}, {3.7069710689723396`*^9, 
  3.70697113652822*^9}, {3.706971278610673*^9, 
  3.7069712998410425`*^9}},ExpressionUUID->"a6bc2d7d-4b6a-4b7b-ac2b-\
14808f56dcc6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "A"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["c", "A"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}], ",", 
   RowBox[{
    SubscriptBox["q", "B"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["c", "B"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338982213214*^9, 3.713341289455179*^9, 3.7133463666789737`*^9, 
   3.7133468358342333`*^9, 3.7133470090647235`*^9, 3.713347131931735*^9, 
   3.7133474326873827`*^9, 3.7133475615990705`*^9, 3.713348621666252*^9, 
   3.7133499118989563`*^9, 3.71335036362273*^9, 3.7133529540258102`*^9, 
   3.7133530689820805`*^9, 3.71335314226466*^9, 3.7133532868178897`*^9, 
   3.7133548772316866`*^9, 3.7133612282502403`*^9, 3.7133615242155914`*^9, 
   3.713365358957106*^9, 3.7133691875007467`*^9, 3.7134243688501697`*^9, 
   3.7134261338284254`*^9, 3.7134563676280594`*^9, 3.713464436426861*^9, 
   3.7134840900989485`*^9, 3.713512129337883*^9, 3.7135177275521946`*^9, 
   3.7135997730616045`*^9, 3.713602209694457*^9, 3.713602799046732*^9, 
   3.713781571280513*^9, 3.7137818585164313`*^9, 3.713786806921382*^9, 
   3.7138922703391867`*^9, 3.713910409227596*^9, 3.7139106656666603`*^9, 
   3.714070837549147*^9, 3.714070876751709*^9, 3.714070921289054*^9, 
   3.71407107496568*^9, 3.714127899039002*^9, 3.714136289315959*^9, 
   3.7141427803797426`*^9, 3.71421009119479*^9, 3.7142109893592386`*^9, {
   3.714216050938985*^9, 3.71421607312523*^9}, 3.7142405822071695`*^9, 
   3.7143401626228137`*^9},ExpressionUUID->"076f4199-70b8-4185-86ec-\
52260cb3c03f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase Ratio Definition", "Subsection",
 CellChangeTimes->{{3.7069761277850475`*^9, 3.7069761303831615`*^9}, {
  3.7134645729564495`*^9, 
  3.7134645901779776`*^9}},ExpressionUUID->"c3dfc326-054f-4c28-b74b-\
2def50611e36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Phi]", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SubscriptBox["\[Epsilon]", "b"]}], ")"}], "/", 
   SubscriptBox["\[Epsilon]", "b"]}]}]], "Input",
 CellChangeTimes->{
  3.706976122161029*^9, {3.713338932913249*^9, 
   3.7133389606679296`*^9}},ExpressionUUID->"031187c5-8279-4892-9376-\
6fd7a3e923a1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   SubscriptBox["\[Epsilon]", "b"]}], 
  SubscriptBox["\[Epsilon]", "b"]]], "Output",
 CellChangeTimes->{
  3.713338982230715*^9, 3.7133412894761825`*^9, 3.7133463666969733`*^9, 
   3.7133468358652334`*^9, 3.713347009079723*^9, 3.713347131950734*^9, 
   3.713347432700382*^9, 3.71334756161407*^9, 3.7133486216833496`*^9, 
   3.713349911918955*^9, 3.713350363639735*^9, 3.7133529540498104`*^9, 
   3.7133530690030785`*^9, 3.713353142286668*^9, 3.7133532868653965`*^9, 
   3.7133548772696953`*^9, 3.713361228265865*^9, 3.713361524222254*^9, 
   3.7133653589727306`*^9, 3.713369187516389*^9, 3.7134243688501697`*^9, 
   3.7134261338284254`*^9, 3.713456367638542*^9, 3.713464436436858*^9, 
   3.7134840901589556`*^9, 3.713512129344884*^9, 3.7135177275611954`*^9, 
   3.7135997730776052`*^9, 3.7136022097089567`*^9, 3.7136027990637317`*^9, 
   3.7137815712961164`*^9, 3.7137818585164313`*^9, 3.71378680696826*^9, 
   3.7138922703860664`*^9, 3.7139104092432194`*^9, 3.713910665682263*^9, 
   3.71407083762728*^9, 3.7140708767829337`*^9, 3.7140709213515606`*^9, 
   3.7140710749813447`*^9, 3.7141278990546017`*^9, 3.714136289315959*^9, 
   3.71414278039537*^9, 3.714210091212787*^9, 3.7142109893822393`*^9, {
   3.714216050953485*^9, 3.7142160731567264`*^9}, 3.7142405822161713`*^9, 
   3.7143401626518154`*^9},ExpressionUUID->"3128abd7-c8da-4874-bf00-\
e03f91cb8c20"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Interstitial Velocity Definition", "Subsection",
 CellChangeTimes->{{3.713464594821023*^9, 
  3.7134646005630226`*^9}},ExpressionUUID->"5b09e3b9-acb8-48c9-bd2d-\
b4376e33e589"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"interstitialVelocity", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "==", 
    FractionBox[
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["f", "\"\<I\>\""], ",", 
       SuperscriptBox["f", "\"\<II\>\""], ",", 
       SuperscriptBox["f", "\"\<III\>\""], ",", 
       SuperscriptBox["f", "\"\<IV\>\""]}], "}"}], 
     RowBox[{
      SubscriptBox["\[Epsilon]", "b"], 
      SubscriptBox["A", "c"]}]]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069770846770887`*^9, 3.7069771929902897`*^9}, {
  3.7133375715885506`*^9, 3.7133376107891293`*^9}, {3.7134646230118504`*^9, 
  3.713464679504154*^9}, {3.713891904781637*^9, 
  3.713891934652076*^9}},ExpressionUUID->"cdc78a48-34ed-4928-a74d-\
7df7491e3058"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Equal]", 
    FractionBox[
     SuperscriptBox["f", "\<\"I\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Equal]", 
    FractionBox[
     SuperscriptBox["f", "\<\"II\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Equal]", 
    FractionBox[
     SuperscriptBox["f", "\<\"III\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Equal]", 
    FractionBox[
     SuperscriptBox["f", "\<\"IV\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713464657444455*^9, 3.7134647287200375`*^9, 3.71348409019346*^9, 
   3.7135121293518834`*^9, 3.713517727572194*^9, 3.713599773088106*^9, 
   3.7136022097214565`*^9, 3.713602799076731*^9, 3.7137815713117666`*^9, 
   3.7137818585320215`*^9, 3.7137868069995146`*^9, 3.7138919378051653`*^9, 
   3.7138922704329453`*^9, 3.713910409258837*^9, 3.7139106656978893`*^9, 
   3.7140708376428785`*^9, 3.71407087679856*^9, 3.714070921367158*^9, 
   3.7140710750125976`*^9, 3.7141278990546017`*^9, 3.71413628933156*^9, 
   3.714142780426623*^9, 3.714210091237789*^9, 3.7142109894042406`*^9, {
   3.714216050968485*^9, 3.7142160731812286`*^9}, 3.7142405822256875`*^9, 
   3.7143401626678143`*^9},ExpressionUUID->"e727cfa2-92a4-4bc2-93c1-\
82579b4bb04f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["M-Value Definition", "Subsection",
 CellChangeTimes->{{3.7141280874691014`*^9, 
  3.7141280926258965`*^9}},ExpressionUUID->"503f60f8-1439-4b37-80a6-\
5cba8874da0f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mValues", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"m", "[", "zone", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox[
         RowBox[{"u", "[", "zone", "]"}], "0"], " ", 
        SubscriptBox["\[Epsilon]", "b"], 
        SubscriptBox["t", "sw"]}], "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "t"], 
        SubscriptBox["L", "c"]}]}], 
      RowBox[{
       SubscriptBox["L", "c"], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"zone", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<I\>\"", ",", "\"\<II\>\"", ",", "\"\<III\>\"", ",", 
        "\"\<IV\>\""}], "}"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.714128134823064*^9, 3.714128172644806*^9}, {
  3.7141282075399384`*^9, 
  3.7141282097119093`*^9}},ExpressionUUID->"f34d8587-f514-4523-89b4-\
c804d363c7cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["m", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["L", "c"]}], " ", 
       SubscriptBox["\[Epsilon]", "t"]}], "+", 
      RowBox[{
       SubscriptBox["t", "sw"], " ", 
       SubscriptBox["\[Epsilon]", "b"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]}], 
     RowBox[{
      SubscriptBox["L", "c"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
   RowBox[{
    SuperscriptBox["m", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["L", "c"]}], " ", 
       SubscriptBox["\[Epsilon]", "t"]}], "+", 
      RowBox[{
       SubscriptBox["t", "sw"], " ", 
       SubscriptBox["\[Epsilon]", "b"], " ", 
       SubsuperscriptBox["u", "0", "\<\"II\"\>"]}]}], 
     RowBox[{
      SubscriptBox["L", "c"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
   RowBox[{
    SuperscriptBox["m", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["L", "c"]}], " ", 
       SubscriptBox["\[Epsilon]", "t"]}], "+", 
      RowBox[{
       SubscriptBox["t", "sw"], " ", 
       SubscriptBox["\[Epsilon]", "b"], " ", 
       SubsuperscriptBox["u", "0", "\<\"III\"\>"]}]}], 
     RowBox[{
      SubscriptBox["L", "c"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
   RowBox[{
    SuperscriptBox["m", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["L", "c"]}], " ", 
       SubscriptBox["\[Epsilon]", "t"]}], "+", 
      RowBox[{
       SubscriptBox["t", "sw"], " ", 
       SubscriptBox["\[Epsilon]", "b"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}], 
     RowBox[{
      SubscriptBox["L", "c"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7141280960323925`*^9, {3.7141281387608433`*^9, 3.714128173551017*^9}, 
   3.7141282108058014`*^9, 3.71413628933156*^9, 3.7141427804422493`*^9, 
   3.7142100912647877`*^9, 3.71421098942924*^9, {3.714216050983985*^9, 
   3.714216073215726*^9}, 3.7142405822356863`*^9, 
   3.714340162683815*^9},ExpressionUUID->"e750773c-236d-49f0-abb3-\
be2f551298a3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Retention Factor Definitions", "Subsection",
 CellChangeTimes->{{3.706973516677366*^9, 
  3.7069735217634172`*^9}},ExpressionUUID->"1a3b5c7b-d694-40bd-b883-\
74f72cda58ee"],

Cell[CellGroupData[{

Cell["Ideal", "Subsubsection",
 CellChangeTimes->{{3.700927282836939*^9, 
  3.700927283372059*^9}},ExpressionUUID->"17c45168-52cd-4a15-8ee0-\
b908007f771f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealRetention", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["a", "B"]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "B"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.700927250790391*^9, 3.7009272773669167`*^9}, {
   3.7009284912956934`*^9, 3.7009285028657093`*^9}, {3.7009504456319914`*^9, 
   3.7009504521905937`*^9}, {3.706973698819386*^9, 3.7069737083463225`*^9}, {
   3.706974221388472*^9, 3.7069742864664307`*^9}, 3.7069746419989896`*^9, {
   3.706979029946501*^9, 3.706979055616598*^9}, {3.713337533221609*^9, 
   3.7133375442303457`*^9}, {3.7133377288589096`*^9, 3.713337737224095*^9}, {
   3.7133468133210235`*^9, 
   3.713346821616871*^9}},ExpressionUUID->"8d53744f-a03c-451a-af3c-\
55077e544482"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389822512136`*^9, 3.713341289511447*^9, 3.713346366746977*^9, 
   3.7133468358977394`*^9, 3.713347009116723*^9, 3.7133471319917383`*^9, 
   3.7133474327298923`*^9, 3.71334756165107*^9, 3.7133486217113495`*^9, 
   3.71334991196346*^9, 3.7133503636773915`*^9, 3.7133529540909233`*^9, 
   3.7133530690445824`*^9, 3.7133531423326683`*^9, 3.7133532869143953`*^9, 
   3.7133548773006964`*^9, 3.7133612282814903`*^9, 3.713361524222254*^9, 
   3.7133653589948616`*^9, 3.7133691875320144`*^9, 3.713424368865795*^9, 
   3.7134261338440514`*^9, 3.713456367650057*^9, 3.713464436466864*^9, 
   3.7134840902389655`*^9, 3.713512129364388*^9, 3.713517727585194*^9, 
   3.713599773102105*^9, 3.7136022097434564`*^9, 3.713602799100732*^9, 
   3.713781571327371*^9, 3.7137818585476494`*^9, 3.713786807046389*^9, 
   3.7138922704954863`*^9, 3.71391040929009*^9, 3.7139106657291408`*^9, 
   3.714070837658531*^9, 3.71407087679856*^9, 3.714070921382785*^9, 
   3.7140710750438213`*^9, 3.7141278990702333`*^9, 3.714136289347185*^9, 
   3.714142780479789*^9, 3.7142100913287883`*^9, 3.7142109894672394`*^9, {
   3.7142160510139866`*^9, 3.7142160732652283`*^9}, 3.7142405822551875`*^9, 
   3.714340162714816*^9},ExpressionUUID->"a892b3c3-49ac-46e1-8070-\
a9ba4023b99a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Non-Ideal", "Subsubsection",
 CellChangeTimes->{{3.7009272879844604`*^9, 3.700927290804271*^9}, {
  3.713889456283883*^9, 
  3.713889456408865*^9}},ExpressionUUID->"53d26786-ca52-4240-b456-\
7ff699da96f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonIdealRetention", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["a", "B"]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}]]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "B"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}]]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.700927305349064*^9, 3.7009273314721465`*^9}, {
  3.700928504670043*^9, 3.700928515225958*^9}, {3.7009504564876337`*^9, 
  3.700950461206908*^9}, {3.7069737114683585`*^9, 3.706973718580208*^9}, {
  3.706974303686753*^9, 3.7069743528909817`*^9}, {3.706975331666441*^9, 
  3.7069753749932384`*^9}, {3.706983809528408*^9, 3.7069838327496595`*^9}, {
  3.7133375332446113`*^9, 3.7133375442323446`*^9}, {3.71333772888491*^9, 
  3.713337737161096*^9}, {3.7133389329462495`*^9, 3.7133389606724305`*^9}, {
  3.713346803429296*^9, 3.713346809543415*^9}, {3.713464148691203*^9, 
  3.713464162619529*^9}, {3.713889487674819*^9, 3.7138895145452185`*^9}, {
  3.714248294897501*^9, 3.7142482953048325`*^9}, {3.7142483889841976`*^9, 
  3.714248389471304*^9}},ExpressionUUID->"cddc9ed1-8521-4152-9510-\
8a50da96fb37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389822752156`*^9, 3.7133412895294476`*^9, 3.71334636676598*^9, 
   3.713346835937611*^9, 3.713347009137748*^9, 3.7133471320108147`*^9, 
   3.7133474327478957`*^9, 3.7133475616710763`*^9, 3.7133486217303505`*^9, 
   3.713349911980771*^9, 3.7133503637003913`*^9, 3.7133529541174307`*^9, 
   3.7133530690700855`*^9, 3.713353142364668*^9, 3.7133532869644012`*^9, 
   3.7133548773366985`*^9, 3.713361228297117*^9, 3.7133615242382336`*^9, 
   3.713365359010494*^9, 3.7133691875496473`*^9, 3.71342436888142*^9, 
   3.7134261338440514`*^9, 3.713456367663542*^9, 3.713464436486869*^9, 
   3.7134840902589684`*^9, 3.713512129375891*^9, 3.713517727598194*^9, 
   3.713599773116605*^9, 3.713602209760957*^9, 3.713602799117236*^9, 
   3.7137815713586235`*^9, 3.7137818585633087`*^9, 3.713786807140154*^9, 
   3.713892270620467*^9, 3.7139104093057165`*^9, 3.7139106657447667`*^9, 
   3.7140708376741323`*^9, 3.7140708768141885`*^9, 3.7140709213984327`*^9, 
   3.7140710750751038`*^9, 3.7141278990858736`*^9, 3.714136289362813*^9, 
   3.714142780495385*^9, 3.7142100913697877`*^9, 3.714210989493617*^9, {
   3.714216051042485*^9, 3.7142160732992263`*^9}, 3.714240582268186*^9, 
   3.7142482960532675`*^9, 3.7142483919863033`*^9, 
   3.714340162735815*^9},ExpressionUUID->"1bdc32a7-1183-49fb-8592-\
7d32c024dbf9"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Decay Factor Definitions", "Subsection",
 CellChangeTimes->{{3.700927400092606*^9, 3.7009274042601995`*^9}, {
  3.7134642255993366`*^9, 
  3.7134642271096077`*^9}},ExpressionUUID->"2b5f5d9d-24ff-4369-8d55-\
599863a9cba8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"decayFactors", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<E\>\""], 
       SubsuperscriptBox["c", "B", "\"\<I\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<s*\>\""], 
       SubsuperscriptBox["c", "A", "\"\<E\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<s\>\""], 
       SubsuperscriptBox["c", "B", "\"\<R\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "A", "\"\<R\>\""], 
       SubsuperscriptBox["c", "A", "\"\<IV\>\""]], "]"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7009274260277*^9, 3.7009274351122284`*^9}, {
   3.7009284705368476`*^9, 3.700928483438323*^9}, {3.700950468393784*^9, 
   3.7009504730975943`*^9}, {3.706973830986437*^9, 3.7069738543944693`*^9}, {
   3.706974589352887*^9, 3.706974605080983*^9}, {3.7133363550795794`*^9, 
   3.7133364412292347`*^9}, {3.7134840814429717`*^9, 3.713484082073532*^9}, 
   3.71360218482189*^9, {3.7136027848711205`*^9, 3.7136027858927937`*^9}, {
   3.7139106582441025`*^9, 
   3.7139106598380213`*^9}},ExpressionUUID->"8fedecd6-acc6-451b-a605-\
977e9e03aa78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"E\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"I\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"s*\"\>"], 
      SubsuperscriptBox["c", "A", "\<\"E\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"s\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"R\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "A", "\<\"R\"\>"], 
      SubsuperscriptBox["c", "A", "\<\"IV\"\>"]], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713910665776025*^9, 3.7140708376897783`*^9, 3.7140708768454833`*^9, 
   3.7140709214140387`*^9, 3.714071075106331*^9, 3.7141278991014814`*^9, 
   3.7141362893784647`*^9, 3.714142780526665*^9, 3.7142100913967876`*^9, 
   3.7142109895206203`*^9, {3.714216051059485*^9, 3.714216073321726*^9}, 
   3.7142405822786674`*^9, 
   3.7143401627628155`*^9},ExpressionUUID->"3845aa30-a91f-4fb3-b964-\
dba0f2529fb7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Characteristic Polynomials", "Subsection",
 CellChangeTimes->{{3.706971225391755*^9, 
  3.706971254700155*^9}},ExpressionUUID->"11fe0391-c1c4-4633-842f-\
28d99a545859"],

Cell[CellGroupData[{

Cell["Primary Definition", "Subsubsection",
 CellChangeTimes->{{3.7069746936318626`*^9, 3.7069746957059355`*^9}, {
  3.7134642440418725`*^9, 
  3.7134642455332575`*^9}},ExpressionUUID->"c585d92c-d06a-4883-a221-\
9db6bbff8dc1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"characteristicPolynomial", "=", 
  RowBox[{
   RowBox[{"Inactivate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["c", "A"]], 
        SubscriptBox["q", "B"]}]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "B"]], 
          SubscriptBox["q", "B"]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "A"]], 
          SubscriptBox["q", "A"]}]}], ")"}], "\[Gamma]"}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        SubscriptBox["c", "B"]], 
       SubscriptBox["q", "A"]}]}], "\[Equal]", "0"}], "]"}], "/.", 
   "isotherm"}]}]], "Input",
 CellChangeTimes->{{3.706971302611926*^9, 
  3.7069713310704417`*^9}},ExpressionUUID->"4a222d56-f6e7-4342-b105-\
586829668d0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", 
     TagBox["^",
      "InactiveToken",
      BaseStyle->"Inactive",
      SyntaxForm->"^"], "2"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["c", "B"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
     "InactiveD"]}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TemplateBox[{"Inactive",FractionBox[
         RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["c", "B"]}], 
         RowBox[{"1", "+", 
           RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["c", "A"]}], "+", 
           RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
       "InactiveD"], 
      TagBox["+",
       "InactiveToken",
       BaseStyle->"Inactive",
       SyntaxForm->"+"], 
      RowBox[{
       RowBox[{"-", "1"}], 
       TagBox["*",
        "InactiveToken",
        BaseStyle->"Inactive",
        SyntaxForm->"*"], 
       TemplateBox[{"Inactive",FractionBox[
          RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["c", "A"]}], 
          RowBox[{"1", "+", 
            RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}], "+", 
            RowBox[{
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
        "InactiveD"]}]}], ")"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], "\[Gamma]"}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"-", "1"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["c", "A"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
     "InactiveD"]}]}], 
  TagBox["\[Equal]",
   "InactiveToken",
   BaseStyle->"Inactive",
   SyntaxForm->"\[Equal]"], "0"}]], "Output",
 CellChangeTimes->{
  3.713338982326214*^9, 3.7133412895623007`*^9, 3.7133463668029785`*^9, 
   3.713346836031618*^9, 3.7133470091697474`*^9, 3.713347132046815*^9, 
   3.713347432782899*^9, 3.713347561718814*^9, 3.713348621762355*^9, 
   3.713349912020568*^9, 3.713350363746398*^9, 3.713352954165013*^9, 
   3.713353069118087*^9, 3.7133531424139333`*^9, 3.7133532870664062`*^9, 
   3.713354877394704*^9, 3.713361228328873*^9, 3.7133615242538404`*^9, 
   3.713365359041744*^9, 3.7133691875695424`*^9, 3.7134243688970456`*^9, 
   3.7134261338596754`*^9, 3.7134563676900377`*^9, 3.71346443653687*^9, 
   3.713484090278966*^9, 3.7135121293988924`*^9, 3.7135177276231947`*^9, 
   3.713599773143105*^9, 3.713602209793457*^9, 3.71360279914528*^9, 
   3.7137815713898773`*^9, 3.7137818585945487`*^9, 3.7137868072807894`*^9, 
   3.713892270823642*^9, 3.713910409415103*^9, 3.713910665791647*^9, 
   3.7140708377054048`*^9, 3.7140708768923273`*^9, 3.714070921429666*^9, 
   3.7140709846528673`*^9, 3.7140710751532373`*^9, 3.7141278991171384`*^9, 
   3.7141362893940725`*^9, 3.7141427805422907`*^9, 3.714210091425788*^9, 
   3.7142109895516224`*^9, {3.7142160510744853`*^9, 3.7142160733497257`*^9}, 
   3.714240582288684*^9, 
   3.714340162791815*^9},ExpressionUUID->"c4dc3eed-02ac-4e83-aac4-\
65308c6abc3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Polynomial", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Activate", "@", "characteristicPolynomial"}], ",", 
    RowBox[{"{", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["c", "A"]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "B"]}]}], ">", "0"}], "}"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971351866922*^9, 
  3.706971379406417*^9}},ExpressionUUID->"ed217de2-e540-42ff-8c37-\
82d4a4560446"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["a", "B"], " ", "\[Gamma]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["b", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["c", "A"], "-", 
        RowBox[{
         SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}], ")"}]}], 
  "\[Equal]", 
  RowBox[{
   SubscriptBox["a", "A"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["b", "B"]}], " ", 
      SubscriptBox["c", "A"]}], "+", "\[Gamma]", "+", 
     RowBox[{
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7133389824517136`*^9, 3.7133412897588205`*^9, 3.7133463669289885`*^9, 
   3.7133468361733913`*^9, 3.713347009313261*^9, 3.7133471322079773`*^9, 
   3.713347432897738*^9, 3.7133475618713274`*^9, 3.7133486218688602`*^9, 
   3.7133499121415787`*^9, 3.7133503638818655`*^9, 3.7133529543015213`*^9, 
   3.7133530692530236`*^9, 3.7133531424744415`*^9, 3.7133532871144066`*^9, 
   3.713354877505716*^9, 3.713361228497429*^9, 3.713361524285092*^9, 
   3.7133653590729933`*^9, 3.7133691876698217`*^9, 3.7134243691001697`*^9, 
   3.7134261339221783`*^9, 3.7134563677375526`*^9, 3.713464436706906*^9, 
   3.7134840903085594`*^9, 3.7135121295859027`*^9, 3.7135177277692256`*^9, 
   3.7135997733534513`*^9, 3.713602209928957*^9, 3.713602799281786*^9, 
   3.7137815724526324`*^9, 3.713781858719573*^9, 3.7137868085465555`*^9, 
   3.713892271214274*^9, 3.7139104094620466`*^9, 3.7139106658229003`*^9, 
   3.7140708377210317`*^9, 3.714070876923612*^9, 3.714070921429666*^9, 
   3.7140710761689625`*^9, 3.7141279001015882`*^9, 3.714136289503482*^9, 
   3.714142780664287*^9, 3.714210091647788*^9, 3.71421098970767*^9, {
   3.7142160511154847`*^9, 3.714216073472228*^9}, 3.714240582455162*^9, 
   3.714340163032817*^9},ExpressionUUID->"bf63547b-8e38-4916-a451-\
dd9f3aeccac4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]PolynomialSolutions", "=", 
  RowBox[{"Simplify", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{"\[Gamma]Polynomial", ",", "\[Gamma]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.70697165303078*^9, 3.706971674686119*^9}, {
  3.7069717400542965`*^9, 
  3.706971770398497*^9}},ExpressionUUID->"c48f687d-6520-4ceb-9cb2-\
69a62c02dc56"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "-", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["c", "A"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "A"], " ", 
           SubscriptBox["c", "B"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "B"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "A"]}], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338982555713*^9, 3.7133412898594294`*^9, 3.7133463670275445`*^9, 
   3.713346836303405*^9, 3.713347009414271*^9, 3.713347132309057*^9, 
   3.7133474330117483`*^9, 3.713347561988343*^9, 3.713348621970867*^9, 
   3.713349912244588*^9, 3.713350363994872*^9, 3.7133529544030323`*^9, 
   3.7133530693540306`*^9, 3.713353142577453*^9, 3.7133532872201405`*^9, 
   3.7133548776217265`*^9, 3.713361228597685*^9, 3.7133615243942337`*^9, 
   3.7133653591923895`*^9, 3.713369187785757*^9, 3.7134243692235155`*^9, 
   3.713426134031551*^9, 3.7134563678475504`*^9, 3.7134644368167915`*^9, 
   3.7134840903185616`*^9, 3.713512129688907*^9, 3.7135177278702326`*^9, 
   3.713599773468953*^9, 3.7136022100389566`*^9, 3.713602799382794*^9, 
   3.713781572874411*^9, 3.713781858844586*^9, 3.713786809249748*^9, 
   3.7138922716831074`*^9, 3.7139104094776115`*^9, 3.7139106658385563`*^9, 
   3.7140708377366405`*^9, 3.714070876954865*^9, 3.7140709214452915`*^9, 
   3.714071076418969*^9, 3.714127900382897*^9, 3.7141362896597185`*^9, 
   3.714142780801196*^9, 3.7142100917597895`*^9, 3.71421098981067*^9, {
   3.714216051225984*^9, 3.7142160735777283`*^9}, 3.7142405825716743`*^9, 
   3.7143401631566925`*^9},ExpressionUUID->"d51d8c69-3965-4b61-996e-\
4c2382c42631"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Values", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Gamma]", "-"], ",", 
      SubscriptBox["\[Gamma]", "+"]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "/.", "\[Gamma]PolynomialSolutions"}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971774342685*^9, 3.706971789238475*^9}, {
  3.713349889939475*^9, 3.7133498967686787`*^9}, {3.713353057359313*^9, 
  3.713353059118727*^9}, {3.7133531250268097`*^9, 
  3.713353131503124*^9}},ExpressionUUID->"59c7991c-1e2f-4204-a0a8-\
bfa12f317946"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338982588214*^9, 3.713341289902938*^9, 3.713346367057749*^9, 
   3.7133468363236265`*^9, 3.7133470094399123`*^9, 3.713347132346058*^9, 
   3.7133474330622835`*^9, 3.7133475620699234`*^9, 3.713348622012868*^9, 
   3.71334991231195*^9, 3.713350364056998*^9, 3.713352954467535*^9, 
   3.7133530694325867`*^9, 3.713353142598951*^9, 3.713353287271159*^9, 
   3.71335487765874*^9, 3.7133612286354523`*^9, 3.713361524414875*^9, 
   3.713365359204217*^9, 3.7133691878169928`*^9, 3.7134243692450747`*^9, 
   3.713426134031551*^9, 3.713456367858038*^9, 3.7134644369164248`*^9, 
   3.7134840903285594`*^9, 3.7135121297199073`*^9, 3.713517727959243*^9, 
   3.713599773649576*^9, 3.7136022101499567`*^9, 3.7136027994708023`*^9, 
   3.713781572921323*^9, 3.713781858875809*^9, 3.713786809374762*^9, 
   3.7138922719331074`*^9, 3.7139104095244904`*^9, 3.713910665869797*^9, 
   3.714070837892948*^9, 3.714070877048626*^9, 3.7140709215547094`*^9, 
   3.714071076465877*^9, 3.7141279004297485`*^9, 3.7141362896909723`*^9, 
   3.714142780829774*^9, 3.714210091836789*^9, 3.7142109898556695`*^9, {
   3.7142160512499866`*^9, 3.7142160736272264`*^9}, 3.714240582600174*^9, 
   3.7143401631955314`*^9},ExpressionUUID->"4b83bc5a-1e6d-4677-baa4-\
6f602d4e02b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["A", "-"], ",", 
    SubscriptBox["A", "+"]}], "}"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"]}], 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], 
       RowBox[{
        SubscriptBox["b", "B"], "/", "\[Gamma]"}]}]}]], "/.", 
    "\[Gamma]PolynomialSolutions"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713349873519145*^9, 3.7133498770766993`*^9}, {
  3.713353052157383*^9, 3.7133530548367743`*^9}, {3.7133531347309446`*^9, 
  3.713353136594575*^9}},ExpressionUUID->"0bdb7d99-c49c-46b0-9970-\
bddf64657860"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "+", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]], ",", 
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "-", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983529714*^9, 3.7133412908380857`*^9, 3.7133463679593053`*^9, 
   3.7133468372257614`*^9, 3.713347010391641*^9, 3.713347133273785*^9, 
   3.7133474340628366`*^9, 3.7133475631233788`*^9, 3.713348622962989*^9, 
   3.7133498825963187`*^9, 3.7133499132715073`*^9, 3.713350365023613*^9, 
   3.713352955399082*^9, 3.71335307039218*^9, 3.7133531435032554`*^9, 
   3.7133532882097425`*^9, 3.7133548786288013`*^9, 3.7133612296575565`*^9, 
   3.713361525386848*^9, 3.7133653601611195`*^9, 3.7133691888363905`*^9, 
   3.71342437024856*^9, 3.713426134921768*^9, 3.7134563688222084`*^9, 
   3.713464437864501*^9, 3.71348409033856*^9, 3.713512130702756*^9, 
   3.713517728953312*^9, 3.713599774698003*^9, 3.7136022111989555`*^9, 
   3.713602800413843*^9, 3.713781574421455*^9, 3.713781859985304*^9, 
   3.7137868144534283`*^9, 3.7138922764023666`*^9, 3.713910409743265*^9, 
   3.7139106658854084`*^9, 3.714070838299203*^9, 3.714070877095499*^9, 
   3.7140709216484385`*^9, 3.7140710782941575`*^9, 3.714127902289319*^9, 
   3.7141362907535844`*^9, 3.7141427819539843`*^9, 3.7142100929093714`*^9, 
   3.71421099077067*^9, {3.7142160521834846`*^9, 3.7142160745777435`*^9}, 
   3.714240583609732*^9, 
   3.7143401642005415`*^9},ExpressionUUID->"48d593a9-472c-4057-b96e-\
c592a541540c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Secondary \[Gamma] definition", "Subsubsection",
 CellChangeTimes->{{3.7069747010202184`*^9, 
  3.706974717036033*^9}},ExpressionUUID->"c8f14563-3016-4c24-9549-\
288f240693cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondary\[Gamma]Values", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       SubscriptBox["a", "A"], "-", 
       RowBox[{
        SubscriptBox["a", "A"], 
        SubscriptBox["b", "B"], 
        SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], 
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubsuperscriptBox["c", "B", "\"\<p\>\""]}]]}], ",", 
    RowBox[{
     SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       SubsuperscriptBox["c", "A", "\"\<p\>\""]}], 
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], 
        SubscriptBox["b", "A"], 
        SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.706974728692503*^9, 3.706974759830389*^9}, {
  3.706974792782261*^9, 3.706974862933106*^9}, {3.7069812267974615`*^9, 
  3.7069812279590883`*^9}, {3.7133377288209095`*^9, 3.7133377371900945`*^9}, {
  3.713346779309186*^9, 
  3.7133467896627607`*^9}},ExpressionUUID->"e7e3e96d-4479-407d-a291-\
9b382cfd5978"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubsuperscriptBox["c", "A", "\<\"p\"\>"]}], 
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983591213*^9, 3.7133412908865705`*^9, 3.7133463679993057`*^9, 
   3.7133468372967997`*^9, 3.7133470104321437`*^9, 3.713347133318866*^9, 
   3.7133474341318417`*^9, 3.713347563216889*^9, 3.7133486230145664`*^9, 
   3.713349913336506*^9, 3.7133503650976653`*^9, 3.7133529554455895`*^9, 
   3.7133530704981885`*^9, 3.713353143541258*^9, 3.7133532882417445`*^9, 
   3.7133548786898108`*^9, 3.7133612297165565`*^9, 3.7133615254866233`*^9, 
   3.71336536020774*^9, 3.7133691889053907`*^9, 3.71342437029856*^9, 
   3.713426134984269*^9, 3.713456368881709*^9, 3.713464437927006*^9, 
   3.7134840903485603`*^9, 3.71351213075826*^9, 3.7135177290443153`*^9, 
   3.7135997748260713`*^9, 3.7136022112741337`*^9, 3.7136028004718513`*^9, 
   3.713781574483961*^9, 3.713781860032219*^9, 3.7137868145940685`*^9, 
   3.713892276558601*^9, 3.713910409774522*^9, 3.713910665916668*^9, 
   3.714070838330493*^9, 3.714070877111126*^9, 3.7140709216484385`*^9, 
   3.7140710783879595`*^9, 3.7141279024299946`*^9, 3.7141362908004913`*^9, 
   3.7141427820119543`*^9, 3.7142100929733686`*^9, 3.714210990822668*^9, {
   3.714216052209485*^9, 3.714216074627243*^9}, 3.7142405836637473`*^9, 
   3.7143401642595387`*^9},ExpressionUUID->"44b02008-dd7c-45f3-b89b-\
3c9907f8358d"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: Outline the Problem", "Section",
 CellChangeTimes->{{3.7069647139816885`*^9, 3.7069647369114227`*^9}, 
   3.7069738098215046`*^9},ExpressionUUID->"9e9c8c5b-b58a-4eb6-9f88-\
3f643224d316"],

Cell["\<\
In this step, we will define various methods for estimating the properties of \
the system.\
\>", "Text",
 CellChangeTimes->{{3.6096062170410075`*^9, 3.609606264631626*^9}, {
  3.706975529035071*^9, 
  3.7069755450306263`*^9}},ExpressionUUID->"25693e43-9eda-4deb-a8a5-\
1d22fcc3d605"],

Cell[CellGroupData[{

Cell["Flow Rate Estimates", "Subsection",
 CellChangeTimes->{{3.7069719669644384`*^9, 
  3.70697197321463*^9}},ExpressionUUID->"3f57054f-f44a-463a-a0f6-\
afae06c30d41"],

Cell[CellGroupData[{

Cell["Zone Velocities", "Subsubsection",
 CellChangeTimes->{{3.7069770657438345`*^9, 
  3.7069770704278774`*^9}},ExpressionUUID->"4cb4e64a-e65d-41fd-8ad6-\
97a54bff7cd5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealZoneVelocityEstimates", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Phi]", "*", "#"}]}], ")"}]}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], "}"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7069792305863423`*^9, 3.7069794058816357`*^9}, {
  3.71333893281275*^9, 3.713338960678429*^9}, {3.713464276128871*^9, 
  3.713464298999878*^9}, {3.713599759741339*^9, 
  3.7135997647049875`*^9}},ExpressionUUID->"ea527e96-ed5e-4e86-85ba-\
5f62eb672d82"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836062136`*^9, 3.713341290901271*^9, 3.7133463680133047`*^9, 
   3.713346837326803*^9, 3.7133470104455504`*^9, 3.7133471333368664`*^9, 
   3.713347434149845*^9, 3.713347563241888*^9, 3.713348623027567*^9, 
   3.7133499133615103`*^9, 3.7133503651146555`*^9, 3.71335295546359*^9, 
   3.713353070547192*^9, 3.7133531435592575`*^9, 3.713353288266747*^9, 
   3.713354878704811*^9, 3.7133612297165565`*^9, 3.7133615255183153`*^9, 
   3.713365360223386*^9, 3.7133691889198914`*^9, 3.7134243703105583`*^9, 
   3.713426134984269*^9, 3.713456368892206*^9, 3.713464299832625*^9, 
   3.713464437947006*^9, 3.7134840903685617`*^9, 3.7135121307657585`*^9, 
   3.713517729052318*^9, 3.7135997748470726`*^9, 3.7136022112895536`*^9, 
   3.71360280048485*^9, 3.7137815744995904`*^9, 3.713781860063439*^9, 
   3.7137868146253214`*^9, 3.713892276605514*^9, 3.713910409805773*^9, 
   3.713910665932288*^9, 3.714071106279114*^9, 3.7140711479157944`*^9, 
   3.714127902492501*^9, 3.7141362908160925`*^9, 3.7141427820432076`*^9, 
   3.714210092985369*^9, 3.71421099083767*^9, {3.714216052233485*^9, 
   3.714216074644742*^9}, 3.7142405836732483`*^9, 
   3.714340164279539*^9},ExpressionUUID->"29d0dfc0-d8f1-4930-b05f-\
401f29f2e778"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonIdealZoneVelocityEstimates", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], 
        SubsuperscriptBox["L", "z", "\"\<I\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<I\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<I\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], 
        SubsuperscriptBox["L", "z", "\"\<II\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<II\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<II\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}]}], ")"}], "v"}],
       "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], 
        SubsuperscriptBox["L", "z", "\"\<III\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<III\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<III\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}]}], ")"}], "v"}], 
      "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], 
        SubsuperscriptBox["L", "z", "\"\<IV\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<IV\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<IV\>\""]]}], ")"}]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7069719796706057`*^9, 3.706972129718485*^9}, {
   3.7069755736149435`*^9, 3.7069756677550144`*^9}, {3.7069757049829063`*^9, 
   3.706975719680606*^9}, {3.7069758023276405`*^9, 3.7069758603763356`*^9}, {
   3.7069770519615784`*^9, 3.7069770548532476`*^9}, {3.7069776256388144`*^9, 
   3.7069776324148607`*^9}, 3.7069794091133423`*^9, {3.7133389328242493`*^9, 
   3.71333896063593*^9}, {3.7134641850843487`*^9, 3.7134641898369284`*^9}, {
   3.7135150193606396`*^9, 
   3.713515039846447*^9}},ExpressionUUID->"3f03ee58-df7c-424b-8f11-\
6bde28dfa428"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"I\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"I\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"II\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"III\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"III\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"IV\"\>"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836237135`*^9, 3.7133412909222713`*^9, 3.713346368028304*^9, 
   3.7133468373598824`*^9, 3.71334701046255*^9, 3.713347133356865*^9, 
   3.713347434170845*^9, 3.713347563265889*^9, 3.7133486230415664`*^9, 
   3.7133499133835135`*^9, 3.713350365134656*^9, 3.713352955482589*^9, 
   3.7133530705941944`*^9, 3.713353143579759*^9, 3.7133532882947474`*^9, 
   3.713354878723811*^9, 3.713361229747815*^9, 3.713361525549582*^9, 
   3.713365360239012*^9, 3.7133691889383917`*^9, 3.713424370326559*^9, 
   3.7134261350467677`*^9, 3.7134563689071884`*^9, 3.7134644379570074`*^9, 
   3.713484090389064*^9, 3.7135121308012624`*^9, 3.713515041015314*^9, 
   3.713517729134323*^9, 3.713599774872072*^9, 3.713602211303052*^9, 
   3.713602800497851*^9, 3.7137815745464697`*^9, 3.713781860157235*^9, 
   3.713786814703457*^9, 3.7138922766836123`*^9, 3.7139104098370237`*^9, 
   3.713910665963541*^9, 3.7140711116390333`*^9, 3.714071148181464*^9, 
   3.714127902601855*^9, 3.714136290847344*^9, 3.7141427820648713`*^9, 
   3.714210093004371*^9, 3.71421099085367*^9, {3.714216052260485*^9, 
   3.714216074661741*^9}, 3.7142405836872425`*^9, 
   3.7143401643015385`*^9},ExpressionUUID->"22fd5221-d858-43a2-a313-\
614063cce5b6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Zone Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.7069770783616886`*^9, 
  3.706977081577528*^9}},ExpressionUUID->"efc1051f-e27b-42d7-ba3f-\
61b59ccfa12f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoneFlowEstimates", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solve", "[", "interstitialVelocity", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7069770846770887`*^9, 3.7069771929902897`*^9}, {
  3.7133375715885506`*^9, 3.7133376107891293`*^9}, {3.7134647090697107`*^9, 
  3.7134647269088154`*^9}},ExpressionUUID->"b2ac3c2b-b560-49eb-b046-\
24b3575b96c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"III\"\>"]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836402135`*^9, 3.713341290942277*^9, 3.7133463680443087`*^9, 
   3.713346837395882*^9, 3.71334701047955*^9, 3.7133471333738656`*^9, 
   3.713347434188848*^9, 3.713347563286434*^9, 3.7133486230570717`*^9, 
   3.713349913405513*^9, 3.7133503651560116`*^9, 3.71335295550159*^9, 
   3.713353070645199*^9, 3.7133531435992637`*^9, 3.7133532883227468`*^9, 
   3.7133548787398167`*^9, 3.713361229763438*^9, 3.7133615256026726`*^9, 
   3.713365360239012*^9, 3.71336918895691*^9, 3.7134243703445597`*^9, 
   3.713426135062393*^9, 3.7134563689216905`*^9, 3.7134644379866085`*^9, 
   3.7134647347843623`*^9, 3.7134840904190683`*^9, 3.7135121308617682`*^9, 
   3.7135177292113266`*^9, 3.7135997749535713`*^9, 3.7136022113750515`*^9, 
   3.713602800558462*^9, 3.7137815749527636`*^9, 3.713781860282242*^9, 
   3.7137868149691415`*^9, 3.71389199635073*^9, 3.7138922767929935`*^9, 
   3.7139104098839035`*^9, 3.71391066599482*^9, 3.714071117041346*^9, 
   3.7140711483221164`*^9, 3.7141279026799917`*^9, 3.7141362908785973`*^9, 
   3.7141427820963993`*^9, 3.7142100930583725`*^9, 3.714210990887669*^9, {
   3.7142160522854853`*^9, 3.714216074698242*^9}, 3.7142405837112474`*^9, 
   3.7143401643495417`*^9},ExpressionUUID->"f833cd66-8139-4b1b-a3a3-\
47771cbf1c71"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Port Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.706977332184824*^9, 
  3.7069773361137943`*^9}},ExpressionUUID->"ece71722-2305-40b5-b4dd-\
66cf29db7a34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"portFlowEstimates", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\"\<R\>\""], "\[Rule]", 
       RowBox[{
        SuperscriptBox["f", "\"\<III\>\""], "-", 
        SuperscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox["f", "\"\<D\>\""], "\[Rule]", 
       RowBox[{
        SuperscriptBox["f", "\"\<I\>\""], "-", 
        SuperscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox["f", "\"\<E\>\""], "\[Rule]", " ", 
       RowBox[{
        SuperscriptBox["f", "\"\<I\>\""], "-", 
        SuperscriptBox["f", "\"\<II\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox["f", "\"\<Recycle\>\""], "\[Rule]", 
       SuperscriptBox["f", "\"\<IV\>\""]}]}], "\[IndentingNewLine]", "}"}], "/.",
     "zoneFlowEstimates"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069773390874557`*^9, 3.706977475818272*^9}, {
   3.7133375716075497`*^9, 3.7133376718854723`*^9}, {3.7133503118874207`*^9, 
   3.713350314812169*^9}, {3.7133532725214005`*^9, 3.713353277157241*^9}, {
   3.713437409029659*^9, 3.713437421289695*^9}, 3.7134374518333993`*^9, {
   3.7138920104960513`*^9, 
   3.713892079006179*^9}},ExpressionUUID->"0ff060bd-4025-463a-b361-\
f945943e4034"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"D\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["f", "\<\"Recycle\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836552143`*^9, 3.713341290966863*^9, 3.7133463680580635`*^9, 
   3.7133468374263854`*^9, 3.7133470104935503`*^9, 3.713347133389372*^9, 
   3.7133474342068453`*^9, 3.7133475633084345`*^9, 3.7133486230695705`*^9, 
   3.7133499134265137`*^9, 3.7133503186302757`*^9, 3.713350365179014*^9, 
   3.713352955521597*^9, 3.713353070690838*^9, 3.7133531436192665`*^9, {
   3.7133532788367634`*^9, 3.7133532883594723`*^9}, 3.713354878756819*^9, 
   3.713361229763438*^9, 3.713361525643771*^9, 3.713365360262143*^9, 
   3.7133691889733906`*^9, 3.713424370358559*^9, 3.713426135062393*^9, 
   3.7134374550263414`*^9, 3.713456368933689*^9, 3.7134644379966087`*^9, 
   3.71348409043907*^9, 3.7135121309002714`*^9, 3.7135177292223244`*^9, 
   3.713599774969572*^9, 3.713602211388939*^9, 3.713602800574462*^9, 
   3.7137815749996824`*^9, 3.7137818602978687`*^9, 3.7137868150003633`*^9, 
   3.7138920847097864`*^9, 3.7138922768555336`*^9, 3.7139104098995295`*^9, 
   3.71391066601042*^9, {3.7140711214014215`*^9, 3.714071148353326*^9}, 
   3.7141279026956472`*^9, 3.7141362908942337`*^9, 3.7141427821276517`*^9, 
   3.7142100930773706`*^9, 3.7142109909096675`*^9, {3.7142160523194876`*^9, 
   3.714216074719242*^9}, 3.7142405837232466`*^9, 
   3.7143401643655386`*^9},ExpressionUUID->"2f80b2b4-9645-489b-9ad5-\
e733d50f5043"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Concentration Estimates", "Subsection",
 CellChangeTimes->{{3.706971482093981*^9, 
  3.7069714862699366`*^9}},ExpressionUUID->"702530e4-951a-4233-8881-\
dc06ab623b6e"],

Cell[CellGroupData[{

Cell["Peak Concentration Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732610853033`*^9, 3.7069732687194195`*^9}, {
  3.713464355467513*^9, 
  3.7134643582089806`*^9}},ExpressionUUID->"aa84a6f6-f8bc-48b8-ad42-\
40a49bc1bf43"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakEstimate", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
       SubscriptBox["A", "-"]}], ",", 
      RowBox[{
       SubsuperscriptBox["c", "B", "\"\<p\>\""], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["A", "+"]}], "/", 
        SubscriptBox["\[Gamma]", "+"]}]}]}], "}"}], "/.", "\[Gamma]Values"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.70697149536306*^9, 3.7069715103032227`*^9}, {
  3.706971806165899*^9, 3.7069718106218185`*^9}, {3.7069737726575537`*^9, 
  3.706973778562495*^9}, {3.7133377288449097`*^9, 3.7133377371980944`*^9}, {
  3.7133467663097467`*^9, 
  3.7133467685329013`*^9}},ExpressionUUID->"cd9f0de9-940e-4427-9900-\
8a9b25de4279"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983767215*^9, 3.7133412911132517`*^9, 3.7133463681673126`*^9, 
   3.7133468375432997`*^9, 3.7133470105991797`*^9, 3.71334713350038*^9, 
   3.7133474343323584`*^9, 3.7133475634426208`*^9, 3.713348623175728*^9, 
   3.7133499135865283`*^9, 3.7133503653590574`*^9, 3.7133529556796036`*^9, 
   3.7133530707993493`*^9, 3.7133531437767825`*^9, 3.7133532885219774`*^9, 
   3.713354878935832*^9, 3.7133612299327574`*^9, 3.713361525803044*^9, 
   3.7133653604284115`*^9, 3.713369189144891*^9, 3.7134243705245595`*^9, 
   3.7134261352186437`*^9, 3.713456369101683*^9, 3.713464438156639*^9, 
   3.713484090449069*^9, 3.7135121310692844`*^9, 3.713517729382341*^9, 
   3.713599775132071*^9, 3.713602211555439*^9, 3.7136028007319746`*^9, 
   3.7137815752340717`*^9, 3.713781860547865*^9, 3.71378681575751*^9, 
   3.7138922776055875`*^9, 3.7139104099307833`*^9, 3.7139106660416965`*^9, {
   3.714071125870655*^9, 3.714071148384617*^9}, 3.7141279029143877`*^9, 
   3.7141362910661154`*^9, 3.7141427823122635`*^9, 3.7142100932373724`*^9, 
   3.7142109910726705`*^9, {3.714216052487486*^9, 3.7142160748932447`*^9}, 
   3.714240583886223*^9, 
   3.71434016453054*^9},ExpressionUUID->"9d74f151-549a-4da8-80a7-\
64387f199965"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakMassBalance", "=", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<F\>\""], 
     SuperscriptBox["f", "\"\<F\>\""], 
     SubscriptBox["y", "target"]}], 
    SuperscriptBox["f", "\"\<R\>\""]]}]}]], "Input",
 CellChangeTimes->{{3.706980478613745*^9, 3.706980536647952*^9}, 
   3.713337473759631*^9, {3.713337625817992*^9, 3.713337638056546*^9}, 
   3.7133377372050953`*^9, {3.713338095272827*^9, 3.7133381193241405`*^9}, {
   3.713346760373721*^9, 3.713346764013403*^9}, {3.7138921038316216`*^9, 
   3.713892111535434*^9}},ExpressionUUID->"1223263f-b3e2-46be-baef-\
cf9e9d0babc9"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
    SubscriptBox["y", "target"], " ", 
    SuperscriptBox["f", "\<\"F\"\>"]}], 
   SuperscriptBox["f", "\<\"R\"\>"]]}]], "Output",
 CellChangeTimes->{
  3.7133389837827144`*^9, 3.713341291129759*^9, 3.7133463681833134`*^9, 
   3.7133468375783*^9, 3.713347010614182*^9, 3.7133471335173864`*^9, 
   3.713347434345862*^9, 3.713347563460621*^9, 3.713348623189728*^9, 
   3.713349913603529*^9, 3.7133503268429627`*^9, 3.713350365377056*^9, 
   3.7133529556986027`*^9, 3.7133530708433557`*^9, 3.7133531437942853`*^9, 
   3.7133532885486794`*^9, 3.713354878958838*^9, 3.7133612299327574`*^9, 
   3.713361525834278*^9, 3.7133653604440393`*^9, 3.713369189159889*^9, 
   3.713424370536559*^9, 3.713426135234269*^9, 3.713456369112187*^9, 
   3.7134644381711445`*^9, 3.7134840904590673`*^9, 3.713512131078806*^9, 
   3.713517729393342*^9, 3.713599775143571*^9, 3.713602211571439*^9, 
   3.713602800746479*^9, 3.7137815752653265`*^9, 3.713781860563492*^9, 
   3.7137868158981504`*^9, 3.7138921128168535`*^9, 3.7138922777306285`*^9, 
   3.71391040994641*^9, 3.713910666057326*^9, {3.7140711322931976`*^9, 
   3.714071148431497*^9}, 3.7141279029143877`*^9, 3.714136291081766*^9, 
   3.7141427823278894`*^9, 3.714210093249369*^9, 3.7142109910866675`*^9, {
   3.714216052498987*^9, 3.714216074908742*^9}, 3.714240583896222*^9, 
   3.714340164544541*^9},ExpressionUUID->"2dbd8184-fe46-4358-9d35-\
634c78d381d2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dilution Concentration Estimates", "Subsubsection",
 CellChangeTimes->{{3.7134643667021017`*^9, 
  3.7134643724749856`*^9}},ExpressionUUID->"1b7895bc-fefa-4e19-91bd-\
fede14a08058"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"denominator", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "A"], 
     SubscriptBox["a", "B"], 
     SubscriptBox["b", "A"], 
     SubscriptBox["b", "B"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Gamma]", "+"], "+", 
       SubscriptBox["\[Gamma]", "-"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "A"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "B"], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "B"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "A"], "2"], 
     SubscriptBox["\[Gamma]", "+"], 
     SubscriptBox["\[Gamma]", "-"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"dilutionEstimate", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubscriptBox["\[Gamma]", "+"], 
       SubscriptBox["\[Gamma]", "-"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}]}], "denominator"]}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], "-", 
         SubscriptBox["a", "A"]}], ")"}]}], "denominator"]}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.706973784342924*^9, 3.706973790586589*^9}, {
  3.71333753325161*^9, 3.7133375442343445`*^9}, {3.7133471532918425`*^9, 
  3.7133471585992737`*^9}},ExpressionUUID->"f162b629-47dc-4cf2-ab01-\
b0ceb7995b10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["\[Gamma]", "-"], " ", 
      SubscriptBox["\[Gamma]", "+"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["b", "B"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983796213*^9, 3.71334129114583*^9, 3.7133463681993136`*^9, 
   3.713346837604298*^9, 3.713347010630187*^9, {3.7133471335343847`*^9, 
   3.713347162734724*^9}, 3.7133474343608613`*^9, 3.713347563482626*^9, 
   3.713348623203147*^9, 3.713349913619529*^9, 3.7133503653940573`*^9, 
   3.7133529557181067`*^9, 3.7133530708849783`*^9, 3.7133531438122854`*^9, 
   3.7133532885756793`*^9, 3.713354878976839*^9, 3.713361229948386*^9, 
   3.713361525865541*^9, 3.7133653604646673`*^9, 3.7133691891768885`*^9, 
   3.7134243705465593`*^9, 3.713426135249895*^9, 3.7134563691241827`*^9, 
   3.7134644381766453`*^9, 3.7134840904690685`*^9, 3.7135121310878057`*^9, 
   3.7135177294043417`*^9, 3.7135997751560717`*^9, 3.713602211584939*^9, 
   3.713602800759982*^9, 3.7137815752653265`*^9, 3.713781860579151*^9, 
   3.7137868159294043`*^9, 3.71389227777748*^9, 3.713910409962036*^9, 
   3.713910666072961*^9, {3.7140711367583404`*^9, 3.7140711484783792`*^9}, 
   3.714127902930025*^9, 3.7141362910973716`*^9, 3.71414278236416*^9, 
   3.7142100932633715`*^9, 3.7142109911016674`*^9, {3.714216052523988*^9, 
   3.714216074925243*^9}, 3.7142405839072227`*^9, 
   3.7143401645595403`*^9},ExpressionUUID->"ab75ac79-e28d-42d7-8a99-\
89d2e6736488"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massBalanceEstimate", "=", 
  RowBox[{"{", 
   RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7006907256001806`*^9, 3.700690730979576*^9}, {
   3.7006918848119802`*^9, 3.7006918993014727`*^9}, {3.700692033459654*^9, 
   3.700692084148734*^9}, {3.7006923383643527`*^9, 3.7006923478520517`*^9}, {
   3.70069307842813*^9, 3.7006930822753067`*^9}, {3.700693129332734*^9, 
   3.7006931980636635`*^9}, 3.70092776998028*^9, {3.700928547745931*^9, 
   3.700928555745161*^9}, 3.70697379573298*^9, {3.7069767726165147`*^9, 
   3.70697679668966*^9}, 3.7133374737816315`*^9, 3.713337638077546*^9, 
   3.713337737213095*^9, {3.713346757441712*^9, 3.7133467576987457`*^9}, {
   3.713349463384637*^9, 3.713349494322274*^9}, {3.71335014013033*^9, 
   3.713350147662957*^9}, {3.713350180925575*^9, 
   3.7133502508118877`*^9}},ExpressionUUID->"4e2778d3-4949-4779-8e6f-\
3aaa12f392fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
     SubscriptBox["y", "target"], " ", 
     SuperscriptBox["f", "\<\"F\"\>"]}], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.713338983813713*^9, 3.71334129116083*^9, 3.7133463682143135`*^9, 
   3.713346837630303*^9, 3.713347010644226*^9, 3.713347133551385*^9, 
   3.7133474343738623`*^9, 3.7133475634996524`*^9, 3.7133486232157273`*^9, 
   3.713349466311381*^9, 3.7133494986520433`*^9, 3.713349913636529*^9, {
   3.7133502099667983`*^9, 3.7133502584217834`*^9}, 3.7133503280318165`*^9, 
   3.7133503654100575`*^9, 3.7133529557365217`*^9, 3.713353070931978*^9, 
   3.7133531438292856`*^9, 3.71335328860168*^9, 3.7133548789938374`*^9, 
   3.713361229948386*^9, 3.713361525918488*^9, 3.7133653604661684`*^9, 
   3.713369189191889*^9, 3.7134243705565586`*^9, 3.713426135249895*^9, 
   3.713456369134182*^9, 3.713464438187146*^9, 3.713484090493573*^9, 
   3.713512131095806*^9, 3.7135177294133415`*^9, 3.7135997751665716`*^9, 
   3.7136022115994387`*^9, 3.7136028007739816`*^9, 3.7137815752809234`*^9, 
   3.7137818606104107`*^9, 3.713786815976281*^9, 3.7138921201690435`*^9, 
   3.713892277824361*^9, 3.713910409993303*^9, 3.713910666088554*^9, {
   3.714071139836792*^9, 3.714071148509633*^9}, 3.7141279029456387`*^9, 
   3.7141362910973716`*^9, 3.714142782380836*^9, 3.714210093276372*^9, 
   3.714210991115668*^9, {3.7142160525474854`*^9, 3.714216074940241*^9}, 
   3.7142405839167213`*^9, 
   3.714340164574541*^9},ExpressionUUID->"e018d3c8-2c66-464c-a540-\
38caa8b517d6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Secondary Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732730436907`*^9, 
  3.706973285566949*^9}},ExpressionUUID->"ae943de9-91c8-4cc7-b22b-\
4dec37bd90be"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"secondaryEstimates", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"First", "@", 
     RowBox[{"Solve", "[", 
      RowBox[{"#", ",", 
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", "1"}], "]"}], "]"}]}], "]"}]}], "&"}], "@", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<R\>\""], "==", 
      FractionBox[
       RowBox[{
        SuperscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
        SubscriptBox["y", "target"]}], 
       SuperscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<E\>\""], "==", 
      FractionBox[
       RowBox[{
        SuperscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["y", "target"]}], ")"}]}], 
       SuperscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s*\>\""], "==", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\"\<III\>\""], 
         SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "-", 
        RowBox[{
         SuperscriptBox["f", "\"\<F\>\""], " ", 
         SubsuperscriptBox["c", "A", "\"\<F\>\""]}]}], 
       SuperscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<IV\>\""], "==", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["u", "0", "\"\<I\>\""], 
        SubsuperscriptBox["c", "A", "\"\<E\>\""]}], 
       SubsuperscriptBox["u", "0", "\"\<IV\>\""]]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<R\>\""], "==", 
      FractionBox[
       RowBox[{
        SuperscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["y", "target"]}], ")"}]}], 
       SuperscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<E\>\""], "==", 
      FractionBox[
       RowBox[{
        SuperscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
        SubscriptBox["y", "target"]}], 
       SuperscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s*\>\""], "==", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\"\<III\>\""], 
         SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "-", 
        RowBox[{
         SuperscriptBox["f", "\"\<F\>\""], "*", 
         SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], 
       SuperscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<I\>\""], "==", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
        SubsuperscriptBox["c", "B", "\"\<R\>\""]}], 
       SubsuperscriptBox["u", "0", "\"\<I\>\""]]}]}], 
    "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secondaryEstimatesFunction", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQrbPyyLTaea8dWQoqpoPoY9LH3eqBdIff82AQvUmI
YzuIFqiyvgGiu9RsXoPoA8f73oBoK85J7AtXvXYUia8QBNFsG1eIg2gdlSQ5
EG310EoZRPcJfVED0dftXKNBdMrzVwkgmiNn0ZSlQDphwezpIFo5wm8fiF4l
eWk/iBYvTPPcCKSDdxeD6Vk8+w+A6Cnc/IdAtIhz+jEQLSS4DUzvuijJcx9I
l7RogmmFT3ZP1q9+7fjovednEP3J4OipHUD6xiaR0yCa89vq1yC66//9NyBa
aR6Piuqa147tNiwaIPpP8AUbEN2ostMeRAMAqgWjIw==
  "],ExpressionUUID->"92b66054-8898-449e-9a50-db6bfdd508cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"R\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     SuperscriptBox["f", "\<\"R\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SuperscriptBox["f", "\<\"F\"\>"]}], 
      SuperscriptBox["f", "\<\"E\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s*\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
        SuperscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
        SuperscriptBox["f", "\<\"III\"\>"]}]}], 
      SuperscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SuperscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
      RowBox[{
       SuperscriptBox["f", "\<\"E\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SuperscriptBox["f", "\<\"F\"\>"]}], 
      SuperscriptBox["f", "\<\"R\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"E\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     SuperscriptBox["f", "\<\"E\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s*\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
        SuperscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
        SuperscriptBox["f", "\<\"III\"\>"]}]}], 
      SuperscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SuperscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
      RowBox[{
       SuperscriptBox["f", "\<\"R\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7139106661198096`*^9, 3.714071148556511*^9, 3.714127903023811*^9, 
   3.7141322888354535`*^9, 3.7141324792389865`*^9, 3.714136291144252*^9, 
   3.7141427823964634`*^9, 3.714210093292369*^9, 3.7142109911276703`*^9, {
   3.714216052570985*^9, 3.714216074958242*^9}, 3.714240583929721*^9, 
   3.71434016461654*^9},ExpressionUUID->"472ecba8-d884-4e45-a46e-\
2f3287113a88"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Superficial Velocity Estimates", "Subsection",
 CellChangeTimes->{{3.706972981877504*^9, 
  3.706972989294876*^9}},ExpressionUUID->"334fb650-13c7-484b-a2e3-\
70aac1e918ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonidealVelocityEstimate", "=", 
  RowBox[{"v", "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"K", " ", 
      SubscriptBox["L", "z"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], "+", 
        SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "-", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], ")"}], 
            "2"], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
                SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], "+", 
               RowBox[{
                SuperscriptBox[
                 SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
                SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}]}], ")"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["f", "\"\<F\>\""], "*", 
                SubscriptBox["L", "z"]}], "+", 
               RowBox[{"E", "*", 
                SubscriptBox["A", "c"], "*", 
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], "+", 
                  SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}], ")"}], 
                "*", 
                SubscriptBox["\[Epsilon]", "b"]}]}], ")"}]}], 
            RowBox[{"K", "*", 
             SuperscriptBox[
              SubscriptBox["L", "z"], "2"], " ", "*", "\[Phi]", "*", 
             SubscriptBox["A", "c"], "*", 
             SubscriptBox["\[Epsilon]", "b"]}]]}], ")"}]}]}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
         SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], "+", 
        RowBox[{
         SuperscriptBox[
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
         SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}]}], ")"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7069721727465696`*^9, 3.7069722269069753`*^9}, {
   3.706972267155734*^9, 3.7069723204820533`*^9}, {3.706976369157633*^9, 
   3.706976375884715*^9}, {3.7069791087554893`*^9, 3.7069791250947285`*^9}, {
   3.7069794238777647`*^9, 3.7069794242312737`*^9}, {3.706979461174863*^9, 
   3.7069794848329644`*^9}, 3.713337638018546*^9, {3.713338932854249*^9, 
   3.71333896065143*^9}},ExpressionUUID->"423b354a-0ad8-40ab-a904-\
77f2171ea3e9"],

Cell[BoxData[
 RowBox[{"v", "\[Rule]", 
  FractionBox[
   RowBox[{"K", " ", 
    SubscriptBox["L", "z"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], "+", 
      SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}], "2"], 
        "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["f", "\<\"F\"\>"], " ", 
             SubscriptBox["L", "z"]}], "+", 
            RowBox[{
             SubscriptBox["A", "c"], " ", "\[ExponentialE]", " ", 
             SubscriptBox["\[Epsilon]", "b"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "+", 
               SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], 
              "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], 
              "2"]}]}], ")"}]}], 
         RowBox[{
          SubscriptBox["A", "c"], " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["L", "z", "2"]}]]}]]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7133389838472137`*^9, 3.7133412911988297`*^9, 3.7133463682488184`*^9, 
   3.7133468376873083`*^9, 3.7133470106782274`*^9, 3.7133471335898895`*^9, 
   3.7133474344048615`*^9, 3.713347563542653*^9, 3.713348623247727*^9, 
   3.713349913675536*^9, 3.713350365449561*^9, 3.71335295577752*^9, 
   3.7133530710224857`*^9, 3.7133531438697925`*^9, 3.713353288664733*^9, 
   3.713354879028838*^9, 3.7133612299796343`*^9, 3.713361525987032*^9, 
   3.7133653604974203`*^9, 3.713369189229388*^9, 3.713424370601162*^9, 
   3.713426135281143*^9, 3.7134563691736813`*^9, 3.7134644382471485`*^9, 
   3.713484090528735*^9, 3.713512131140806*^9, 3.713517729500351*^9, 
   3.7135997752515717`*^9, 3.7136022116845927`*^9, 3.7136028008099813`*^9, 
   3.713781575593489*^9, 3.71378186075105*^9, 3.713786816163803*^9, 
   3.7138922780431347`*^9, 3.713910410055797*^9, 3.7139106661510596`*^9, 
   3.7140711486033525`*^9, 3.714127903070698*^9, 3.714136291159895*^9, 
   3.714142782443342*^9, 3.7142100933103714`*^9, 3.7142109911466694`*^9, {
   3.714216052600485*^9, 3.7142160749787407`*^9}, 3.714240583944739*^9, 
   3.7143401646365414`*^9},ExpressionUUID->"7122b90e-5774-4a46-a151-\
40122d697a35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonidealVelocityEstimate", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"First", "[", "#", "]"}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", "<", 
         SubscriptBox["\[Epsilon]", "b"], "<", "1"}], "}"}]}]}], "]"}], "&"}],
    "@", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
            SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], 
           RowBox[{
            SubsuperscriptBox["Kf", "A", "\"\<II\>\""], 
            SubsuperscriptBox["L", "z", "\"\<II\>\""]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
            SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}], 
           RowBox[{
            SubsuperscriptBox["Kf", "B", "\"\<III\>\""], 
            SubsuperscriptBox["L", "z", "\"\<III\>\""]}]]}], ")"}], 
        SuperscriptBox["v", "2"]}], "-", 
       RowBox[{"\[Phi]", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "-", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], ")"}], "v"}], 
       "+", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SubscriptBox["f", "\"\<F\>\""], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], 
           SubscriptBox["A", "c"]}]], "+", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{
            SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], 
            SubsuperscriptBox["E", "A", "\"\<II\>\""]}]}], 
          SubsuperscriptBox["L", "z", "\"\<II\>\""]], "+", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{
            SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], 
            SubsuperscriptBox["E", "B", "\"\<III\>\""]}]}], 
          SubsuperscriptBox["L", "z", "\"\<III\>\""]]}], ")"}]}], "\[Equal]", 
      "0"}], ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.713514026309306*^9, 3.7135140334644513`*^9}, {
  3.7135141619521914`*^9, 3.713514177750845*^9}, {3.7135142125830193`*^9, 
  3.713514481852901*^9}, {3.7135146589506416`*^9, 3.713514678937645*^9}, {
  3.713514827116113*^9, 3.7135148289776287`*^9}, {3.7135148985791974`*^9, 
  3.713514900559186*^9}},ExpressionUUID->"16a2dfa5-6317-4e84-bc39-\
506793d0e5b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v", "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
     SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
     SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
     SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], " ", 
        SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], "-", 
       SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "+", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], " ", 
        SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
               SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}], 
             "2"]}], "+", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["f", "\<\"F\"\>"], " ", 
                SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["L", "z", "\<\"III\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["A", "c"], " ", 
                SubscriptBox["\[Epsilon]", "b"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], 
                   " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
                   SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], 
                   " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"]}]}], 
                 ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
                SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], 
                 "2"]}], "+", 
               RowBox[{
                SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], 
                 "2"]}]}], ")"}]}], 
            RowBox[{
             SubscriptBox["A", "c"], " ", 
             SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
             SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["L", "z", "\<\"II\"\>"], ")"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["L", "z", "\<\"III\"\>"], ")"}], "2"]}]]}], 
          ")"}]}]]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
        SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
        SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], 
       "+", 
       RowBox[{
        SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
        SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
        SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}]}], 
      ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.713514472152644*^9, 3.713514483717857*^9}, 
   3.7135146812463875`*^9, 3.7135148304454803`*^9, 3.7135149015156884`*^9, 
   3.7135177301686287`*^9, 3.713599775948571*^9, 3.713602212374093*^9, 
   3.7136028014551144`*^9, 3.713781576718608*^9, 3.713781861626106*^9, 
   3.7137868194454317`*^9, 3.713892281293479*^9, 3.7139104109465303`*^9, 
   3.7139106669167976`*^9, 3.7140711494159393`*^9, 3.714127904102048*^9, 
   3.7141362919256134`*^9, 3.714142783242221*^9, 3.714210093967372*^9, 
   3.714210991808669*^9, {3.714216053209485*^9, 3.71421607565674*^9}, 
   3.7142405846462765`*^9, 
   3.714340165338564*^9},ExpressionUUID->"11cfa52f-cc4d-45ac-924e-\
9773e1e24c14"]
}, Open  ]],

Cell["\<\
The velocity estimate comes from solving the following system of equations\
\>", "Text",
 CellChangeTimes->{{3.713352961258211*^9, 
  3.713352983208372*^9}},ExpressionUUID->"7a7b9e98-19d5-46d5-a8b0-\
b73deb8286bf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<I\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<II\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<III\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], " "}]}]]}], ",", 
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], 
        SubscriptBox["A", "c"], 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\"\<III\>\""], "-", 
          SubsuperscriptBox["u", "0", "\"\<II\>\""]}], ")"}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7133528518942165`*^9, 
  3.713352853603495*^9}},ExpressionUUID->"5ef3935a-610f-4aef-a7b8-\
f9b52bcaccbb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", "\[Rule]", 
     FractionBox[
      SubscriptBox["f", "\<\"F\"\>"], 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}], ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}]}],
    "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.713352784695923*^9, 3.713352854211293*^9, 3.713352955846099*^9, 
   3.713353071059018*^9, 3.713353143891296*^9, 3.7133532887017336`*^9, 
   3.713354879072847*^9, 3.713361230017376*^9, 3.713361526033969*^9, 
   3.7133653605286913`*^9, 3.7133691892633896`*^9, 3.713424370632413*^9, 
   3.7134261353436427`*^9, 3.7134563692251806`*^9, 3.713464438287161*^9, 
   3.713484090639249*^9, 3.7135121311743126`*^9, 3.7135177302726374`*^9, 
   3.7135997760755725`*^9, 3.7136022124910936`*^9, 3.713602801527116*^9, 
   3.7137815768435907`*^9, 3.7137818617354965`*^9, 3.71378681978918*^9, 
   3.7138922815122814`*^9, 3.713910411087202*^9, 3.713910666979274*^9, 
   3.7140711495253263`*^9, 3.714127904242669*^9, 3.7141362920037165`*^9, 
   3.7141427833097687`*^9, 3.71421009404937*^9, 3.71421099186567*^9, {
   3.7142160532869873`*^9, 3.714216075760245*^9}, 3.7142405847014236`*^9, 
   3.714340165414568*^9},ExpressionUUID->"7df56a02-5041-44c3-b8c5-\
4fd3380eea7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealVelocityEstimate", "=", 
  RowBox[{"v", "\[Rule]", 
   FractionBox[
    SuperscriptBox["f", "\"\<F\>\""], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "-", 
       SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], 
      ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.706979114270035*^9, 3.7069791332719812`*^9}, {
   3.7069794355664086`*^9, 3.706979457693653*^9}, {3.7069795106918306`*^9, 
   3.7069795210761013`*^9}, 3.7133376380365467`*^9, {3.713338932875249*^9, 
   3.71333896066593*^9}, 3.713352801180873*^9, {3.7140723870087204`*^9, 
   3.7140723918841653`*^9}},ExpressionUUID->"20ffdedd-916a-4641-972f-\
751dd48135a3"],

Cell[BoxData[
 RowBox[{"v", "\[Rule]", 
  FractionBox[
   SuperscriptBox["f", "\<\"F\"\>"], 
   RowBox[{
    SubscriptBox["A", "c"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
      SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7133389838617134`*^9, 3.713341291215831*^9, 3.713346368264715*^9, 
   3.713346837696307*^9, 3.713347010694228*^9, 3.713347133608917*^9, 
   3.713347434417862*^9, 3.713347563564652*^9, 3.713348623261731*^9, 
   3.7133499136925364`*^9, 3.713350365467063*^9, 3.7133528034327435`*^9, 
   3.713352955871101*^9, 3.7133530710930166`*^9, 3.713353143914296*^9, 
   3.7133532887342377`*^9, 3.7133548790948467`*^9, 3.713361230017376*^9, 
   3.71336152606155*^9, 3.7133653605443134`*^9, 3.713369189275406*^9, 
   3.713424370648037*^9, 3.713426135359268*^9, 3.7134563692376795`*^9, 
   3.713464438307163*^9, 3.713484090649249*^9, 3.7135121311813126`*^9, 
   3.713517730285637*^9, 3.7135997760950713`*^9, 3.7136022125090933`*^9, 
   3.713602801542116*^9, 3.7137815768592167`*^9, 3.7137818617667775`*^9, 
   3.7137868198360677`*^9, 3.7138922815747876`*^9, 3.7139104111027837`*^9, 
   3.713910667010527*^9, 3.714071149540989*^9, {3.7140723951657133`*^9, 
   3.714072397525331*^9}, 3.71412790430516*^9, 3.7141362920037165`*^9, 
   3.7141427833253984`*^9, 3.714210094062372*^9, 3.7142109918796687`*^9, {
   3.7142160532984877`*^9, 3.714216075776743*^9}, 3.7142405847104244`*^9, 
   3.7143401654465647`*^9},ExpressionUUID->"455ab878-22f2-4052-8c44-\
b75afb2c19ec"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mass Transfer Estimates", "Subsection",
 CellChangeTimes->{{3.7069760065371075`*^9, 
  3.7069760128208933`*^9}},ExpressionUUID->"3000d778-6199-429b-9869-\
cbc7e506cdea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"effectiveDiffusionEstimate", "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["D", "p"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], 
      SubscriptBox["D", "m"]}], 
     SubscriptBox["\[Tau]", "tor"]]}], "/.", 
   RowBox[{
    SubscriptBox["\[Tau]", "tor"], "\[Rule]", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], 
     SubscriptBox["\[Epsilon]", "p"]]}]}]}]], "Input",
 CellChangeTimes->{{3.713345371386857*^9, 
  3.713345451756318*^9}},ExpressionUUID->"2cb472a9-1672-4231-8259-\
2cb459e2813e"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "p"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["D", "m"], " ", 
    SubsuperscriptBox["\[Epsilon]", "p", "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "-", 
      SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{
  3.713345452721058*^9, 3.7133463682797155`*^9, 3.7133468377063084`*^9, 
   3.7133470107112293`*^9, 3.7133471336309185`*^9, 3.713347434430867*^9, 
   3.7133475635918255`*^9, 3.71334862327481*^9, 3.713349913711536*^9, 
   3.713350365488063*^9, 3.713352955894099*^9, 3.7133530711260166`*^9, 
   3.713353143940753*^9, 3.713353288764241*^9, 3.713354879116849*^9, 
   3.713361230033009*^9, 3.7133615261028805`*^9, 3.713365360566428*^9, 
   3.713369189291054*^9, 3.713424370648037*^9, 3.7134261353748937`*^9, 
   3.7134563692496796`*^9, 3.7134644383171597`*^9, 3.7134840906692476`*^9, 
   3.7135121311913133`*^9, 3.713517730299638*^9, 3.713599776113572*^9, 
   3.7136022125295944`*^9, 3.7136028015551214`*^9, 3.713781576874843*^9, 
   3.7137818617980366`*^9, 3.7137868198673205`*^9, 3.713892281621668*^9, 
   3.7139104111184125`*^9, 3.7139106670261836`*^9, 3.714071149556592*^9, 
   3.714127904336442*^9, 3.714136292019375*^9, 3.7141427833475266`*^9, 
   3.714210094077371*^9, 3.7142109918946695`*^9, {3.714216053325986*^9, 
   3.714216075801244*^9}, 3.714240584720909*^9, 
   3.7143401654709673`*^9},ExpressionUUID->"e9726eec-8e5f-4c35-bb08-\
a4e4d64a13bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massTransferEstimate", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[Rule]", 
     FractionBox[
      RowBox[{"15", " ", 
       SubscriptBox["D", "p"], " ", 
       SubscriptBox["\[Epsilon]", "p"]}], 
      SubsuperscriptBox["r", "p", "2"]]}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["Kf", "B", "\"\<I\>\""], ",", 
     SubsuperscriptBox["Kf", "A", "\"\<II\>\""], ",", 
     SubsuperscriptBox["Kf", "B", "\"\<III\>\""], ",", 
     SubsuperscriptBox["Kf", "A", "\"\<IV\>\""]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.706976018369915*^9, 3.706976101145649*^9}, {
  3.70697640799788*^9, 
  3.7069765081339483`*^9}},ExpressionUUID->"e3eddeeb-f947-4383-b0b2-\
cc7916d84459"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983877714*^9, 3.7133412912358384`*^9, 3.713346368298715*^9, 
   3.7133468377368145`*^9, 3.71334701072873*^9, 3.7133471336549177`*^9, 
   3.713347434446871*^9, 3.713347563618825*^9, 3.7133486232928095`*^9, 
   3.7133499137325363`*^9, 3.7133503655120635`*^9, 3.713352955916602*^9, 
   3.713353071159525*^9, 3.7133531439677525`*^9, 3.713353288794241*^9, 
   3.713354879140355*^9, 3.713361230033009*^9, 3.713361526149774*^9, 
   3.71336536058206*^9, 3.713369189306676*^9, 3.713424370663662*^9, 
   3.7134261353748937`*^9, 3.713456369261179*^9, 3.7134644383378134`*^9, 
   3.71348409067925*^9, 3.7135121312013135`*^9, 3.7135177303126373`*^9, 
   3.7135997761305714`*^9, 3.713602212549594*^9, 3.7136028015691266`*^9, 
   3.7137815768904696`*^9, 3.713781861829254*^9, 3.7137868198985996`*^9, 
   3.7138922816842003`*^9, 3.713910411134037*^9, 3.7139106670417833`*^9, 
   3.714071149572235*^9, 3.714127904383294*^9, 3.714136292034995*^9, 
   3.714142783378811*^9, 3.714210094097372*^9, 3.7142109919086695`*^9, {
   3.7142160533594856`*^9, 3.714216075830742*^9}, 3.714240584730906*^9, 
   3.7143401655020056`*^9},ExpressionUUID->"b9456266-146c-4c10-acf4-\
e2ef8e625888"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"filmTransferEstimate", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{"5", 
     SubscriptBox["D", "p"]}], 
    SubscriptBox["r", "p"]]}]}]], "Input",
 CellChangeTimes->{{3.713344709290055*^9, 
  3.7133447510517273`*^9}},ExpressionUUID->"dbf91b15-f4b1-4e9d-b101-\
40d7af190ef6"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"5", " ", 
    SubscriptBox["D", "p"]}], 
   SubscriptBox["r", "p"]]}]], "Output",
 CellChangeTimes->{
  3.7133412912553434`*^9, 3.7133447578410683`*^9, 3.7133463683237143`*^9, 
   3.7133468377453146`*^9, 3.71334701074629*^9, 3.7133471336779184`*^9, 
   3.713347434463872*^9, 3.7133475636418257`*^9, 3.7133486233118114`*^9, 
   3.713349913755044*^9, 3.713350365535112*^9, 3.713352955935169*^9, 
   3.713353071191524*^9, 3.7133531439942594`*^9, 3.7133532888252416`*^9, 
   3.713354879160859*^9, 3.7133612300486317`*^9, 3.7133615261870513`*^9, 
   3.7133653605976863`*^9, 3.713369189322301*^9, 3.7134243706792865`*^9, 
   3.713426135390519*^9, 3.7134563692736773`*^9, 3.7134644383578157`*^9, 
   3.7134840906987543`*^9, 3.7135121312168713`*^9, 3.7135177303276377`*^9, 
   3.7135997761455717`*^9, 3.713602212570093*^9, 3.713602801585125*^9, 
   3.7137815769060965`*^9, 3.7137818618449173`*^9, 3.7137868199454517`*^9, 
   3.7138922817623067`*^9, 3.7139104111496644`*^9, 3.7139106670574074`*^9, 
   3.7140711495878325`*^9, 3.714127904445799*^9, 3.7141362920505953`*^9, 
   3.714142783410036*^9, 3.714210094120372*^9, 3.7142109919256697`*^9, {
   3.714216053389485*^9, 3.714216075856241*^9}, 3.7142405847429085`*^9, 
   3.714340165535005*^9},ExpressionUUID->"063b1fb5-c2ad-4b72-b0d8-\
f1d3e4c899bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wilsonGeankoplis", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["D", "p"], 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubscriptBox["r", "p"]], 
    FractionBox["1.09", 
     SubscriptBox["\[Epsilon]", "b"]], 
    SuperscriptBox[
     SubscriptBox[
      RowBox[{"Pe", "[", "zone", "]"}], "i"], "0.33"]}]}]}]], "Input",
 CellChangeTimes->{{3.713344944575387*^9, 
  3.7133450596717334`*^9}},ExpressionUUID->"b63fdf27-1287-4b97-85bd-\
e56e7ecf58e2"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"1.09`", " ", 
    SubscriptBox["D", "p"], " ", 
    SubscriptBox["\[Epsilon]", "p"], " ", 
    SubsuperscriptBox[
     RowBox[{"Pe", "[", "zone", "]"}], "i", "0.33`"]}], 
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox["\[Epsilon]", "b"]}]]}]], "Output",
 CellChangeTimes->{
  3.7133450740752134`*^9, 3.713346368347719*^9, 3.713346837755316*^9, 
   3.7133470107632885`*^9, 3.713347133700921*^9, 3.7133474344808707`*^9, 
   3.7133475636694684`*^9, 3.7133486233398094`*^9, 3.713349913776181*^9, 
   3.7133503655591145`*^9, 3.71335295595817*^9, 3.713353071223524*^9, 
   3.7133531440222597`*^9, 3.7133532888552494`*^9, 3.7133548791828585`*^9, 
   3.7133612300642567`*^9, 3.7133615262183332`*^9, 3.7133653606133122`*^9, 
   3.7133691893379264`*^9, 3.7134243706792865`*^9, 3.713426135390519*^9, 
   3.713456369285178*^9, 3.713464438374955*^9, 3.7134840907067556`*^9, 
   3.713512131229871*^9, 3.7135177303426423`*^9, 3.7135997761615715`*^9, 
   3.7136022125905943`*^9, 3.713602801603126*^9, 3.713781576921723*^9, 
   3.713781861876171*^9, 3.7137868199767017`*^9, 3.713892281809188*^9, 
   3.71391041116529*^9, 3.7139106670730343`*^9, 3.71407114960347*^9, 
   3.714127904477054*^9, 3.714136292066224*^9, 3.714142783425689*^9, 
   3.7142100941426973`*^9, 3.7142109919456697`*^9, {3.714216053419486*^9, 
   3.7142160758852434`*^9}, 3.7142405847539053`*^9, 
   3.7143401655650053`*^9},ExpressionUUID->"44dc4dad-deb9-4fe8-81b8-\
111e8725b245"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"chungWen", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"E", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{"2", 
     SubscriptBox["r", "p"], " ", 
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     SubscriptBox["\[Epsilon]", "b"]}], 
    RowBox[{"0.2", "+", 
     RowBox[{"0.011", 
      SuperscriptBox[
       RowBox[{"Reynolds", "[", "zone", "]"}], "0.48"]}]}]]}]}]], "Input",
 CellChangeTimes->{{3.71334259224177*^9, 3.7133427202762713`*^9}, {
  3.7133428461904764`*^9, 
  3.7133428480610447`*^9}},ExpressionUUID->"23e1db72-ea57-4658-a51b-\
bc9b2390089f"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"\[ExponentialE]", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["r", "p"], " ", 
    SubscriptBox["\[Epsilon]", "b"], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], 
   RowBox[{"0.2`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.011`", " ", 
     SuperscriptBox[
      RowBox[{"Reynolds", "[", "zone", "]"}], "0.48`"]}]}]]}]], "Output",
 CellChangeTimes->{
  3.7133455123297296`*^9, 3.713346368367256*^9, 3.7133468377643166`*^9, 
   3.713347010781288*^9, 3.713347133721979*^9, 3.7133474344988737`*^9, 
   3.7133475637024746`*^9, 3.7133486233598146`*^9, 3.7133499137971807`*^9, 
   3.713350365584114*^9, 3.7133529559811687`*^9, 3.713353071254533*^9, 
   3.7133531440542574`*^9, 3.7133532888862495`*^9, 3.713354879211859*^9, 
   3.7133612300642567`*^9, 3.7133615262652073`*^9, 3.7133653606133122`*^9, 
   3.7133691893535504`*^9, 3.7134243706949115`*^9, 3.713426135406143*^9, 
   3.7134563692966805`*^9, 3.713464438387462*^9, 3.7134840907256975`*^9, 
   3.7135121312408714`*^9, 3.7135177303546467`*^9, 3.713599776176071*^9, 
   3.713602212610093*^9, 3.7136028016201243`*^9, 3.713781576937357*^9, 
   3.7137818619074173`*^9, 3.713786820007959*^9, 3.713892281871668*^9, 
   3.713910411180917*^9, 3.713910667104306*^9, 3.71407114960347*^9, 
   3.7141279045083265`*^9, 3.714136292066224*^9, 3.7141427834478416`*^9, 
   3.7142100941656947`*^9, 3.7142109919686704`*^9, {3.7142160534499855`*^9, 
   3.7142160759127417`*^9}, 3.7142405847644024`*^9, 
   3.7143401655980077`*^9},ExpressionUUID->"68c42b8a-9452-4cb3-a1e0-\
2bbadc6db71a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimensionless Quantities", "Subsection",
 CellChangeTimes->{{3.7133406818150587`*^9, 
  3.7133406871171308`*^9}},ExpressionUUID->"b5e31ced-f874-4499-a8d6-\
f2915d0ddff3"],

Cell[CellGroupData[{

Cell["Peclet Number", "Subsubsection",
 CellChangeTimes->{{3.713340897251177*^9, 
  3.713340900217434*^9}},ExpressionUUID->"f8d98dc7-32a7-4c09-b55d-\
0c7ffd7d1f22"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peclet", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"Pe", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     SubscriptBox["r", "p"]}], 
    SubscriptBox[
     RowBox[{"E", "[", "zone", "]"}], "i"]]}]}]], "Input",
 CellChangeTimes->{{3.713340911679635*^9, 3.7133409336074166`*^9}, {
  3.7133409641920156`*^9, 3.71334100516239*^9}, {3.713341093955575*^9, 
  3.7133411216715937`*^9}, {3.713345575526943*^9, 
  3.713345607774027*^9}},ExpressionUUID->"a119b786-d9e0-4809-ace9-\
4c8dce609cd2"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"Pe", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], 
   SubscriptBox[
    RowBox[{"\[ExponentialE]", "[", "zone", "]"}], "i"]]}]], "Output",
 CellChangeTimes->{
  3.71334093719689*^9, {3.713341105600179*^9, 3.713341122833452*^9}, 
   3.713341291293342*^9, 3.7133456881473856`*^9, 3.7133463683892565`*^9, 
   3.7133468377753167`*^9, 3.7133470107992887`*^9, 3.713347133744978*^9, 
   3.7133474345148716`*^9, 3.7133475637324734`*^9, 3.713348623379833*^9, 
   3.7133499138191805`*^9, 3.7133503656121144`*^9, 3.7133529560036736`*^9, 
   3.7133530712845325`*^9, 3.713353144080763*^9, 3.7133532889162498`*^9, 
   3.7133548792318583`*^9, 3.7133612300798793`*^9, 3.713361526303136*^9, 
   3.713365360628935*^9, 3.7133691893706636`*^9, 3.7134243706949115`*^9, 
   3.713426135421768*^9, 3.7134563693076773`*^9, 3.713464438402678*^9, 
   3.71348409073678*^9, 3.7135121312528715`*^9, 3.713517730367646*^9, 
   3.7135997761910715`*^9, 3.713602212631093*^9, 3.7136028016371245`*^9, 
   3.713781576952992*^9, 3.713781861938677*^9, 3.7137868200392127`*^9, 
   3.71389228193417*^9, 3.7139104111965427`*^9, 3.713910667119914*^9, 
   3.7140711496191044`*^9, 3.7141279045395927`*^9, 3.714136292081875*^9, 
   3.7141427834791346`*^9, 3.7142100941886945`*^9, 3.7142109919916706`*^9, {
   3.7142160534794855`*^9, 3.714216075943742*^9}, 3.714240584773902*^9, 
   3.7143401656250057`*^9},ExpressionUUID->"88958483-3e4c-4589-928c-\
ae89ad75f909"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Stanton Number", "Subsubsection",
 CellChangeTimes->{{3.713341131935182*^9, 
  3.7133411348525944`*^9}},ExpressionUUID->"8d8dd606-f2e2-422b-b20b-\
646fb8964387"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stanton", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"St", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox["1", 
    RowBox[{
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SubscriptBox["R", "p"], 
        RowBox[{"15", " ", 
         SubscriptBox["\[Epsilon]", "p"], " ", "Dp"}]], "+", 
       FractionBox["1", 
        RowBox[{"3", 
         SubscriptBox[
          RowBox[{"kf", "[", "zone", "]"}], "i"]}]]}], ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.713341144721283*^9, 3.713341213283687*^9}, {
  3.713341251363948*^9, 3.7133412527759175`*^9}, {3.7133413396362753`*^9, 
  3.713341359779224*^9}, {3.71334154323908*^9, 
  3.7133415440023394`*^9}},ExpressionUUID->"bdb7ac9b-ffc0-4f70-85f9-\
e7c2193001f8"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"St", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SubscriptBox["R", "p"], 
       RowBox[{"15", " ", "Dp", " ", 
        SubscriptBox["\[Epsilon]", "p"]}]], "+", 
      FractionBox["1", 
       RowBox[{"3", " ", 
        SubscriptBox[
         RowBox[{"kf", "[", "zone", "]"}], "i"]}]]}], ")"}], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}]]}]], "Output",
 CellChangeTimes->{
  3.7133412172627444`*^9, 3.7133412533418956`*^9, 3.713341291312343*^9, {
   3.7133413463754425`*^9, 3.7133413613973427`*^9}, 3.713341544812383*^9, 
   3.7133463684062557`*^9, 3.713346837788318*^9, 3.713347010817289*^9, 
   3.713347133766979*^9, 3.7133474345323753`*^9, 3.713347563757476*^9, 
   3.7133486234018326`*^9, 3.7133499138431816`*^9, 3.713350365644619*^9, 
   3.7133529560261984`*^9, 3.713353071316532*^9, 3.7133531441057973`*^9, 
   3.713353288946258*^9, 3.7133548792618713`*^9, 3.7133612300798793`*^9, 
   3.713361526334387*^9, 3.71336536064456*^9, 3.713369189375663*^9, 
   3.713424370710538*^9, 3.713426135421768*^9, 3.7134563693206816`*^9, 
   3.7134644384158125`*^9, 3.7134840907567816`*^9, 3.713512131265375*^9, 
   3.7135177303826456`*^9, 3.7135997762065716`*^9, 3.713602212654092*^9, 
   3.7136028016546288`*^9, 3.713781576968604*^9, 3.713781861969897*^9, 
   3.713786820086094*^9, 3.7138922819966803`*^9, 3.713910411212171*^9, 
   3.7139106671355596`*^9, 3.714071149634718*^9, 3.7141279045864773`*^9, 
   3.7141362920975*^9, 3.714142783494723*^9, 3.7142100942161474`*^9, 
   3.7142109920146685`*^9, {3.714216053511485*^9, 3.714216075979241*^9}, 
   3.7142405847854004`*^9, 
   3.7143401656530066`*^9},ExpressionUUID->"50d310a2-d1c7-49f0-920b-\
4b7538408949"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sherwood Number", "Subsubsection",
 CellChangeTimes->{{3.7133415158931227`*^9, 
  3.7133415199855165`*^9}},ExpressionUUID->"0085e4db-b1b1-4a9d-9dfe-\
d6131bdfe6fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sherwood", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"Sh", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      RowBox[{"kf", "[", "zone", "]"}], "i"], " ", 
     SubscriptBox["r", "p"]}], 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", 
     SubscriptBox["D", "p"]}]]}]}]], "Input",
 CellChangeTimes->{{3.7133415226754265`*^9, 3.7133416093960714`*^9}, 
   3.7133417070769014`*^9, {3.7133417990181446`*^9, 3.7133418261415596`*^9}, 
   3.713342412820716*^9},ExpressionUUID->"823285e6-db39-4762-bebd-\
77302b87fb0b"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"Sh", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox[
     RowBox[{"kf", "[", "zone", "]"}], "i"]}], 
   RowBox[{
    SubscriptBox["D", "p"], " ", 
    SubscriptBox["\[Epsilon]", "p"]}]]}]], "Output",
 CellChangeTimes->{
  3.7133418298001804`*^9, 3.7133424137693167`*^9, 3.7133463684242563`*^9, 
   3.713346837800317*^9, 3.7133470108352933`*^9, 3.713347133787983*^9, 
   3.7133474345478783`*^9, 3.713347563777477*^9, 3.7133486234258337`*^9, 
   3.713349913865184*^9, 3.713350365666972*^9, 3.7133529560501986`*^9, 
   3.7133530713335333`*^9, 3.713353144131798*^9, 3.7133532889772577`*^9, 
   3.713354879284872*^9, 3.7133612300955095`*^9, 3.713361526365636*^9, 
   3.713365360666729*^9, 3.7133691893912935`*^9, 3.713424370726162*^9, 
   3.7134261354373927`*^9, 3.7134563693316817`*^9, 3.7134644384258127`*^9, 
   3.7134840907877846`*^9, 3.7135121312763777`*^9, 3.713517730395646*^9, 
   3.713599776221572*^9, 3.7136022126720943`*^9, 3.7136028016701326`*^9, 
   3.71378157698423*^9, 3.713781862001186*^9, 3.7137868201173477`*^9, 
   3.7138922820435886`*^9, 3.7139104112278137`*^9, 3.713910667151167*^9, 
   3.714071149650339*^9, 3.714127904617731*^9, 3.714136292113103*^9, 
   3.714142783526003*^9, 3.7142100942411475`*^9, 3.71421099203867*^9, {
   3.714216053544485*^9, 3.714216076005743*^9}, 3.7142405847954197`*^9, 
   3.714340165682007*^9},ExpressionUUID->"38f0d5d1-c8a5-4a3e-9d5c-\
42f8d34981c7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reynolds Number", "Subsubsection",
 CellChangeTimes->{{3.713342577845748*^9, 
  3.713342580758417*^9}},ExpressionUUID->"b6588551-f796-432a-9463-\
1fa2a88ed1f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"reynolds", "=", 
  RowBox[{
   RowBox[{"Reynolds", "[", "zone_", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "p"], 
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], "\[Rho]"}], 
    "\[Mu]"]}]}]], "Input",
 CellChangeTimes->{{3.713342582454962*^9, 3.7133425844041386`*^9}, {
  3.71334273631691*^9, 3.71334274062188*^9}, {3.7133428317805986`*^9, 
  3.713342860120889*^9}, {3.713343014926419*^9, 
  3.7133430216207924`*^9}},ExpressionUUID->"b9a2d80b-7c33-49f0-a0eb-\
5ccfe215fa26"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Reynolds", "[", "zone_", "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", "\[Rho]", " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], "\[Mu]"]}]], "Output",
 CellChangeTimes->{
  3.7133458129267263`*^9, 3.713346368441761*^9, 3.713346837812315*^9, 
   3.713347010853318*^9, 3.7133471338051405`*^9, 3.713347434563879*^9, 
   3.7133475637980003`*^9, 3.713348623450832*^9, 3.7133499138903303`*^9, 
   3.713350365688972*^9, 3.7133529560726347`*^9, 3.713353071372167*^9, 
   3.7133531441587963`*^9, 3.713353289006257*^9, 3.7133548793058715`*^9, 
   3.7133612300955095`*^9, 3.7133615264034076`*^9, 3.713365360666729*^9, 
   3.713369189406919*^9, 3.713424370726162*^9, 3.7134261354373927`*^9, 
   3.713456369343195*^9, 3.713464438446322*^9, 3.713484090809291*^9, 
   3.7135121312873774`*^9, 3.7135177304086437`*^9, 3.7135997762375717`*^9, 
   3.7136022126890945`*^9, 3.713602801687132*^9, 3.713781576999859*^9, 
   3.713781862016817*^9, 3.7137868201486006`*^9, 3.7138922820904775`*^9, 
   3.7139104112590504`*^9, 3.7139106671667967`*^9, 3.7140711496659656`*^9, 
   3.714127904648986*^9, 3.714136292113103*^9, 3.7141427835481787`*^9, 
   3.714210094265148*^9, 3.71421099206467*^9, {3.714216053579488*^9, 
   3.7142160760397415`*^9}, 3.714240584805417*^9, 
   3.7143401657090073`*^9},ExpressionUUID->"4a7a529d-e1b2-436d-bd02-\
6c1a12316ecd"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Compose our Estimates into a Procedure", "Section",
 CellChangeTimes->{{3.7069781924420786`*^9, 
  3.7069782065902877`*^9}},ExpressionUUID->"d5426215-cdad-411b-930b-\
2e939a3d0036"],

Cell[CellGroupData[{

Cell["Ideal System", "Subsection",
 CellChangeTimes->{{3.706978229054186*^9, 
  3.706978230912442*^9}},ExpressionUUID->"5f6ee1ff-570f-48ff-b49d-\
8b96d24c8ce8"],

Cell[CellGroupData[{

Cell[TextData[{
 "The ideal solution starts with the first ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "p"], TraditionalForm]],ExpressionUUID->
  "2919dfc0-c4eb-4f6d-951f-7bf805495cab"],
 " estimate from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "s"], TraditionalForm]],ExpressionUUID->
  "387a438d-a0f4-446a-8bec-de61f5a2f94a"]
}], "Subsubsection",
 CellChangeTimes->{{3.7069788252912216`*^9, 3.706978843148952*^9}, {
  3.706978931021088*^9, 3.7069789313794847`*^9}, {3.7133382915697927`*^9, 
  3.7133382989552493`*^9}},ExpressionUUID->"42c18ab8-cf03-4971-9a39-\
f2161e06e96e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"initialIdealPeakFunction", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "A"], ":", "_"}], ",", 
    RowBox[{
     SubscriptBox["c", "B"], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "peakEstimate", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"initialIdealPeak", "=", 
  RowBox[{"initialIdealPeakFunction", "[", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.706978844185402*^9, 3.7069788686256866`*^9}, {
  3.706978934051138*^9, 3.7069789348076525`*^9}, {3.7069806546001153`*^9, 
  3.7069806583859673`*^9}, {3.7069808517667246`*^9, 3.7069808756600485`*^9}, {
  3.71333753328761*^9, 3.713337544227348*^9}, {3.7133469828155413`*^9, 
  3.713346985760971*^9}, {3.7133661435142803`*^9, 3.7133661454856467`*^9}, {
  3.7140712425681753`*^9, 
  3.7140713811181436`*^9}},ExpressionUUID->"4dfaa058-5e98-431f-aaad-\
3a70fd82e0c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983897713*^9, 3.7133412913882713`*^9, 3.7133463684602704`*^9, 
   3.7133468378462677`*^9, 3.7133470108703194`*^9, 3.7133471338241405`*^9, 
   3.7133474345808783`*^9, 3.7133475638220005`*^9, 3.713348623472971*^9, 
   3.71334991391333*^9, 3.713350365710972*^9, 3.7133529560969033`*^9, 
   3.713353071401167*^9, 3.713353144186309*^9, 3.7133532890377617`*^9, 
   3.713354879333375*^9, 3.713361230117645*^9, 3.713361526450296*^9, 
   3.7133653606823587`*^9, 3.7133661461137094`*^9, 3.7133691894225435`*^9, 
   3.7134243707496576`*^9, 3.7134261354530177`*^9, 3.713456369354679*^9, 
   3.7134644384588337`*^9, 3.713484090849291*^9, 3.713512131300378*^9, 
   3.713517730421645*^9, 3.713599776254072*^9, 3.7136022127070932`*^9, 
   3.713602801704132*^9, 3.713781577015484*^9, 3.713781862048064*^9, 
   3.713786820273616*^9, 3.7138922822467065`*^9, 3.713910411274677*^9, 
   3.7139106671824207`*^9, 3.7140712209333477`*^9, 3.714071302417096*^9, 
   3.7140713817588353`*^9, 3.7141279046802373`*^9, 3.714136292128743*^9, 
   3.7141427835638328`*^9, 3.7142100942941484`*^9, 3.7142109920957932`*^9, {
   3.714216053613985*^9, 3.714216076070243*^9}, 3.7142405848169003`*^9, 
   3.7143401657450075`*^9},ExpressionUUID->"577fb888-ecf7-40d2-a5cd-\
374d741ac467"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Which are used to calculate the first estimate of the retention factors\
\>", "Subsubsection",
 CellChangeTimes->{{3.706978954974704*^9, 3.706978973606929*^9}, {
  3.713338325625347*^9, 
  3.713338332237108*^9}},ExpressionUUID->"368d9931-cf20-4a69-960a-\
7a28eb7f9a4e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"idealRetention", "/.", 
   RowBox[{"initialIdealPeakFunction", "[", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
     SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idealRetentionFunction", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7069789952388783`*^9, 3.7069790183939857`*^9}, {
   3.7069790642834597`*^9, 3.706979074178793*^9}, {3.7069797213514547`*^9, 
   3.706979725015319*^9}, {3.706980634020439*^9, 3.706980651580159*^9}, 
   3.7069808912429395`*^9, {3.71407140515994*^9, 3.714071466855137*^9}, {
   3.7140715067676415`*^9, 3.7140715380018387`*^9}, {3.7140715929302006`*^9, 
   3.714071593680415*^9}, {3.714129182061863*^9, 3.7141291858591175`*^9}, {
   3.714129307647993*^9, 3.7141293582871604`*^9}, {3.7141294034165063`*^9, 
   3.7141294925769386`*^9}},ExpressionUUID->"d32dc7f4-3ae0-4eec-9419-\
596edf4ecabe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["a", "B"], "+", 
     SubscriptBox["\[Epsilon]", "p"], "-", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["\[Epsilon]", "p"]}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7140714678707366`*^9, {3.7140715215348096`*^9, 3.714071538783544*^9}, 
   3.714127904992733*^9, 3.714129186780995*^9, {3.714129335448673*^9, 
   3.714129358927851*^9}, {3.714129409760825*^9, 3.714129493561279*^9}, 
   3.71413629231625*^9, 3.714142783764021*^9, 3.714210094444152*^9, 
   3.7142109922518997`*^9, {3.714216053783985*^9, 3.7142160762322435`*^9}, 
   3.7142405849678946`*^9, 
   3.7143401659074*^9},ExpressionUUID->"568458b3-82de-4149-8005-fd8bf5dd9736"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
These retention factors are then used to calculate the system velocities\
\>", "Subsubsection",
 CellChangeTimes->{{3.7069796980414314`*^9, 3.7069797111351843`*^9}, {
  3.7133383466774664`*^9, 
  3.713338349635667*^9}},ExpressionUUID->"802fa45c-76fb-4d78-a1cf-\
9a06f82838b9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"idealZoneVelocityEstimates", "/.", "idealVelocityEstimate"}], "/.", 
   RowBox[{"idealRetentionFunction", "[", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
     SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idealZoneVelocityFunction", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.706979713657446*^9, 3.706979768519618*^9}, {
   3.706979867971958*^9, 3.706979867974459*^9}, {3.70697990218363*^9, 
   3.70697991552148*^9}, {3.7069799908921824`*^9, 3.7069799933624125`*^9}, {
   3.706980055128106*^9, 3.706980056637744*^9}, {3.7140715542343936`*^9, 
   3.714071580717355*^9}, {3.7140716115821753`*^9, 3.714071641313594*^9}, {
   3.7140716886296453`*^9, 3.714071719218884*^9}, {3.714071827864349*^9, 
   3.7140718490940557`*^9}, 3.714071891029255*^9, {3.714129129808606*^9, 
   3.7141291340518627`*^9}, {3.714129530174307*^9, 
   3.7141295701499715`*^9}},ExpressionUUID->"e52d7032-3c09-4899-9c4c-\
f1d9d8a7ab0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "B"], "+", 
            SubscriptBox["\[Epsilon]", "p"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["\[Epsilon]", "p"]}]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "B"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SuperscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.714071720453387*^9, 3.71407184975876*^9, 3.714072352098481*^9, 
   3.71412790607097*^9, 3.714129134848714*^9, 3.714129571775006*^9, 
   3.714136293066329*^9, 3.7141427845503387`*^9, 3.714210095057152*^9, 
   3.7142109928669004`*^9, {3.714216054424986*^9, 3.7142160768562417`*^9}, 
   3.7142405856139317`*^9, 
   3.714340166557404*^9},ExpressionUUID->"936633a1-2c3c-4254-a21e-\
a8cd0a5c55b2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Estimate the peak concentrations again, based on mass balances\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980682132275*^9, 
  3.70698070656619*^9}},ExpressionUUID->"3be769dd-845e-4516-b131-\
824be7c66758"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealPeak2", "=", 
  RowBox[{
   RowBox[{"initialIdealPeakFunction", "[", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
     SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.70698039541459*^9, 3.7069804487190475`*^9}, {
  3.706980749074515*^9, 3.7069807513023925`*^9}, {3.713337473733631*^9, 
  3.7133374837736053`*^9}, {3.7133469766355376`*^9, 3.7133469789252863`*^9}, {
  3.7140719215105405`*^9, 3.7140719246046314`*^9}, {3.7140719613745413`*^9, 
  3.7140719825305133`*^9}},ExpressionUUID->"61671682-6fca-4550-bd65-\
4fca0a704785"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "A"]}], "+", 
    SubscriptBox["a", "B"], "+", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"], " ", 
     SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
    RowBox[{
     SubscriptBox["a", "A"], " ", 
     SubscriptBox["b", "B"], " ", 
     SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["a", "A"], " ", 
    SubscriptBox["b", "B"]}]]}]], "Output",
 CellChangeTimes->{
  3.7133389846647153`*^9, 3.7133412921336527`*^9, 3.713346369174189*^9, 
   3.7133468386123066`*^9, 3.713347011685094*^9, 3.713347134643341*^9, 
   3.7133474354577703`*^9, 3.7133475647690434`*^9, 3.7133486243025513`*^9, 
   3.7133499147247295`*^9, 3.7133503665588183`*^9, 3.713352956882077*^9, 
   3.713353072231753*^9, 3.7133531449828577`*^9, 3.713353289806444*^9, 
   3.7133548801367817`*^9, 3.713361230937462*^9, 3.713361527252093*^9, 
   3.713365361512575*^9, 3.7133691902906766`*^9, 3.713424371588476*^9, 
   3.7134261362655177`*^9, 3.7134563701651764`*^9, 3.7134644386273594`*^9, 
   3.7134840909988046`*^9, 3.7135121314686604`*^9, 3.7135177305846653`*^9, 
   3.7135997771650734`*^9, 3.7136022135451612`*^9, 3.7136028024587803`*^9, 
   3.713781578015591*^9, 3.7137818630793877`*^9, 3.7137868240865183`*^9, 
   3.7138922861762414`*^9, 3.713910411524703*^9, 3.7139106674011946`*^9, 
   3.714071907499648*^9, 3.7140719455683413`*^9, 3.714071983468006*^9, 
   3.7141279061022243`*^9, 3.7141362931132355`*^9, 3.714142784597252*^9, 
   3.71421009512115*^9, 3.714210992893903*^9, {3.714216054452485*^9, 
   3.7142160769017425`*^9}, 3.714240585623909*^9, 
   3.7143401665974045`*^9},ExpressionUUID->"cc346e8e-9777-498a-ade6-\
cb5ebd4887a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "/.", 
   RowBox[{"idealZoneVelocityFunction", "[", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
     SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idealPeak1Function", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.706980556163006*^9, 3.7069806034279537`*^9}, {
  3.706980753848175*^9, 3.7069807554623966`*^9}, {3.7140719291988716`*^9, 
  3.714071931238821*^9}, {3.71407203714522*^9, 3.714072117625863*^9}, {
  3.714072247281376*^9, 3.7140722771057997`*^9}, {3.7141290672257414`*^9, 
  3.7141290725941*^9}, {3.7141296087691092`*^9, 
  3.714129678757082*^9}},ExpressionUUID->"9f7935f7-561f-4fd4-837a-\
5ab239530ce3"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["a", "A"], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SubsuperscriptBox["a", "A", "2"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"]}], "+", 
      SubsuperscriptBox["a", "B", "2"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}]}],
      ")"}], " ", 
    SubscriptBox["y", "target"]}], 
   RowBox[{
    SubscriptBox["a", "B"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["a", "A"], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{
  3.713338984773714*^9, 3.713341292283202*^9, 3.7133463692802043`*^9, 
   3.7133468387608414`*^9, 3.713347011790102*^9, 3.713347134745865*^9, 
   3.713347435546276*^9, 3.713347564875677*^9, 3.713348624392061*^9, 
   3.7133495161872025`*^9, 3.713349914806242*^9, 3.7133503666453238`*^9, 
   3.7133529569620867`*^9, 3.713353072320616*^9, 3.7133531450799017`*^9, 
   3.713353289884452*^9, 3.713354880220786*^9, 3.713361231016588*^9, 
   3.7133615273211327`*^9, 3.713365361589594*^9, 3.7133691903746915`*^9, 
   3.7134243716674767`*^9, 3.7134261363436437`*^9, 3.713456370241155*^9, 
   3.7134644386880727`*^9, 3.7134840910092354`*^9, 3.713512131499665*^9, 
   3.713517730662675*^9, 3.713599777250574*^9, 3.7136022136301613`*^9, 
   3.713602802543285*^9, 3.7137815781093526`*^9, 3.713781863204427*^9, 
   3.7137868244615555`*^9, 3.713892286566946*^9, 3.7139104115716143`*^9, 
   3.71391066743346*^9, 3.7140719123219833`*^9, {3.714072089908948*^9, 
   3.714072118235324*^9}, 3.714072278152701*^9, 3.714072366170807*^9, 
   3.714127906992942*^9, 3.714129074266016*^9, {3.714129635376593*^9, 
   3.7141296471348863`*^9}, 3.714129686504408*^9, 3.7141362932069693`*^9, 
   3.714142784697107*^9, 3.7142100951993723`*^9, 3.7142109929739017`*^9, {
   3.714216054537485*^9, 3.714216076985243*^9}, 3.714240585700925*^9, 
   3.714340166679405*^9},ExpressionUUID->"89b36b12-43e9-4b7e-b207-\
6e81e2ee8837"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{
   RowBox[{"idealPeak1Function", "[", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
     SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}], ",", "idealPeak2"}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idealPeakUpdateFunction", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7069807619015074`*^9, 3.706980768562213*^9}, {
  3.71378163717185*^9, 3.7137817382932596`*^9}, {3.7140724148003116`*^9, 
  3.714072557691358*^9}, {3.714129699380772*^9, 
  3.7141297488710604`*^9}},ExpressionUUID->"6fdeb492-68c2-4f3c-bf95-\
9fe8f38755a6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SubsuperscriptBox["a", "A", "2"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"]}], "+", 
        SubsuperscriptBox["a", "B", "2"], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["a", "A", "2"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubsuperscriptBox["a", "B", "2"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["a", "A", "2"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
            "2"]}]]}]}], ")"}], " ", 
      SubscriptBox["y", "target"]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389847912135`*^9, 3.7133412923132033`*^9, 3.713346369303203*^9, 
   3.7133468388058386`*^9, 3.7133470118171034`*^9, 3.713347134792368*^9, 
   3.7133474355792756`*^9, 3.7133475649071817`*^9, 3.7133486244350615`*^9, 
   3.7133499148412404`*^9, 3.7133503666733274`*^9, 3.7133529569911337`*^9, 
   3.713353072352622*^9, 3.713353145134404*^9, 3.7133532899139*^9, 
   3.713354880247792*^9, 3.7133612310352287`*^9, 3.7133615273367567`*^9, 
   3.7133653616070924`*^9, 3.7133691903961906`*^9, 3.7134243716884766`*^9, 
   3.713426136359268*^9, 3.7134563702536716`*^9, 3.7134644386980715`*^9, 
   3.713484091019236*^9, 3.713512131508664*^9, 3.713517730675674*^9, 
   3.713599777267074*^9, 3.7136022136451607`*^9, 3.713602802572131*^9, 
   3.7137815781406097`*^9, 3.7137817781896896`*^9, 3.7137818632200375`*^9, 
   3.713786824492809*^9, 3.713892286629447*^9, 3.713910411587229*^9, 
   3.713910667468328*^9, {3.7140725197805805`*^9, 3.7140725540191145`*^9}, 
   3.7141279070085683`*^9, {3.714129733405607*^9, 3.714129749527279*^9}, 
   3.7141362932226257`*^9, 3.71414278472835*^9, 3.7142100952145195`*^9, 
   3.714210992997902*^9, {3.714216054568985*^9, 3.714216077008743*^9}, 
   3.7142405857374077`*^9, 
   3.7143401667064066`*^9},ExpressionUUID->"8aa44888-9bac-42e4-be74-\
967d081d1667"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Calculate the difference between the initial peak values, and this second \
estimate\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980733620349*^9, 3.706980741374005*^9}, {
  3.713338403127731*^9, 
  3.713338417737518*^9}},ExpressionUUID->"2dfb92a4-9839-4936-be91-\
ebdb620133cd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"idealToleranceFunction", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "A"], ":", "_"}], ",", 
      RowBox[{
       SubscriptBox["c", "B"], ":", "_"}]}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Abs", "[", "#", "]"}], ">", "0.0001"}], "&"}], "/@", 
    RowBox[{"Subtract", "@@", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
         SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"initialIdealPeakFunction", "[", 
          RowBox[{
           SubscriptBox["c", "A"], ",", 
           SubscriptBox["c", "B"]}], "]"}], ",", 
         RowBox[{"idealPeakUpdateFunction", "[", 
          RowBox[{
           SubscriptBox["c", "A"], ",", 
           SubscriptBox["c", "B"]}], "]"}]}], "}"}]}], ")"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"idealToleranceFunction", "[", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.714072574045128*^9, 3.7140727450887756`*^9}, {
   3.714072948860397*^9, 3.7140730370918474`*^9}, {3.7140732749578924`*^9, 
   3.714073305264144*^9}, 3.7140737015206347`*^9, {3.714128890181714*^9, 
   3.7141288995265813`*^9}, {3.7141297636851296`*^9, 
   3.714129805435814*^9}},ExpressionUUID->"d2881159-0399-4d00-a688-\
1fa82d568e21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"]}]], "-", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubsuperscriptBox["a", "A", "2"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"]}], "+", 
          SubsuperscriptBox["a", "B", "2"], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "B", "2"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}]}], ")"}], " ", 
        SubscriptBox["y", "target"]}], 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "A"]}], "+", 
          SubscriptBox["a", "B"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}]}]]}], "]"}], ">", "0.0001`"}], ",", "False"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.714072707677662*^9, {3.7140729822546864`*^9, 3.71407300342101*^9}, 
   3.7140730385137386`*^9, 3.714073702723755*^9, 3.7141279070241966`*^9, 
   3.7141289002452755`*^9, 3.7141298064983864`*^9, 3.7141362932538753`*^9, 
   3.7141427847657022`*^9, 3.7142100952295237`*^9, 3.7142109930229025`*^9, {
   3.7142160546069856`*^9, 3.7142160770262423`*^9}, 3.7142405857489266`*^9, 
   3.7143401667254057`*^9},ExpressionUUID->"b8c8097c-0d9e-4abb-bc21-\
c7e5b591a56a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assuming we haven\[CloseCurlyQuote]t converged, calculate new \[Gamma] \
values", "Subsubsection",
 CellChangeTimes->{{3.7069810861321573`*^9, 
  3.706981113672449*^9}},ExpressionUUID->"602da070-dd31-479b-ae17-\
5941695694ee"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"secondary\[Gamma]Values", "/.", 
  RowBox[{"idealPeakUpdateFunction", "[", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<s\>\""]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"second\[Gamma]EstimateFunction", "[", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7069811158565035`*^9, 3.7069811277049484`*^9}, {
  3.706981188772627*^9, 3.7069811946623883`*^9}, {3.7140737254710655`*^9, 
  3.714073807474044*^9}, {3.714129833385082*^9, 
  3.714129871327913*^9}},ExpressionUUID->"de6cde1a-5e7f-4755-b326-\
8f22cc946de7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           SubscriptBox["a", "B"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["a", "A", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "+", 
         SubsuperscriptBox["a", "B", "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "-", 
         FractionBox[
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "+", 
             SubscriptBox["a", "B"], "+", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "A"], "-", 
                  RowBox[{
                   SubscriptBox["a", "B"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SubscriptBox["a", "A"], " ", 
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                "2"]}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SubsuperscriptBox["a", "A", "2"]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"]}], "+", 
             SubsuperscriptBox["a", "B", "2"], "-", 
             RowBox[{"2", " ", 
              SubsuperscriptBox["a", "A", "2"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
             RowBox[{
              SubsuperscriptBox["a", "B", "2"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
             RowBox[{"2", " ", 
              SubsuperscriptBox["a", "A", "2"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}]}], ")"}], " ", 
           SubscriptBox["y", "target"]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "+", 
             SubscriptBox["a", "B"], "+", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
             SqrtBox[
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "A"], "-", 
                  RowBox[{
                   SubscriptBox["a", "B"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SubscriptBox["a", "A"], " ", 
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                "2"]}]]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["a", "A"]}], "+", 
             SubscriptBox["a", "B"], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "A"], "-", 
                  RowBox[{
                   SubscriptBox["a", "B"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SubscriptBox["a", "A"], " ", 
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                "2"]}]]}], ")"}]}]]}], ")"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.714073780430768*^9, 3.714073808317783*^9}, 
   3.7141279070554485`*^9, {3.714129865085433*^9, 3.7141298727967124`*^9}, 
   3.7141362932851305`*^9, 3.7141427848281717`*^9, 3.7142100952495227`*^9, 
   3.714210993051902*^9, {3.7142160546389875`*^9, 3.7142160770462427`*^9}, 
   3.7142405857624173`*^9, 
   3.7143401667464066`*^9},ExpressionUUID->"49039c74-80ab-44e1-b25f-\
7a8bbec44249"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Use the new \[Gamma] values to calculate new cs estimates", \
"Subsubsection",
 CellChangeTimes->{{3.706981149036009*^9, 3.7069811736421733`*^9}, {
  3.713781793621079*^9, 
  3.713781796011834*^9}},ExpressionUUID->"37548c11-57de-4acb-a17b-\
78150627772c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], "/.", 
  RowBox[{"Simplify", "[", 
   RowBox[{"dilutionEstimate", "/.", 
    RowBox[{"second\[Gamma]EstimateFunction", "[", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"idealNextEstimateFunction", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "%", "]"}]}]}], "Input",
 CellChangeTimes->{{3.706981177248345*^9, 3.7069811995752*^9}, {
  3.706981263784754*^9, 3.706981265664357*^9}, {3.7133461141988926`*^9, 
  3.7133461169762964`*^9}, {3.71407421634254*^9, 3.7140743001669235`*^9}, {
  3.714128853803005*^9, 3.7141288758916407`*^9}, {3.714129887110837*^9, 
  3.7141299312403417`*^9}, {3.7141299873414235`*^9, 
  3.714130000134881*^9}},ExpressionUUID->"bed184b2-6f4c-4eef-ad0b-\
ade4b9cf5de7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["a", "A", "2"]}], "-", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"]}], "-", 
        SubsuperscriptBox["a", "B", "2"], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["a", "A", "2"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
        RowBox[{
         SubsuperscriptBox["a", "B", "2"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["a", "A", "2"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
            "2"]}]]}]}], ")"}], " ", 
      SubscriptBox["y", "target"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", " ", 
      SubscriptBox["a", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "-", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["a", "A", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "B"], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
             ")"}]}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubsuperscriptBox["b", "A", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "B"], "+", 
                 RowBox[{
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], 
              "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "A"], "+", 
                 RowBox[{
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], 
              "+", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "-", 
                 RowBox[{
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
                ")"}]}]}]]}], "+", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
                  SubscriptBox["y", "target"]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["b", "B"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7140743024170675`*^9, 3.7141279078836613`*^9, 
  3.714128877282302*^9, 3.7141299331779385`*^9, 3.7141300022757254`*^9, 
  3.7141362940664587`*^9, 3.7141427856717377`*^9, 3.7142100958945265`*^9, 
  3.7142109937109027`*^9, 3.714216077702243*^9, 3.7142405864484034`*^9, 
  3.7143401674144106`*^9},ExpressionUUID->"26cf505f-688d-4171-b4d3-\
c4ccdbf22176"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the iteration", "Subsubsection",
 CellChangeTimes->{{3.7133460384320483`*^9, 
  3.713346042106112*^9}},ExpressionUUID->"e7a2a9ae-2249-4e38-bbaa-\
6365cf96addf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"idealSWD", "[", 
   RowBox[{
   "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "yt_", ",", "cf1_", ",", 
    "cf2_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "A"], "=", "a1"}], ",", 
      RowBox[{
       SubscriptBox["a", "B"], "=", "a2"}], ",", 
      RowBox[{
       SubscriptBox["b", "A"], "=", "b1"}], ",", 
      RowBox[{
       SubscriptBox["b", "B"], "=", "b2"}], ",", 
      RowBox[{
       SubscriptBox["y", "target"], "=", "yt"}], ",", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\"\<F\>\""], "=", "cf1"}], ",", 
      RowBox[{
       SubsuperscriptBox["c", "B", "\"\<F\>\""], "=", "cf2"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"iterationResults", "=", 
      RowBox[{"NestWhileList", "[", 
       RowBox[{"idealNextEstimateFunction", ",", 
        RowBox[{"{", 
         RowBox[{
          SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
          SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], ",", 
        RowBox[{
         RowBox[{"Or", "@@", 
          RowBox[{"idealToleranceFunction", "[", "#", "]"}]}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"#", "~", "Join", "~", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}]}], "/.", 
        RowBox[{"(", 
         RowBox[{"idealPeakUpdateFunction", "@@", "#"}], ")"}]}], "&"}], "/@",
       "iterationResults"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.7141328081353326`*^9, 3.714132858309893*^9}, {
  3.7141329213948135`*^9, 3.714133083308231*^9}, {3.7141331624125366`*^9, 
  3.7141332350243697`*^9}, {3.7141334457527475`*^9, 3.7141334729830513`*^9}, {
  3.714134193698429*^9, 
  3.7141341938234444`*^9}},ExpressionUUID->"b816a541-624c-4f63-9b14-\
1b9d1a6a0b4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"calculateMvalues", "[", 
    RowBox[{
    "cs_", ",", "ep_", ",", "eb_", ",", "lc_", ",", "db_", ",", "ff_", ",", 
     "yt_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["A", "c"], "=", 
        RowBox[{"\[Pi]", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["db", "2"], ")"}], "2"]}]}], ",", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "p"], "=", "ep"}], ",", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], "=", "eb"}], ",", 
       RowBox[{
        SubscriptBox["L", "c"], "=", "lc"}], ",", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "t"], "=", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "b"], "+", 
         RowBox[{
          SubscriptBox["\[Epsilon]", "p"], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"zoneVelocityResults", "=", 
        RowBox[{"idealZoneVelocityFunction", "@@", "cs"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"retentionResults", "=", 
        RowBox[{"idealRetentionFunction", "@@", "cs"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"feed", "=", 
        RowBox[{
         SuperscriptBox["f", "\"\<F\>\""], "\[Rule]", "ff"}]}], ",", "mvals", 
       ",", "tsw"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"zoneFlowResults", "=", 
       RowBox[{"zoneFlowEstimates", "/.", "zoneVelocityResults"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"portFlowResults", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"portFlowEstimates", "/.", "zoneFlowResults"}], "/.", 
         "zoneVelocityResults"}], "/.", "feed"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"concentrationResults", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"secondaryEstimatesFunction", "@@", "cs"}], "/.", 
          "zoneFlowResults"}], "/.", "portFlowResults"}], "/.", "feed"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"tsw", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["t", "sw"], "\[Rule]", 
           FractionBox[
            SubscriptBox["L", "c"], "v"]}], "/.", "idealVelocityEstimate"}], "/.",
          "retentionResults"}], "/.", "feed"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mvals", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"mValues", "/.", "zoneVelocityResults"}], "/.", "feed"}], "/.",
         "tsw"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Association", "[", 
       RowBox[{
        RowBox[{"{", "tsw", "}"}], "~", "Join", "~", "mvals", "~", "Join", 
        "~", "portFlowResults", "~", "Join", "~", "concentrationResults"}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.71336534820242*^9, 3.713365348903594*^9}, {
   3.7133672166640797`*^9, 3.713367232379471*^9}, {3.713367264943421*^9, 
   3.7133673251679497`*^9}, {3.7133673656191206`*^9, 3.71336740881384*^9}, {
   3.713367624385961*^9, 3.713368012610828*^9}, {3.713368183923693*^9, 
   3.713368193439434*^9}, {3.7133683422540445`*^9, 3.7133684012941003`*^9}, {
   3.713368494751278*^9, 3.7133685183730564`*^9}, {3.71336992564083*^9, 
   3.713369955953268*^9}, {3.7133703907290297`*^9, 3.7133704713900423`*^9}, {
   3.7133705494647818`*^9, 3.713370553830155*^9}, {3.7133709615908437`*^9, 
   3.713371022737687*^9}, 3.7133710808620205`*^9, {3.713371121118045*^9, 
   3.7133711228027134`*^9}, 3.7133714387729197`*^9, {3.7133714801891603`*^9, 
   3.713371485234321*^9}, {3.713371754168645*^9, 3.713371764519052*^9}, {
   3.7133718536693773`*^9, 3.7133718739033484`*^9}, {3.713372001583313*^9, 
   3.713372030686575*^9}, {3.7134259763403625`*^9, 3.713425980214201*^9}, {
   3.7134260550145335`*^9, 3.7134261155612726`*^9}, 3.7134264672378664`*^9, {
   3.713426582662972*^9, 3.7134265938661394`*^9}, {3.713426642282429*^9, 
   3.713426698906968*^9}, {3.713426732974614*^9, 3.713426750642109*^9}, {
   3.7134268135470448`*^9, 3.713426854374708*^9}, {3.713426899412753*^9, 
   3.713426901512068*^9}, {3.71343515320172*^9, 3.713435188094446*^9}, {
   3.71343636268979*^9, 3.713436383211113*^9}, {3.713437293805332*^9, 
   3.713437306873647*^9}, {3.713437581792432*^9, 3.713437584636244*^9}, {
   3.7134384424884524`*^9, 3.71343846449323*^9}, {3.7134385578378057`*^9, 
   3.7134385586182456`*^9}, {3.7134408867741084`*^9, 
   3.7134409215385637`*^9}, {3.7134412441244307`*^9, 
   3.7134412708929024`*^9}, {3.7141282271758623`*^9, 
   3.7141282312231636`*^9}, {3.7141302793848915`*^9, 
   3.7141302831041694`*^9}, {3.7141304163547096`*^9, 
   3.7141304300664253`*^9}, {3.7141305638203063`*^9, 3.714130573430833*^9}, {
   3.7141306757981124`*^9, 3.714130715181575*^9}, {3.714130751580972*^9, 
   3.7141308064325027`*^9}, {3.7141308398976617`*^9, 
   3.7141308441324825`*^9}, {3.7141308772174187`*^9, 
   3.7141309297664227`*^9}, {3.7141309789905043`*^9, 3.714131014745922*^9}, {
   3.7141310674697824`*^9, 3.7141310727767725`*^9}, {3.7141311406778684`*^9, 
   3.7141311607036543`*^9}, {3.714131191979329*^9, 3.7141312231233644`*^9}, {
   3.714131253883638*^9, 3.714131276112744*^9}, {3.7141317018673487`*^9, 
   3.7141317456740546`*^9}, {3.714131795938833*^9, 3.714131798673589*^9}, {
   3.7141318617842693`*^9, 3.714131965488223*^9}, {3.714132054238318*^9, 
   3.7141321651961575`*^9}, {3.7141323010156064`*^9, 
   3.7141323176736245`*^9}, {3.7141324145993023`*^9, 
   3.714132423373063*^9}},ExpressionUUID->"1bd31a41-aa24-48f9-9f60-\
fc54c49be2f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"formatSWD", "[", "result_", "]"}], ":=", 
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
        SubsuperscriptBox["c", "B", "\"\<s\>\""], ",", 
        SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
        SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "}"}], "~", "Join",
      "~", "result"}], ",", 
    RowBox[{"Frame", "\[Rule]", "All"}], ",", 
    RowBox[{"Background", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "\[Rule]", "Gray"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "\[Rule]", 
          RowBox[{"Lighter", "[", "Gray", "]"}]}]}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7141331090528393`*^9, 3.714133111709483*^9}, {
  3.7141332647954435`*^9, 3.7141333033075914`*^9}, {3.714133349657351*^9, 
  3.7141333928499126`*^9}, {3.7141334941958165`*^9, 3.714133555498208*^9}, {
  3.714133593080818*^9, 3.714133617451826*^9}, {3.714133701842946*^9, 
  3.714133702890071*^9}, {3.7141337468964863`*^9, 3.7141338735628357`*^9}, {
  3.7141339140534945`*^9, 3.7141339927410917`*^9}, {3.7141349413931694`*^9, 
  3.7141349560142264`*^9}},ExpressionUUID->"3a280928-1fbc-4298-984e-\
c8f3fb9fdad3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"idealSWDdesign", "[", 
    RowBox[{
    "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "yt_", ",", "cf1_", ",", 
     "cf2_", ",", "ep_", ",", "eb_", ",", "lc_", ",", "db_", ",", "ff_"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "A"], "=", "a1"}], ",", 
       RowBox[{
        SubscriptBox["a", "B"], "=", "a2"}], ",", 
       RowBox[{
        SubscriptBox["b", "A"], "=", "b1"}], ",", 
       RowBox[{
        SubscriptBox["b", "B"], "=", "b2"}], ",", 
       RowBox[{
        SubscriptBox["y", "target"], "=", "yt"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "=", "cf1"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "=", "cf2"}], ",", 
       "iterationResults", ",", "formattedIteration", ",", "designResults"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"iterationResults", "=", 
       RowBox[{"NestWhileList", "[", 
        RowBox[{"idealNextEstimateFunction", ",", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], ",", 
         RowBox[{
          RowBox[{"Or", "@@", 
           RowBox[{"idealToleranceFunction", "[", "#", "]"}]}], "&"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"formattedIteration", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "~", "Join", "~", 
           RowBox[{"{", 
            RowBox[{
             SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
             SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}]}], "/.", 
          RowBox[{"(", 
           RowBox[{"idealPeakUpdateFunction", "@@", "#"}], ")"}]}], "&"}], "/@",
         "iterationResults"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"designResults", "=", 
       RowBox[{"calculateMvalues", "[", 
        RowBox[{
         RowBox[{"iterationResults", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], ",", "ep", ",", "eb", ",", "lc", 
         ",", "db", ",", "ff", ",", "yt"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Grid", "[", 
       RowBox[{GridBox[{
          {"\"\<Iteration Results\>\"", "\"\<Final Design\>\"", 
           "\"\<Concentration Predictions\>\""},
          {
           RowBox[{"formatSWD", "[", "formattedIteration", "]"}], 
           RowBox[{"Dataset", "[", 
            RowBox[{"designResults", "[", 
             RowBox[{"[", 
              RowBox[{";;", 
               RowBox[{"-", "9"}]}], "]"}], "]"}], "]"}], 
           RowBox[{"Dataset", "[", 
            RowBox[{"designResults", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"-", "8"}], ";;"}], "]"}], "]"}], "]"}]}
         }], ",", "\[IndentingNewLine]", 
        RowBox[{"Frame", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"True", ",", "True", ",", "True"}], "}"}], ",", "False"}],
           "}"}]}], ",", 
        RowBox[{"ItemSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Automatic", ",", 
           RowBox[{"{", "4", "}"}]}], "}"}]}], ",", 
        RowBox[{"Alignment", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Center", ",", 
           RowBox[{"{", 
            RowBox[{"Center", ",", "Top"}], "}"}]}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.71334838892173*^9, 3.7133484157749825`*^9}, {
   3.7133484816074657`*^9, 3.713348572964994*^9}, {3.713348635877905*^9, 
   3.7133486398002987`*^9}, {3.7133486804523497`*^9, 
   3.7133487328985577`*^9}, {3.713348763591322*^9, 3.713348808444786*^9}, {
   3.713348904038522*^9, 3.7133490143287745`*^9}, {3.7133491223601575`*^9, 
   3.713349367417217*^9}, {3.7133496184772663`*^9, 3.7133496189549747`*^9}, {
   3.713349961875225*^9, 3.713349997097623*^9}, {3.713350386061716*^9, 
   3.713350393408285*^9}, {3.7133504391341023`*^9, 3.713350545011199*^9}, {
   3.713350577847618*^9, 3.713350627902082*^9}, {3.713350771208232*^9, 
   3.7133508195275707`*^9}, {3.7133508547945404`*^9, 3.713350899612611*^9}, {
   3.7133509764347796`*^9, 3.7133510136961746`*^9}, {3.713351052158817*^9, 
   3.7133510526720405`*^9}, {3.7133511511511936`*^9, 
   3.7133512038268733`*^9}, {3.7133514342412663`*^9, 
   3.7133515120269003`*^9}, {3.713351555865802*^9, 3.7133516816647587`*^9}, {
   3.713351755707103*^9, 3.713351889697209*^9}, {3.713351929849571*^9, 
   3.713352002820095*^9}, {3.713352033776746*^9, 3.7133520625675793`*^9}, {
   3.713353010025146*^9, 3.713353039045745*^9}, {3.7133533084968605`*^9, 
   3.713353390241003*^9}, {3.7133548915358353`*^9, 3.7133549002485185`*^9}, {
   3.7133550094882603`*^9, 3.713355019306679*^9}, {3.7133550504322205`*^9, 
   3.7133550525490665`*^9}, {3.7133553989446926`*^9, 3.713355400779934*^9}, {
   3.713356458992903*^9, 3.7133565024254293`*^9}, {3.7133574498348975`*^9, 
   3.7133574824327354`*^9}, {3.7133575229169674`*^9, 
   3.7133575815353537`*^9}, {3.7133578332619047`*^9, 
   3.7133578351232114`*^9}, {3.7133651530581465`*^9, 
   3.7133651769821053`*^9}, {3.7133653772263184`*^9, 
   3.7133653790974874`*^9}, {3.713365415273676*^9, 3.71336545184683*^9}, {
   3.7133659058127365`*^9, 3.713365932263769*^9}, {3.7133660328995714`*^9, 
   3.7133660742673492`*^9}, {3.7133661911362677`*^9, 3.713366258940174*^9}, {
   3.713366826113123*^9, 3.7133670111623077`*^9}, {3.713370511286664*^9, 
   3.713370531406848*^9}, {3.7133709068987303`*^9, 3.7133709078515434`*^9}, {
   3.71337099701313*^9, 3.7133710006736345`*^9}, {3.7133710873571415`*^9, 
   3.7133710972342978`*^9}, 3.713371511464295*^9, {3.71337173003877*^9, 
   3.713371743942113*^9}, {3.713371785064848*^9, 3.713371814559945*^9}, 
   3.7141277816172476`*^9, {3.7141278218737226`*^9, 3.7141278918897123`*^9}, {
   3.714128969361203*^9, 3.7141290154606423`*^9}, {3.7141300488026457`*^9, 
   3.71413007175827*^9}, {3.714130328440097*^9, 3.714130394126361*^9}, {
   3.714131301098525*^9, 3.714131349355358*^9}, {3.7141340720480905`*^9, 
   3.714134122350404*^9}, {3.71413417076553*^9, 3.714134595742275*^9}, {
   3.714134631482591*^9, 3.7141347600837984`*^9}, {3.7141347994799356`*^9, 
   3.7141348691591873`*^9}, {3.714134994575663*^9, 3.714135080559595*^9}, {
   3.7141351148365107`*^9, 
   3.714135136179759*^9}},ExpressionUUID->"d32acda3-3c86-430f-afc0-\
7ec3f852d9cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealSWDdesign", "[", 
  RowBox[{
  "1", ",", "2", ",", "0.1", ",", "0.2", ",", "1", ",", "3", ",", "3", ",", 
   "0", ",", "0.45", ",", "96", ",", "2.56", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.714131531778886*^9, 3.7141315436358786`*^9}, {
   3.7141316208308897`*^9, 3.714131679544426*^9}, {3.7141340196361647`*^9, 
   3.714134026949439*^9}, 3.7141340623440676`*^9, 3.714134394417635*^9, 
   3.714134536151928*^9},ExpressionUUID->"2a7c9c9c-7900-4ef1-8d9b-\
4db834e0ec2c"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Iteration Results\"\>", "\<\"Final Design\"\>", "\<\"Concentration \
Predictions\"\>"},
    {
     TagBox[GridBox[{
        {
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"], 
         SubsuperscriptBox["c", "A", "\<\"p\"\>"], 
         SubsuperscriptBox["c", "B", "\<\"p\"\>"]},
        {"3", "3", "2.4646123541579934`", "1.5948751620466728`"},
        {"1.6784625486140017`", "2.381024967590667`", "3.3194323282305267`", 
         "1.5948751620466728`"},
        {"2.260616293752602`", "2.6536911965245973`", "2.9428734582539735`", 
         "1.5948751620466728`"},
        {"2.0041703015308423`", "2.5335783187698047`", "3.108752341362507`", 
         "1.5948751620466728`"},
        {"2.117137962523807`", "2.5864895408853728`", "3.035680622555173`", 
         "1.5948751620466728`"},
        {"2.0673742975912477`", "2.563181487010598`", "3.067869626902186`", 
         "1.5948751620466728`"},
        {"2.089295813233449`", "2.573448975715409`", "3.053689968646383`", 
         "1.5948751620466728`"},
        {"2.0796391119293434`", "2.5689260187637135`", "3.059936285124017`", 
         "1.5948751620466728`"},
        {"2.0838930094060855`", "2.570918437764605`", "3.057184704737882`", 
         "1.5948751620466728`"},
        {"2.082019114462795`", "2.57004075232176`", "3.05839681024814`", 
         "1.5948751620466728`"},
        {"2.082844588578634`", "2.5704273837161793`", "3.0578628626391966`", 
         "1.5948751620466728`"},
        {"2.0824809569255582`", "2.570257067760312`", "3.0580980732266285`", 
         "1.5948751620466728`"},
        {"2.0826411412082413`", "2.5703320940650594`", "3.057994460026544`", 
         "1.5948751620466728`"},
        {"2.082570578032012`", "2.570299044041205`", "3.0580401029346667`", 
         "1.5948751620466728`"}
       },
       AutoDelete->False,
       GridBoxBackground->{
        "Columns" -> {{Automatic}}, 
         "RowsIndexed" -> {
          1 -> GrayLevel[0.5], -1 -> 
           RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666]}},
       GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Grid"], 
     TemplateBox[{TagBox[
        DynamicModuleBox[{
         TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
          Data`UnorderedAssociation[
           "RowCount" -> 9, "Length" -> 9, "InitialType" -> 
            TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Atom[Real], 9], "Shape" -> 
            TypeSystem`PackageScope`Limited[
              TypeSystem`PackageScope`ColumnShape[
               TypeSystem`PackageScope`KeyValueShape[
               TypeSystem`PackageScope`UnknownShape, 
                TypeSystem`PackageScope`AtomShape[60]]], 9, {}], 
            "InitialData" -> TypeSystem`PackageScope`CacheHandle[152111316], 
            "Type" -> TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Atom[Real], 9], "HandleQ" -> True, "RowTarget" -> 20,
             "Data" -> TypeSystem`PackageScope`CacheHandle[152111316]], 
          TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
          TypeSystem`NestedGrid`PackagePrivate`$pos$$ = 1, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
          DynamicModule[{
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
               Style[
                Grid[{{
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubscriptBox["t", "sw"], FontFamily -> "Source Code Pro", 
                    FontSize -> 13, ShowStringCharacters -> True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`t\[UnderBracket]Subscript\[UnderBracket]\
sw]]], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["21.9081"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`t\[UnderBracket]Subscript\[UnderBracket]\
sw]]], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["m", "\"I\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["I"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["2."], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["I"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["m", "\"II\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["II"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0.758164"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["II"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["m", "\"III\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["III"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["1.16123"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["III"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["m", "\"IV\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["IV"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0.765814"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`m["IV"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["f", "\"R\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["R"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["4.9051"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["R"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["f", "\"D\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["D"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["15.3101"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["D"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["f", "\"E\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["E"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["15.405"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["E"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SuperscriptBox["f", "\"Recycle\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["Recycle"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["19.6495"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1326645999][
                    GeneralUtilities`Slice[
                    Key[
                    $CellContext`f["Recycle"]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}}, 
                 BaseStyle -> {ContextMenu -> {
                    MenuItem["Copy position to clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy data to clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste position in new cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste data in new cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}, FontFamily -> "Verdana", 
                   FontSize -> 12}, Alignment -> Left, RowMinHeight -> 1.5, 
                 Dividers -> All, FrameStyle -> GrayLevel[0.85], 
                 BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
                LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> 
                False, ShowAutoStyles -> False]], 
             TypeSystem`NestedGrid`PackagePrivate`initialQ = True, 
             TypeSystem`NestedGrid`PackagePrivate`self = $Failed}, 
            Dynamic[
             TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
             TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
                Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
                
                Module[{
                 TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
                  TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
                  TypeSystem`NestedGrid`PackagePrivate`LookupCacheValue[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$["Data"]]}, 
                 TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = 
                  If[TypeSystem`NestedGrid`PackagePrivate`tmpData$ === 
                    TypeSystem`NestedGrid`PackagePrivate`$NotCached, 
                    TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
                    TypeSystem`NestedGrid`PackagePrivate`renderGrid[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 1326645999][
                    TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
                   Not[
                    FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
                   TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
                   TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
              TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
              TypeSystem`NestedGrid`PackagePrivate`$pos$$; If[
                FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
                TypeSystem`SparseGrid[
                 TypeSystem`H["(data no longer present)"]], 
                If[GeneralUtilities`$DebugMode, 
                 Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
                   TypeSystem`NestedGrid`PackagePrivate`formatState[
                   TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$]}], 
                 TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
             TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$pos$$}],
             DynamicModuleValues :> {}], 
          TypeSystem`NestedGrid`PackagePrivate`$posCell$$, 
          TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
            TypeSystem`NestedGrid`PackagePrivate`alignBar[
            TypeSystem`NestedGrid`PackagePrivate`$state$$][
             TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
              TypeSystem`PackageScope`Pathbar[
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
               TypeSystem`NestedGrid`PackagePrivate`updateState[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$grid$$, 1326645999]]]], 
            TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}],
           TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Framed[
            Dynamic[
             Replace[
              MouseAnnotation[Null], {
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[1326645999][
                Null] -> "", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[1326645999][
                 Pattern[TypeSystem`NestedGrid`PackagePrivate`path, 
                  Blank[]]] :> (
                TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
                 TypeSystem`NestedGrid`PackagePrivate`path; 
                TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
                 TypeSystem`NestedGrid`PackagePrivate`path, 
                  TypeSystem`NestedGrid`PackagePrivate`makePathElements]), 
               Null :> Spacer[10], Blank[] :> Spacer[10]}], 
             TrackedSymbols :> {}], FrameStyle -> None, ImageMargins -> 0, 
            FrameMargins -> 0, Alignment -> Top, 
            ImageSize -> {Automatic, 14}]}, 
         DynamicBox[
          ToBoxes[
           Column[
            If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, {
              TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
               TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
              TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
               TypeSystem`NestedGrid`PackagePrivate`alignBar[
               TypeSystem`NestedGrid`PackagePrivate`$state$$][
               TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}, {
             TypeSystem`NestedGrid`PackagePrivate`$topBar$$, 
              TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
               TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
              TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
               TypeSystem`NestedGrid`PackagePrivate`alignBar[
               TypeSystem`NestedGrid`PackagePrivate`$state$$][
               TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}], 
            Spacings -> 
            If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, 
              0, {{}, {0, 0.05, 0}}]], StandardForm], 
          ImageSizeCache -> {140., {122., 128.}}, 
          TrackedSymbols :> {
           TypeSystem`NestedGrid`PackagePrivate`$state$$, 
            TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
         BaseStyle -> {LineBreakWithin -> False}, Deinitialization :> 
         TypeSystem`NestedGrid`PackagePrivate`deleteState[
          TypeSystem`NestedGrid`PackagePrivate`$state$$], 
         DynamicModuleValues :> {}, Initialization :> 
         Block[{$ContextPath = $ContextPath}, 
           Needs["TypeSystem`"]]], Deploy, DefaultBaseStyle -> "Deploy"]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("Dataset[<>]"& )], 
     TemplateBox[{TagBox[
        DynamicModuleBox[{
         TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
          Data`UnorderedAssociation[
           "RowCount" -> 8, "Length" -> 8, "InitialType" -> 
            TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Atom[Real], 8], "Shape" -> 
            TypeSystem`PackageScope`Limited[
              TypeSystem`PackageScope`ColumnShape[
               TypeSystem`PackageScope`KeyValueShape[
               TypeSystem`PackageScope`UnknownShape, 
                TypeSystem`PackageScope`AtomShape[60]]], 8, {}], 
            "InitialData" -> TypeSystem`PackageScope`CacheHandle[231347766], 
            "Type" -> TypeSystem`Assoc[TypeSystem`AnyType, 
              TypeSystem`Atom[Real], 8], "HandleQ" -> True, "RowTarget" -> 20,
             "Data" -> TypeSystem`PackageScope`CacheHandle[231347766]], 
          TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
          TypeSystem`NestedGrid`PackagePrivate`$pos$$ = 1, 
          TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
          DynamicModule[{
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
               Style[
                Grid[{{
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "A", "\"R\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["3.05804"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "A", "\"E\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "A", "\"s*\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]Times\[UnderBracket]DoubleQuote]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["1.84799"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]Times\[UnderBracket]DoubleQuote]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "A", "\"IV\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    Key[
                    Subscript[
                    $CellContext`c["IV"], $CellContext`A]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    Key[
                    Subscript[
                    $CellContext`c["IV"], $CellContext`A]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "B", "\"R\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "B", "\"E\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0.973709"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\
\[UnderBracket]DoubleQuote]]], "Mouse"], ImageSize -> {{60, Full}, Automatic},
                     Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "B", "\"s*\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]Times\[UnderBracket]DoubleQuote]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["2.46043"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    
                    Key[$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]Times\[UnderBracket]DoubleQuote]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}, {
                   Item[
                    Pane[
                    Pane[
                    Annotation[
                    RawBoxes[
                    StyleBox[
                    SubsuperscriptBox["c", "B", "\"I\""], FontFamily -> 
                    "Source Code Pro", FontSize -> 13, ShowStringCharacters -> 
                    True]], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    Key[
                    Subscript[
                    $CellContext`c["I"], $CellContext`B]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}], 
                    ImageSize -> {{60, Full}, Automatic}], Background -> 
                    GrayLevel[0.95], Alignment -> {Left, Baseline}], 
                   Pane[
                    Annotation[
                    RawBoxes["0"], 
                    TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                    1507699124][
                    GeneralUtilities`Slice[
                    Key[
                    Subscript[
                    $CellContext`c["I"], $CellContext`B]]]], "Mouse"], 
                    ImageSize -> {{60, Full}, Automatic}, 
                    Alignment -> {Left, Baseline}]}}, 
                 BaseStyle -> {ContextMenu -> {
                    MenuItem["Copy position to clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy data to clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste position in new cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste data in new cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}, FontFamily -> "Verdana", 
                   FontSize -> 12}, Alignment -> Left, RowMinHeight -> 1.5, 
                 Dividers -> All, FrameStyle -> GrayLevel[0.85], 
                 BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
                LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> 
                False, ShowAutoStyles -> False]], 
             TypeSystem`NestedGrid`PackagePrivate`initialQ = True, 
             TypeSystem`NestedGrid`PackagePrivate`self = $Failed}, 
            Dynamic[
             TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
             TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
                Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
                
                Module[{
                 TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
                  TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
                  TypeSystem`NestedGrid`PackagePrivate`LookupCacheValue[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$["Data"]]}, 
                 TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = 
                  If[TypeSystem`NestedGrid`PackagePrivate`tmpData$ === 
                    TypeSystem`NestedGrid`PackagePrivate`$NotCached, 
                    TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
                    TypeSystem`NestedGrid`PackagePrivate`renderGrid[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 1507699124][
                    TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
                   Not[
                    FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
                   TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
                   TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
              TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
              TypeSystem`NestedGrid`PackagePrivate`$pos$$; If[
                FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
                TypeSystem`SparseGrid[
                 TypeSystem`H["(data no longer present)"]], 
                If[GeneralUtilities`$DebugMode, 
                 Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
                   TypeSystem`NestedGrid`PackagePrivate`formatState[
                   TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$]}], 
                 TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
             TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$pos$$}],
             DynamicModuleValues :> {}], 
          TypeSystem`NestedGrid`PackagePrivate`$posCell$$, 
          TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
            TypeSystem`NestedGrid`PackagePrivate`alignBar[
            TypeSystem`NestedGrid`PackagePrivate`$state$$][
             TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
              TypeSystem`PackageScope`Pathbar[
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
               TypeSystem`NestedGrid`PackagePrivate`updateState[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                TypeSystem`NestedGrid`PackagePrivate`$grid$$, 1507699124]]]], 
            TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}],
           TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Framed[
            Dynamic[
             Replace[
              MouseAnnotation[Null], {
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[1507699124][
                Null] -> "", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[1507699124][
                 Pattern[TypeSystem`NestedGrid`PackagePrivate`path, 
                  Blank[]]] :> (
                TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
                 TypeSystem`NestedGrid`PackagePrivate`path; 
                TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
                 TypeSystem`NestedGrid`PackagePrivate`path, 
                  TypeSystem`NestedGrid`PackagePrivate`makePathElements]), 
               Null :> Spacer[10], Blank[] :> Spacer[10]}], 
             TrackedSymbols :> {}], FrameStyle -> None, ImageMargins -> 0, 
            FrameMargins -> 0, Alignment -> Top, 
            ImageSize -> {Automatic, 14}]}, 
         DynamicBox[
          ToBoxes[
           Column[
            If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, {
              TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
               TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
              TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
               TypeSystem`NestedGrid`PackagePrivate`alignBar[
               TypeSystem`NestedGrid`PackagePrivate`$state$$][
               TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}, {
             TypeSystem`NestedGrid`PackagePrivate`$topBar$$, 
              TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
               TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
              TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
               TypeSystem`NestedGrid`PackagePrivate`alignBar[
               TypeSystem`NestedGrid`PackagePrivate`$state$$][
               TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}], 
            Spacings -> 
            If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, 
              0, {{}, {0, 0.05, 0}}]], StandardForm], 
          ImageSizeCache -> {140., {109., 115.}}, 
          TrackedSymbols :> {
           TypeSystem`NestedGrid`PackagePrivate`$state$$, 
            TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
         BaseStyle -> {LineBreakWithin -> False}, Deinitialization :> 
         TypeSystem`NestedGrid`PackagePrivate`deleteState[
          TypeSystem`NestedGrid`PackagePrivate`$state$$], 
         DynamicModuleValues :> {}, Initialization :> 
         Block[{$ContextPath = $ContextPath}, 
           Needs["TypeSystem`"]]], Deploy, DefaultBaseStyle -> "Deploy"]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("Dataset[<>]"& )]}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {Center, Top}},
   GridBoxFrame->{"Columns" -> {True, True, True}, "Rows" -> False},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {4}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.7141315339510126`*^9, 3.7141315441358232`*^9}, {
   3.714131662503641*^9, 3.714131680825677*^9}, {3.714131727359481*^9, 
   3.714131749966449*^9}, 3.7141318051741443`*^9, 3.7141319768253765`*^9, {
   3.714132067489582*^9, 3.7141321713060417`*^9}, 3.7141323247599297`*^9, 
   3.7141324435872164`*^9, 3.7141324871698947`*^9, {3.7141340151426196`*^9, 
   3.7141340276212783`*^9}, 3.7141343952144976`*^9, {3.714134469475994*^9, 
   3.714134485727689*^9}, {3.714134526092181*^9, 3.714134610207329*^9}, 
   3.7141346416712*^9, {3.7141346748473315`*^9, 3.71413476353728*^9}, {
   3.7141348390056157`*^9, 3.7141348739878464`*^9}, 3.714134960452091*^9, {
   3.7141350149914775`*^9, 3.7141350524327526`*^9}, 3.714135083200481*^9, {
   3.7141351225376134`*^9, 3.714135138601774*^9}, 3.7141362942383585`*^9, 
   3.714142785944504*^9, 3.714210096023182*^9, 3.714210995419901*^9, 
   3.7142160778961244`*^9, 3.7142405866443777`*^9, 
   3.7143401677074127`*^9},ExpressionUUID->"625c06ed-3b00-4db4-bd14-\
84b89ceff0f8"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Wrap the Procedure into a User Interface", "Section",
 CellChangeTimes->{{3.7133620544850044`*^9, 
  3.7133620682539067`*^9}},ExpressionUUID->"feb813be-cbab-4d55-be97-\
a79fb3edf217"],

Cell[CellGroupData[{

Cell["Ideal", "Subsection",
 CellChangeTimes->{{3.71344494192712*^9, 
  3.7134449433781724`*^9}},ExpressionUUID->"7a45ab68-6038-4ed7-b168-\
3822beb688e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"idealSWDdesign", "[", 
    RowBox[{
    "a1", ",", "a2", ",", "b1", ",", "b2", ",", "yt", ",", "cf1", ",", "cf2", 
     ",", "ep", ",", "eb", ",", "lc", ",", "db", ",", "ff"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a1", ",", "1", ",", 
       "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(A\)]\)\>\""}], 
      "}"}], ",", "0", ",", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "a2", ",", "2", ",", 
       "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(B\)]\)\>\""}], 
      "}"}], ",", "0", ",", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b1", ",", "0.1", ",", 
       "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(A\)]\)\>\""}], 
      "}"}], ",", "0", ",", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "b2", ",", "0.2", ",", 
       "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(B\)]\)\>\""}], 
      "}"}], ",", "0", ",", "5", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "yt", ",", "1", ",", 
       "\"\<Yield Target: \!\(\*SubscriptBox[\(y\), \(target\)]\)\>\""}], 
      "}"}], ",", "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "cf1", ",", "3", ",", 
       "\"\<Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(A\), \
\(F\)]\)\>\""}], "}"}], ",", "0", ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "cf2", ",", "3", ",", 
       "\"\<Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(B\), \
\(F\)]\)\>\""}], "}"}], ",", "0", ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "eb", ",", "0.46", ",", 
       "\"\<Bed Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \
\(b\)]\)\>\""}], "}"}], ",", "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ep", ",", "0", ",", 
       "\"\<Particle Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\
\)\>\""}], "}"}], ",", "0", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "lc", ",", "96", ",", 
       "\"\<Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)\>\""}], "}"}], ",",
      "0", ",", "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "db", ",", "2.56", ",", 
       "\"\<Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)\>\""}], "}"}], 
     ",", "0", ",", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ff", ",", "5.7", ",", 
       "\"\<Feed Flow: \!\(\*SuperscriptBox[\(f\), \(F\)]\)\>\""}], "}"}], 
     ",", "0", ",", "50", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.714128255206359*^9, 3.714128373130574*^9}, {
  3.7141284079201365`*^9, 3.714128470314571*^9}, {3.714130082196892*^9, 
  3.7141300854002237`*^9}, {3.714135199448295*^9, 3.7141353335147977`*^9}, {
  3.7141354908273463`*^9, 3.714135496515463*^9}, {3.7141413137537875`*^9, 
  3.7141413173115683`*^9}, {3.714141543563696*^9, 3.714141649144135*^9}, {
  3.7141417171875625`*^9, 3.7141417238772893`*^9}, {3.7141419453649836`*^9, 
  3.714142243037202*^9}, {3.7141425415199437`*^9, 
  3.714142598739427*^9}},ExpressionUUID->"84569ca5-02f1-4c59-a6ec-\
70e50214199e"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a1$$ = 1, $CellContext`a2$$ = 
    2, $CellContext`b1$$ = 0.1, $CellContext`b2$$ = 0.2, $CellContext`cf1$$ = 
    3, $CellContext`cf2$$ = 3, $CellContext`db$$ = 2.56, $CellContext`eb$$ = 
    0.46, $CellContext`ep$$ = 0, $CellContext`ff$$ = 5.7, $CellContext`lc$$ = 
    96, $CellContext`yt$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`a1$$], 1, 
       "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(A\)]\)"}, 0, 5}, {{
       Hold[$CellContext`a2$$], 2, 
       "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(B\)]\)"}, 0, 5}, {{
       Hold[$CellContext`b1$$], 0.1, 
       "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(A\)]\)"}, 0, 5}, {{
       Hold[$CellContext`b2$$], 0.2, 
       "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(B\)]\)"}, 0, 5}, {{
       Hold[$CellContext`yt$$], 1, 
       "Yield Target: \!\(\*SubscriptBox[\(y\), \(target\)]\)"}, 0, 1}, {{
       Hold[$CellContext`cf1$$], 3, 
       "Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(A\), \(F\)]\)"}, 
      0, 10}, {{
       Hold[$CellContext`cf2$$], 3, 
       "Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(B\), \(F\)]\)"}, 
      0, 10}, {{
       Hold[$CellContext`eb$$], 0.46, 
       "Bed Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)"}, 0, 
      1}, {{
       Hold[$CellContext`ep$$], 0, 
       "Particle Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)"},
       0, 1}, {{
       Hold[$CellContext`lc$$], 96, 
       "Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)"}, 0, 100}, {{
       Hold[$CellContext`db$$], 2.56, 
       "Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)"}, 0, 10}, {{
       Hold[$CellContext`ff$$], 5.7, 
       "Feed Flow: \!\(\*SuperscriptBox[\(f\), \(F\)]\)"}, 0, 50}}, 
    Typeset`size$$ = {587., {167., 173.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`a1$6346$$ = 0, $CellContext`a2$6351$$ = 
    0, $CellContext`b1$6352$$ = 0, $CellContext`b2$6353$$ = 
    0, $CellContext`yt$6354$$ = 0, $CellContext`cf1$6355$$ = 
    0, $CellContext`cf2$6356$$ = 0, $CellContext`eb$6357$$ = 
    0, $CellContext`ep$6358$$ = 0, $CellContext`lc$6359$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a1$$ = 1, $CellContext`a2$$ = 
        2, $CellContext`b1$$ = 0.1, $CellContext`b2$$ = 
        0.2, $CellContext`cf1$$ = 3, $CellContext`cf2$$ = 
        3, $CellContext`db$$ = 2.56, $CellContext`eb$$ = 
        0.46, $CellContext`ep$$ = 0, $CellContext`ff$$ = 
        5.7, $CellContext`lc$$ = 96, $CellContext`yt$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`a1$$, $CellContext`a1$6346$$, 0], 
        Hold[$CellContext`a2$$, $CellContext`a2$6351$$, 0], 
        Hold[$CellContext`b1$$, $CellContext`b1$6352$$, 0], 
        Hold[$CellContext`b2$$, $CellContext`b2$6353$$, 0], 
        Hold[$CellContext`yt$$, $CellContext`yt$6354$$, 0], 
        Hold[$CellContext`cf1$$, $CellContext`cf1$6355$$, 0], 
        Hold[$CellContext`cf2$$, $CellContext`cf2$6356$$, 0], 
        Hold[$CellContext`eb$$, $CellContext`eb$6357$$, 0], 
        Hold[$CellContext`ep$$, $CellContext`ep$6358$$, 0], 
        Hold[$CellContext`lc$$, $CellContext`lc$6359$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`idealSWDdesign[$CellContext`a1$$, \
$CellContext`a2$$, $CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, \
$CellContext`cf1$$, $CellContext`cf2$$, $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`ff$$], 
      "Specifications" :> {{{$CellContext`a1$$, 1, 
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(A\)]\)"}, 0, 5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`a2$$, 2, 
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(B\)]\)"}, 0, 5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`b1$$, 0.1, 
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(A\)]\)"}, 0, 5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`b2$$, 0.2, 
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(B\)]\)"}, 0, 5, 
         Appearance -> 
         "Labeled"}, {{$CellContext`yt$$, 1, 
          "Yield Target: \!\(\*SubscriptBox[\(y\), \(target\)]\)"}, 0, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`cf1$$, 3, 
          "Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(A\), \
\(F\)]\)"}, 0, 10, Appearance -> 
         "Labeled"}, {{$CellContext`cf2$$, 3, 
          "Feed Concentration: \!\(\*SubsuperscriptBox[\(c\), \(B\), \
\(F\)]\)"}, 0, 10, Appearance -> 
         "Labeled"}, {{$CellContext`eb$$, 0.46, 
          "Bed Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)"}, 
         0, 1, Appearance -> 
         "Labeled"}, {{$CellContext`ep$$, 0, 
          "Particle Void Fraction: \!\(\*SubscriptBox[\(\[Epsilon]\), \
\(p\)]\)"}, 0, 1, Appearance -> 
         "Labeled"}, {{$CellContext`lc$$, 96, 
          "Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)"}, 0, 100, 
         Appearance -> 
         "Labeled"}, {{$CellContext`db$$, 2.56, 
          "Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)"}, 0, 10, 
         Appearance -> 
         "Labeled"}, {{$CellContext`ff$$, 5.7, 
          "Feed Flow: \!\(\*SuperscriptBox[\(f\), \(F\)]\)"}, 0, 50, 
         Appearance -> "Labeled"}}, 
      "Options" :> {ContinuousAction -> False, ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1033., {199., 205.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`idealSWDdesign[
         Pattern[$CellContext`a1, 
          Blank[]], 
         Pattern[$CellContext`a2, 
          Blank[]], 
         Pattern[$CellContext`b1, 
          Blank[]], 
         Pattern[$CellContext`b2, 
          Blank[]], 
         Pattern[$CellContext`yt, 
          Blank[]], 
         Pattern[$CellContext`cf1, 
          Blank[]], 
         Pattern[$CellContext`cf2, 
          Blank[]], 
         Pattern[$CellContext`ep, 
          Blank[]], 
         Pattern[$CellContext`eb, 
          Blank[]], 
         Pattern[$CellContext`lc, 
          Blank[]], 
         Pattern[$CellContext`db, 
          Blank[]], 
         Pattern[$CellContext`ff, 
          Blank[]]] := 
       Block[{$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A = \
$CellContext`a1, $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B = \
$CellContext`a2, $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A = \
$CellContext`b1, $CellContext`b\[UnderBracket]Subscript\[UnderBracket]B = \
$CellContext`b2, $CellContext`y\[UnderBracket]Subscript\[UnderBracket]target = \
$CellContext`yt, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]\
DoubleQuote = $CellContext`cf1, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\
\[UnderBracket]DoubleQuote = $CellContext`cf2, $CellContext`iterationResults, \
$CellContext`formattedIteration, $CellContext`designResults}, \
$CellContext`iterationResults = 
          NestWhileList[$CellContext`idealNextEstimateFunction, \
{$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote, \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote}, Apply[
            Or, 
             $CellContext`idealToleranceFunction[#]]& ]; \
$CellContext`formattedIteration = Map[ReplaceAll[
             
             Join[#, {$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote}], 
             
             Apply[$CellContext`idealPeakUpdateFunction, #]]& , \
$CellContext`iterationResults]; $CellContext`designResults = \
$CellContext`calculateMvalues[
            
            Part[$CellContext`iterationResults, -1], $CellContext`ep, \
$CellContext`eb, $CellContext`lc, $CellContext`db, $CellContext`ff, \
$CellContext`yt]; 
         Grid[{{"Iteration Results", "Final Design", 
             "Concentration Predictions"}, {
             $CellContext`formatSWD[$CellContext`formattedIteration], 
             Dataset[
              Part[$CellContext`designResults, 
               Span[1, -9]]], 
             Dataset[
              Part[$CellContext`designResults, 
               Span[-8, All]]]}}, Frame -> {{True, True, True}, False}, 
           ItemSize -> {Automatic, {4}}, 
           Alignment -> {
            Center, {Center, Top}}]], $CellContext`idealNextEstimateFunction[{
          
          Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
           Blank[]], 
          
          Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
           
           Blank[]]}] := {($CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\
\[UnderBracket]DoubleQuote ($CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]A - $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote)^2]) \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
           Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) (
           2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B^2 + 
           2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
           2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B 
            Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                 1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target)/(
         4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B) \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
          1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
          4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
              1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])), \
(($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + 
           Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote)^2]) \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 (
             1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) (-1 + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote $CellContext`y\
\[UnderBracket]Subscript\[UnderBracket]target) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A 
            Sqrt[($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2 + \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2 + 
              2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (-1 - $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote (-1 + $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote))] (
             1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
             2 - $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target + $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A^2 \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B (-
              Sqrt[($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2 + \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2 + 
                2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (-1 - $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote (-1 + $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote))] + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (-1 + $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - 
                 2 $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]\
A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]\
DoubleQuote $CellContext`y\[UnderBracket]Subscript\[UnderBracket]target)))))/(
         2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B) \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
          4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
              1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]))}, \
$CellContext`idealToleranceFunction[{
          Pattern[$CellContext`c\[UnderBracket]Subscript\[UnderBracket]A, 
           Blank[]], 
          Pattern[$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B, 
           Blank[]]}] := Map[Abs[#] > 0.0001& , 
         Apply[Subtract, 
          
          ReplaceAll[{$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote}, {
            $CellContext`initialIdealPeakFunction[$CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]A, \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B], 
            $CellContext`idealPeakUpdateFunction[$CellContext`c\[UnderBracket]\
Subscript\[UnderBracket]A, $CellContext`c\[UnderBracket]Subscript\
\[UnderBracket]B]}]]], $CellContext`initialIdealPeakFunction[
         Pattern[$CellContext`c\[UnderBracket]Subscript\[UnderBracket]A, 
          Blank[]], 
         Pattern[$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B, 
          
          Blank[]]] := {$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote -> ($CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]A - $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]B + 
           Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]A) + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]B)^2])/(
          2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A), $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]p\[UnderBracket]DoubleQuote -> (-$CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]A + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]B + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subscript\[UnderBracket]A) + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subscript\[UnderBracket]B)^2])/(
          2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B)}, \
$CellContext`idealPeakUpdateFunction[
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]], 
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          
          Blank[]]] := {$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\
\[UnderBracket]DoubleQuote -> ($CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\
\[UnderBracket]DoubleQuote ($CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]A + $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
            Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                 1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) \
((-2) $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B^2 - 
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - 
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B 
            Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                 1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target)/($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) \
(-$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B - 
           2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
           Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])), \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]p\[UnderBracket]DoubleQuote -> \
(-$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote)^2])/(
          2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B)}, \
$CellContext`calculateMvalues[
         Pattern[$CellContext`cs, 
          Blank[]], 
         Pattern[$CellContext`ep, 
          Blank[]], 
         Pattern[$CellContext`eb, 
          Blank[]], 
         Pattern[$CellContext`lc, 
          Blank[]], 
         Pattern[$CellContext`db, 
          Blank[]], 
         Pattern[$CellContext`ff, 
          Blank[]], 
         Pattern[$CellContext`yt, 
          Blank[]]] := 
       Block[{$CellContext`A\[UnderBracket]Subscript\[UnderBracket]c = 
          Pi ($CellContext`db/
             2)^2, $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]p = $CellContext`ep, \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b = \
$CellContext`eb, $CellContext`L\[UnderBracket]Subscript\[UnderBracket]c = \
$CellContext`lc, $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]t = $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b + $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]p (
             1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b), $CellContext`zoneVelocityResults = 
          Apply[$CellContext`idealZoneVelocityFunction, $CellContext`cs], \
$CellContext`retentionResults = 
          Apply[$CellContext`idealRetentionFunction, $CellContext`cs], \
$CellContext`feed = $CellContext`f[
            "F"] -> $CellContext`ff, $CellContext`mvals, $CellContext`tsw}, \
$CellContext`zoneFlowResults = 
          ReplaceAll[$CellContext`zoneFlowEstimates, \
$CellContext`zoneVelocityResults]; $CellContext`portFlowResults = ReplaceAll[
            ReplaceAll[
             
             ReplaceAll[$CellContext`portFlowEstimates, \
$CellContext`zoneFlowResults], $CellContext`zoneVelocityResults], \
$CellContext`feed]; $CellContext`concentrationResults = ReplaceAll[
            ReplaceAll[
             ReplaceAll[
              
              Apply[$CellContext`secondaryEstimatesFunction, \
$CellContext`cs], $CellContext`zoneFlowResults], \
$CellContext`portFlowResults], $CellContext`feed]; $CellContext`tsw = 
          ReplaceAll[
            ReplaceAll[
             
             ReplaceAll[$CellContext`t\[UnderBracket]Subscript\[UnderBracket]\
sw -> $CellContext`L\[UnderBracket]Subscript\[UnderBracket]c/$CellContext`v, \
$CellContext`idealVelocityEstimate], $CellContext`retentionResults], \
$CellContext`feed]; $CellContext`mvals = ReplaceAll[
            ReplaceAll[
             
             ReplaceAll[$CellContext`mValues, \
$CellContext`zoneVelocityResults], $CellContext`feed], $CellContext`tsw]; 
         Association[
           Join[
            Join[
             
             Join[{$CellContext`tsw}, $CellContext`mvals], \
$CellContext`portFlowResults], $CellContext`concentrationResults]]], \
$CellContext`idealZoneVelocityFunction[
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]], 
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]]] := {Subscript[
           $CellContext`u["I"], 
           0] -> ((1 + ((
               1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b) ($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))/$\
CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) \
$CellContext`f[
            "F"])/($CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B/(
            
            1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) - (
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2)/($\
CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])) \
(-1 + $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) (-1 + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p)), Subscript[
           $CellContext`u["II"], 
           0] -> ((1 + ((
               1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b) (((-2) \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 (-1 + $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))/($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
                4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                    1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]\
A $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))/$\
CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) \
$CellContext`f[
            "F"])/($CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B/(
            1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) - (
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2)/($\
CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])) \
(-1 + $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) (-1 + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p)), Subscript[
           $CellContext`u["III"], 
           0] -> ((1 + ((
               1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b) ($CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]p + ($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p)/(
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)))/$CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) $CellContext`f[
            "F"])/($CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B/(
            1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) - (
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2)/($\
CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])) \
(-1 + $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) (-1 + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p)), Subscript[
           $CellContext`u["IV"], 
           0] -> ((1 + ((
               1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]b) (((-2) \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B (-1 + $CellContext`\[Epsilon]\
\[UnderBracket]Subscript\[UnderBracket]p))/($CellContext`a\[UnderBracket]\
Subscript\[UnderBracket]A + $CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]B + $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
                Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                    1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]\
A $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))/$\
CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) \
$CellContext`f[
            "F"])/($CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B/(
            1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) - (
            2 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2)/($\
CellContext`a\[UnderBracket]Subscript\[UnderBracket]A + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2])) \
(-1 + $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) (-1 + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))}, 
       Attributes[Subscript] = {
        NHoldRest}, $CellContext`idealRetentionFunction[
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]], 
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]]] := {Subscript[
           $CellContext`\[Delta][
           "I"], $CellContext`B] -> $CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]B + $CellContext`\[Epsilon]\[UnderBracket]Subscript\
\[UnderBracket]p - $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p, Subscript[
           $CellContext`\[Delta][
           "II"], $CellContext`A] -> ((-2) \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A^2 (-1 + $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p))/($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote - Sqrt[
           4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
               1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p, Subscript[
           $CellContext`\[Delta][
           "III"], $CellContext`B] -> \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p + \
($CellContext`a\[UnderBracket]Subscript\[UnderBracket]B - $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B $CellContext`\[Epsilon]\
\[UnderBracket]Subscript\[UnderBracket]p)/(
           1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote), Subscript[
           $CellContext`\[Delta][
           "IV"], $CellContext`A] -> ((-2) \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]B (-1 + $CellContext`\[Epsilon]\
\[UnderBracket]Subscript\[UnderBracket]p))/($CellContext`a\[UnderBracket]\
Subscript\[UnderBracket]A + $CellContext`a\[UnderBracket]Subscript\
\[UnderBracket]B + $CellContext`a\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]A $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + $CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + 
           Sqrt[4 $CellContext`a\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`b\[UnderBracket]Subscript\[UnderBracket]B $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote $CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote + ($CellContext`a\
\[UnderBracket]Subscript\[UnderBracket]A - \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]B (
                1 + $CellContext`b\[UnderBracket]Subscript\[UnderBracket]A \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote) + \
$CellContext`a\[UnderBracket]Subscript\[UnderBracket]A $CellContext`b\
\[UnderBracket]Subscript\[UnderBracket]B \
$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]and\
\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]DoubleQuote)^2]) + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]p}, \
$CellContext`zoneFlowResults = {$CellContext`f["I"] -> 
         6.9919305749370055` $CellContext`f["F"], $CellContext`f["II"] -> 
         3.910927146022414 $CellContext`f["F"], $CellContext`f["III"] -> 
         4.910927146022414 $CellContext`f["F"], $CellContext`f["IV"] -> 
         3.929906656094557 $CellContext`f[
           "F"]}, $CellContext`zoneFlowEstimates = {$CellContext`f[
          "I"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
            $CellContext`u["I"], 0], $CellContext`f[
          "II"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
            $CellContext`u["II"], 0], $CellContext`f[
          "III"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
            $CellContext`u["III"], 0], $CellContext`f[
          "IV"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
            $CellContext`u["IV"], 
            0]}, $CellContext`portFlowResults = {$CellContext`f["R"] -> 
         4.905102449639288, $CellContext`f["D"] -> 
         15.310119594212246`, $CellContext`f["E"] -> 
         15.405017144572959`, $CellContext`f["Recycle"] -> 
         19.649533280472784`}, $CellContext`portFlowEstimates = \
{$CellContext`f[
          "R"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b (Subscript[
             $CellContext`u["III"], 0] - Subscript[
            $CellContext`u["IV"], 0]), $CellContext`f[
          "D"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b (Subscript[
             $CellContext`u["I"], 0] - Subscript[
            $CellContext`u["IV"], 0]), $CellContext`f[
          "E"] -> $CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b (Subscript[
             $CellContext`u["I"], 0] - Subscript[
            $CellContext`u["II"], 0]), $CellContext`f[
          "Recycle"] -> \
$CellContext`A\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
            $CellContext`u["IV"], 
            0]}, $CellContext`concentrationResults = {$CellContext`c\
\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]and\[UnderBracket]\
DoubleQuote\[UnderBracket]R\[UnderBracket]DoubleQuote -> 
         3.0580401029346636`, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\
\[UnderBracket]DoubleQuote -> 
         0, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
Times\[UnderBracket]DoubleQuote -> 1.8479895214912236`, Subscript[
           $CellContext`c["IV"], $CellContext`A] -> 
         0, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\[UnderBracket]\
DoubleQuote -> 
         0, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\[UnderBracket]\
DoubleQuote -> 
         0.9737087508068343, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]Times\[UnderBracket]DoubleQuote -> 2.4604271543549388`, 
         Subscript[
           $CellContext`c["I"], $CellContext`B] -> 
         0}, $CellContext`secondaryEstimatesFunction[
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          Blank[]], 
         Pattern[$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, 
          
          Blank[]]] := {$CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\
\[UnderBracket]DoubleQuote -> ($CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\
\[UnderBracket]DoubleQuote $CellContext`y\[UnderBracket]Subscript\
\[UnderBracket]target $CellContext`f["F"])/$CellContext`f[
          "R"], $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\[UnderBracket]\
DoubleQuote -> -(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]\
DoubleQuote (-1 + \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) $CellContext`f[
             "F"])/$CellContext`f[
           "E"]), $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
Times\[UnderBracket]DoubleQuote -> \
-(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote \
$CellContext`f[
              "F"] - $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]DoubleQuote $CellContext`f["III"])/$CellContext`f["II"]), 
         Subscript[
           $CellContext`c[
           "IV"], $CellContext`A] -> \
-(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote (-1 + \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) $CellContext`f[
             "F"] Subscript[
              $CellContext`u["I"], 0])/($CellContext`f["E"] Subscript[
             $CellContext`u["IV"], 
             0])), $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]\
B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]R\[UnderBracket]\
DoubleQuote -> -(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]\
DoubleQuote (-1 + \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) $CellContext`f[
             "F"])/$CellContext`f[
           "R"]), $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]E\[UnderBracket]\
DoubleQuote -> ($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]\
DoubleQuote $CellContext`y\[UnderBracket]Subscript\[UnderBracket]target \
$CellContext`f["F"])/$CellContext`f[
          "E"], $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
Times\[UnderBracket]DoubleQuote -> \
-(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote \
$CellContext`f[
              "F"] - $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\
\[UnderBracket]DoubleQuote $CellContext`f["III"])/$CellContext`f["II"]), 
         Subscript[
           $CellContext`c[
           "I"], $CellContext`B] -> \
-(($CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\[UnderBracket]\
and\[UnderBracket]DoubleQuote\[UnderBracket]F\[UnderBracket]DoubleQuote (-1 + \
$CellContext`y\[UnderBracket]Subscript\[UnderBracket]target) $CellContext`f[
             "F"] Subscript[
              $CellContext`u["IV"], 0])/($CellContext`f["R"] Subscript[
             $CellContext`u["I"], 
             0]))}, $CellContext`idealVelocityEstimate = $CellContext`v -> \
$CellContext`f[
          "F"]/($CellContext`A\[UnderBracket]Subscript\[UnderBracket]c (-1 + \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b) (Subscript[
            $CellContext`\[Delta]["II"], $CellContext`A] - Subscript[
           $CellContext`\[Delta][
           "III"], $CellContext`B])), $CellContext`mValues = {$CellContext`m[
          "I"] -> (-($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]t) + \
$CellContext`t\[UnderBracket]Subscript\[UnderBracket]sw $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
              $CellContext`u["I"], 
              0])/($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c (
           1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]\
t)), $CellContext`m[
          "II"] -> (-($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]t) + \
$CellContext`t\[UnderBracket]Subscript\[UnderBracket]sw $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
              $CellContext`u["II"], 
              0])/($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c (
           1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]\
t)), $CellContext`m[
          "III"] -> (-($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]t) + \
$CellContext`t\[UnderBracket]Subscript\[UnderBracket]sw $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
              $CellContext`u["III"], 
              0])/($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c (
           1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]\
t)), $CellContext`m[
          "IV"] -> (-($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c \
$CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]t) + \
$CellContext`t\[UnderBracket]Subscript\[UnderBracket]sw $CellContext`\
\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]b Subscript[
              $CellContext`u["IV"], 
              0])/($CellContext`L\[UnderBracket]Subscript\[UnderBracket]c (
           1 - $CellContext`\[Epsilon]\[UnderBracket]Subscript\[UnderBracket]\
t))}, $CellContext`formatSWD[
         Pattern[$CellContext`result, 
          Blank[]]] := Grid[
         Join[{{$CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]s\[UnderBracket]\
DoubleQuote, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]A\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\[UnderBracket]\
DoubleQuote, $CellContext`c\[UnderBracket]Subsuperscript\[UnderBracket]B\
\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]p\[UnderBracket]\
DoubleQuote}}, $CellContext`result], Frame -> All, 
         Background -> {Automatic, {1 -> Gray, -1 -> Lighter[Gray]}}]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.7141283746151004`*^9, 3.714128471595848*^9, 3.7141289198021946`*^9, {
   3.7141300410518208`*^9, 3.7141300858690205`*^9}, 3.7141313614276037`*^9, 
   3.7141314747599654`*^9, 3.714132573559887*^9, 3.71413533454618*^9, {
   3.7141354971405334`*^9, 3.714135579434822*^9}, 3.7141363822436233`*^9, 
   3.71414131968531*^9, 3.714141649776025*^9, 3.714141724609681*^9, {
   3.714141771853109*^9, 3.71414183725035*^9}, 3.7141422090320683`*^9, 
   3.714142243876466*^9, 3.714142544757058*^9, {3.7141425769036255`*^9, 
   3.714142599355878*^9}, {3.714142680444334*^9, 3.7141426905023303`*^9}, 
   3.714216077993122*^9, 3.714240587001171*^9, {3.714241291490014*^9, 
   3.7142412916845074`*^9}, {3.7142433580126543`*^9, 3.714243362062298*^9}, 
   3.714340168323181*^9},ExpressionUUID->"b3c76e85-a1dd-4da2-b78e-\
2f05c95c590b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1718, 1348},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "cf1" -> 
  SubsuperscriptBox["c", "1", "\"F\""], "cf2" -> 
  SubsuperscriptBox["c", "2", "\"F\""], "d1" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"I\""], "d2" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"II\""], "d3" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"III\""], "d4" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"IV\""], "b1" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"I\""], "b2" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"II\""], "b3" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"III\""], "b4" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"IV\""], "u1" -> 
  SubsuperscriptBox["u", "0", "\"I\""], "u2" -> 
  SubsuperscriptBox["u", "0", "\"II\""], "u3" -> 
  SubsuperscriptBox["u", "0", "\"III\""], "u4" -> 
  SubsuperscriptBox["u", "0", "\"IV\""], "kf1" -> 
  SubsuperscriptBox["Kf", "B", "\"I\""], "kf2" -> 
  SubsuperscriptBox["Kf", "A", "\"II\""], "kf3" -> 
  SubsuperscriptBox["Kf", "B", "\"III\""], "kf4" -> 
  SubsuperscriptBox["Kf", "A", "\"IV\""], "e1" -> 
  SubsuperscriptBox["E", "B", "\"I\""], "e2" -> 
  SubsuperscriptBox["E", "A", "\"II\""], "e3" -> 
  SubsuperscriptBox["E", "B", "\"III\""], "e4" -> 
  SubsuperscriptBox["E", "A", "\"IV\""], "ep" -> 
  SubscriptBox["\[Epsilon]", "p"], "eb" -> SubscriptBox["\[Epsilon]", "b"], 
  "et" -> SubscriptBox["\[Epsilon]", "t"], "feed" -> 
  SuperscriptBox["f", "\"F\""], "des" -> SuperscriptBox["f", "\"D\""], "ext" -> 
  SuperscriptBox["f", "\"E\""], "raff" -> SuperscriptBox["f", "\"R\""]},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 231, 4, 100, "Title", "ExpressionUUID" -> \
"ed01b458-61fa-4d99-ac4d-a1e3f1e77b60"],
Cell[CellGroupData[{
Cell[836, 30, 182, 3, 72, "Section", "ExpressionUUID" -> \
"64a4e308-567b-49f3-9c40-eafbfc332c20"],
Cell[1021, 35, 2585, 58, 125, "Text", "ExpressionUUID" -> \
"53e94bd3-e81c-4894-96c9-29043d3a0b68"],
Cell[3609, 95, 693, 14, 49, "Text", "ExpressionUUID" -> \
"31fb755a-cc65-4f0e-8aae-deb062cdca1f"],
Cell[CellGroupData[{
Cell[4327, 113, 380, 10, 43, "Input", "ExpressionUUID" -> \
"8f8ef682-bc38-4d4c-af6f-745ca10b7703"],
Cell[4710, 125, 1280, 19, 39, "Output", "ExpressionUUID" -> \
"c6ee60db-e8ec-4fc1-898d-1528ad48206d"]
}, Open  ]],
Cell[6005, 147, 564, 14, 30, "Text", "ExpressionUUID" -> \
"839c5116-e256-4c10-92c0-fbece89ea0aa"],
Cell[6572, 163, 684, 13, 68, "Text", "ExpressionUUID" -> \
"0ff5e4fa-f9fb-4f1f-b955-25c031b10434"],
Cell[7259, 178, 661, 10, 39, "Input", "ExpressionUUID" -> \
"ba626c86-ac46-47e4-8dc8-8d5f7f809b82"],
Cell[7923, 190, 2294, 57, 340, "Input", "ExpressionUUID" -> \
"3a099395-8913-48de-b810-ef550bb54ac5"],
Cell[10220, 249, 756, 17, 86, "Input", "ExpressionUUID" -> \
"d7c7f4c0-c5f8-47cc-bcc4-c9d7fc419dac"],
Cell[CellGroupData[{
Cell[11001, 270, 1423, 35, 73, "Input", "ExpressionUUID" -> \
"f5b532f4-4de4-4997-9144-c9ef8b66d02e"],
Cell[12427, 307, 3301, 92, 155, "Output", "ExpressionUUID" -> \
"d1f12ddb-69ed-40d7-a26b-6baeea1690df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15765, 404, 1599, 38, 75, "Input", "ExpressionUUID" -> \
"88170bbe-01ee-44b2-85f5-5cdf48e680ef"],
Cell[17367, 444, 4378, 125, 220, "Output", "ExpressionUUID" -> \
"50f4a91c-2148-40fd-9781-2d71be60c96a"]
}, Open  ]],
Cell[21760, 572, 1443, 34, 166, "Input", "ExpressionUUID" -> \
"3dfd05d9-ad20-49be-ac4d-b2bff679cd45"],
Cell[23206, 608, 960, 17, 31, "Text", "ExpressionUUID" -> \
"40a18de7-32e1-465d-bca5-5928c3b00b56"],
Cell[24169, 627, 4388, 97, 176, "Input", "ExpressionUUID" -> \
"903971f3-e12d-43b9-9364-be8a356e2a53"],
Cell[28560, 726, 1857, 37, 255, "Input", "ExpressionUUID" -> \
"e250de69-62f7-4604-a02a-ad4570996a35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30454, 768, 177, 3, 72, "Section", "ExpressionUUID" -> \
"81cb6831-dc10-4571-8c85-777c460dc4d5"],
Cell[CellGroupData[{
Cell[30656, 775, 168, 3, 37, "Subsection", "ExpressionUUID" -> \
"23dfa824-aa7e-4bd6-8cb0-66ab78b6f783"],
Cell[CellGroupData[{
Cell[30849, 782, 1149, 34, 70, "Input", "ExpressionUUID" -> \
"a6bc2d7d-4b6a-4b7b-ac2b-14808f56dcc6"],
Cell[32001, 818, 2050, 47, 70, "Output", "ExpressionUUID" -> \
"076f4199-70b8-4185-86ec-52260cb3c03f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[34100, 871, 227, 4, 37, "Subsection", "ExpressionUUID" -> \
"c3dfc326-054f-4c28-b74b-2def50611e36"],
Cell[CellGroupData[{
Cell[34352, 879, 356, 10, 70, "Input", "ExpressionUUID" -> \
"031187c5-8279-4892-9376-6fd7a3e923a1"],
Cell[34711, 891, 1410, 23, 70, "Output", "ExpressionUUID" -> \
"3128abd7-c8da-4874-bf00-e03f91cb8c20"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36170, 920, 182, 3, 37, "Subsection", "ExpressionUUID" -> \
"5b09e3b9-acb8-48c9-bd2d-b4376e33e589"],
Cell[CellGroupData[{
Cell[36377, 927, 987, 24, 70, "Input", "ExpressionUUID" -> \
"cdc78a48-34ed-4928-a74d-7df7491e3058"],
Cell[37367, 953, 1736, 42, 70, "Output", "ExpressionUUID" -> \
"e727cfa2-92a4-4bc2-93c1-82579b4bb04f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[39152, 1001, 170, 3, 37, "Subsection", "ExpressionUUID" -> \
"503f60f8-1439-4b37-80a6-5cba8874da0f"],
Cell[CellGroupData[{
Cell[39347, 1008, 985, 30, 70, "Input", "ExpressionUUID" -> \
"f34d8587-f514-4523-89b4-c804d363c7cd"],
Cell[40335, 1040, 2543, 77, 70, "Output", "ExpressionUUID" -> \
"e750773c-236d-49f0-abb3-be2f551298a3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[42927, 1123, 178, 3, 37, "Subsection", "ExpressionUUID" -> \
"1a3b5c7b-d694-40bd-b883-74f72cda58ee"],
Cell[CellGroupData[{
Cell[43130, 1130, 156, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"17c45168-52cd-4a15-8ee0-b908007f771f"],
Cell[CellGroupData[{
Cell[43311, 1137, 2536, 69, 70, "Input", "ExpressionUUID" -> \
"8d53744f-a03c-451a-af3c-55077e544482"],
Cell[45850, 1208, 3085, 75, 70, "Output", "ExpressionUUID" -> \
"a892b3c3-49ac-46e1-8070-a9ba4023b99a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[48984, 1289, 211, 4, 35, "Subsubsection", "ExpressionUUID" -> \
"53d26786-ca52-4240-b456-7ff699da96f8"],
Cell[CellGroupData[{
Cell[49220, 1297, 3512, 89, 256, "Input", "ExpressionUUID" -> \
"cddc9ed1-8521-4152-9510-8a50da96fb37"],
Cell[52735, 1388, 4021, 104, 69, "Output", "ExpressionUUID" -> \
"1bdc32a7-1183-49fb-8592-7d32c024dbf9"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[56817, 1499, 227, 4, 37, "Subsection", "ExpressionUUID" -> \
"2b5f5d9d-24ff-4369-8d55-599863a9cba8"],
Cell[CellGroupData[{
Cell[57069, 1507, 1716, 40, 70, "Input", "ExpressionUUID" -> \
"8fedecd6-acc6-451b-a605-977e9e03aa78"],
Cell[58788, 1549, 1415, 34, 70, "Output", "ExpressionUUID" -> \
"3845aa30-a91f-4fb3-b964-dba0f2529fb7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[60252, 1589, 174, 3, 37, "Subsection", "ExpressionUUID" -> \
"11fe0391-c1c4-4633-842f-28d99a545859"],
Cell[CellGroupData[{
Cell[60451, 1596, 226, 4, 35, "Subsubsection", "ExpressionUUID" -> \
"c585d92c-d06a-4883-a221-9db6bbff8dc1"],
Cell[CellGroupData[{
Cell[60702, 1604, 979, 30, 70, "Input", "ExpressionUUID" -> \
"4a222d56-f6e7-4342-b105-586829668d0e"],
Cell[61684, 1636, 4052, 115, 70, "Output", "ExpressionUUID" -> \
"c4dc3eed-02ac-4e83-aac4-65308c6abc3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65773, 1756, 651, 19, 70, "Input", "ExpressionUUID" -> \
"ed217de2-e540-42ff-8c37-82d4a4560446"],
Cell[66427, 1777, 1963, 43, 70, "Output", "ExpressionUUID" -> \
"bf63547b-8e38-4916-a451-dd9f3aeccac4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68427, 1825, 363, 8, 70, "Input", "ExpressionUUID" -> \
"c48f687d-6520-4ceb-9cb2-69a62c02dc56"],
Cell[68793, 1835, 4223, 107, 70, "Output", "ExpressionUUID" -> \
"d51d8c69-3965-4b61-996e-4c2382c42631"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73053, 1947, 605, 15, 70, "Input", "ExpressionUUID" -> \
"59c7991c-1e2f-4204-a0a8-bfa12f317946"],
Cell[73661, 1964, 4132, 107, 70, "Output", "ExpressionUUID" -> \
"4b83bc5a-1e6d-4677-baa4-6f602d4e02b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77830, 2076, 781, 24, 70, "Input", "ExpressionUUID" -> \
"0bdb7d99-c49c-46b0-9970-bddf64657860"],
Cell[78614, 2102, 3809, 100, 70, "Output", "ExpressionUUID" -> \
"48d593a9-472c-4057-b96e-c592a541540c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[82472, 2208, 182, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"c8f14563-3016-4c24-9549-288f240693cd"],
Cell[CellGroupData[{
Cell[82679, 2215, 1315, 37, 70, "Input", "ExpressionUUID" -> \
"e7e3e96d-4479-407d-a291-9b382cfd5978"],
Cell[83997, 2254, 2253, 50, 70, "Output", "ExpressionUUID" -> \
"44b02008-dd7c-45f3-b89b-3c9907f8358d"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86323, 2312, 201, 3, 72, "Section", "ExpressionUUID" -> \
"9e9c8c5b-b58a-4eb6-9f88-3f643224d316"],
Cell[86527, 2317, 294, 7, 30, "Text", "ExpressionUUID" -> \
"25693e43-9eda-4deb-a8a5-1d22fcc3d605"],
Cell[CellGroupData[{
Cell[86846, 2328, 168, 3, 37, "Subsection", "ExpressionUUID" -> \
"3f57054f-f44a-463a-a0f6-afae06c30d41"],
Cell[CellGroupData[{
Cell[87039, 2335, 170, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"4cb4e64a-e65d-41fd-8ad6-97a54bff7cd5"],
Cell[CellGroupData[{
Cell[87234, 2342, 1150, 28, 70, "Input", "ExpressionUUID" -> \
"ea527e96-ed5e-4e86-85ba-5f62eb672d82"],
Cell[88387, 2372, 2930, 69, 70, "Output", "ExpressionUUID" -> \
"29d0dfc0-d8f1-4930-b05f-401f29f2e778"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91354, 2446, 4077, 112, 70, "Input", "ExpressionUUID" -> \
"3f03ee58-df7c-424b-8f11-6bde28dfa428"],
Cell[95434, 2560, 5959, 149, 70, "Output", "ExpressionUUID" -> \
"22fd5221-d858-43a2-a313-614063cce5b6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[101442, 2715, 168, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"efc1051f-e27b-42d7-ba3f-61b59ccfa12f"],
Cell[CellGroupData[{
Cell[101635, 2722, 377, 7, 70, "Input", "ExpressionUUID" -> \
"b2ac3c2b-b560-49eb-b046-24b3575b96c6"],
Cell[102015, 2731, 2184, 45, 70, "Output", "ExpressionUUID" -> \
"f833cd66-8139-4b1b-a3a3-47771cbf1c71"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[104248, 2782, 168, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"ece71722-2305-40b5-b4dd-66cf29db7a34"],
Cell[CellGroupData[{
Cell[104441, 2789, 1387, 31, 70, "Input", "ExpressionUUID" -> \
"0ff060bd-4025-463a-b361-f945943e4034"],
Cell[105831, 2822, 2547, 55, 70, "Output", "ExpressionUUID" -> \
"2f80b2b4-9645-489b-9ad5-e733d50f5043"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[108439, 2884, 173, 3, 37, "Subsection", "ExpressionUUID" -> \
"702530e4-951a-4233-8881-dc06ab623b6e"],
Cell[CellGroupData[{
Cell[108637, 2891, 234, 4, 35, "Subsubsection", "ExpressionUUID" -> \
"aa84a6f6-f8bc-48b8-ad42-40a49bc1bf43"],
Cell[CellGroupData[{
Cell[108896, 2899, 823, 21, 70, "Input", "ExpressionUUID" -> \
"cd9f0de9-940e-4427-9900-8a9b25de4279"],
Cell[109722, 2922, 3991, 104, 70, "Output", "ExpressionUUID" -> \
"9d74f151-549a-4da8-80a7-64387f199965"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113750, 3031, 695, 15, 70, "Input", "ExpressionUUID" -> \
"1223263f-b3e2-46be-baef-cf9e9d0babc9"],
Cell[114448, 3048, 1552, 27, 70, "Output", "ExpressionUUID" -> \
"2dbd8184-fe46-4358-9d35-634c78d381d2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[116049, 3081, 187, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"1b7895bc-fefa-4e19-91bd-fede14a08058"],
Cell[CellGroupData[{
Cell[116261, 3088, 1723, 54, 70, "Input", "ExpressionUUID" -> \
"f162b629-47dc-4cf2-ab01-b0ceb7995b10"],
Cell[117987, 3144, 3267, 80, 70, "Output", "ExpressionUUID" -> \
"ab75ac79-e28d-42d7-8a99-89d2e6736488"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121291, 3229, 941, 15, 70, "Input", "ExpressionUUID" -> \
"4e2778d3-4949-4779-8e6f-3aaa12f392fb"],
Cell[122235, 3246, 1900, 37, 70, "Output", "ExpressionUUID" -> \
"e018d3c8-2c66-464c-a540-38caa8b517d6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[124184, 3289, 172, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"ae943de9-91c8-4cc7-b22b-4dec37bd90be"],
Cell[CellGroupData[{
Cell[124381, 3296, 3914, 101, 70, "Input", "ExpressionUUID" -> \
"92b66054-8898-449e-9a50-db6bfdd508cd"],
Cell[128298, 3399, 3701, 103, 70, "Output", "ExpressionUUID" -> \
"472ecba8-d884-4e45-a46e-2f3287113a88"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[132060, 3509, 178, 3, 37, "Subsection", "ExpressionUUID" -> \
"334fb650-13c7-484b-a2e3-70aac1e918ad"],
Cell[CellGroupData[{
Cell[132263, 3516, 2963, 72, 70, "Input", "ExpressionUUID" -> \
"423b354a-0ad8-40ab-a904-77f2171ea3e9"],
Cell[135229, 3590, 3592, 84, 70, "Output", "ExpressionUUID" -> \
"7122b90e-5774-4a46-a151-40122d697a35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138858, 3679, 2607, 67, 70, "Input", "ExpressionUUID" -> \
"16a2dfa5-6317-4e84-bc39-506793d0e5b6"],
Cell[141468, 3748, 5343, 124, 70, "Output", "ExpressionUUID" -> \
"11cfa52f-cc4d-45ac-924e-9773e1e24c14"]
}, Open  ]],
Cell[146826, 3875, 224, 5, 70, "Text", "ExpressionUUID" -> \
"7a7b9e98-19d5-46d5-a8b0-b73deb8286bf"],
Cell[CellGroupData[{
Cell[147075, 3884, 1835, 48, 70, "Input", "ExpressionUUID" -> \
"5ef3935a-610f-4aef-a7b8-f9b52bcaccbb"],
Cell[148913, 3934, 5334, 143, 70, "Output", "ExpressionUUID" -> \
"7df56a02-5041-44c3-b8c5-4fd3380eea7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154284, 4082, 873, 21, 70, "Input", "ExpressionUUID" -> \
"20ffdedd-916a-4641-972f-751dd48135a3"],
Cell[155160, 4105, 1708, 33, 70, "Output", "ExpressionUUID" -> \
"455ab878-22f2-4052-8c44-b75afb2c19ec"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[156917, 4144, 175, 3, 37, "Subsection", "ExpressionUUID" -> \
"3000d778-6199-429b-9869-cbc7e506cdea"],
Cell[CellGroupData[{
Cell[157117, 4151, 652, 20, 70, "Input", "ExpressionUUID" -> \
"2cb472a9-1672-4231-8259-2cb459e2813e"],
Cell[157772, 4173, 1474, 28, 70, "Output", "ExpressionUUID" -> \
"e9726eec-8e5f-4c35-bb08-a4e4d64a13bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159283, 4206, 728, 19, 70, "Input", "ExpressionUUID" -> \
"e3eddeeb-f947-4383-b0b2-cc7916d84459"],
Cell[160014, 4227, 2204, 48, 70, "Output", "ExpressionUUID" -> \
"b9456266-146c-4c10-acf4-e2ef8e625888"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162255, 4280, 375, 11, 70, "Input", "ExpressionUUID" -> \
"dbf91b15-f4b1-4e9d-b101-40d7af190ef6"],
Cell[162633, 4293, 1416, 25, 70, "Output", "ExpressionUUID" -> \
"063b1fb5-c2ad-4b72-b0d8-f1d3e4c899bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164086, 4323, 584, 18, 70, "Input", "ExpressionUUID" -> \
"b63fdf27-1287-4b97-85bd-e56e7ecf58e2"],
Cell[164673, 4343, 1572, 30, 70, "Output", "ExpressionUUID" -> \
"44dc4dad-deb9-4fe8-81b8-111e8725b245"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166282, 4378, 625, 18, 70, "Input", "ExpressionUUID" -> \
"23e1db72-ea57-4658-a51b-bc9b2390089f"],
Cell[166910, 4398, 1643, 31, 70, "Output", "ExpressionUUID" -> \
"68c42b8a-9452-4cb3-a1e0-2bbadc6db71a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[168602, 4435, 176, 3, 37, "Subsection", "ExpressionUUID" -> \
"b5e31ced-f874-4499-a8d6-f2915d0ddff3"],
Cell[CellGroupData[{
Cell[168803, 4442, 164, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"f8d98dc7-32a7-4c09-b55d-0c7ffd7d1f22"],
Cell[CellGroupData[{
Cell[168992, 4449, 602, 16, 70, "Input", "ExpressionUUID" -> \
"a119b786-d9e0-4809-ace9-4c8dce609cd2"],
Cell[169597, 4467, 1589, 29, 70, "Output", "ExpressionUUID" -> \
"88958483-3e4c-4589-928c-ae89ad75f909"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[171235, 4502, 167, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"8d8dd606-f2e2-422b-b20b-646fb8964387"],
Cell[CellGroupData[{
Cell[171427, 4509, 825, 23, 70, "Input", "ExpressionUUID" -> \
"bdb7ac9b-ffc0-4f70-85f9-e7c2193001f8"],
Cell[172255, 4534, 1815, 37, 70, "Output", "ExpressionUUID" -> \
"50d310a2-d1c7-49f0-920b-4b7538408949"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[174119, 4577, 170, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"0085e4db-b1b1-4a9d-9dfe-d6131bdfe6fb"],
Cell[CellGroupData[{
Cell[174314, 4584, 592, 16, 70, "Input", "ExpressionUUID" -> \
"823285e6-db39-4762-bebd-77302b87fb0b"],
Cell[174909, 4602, 1520, 29, 70, "Output", "ExpressionUUID" -> \
"38f0d5d1-c8a5-4a3e-9d5c-42f8d34981c7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[176478, 4637, 166, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"b6588551-f796-432a-9463-1fa2a88ed1f6"],
Cell[CellGroupData[{
Cell[176669, 4644, 545, 14, 70, "Input", "ExpressionUUID" -> \
"b9a2d80b-7c33-49f0-a0eb-5ccfe215fa26"],
Cell[177217, 4660, 1416, 25, 70, "Output", "ExpressionUUID" -> \
"4a7a529d-e1b2-436d-bd02-6c1a12316ecd"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178706, 4693, 195, 3, 72, "Section", "ExpressionUUID" -> \
"d5426215-cdad-411b-930b-2e939a3d0036"],
Cell[CellGroupData[{
Cell[178926, 4700, 160, 3, 37, "Subsection", "ExpressionUUID" -> \
"5f6ee1ff-570f-48ff-b49d-8b96d24c8ce8"],
Cell[CellGroupData[{
Cell[179111, 4707, 596, 15, 35, "Subsubsection", "ExpressionUUID" -> \
"42c18ab8-cf03-4971-9a39-f2161e06e96e"],
Cell[CellGroupData[{
Cell[179732, 4726, 981, 21, 70, "Input", "ExpressionUUID" -> \
"4dfaa058-5e98-431f-aaad-3a70fd82e0c2"],
Cell[180716, 4749, 4247, 104, 70, "Output", "ExpressionUUID" -> \
"577fb888-ecf7-40d2-a5cd-374d741ac467"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[185012, 4859, 279, 6, 35, "Subsubsection", "ExpressionUUID" -> \
"368d9931-cf20-4a69-960a-7a28eb7f9a4e"],
Cell[CellGroupData[{
Cell[185316, 4869, 1171, 24, 69, "Input", "ExpressionUUID" -> \
"d32dc7f4-3ae0-4eec-9419-596edf4ecabe"],
Cell[186490, 4895, 4868, 132, 80, "Output", "ExpressionUUID" -> \
"568458b3-82de-4149-8005-fd8bf5dd9736"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[191407, 5033, 286, 6, 35, "Subsubsection", "ExpressionUUID" -> \
"802fa45c-76fb-4d78-a1cf-9a06f82838b9"],
Cell[CellGroupData[{
Cell[191718, 5043, 1293, 26, 70, "Input", "ExpressionUUID" -> \
"e52d7032-3c09-4899-9c4c-f1d9d8a7ab0e"],
Cell[193014, 5071, 15781, 422, 70, "Output", "ExpressionUUID" -> \
"936633a1-2c3c-4254-a21e-a8cd0a5c55b2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[208844, 5499, 220, 5, 35, "Subsubsection", "ExpressionUUID" -> \
"3be769dd-845e-4516-b131-824be7c66758"],
Cell[CellGroupData[{
Cell[209089, 5508, 655, 13, 70, "Input", "ExpressionUUID" -> \
"61671682-6fca-4550-bd65-4fca0a704785"],
Cell[209747, 5523, 2664, 61, 70, "Output", "ExpressionUUID" -> \
"cc346e8e-9777-498a-ade6-cb5ebd4887a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212448, 5589, 1023, 23, 70, "Input", "ExpressionUUID" -> \
"9f7935f7-561f-4fd4-837a-5ab239530ce3"],
Cell[213474, 5614, 7641, 198, 70, "Output", "ExpressionUUID" -> \
"89b36b12-43e9-4b7e-b207-6e81e2ee8837"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221152, 5817, 816, 20, 70, "Input", "ExpressionUUID" -> \
"6fdeb492-68c2-4f3c-bf95-9fe8f38755a6"],
Cell[221971, 5839, 9404, 241, 70, "Output", "ExpressionUUID" -> \
"8aa44888-9bac-42e4-be74-967d081d1667"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[231424, 6086, 292, 7, 35, "Subsubsection", "ExpressionUUID" -> \
"2dfb92a4-9839-4936-be91-ebdb620133cd"],
Cell[CellGroupData[{
Cell[231741, 6097, 1570, 42, 70, "Input", "ExpressionUUID" -> \
"d2881159-0399-4d00-a688-1fa82d568e21"],
Cell[233314, 6141, 8963, 229, 70, "Output", "ExpressionUUID" -> \
"b8c8097c-0d9e-4abb-bc21-c7e5b591a56a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[242326, 6376, 232, 4, 35, "Subsubsection", "ExpressionUUID" -> \
"602da070-dd31-479b-ae17-5941695694ee"],
Cell[CellGroupData[{
Cell[242583, 6384, 817, 19, 70, "Input", "ExpressionUUID" -> \
"de6cde1a-5e7f-4755-b326-8f22cc946de7"],
Cell[243403, 6405, 18250, 465, 70, "Output", "ExpressionUUID" -> \
"49039c74-80ab-44e1-b25f-7a8bbec44249"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[261702, 6876, 261, 5, 35, "Subsubsection", "ExpressionUUID" -> \
"37548c11-57de-4acb-a17b-78150627772c"],
Cell[CellGroupData[{
Cell[261988, 6885, 1185, 28, 69, "Input", "ExpressionUUID" -> \
"bed184b2-6f4c-4eef-ad0b-ade4b9cf5de7"],
Cell[263176, 6915, 15532, 416, 272, "Output", "ExpressionUUID" -> \
"26cf505f-688d-4171-b4d3-c4ccdbf22176"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278757, 7337, 173, 3, 35, "Subsubsection", "ExpressionUUID" -> \
"e7a2a9ae-2249-4e38-bbaa-6365cf96addf"],
Cell[278933, 7342, 2007, 53, 70, "Input", "ExpressionUUID" -> \
"b816a541-624c-4f63-9b14-1b9d1a6a0b4b"],
Cell[280943, 7397, 5674, 118, 70, "Input", "ExpressionUUID" -> \
"1bd31a41-aa24-48f9-9f60-fc54c49be2f8"],
Cell[286620, 7517, 1367, 32, 70, "Input", "ExpressionUUID" -> \
"3a280928-1fbc-4298-984e-c8f3fb9fdad3"],
Cell[287990, 7551, 6586, 136, 70, "Input", "ExpressionUUID" -> \
"d32acda3-3c86-430f-afc0-7ec3f852d9cb"],
Cell[CellGroupData[{
Cell[294601, 7691, 509, 9, 70, "Input", "ExpressionUUID" -> \
"2a7c9c9c-7900-4ef1-8d9b-4db834e0ec2c"],
Cell[295113, 7702, 45544, 882, 70, "Output", "ExpressionUUID" -> \
"625c06ed-3b00-4db4-bd14-84b89ceff0f8"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[340730, 8592, 197, 3, 72, "Section", "ExpressionUUID" -> \
"feb813be-cbab-4d55-be97-a79fb3edf217"],
Cell[CellGroupData[{
Cell[340952, 8599, 154, 3, 37, "Subsection", "ExpressionUUID" -> \
"7a45ab68-6038-4ed7-b168-3822beb688e1"],
Cell[CellGroupData[{
Cell[341131, 8606, 4764, 127, 312, "Input", "ExpressionUUID" -> \
"84569ca5-02f1-4c59-a6ec-70e50214199e"],
Cell[345898, 8735, 81712, 1325, 430, "Output", "ExpressionUUID" -> \
"b3c76e85-a1dd-4da2-b78e-2f05c95c590b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

