(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    310673,       8123]
NotebookOptionsPosition[    297978,       7757]
NotebookOutlinePosition[    303022,       7860]
CellTagsIndexPosition[    302979,       7857]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Standing Wave Design - Ideal Langmuir", "Title",
 CellChangeTimes->{{3.706963901015277*^9, 3.706963917889349*^9}, {
  3.713336670750559*^9, 
  3.7133366707705584`*^9}},ExpressionUUID->"844850aa-9b17-4736-b88b-\
edee74b5a5c1"],

Cell[CellGroupData[{

Cell["Step 1: Define the Problem Notation", "Section",
 CellChangeTimes->{{3.7069639650830946`*^9, 
  3.706963974809104*^9}},ExpressionUUID->"6ad0c834-3786-49ca-8c6e-\
49dc4a403272"],

Cell[TextData[{
 "In this section, we \
\[OpenCurlyDoubleQuote]symbolize\[CloseCurlyDoubleQuote] some variables so \
that we can use them later.  By default, if we enter a variable with a \
subscript (e.g. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "36252514-941e-4a5e-8895-0ed1182851d3"],
 ") Mathematica sees Subscript[a,1] instead of a regular symbol like a1.  So \
when you try to assign a value to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "7cccaf37-83e1-43dc-9957-2e1ad77ade90"],
 " (e.g. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "6"}], TraditionalForm]],ExpressionUUID->
  "c16c83f0-a931-43fc-ac9a-36b2a50348b9"],
 "), Mathematica instead says to itself:\n\[OpenCurlyDoubleQuote]the user \
wants to assign a value to Subscript[a,1].  I will add Subscript[_, 1] = 5 to \
the set of things I know about a.\[CloseCurlyDoubleQuote]\nWhen Mathematica \
does this, it is referred to as an \[OpenCurlyDoubleQuote]Upvalue\
\[CloseCurlyDoubleQuote] of the symbol a.\nUsing the Symbolize, function lets \
us tell Mathematica not to interpret ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "ecbb0117-3069-4818-a396-0a505293d427"],
 " as a Subscript function, and so we avoid the use of upvalues.  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "392c2751-62df-465d-827e-5b13a7148baf"],
 " is treated as its own symbol and is no longer connected to the \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] symbol.  That way, when we \
say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "5"}], TraditionalForm]],ExpressionUUID->
  "0a284276-da21-46d7-99e6-f2d927ec645c"],
 " all Mathematica does is assign the value of 5 to the symbol ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "755dd16d-d00b-491c-96c4-f1aec4472e24"],
 " without any kind of upvalues."
}], "Text",
 CellChangeTimes->{{3.706697811970934*^9, 3.7066978572260523`*^9}, {
  3.706698028311755*^9, 3.706698138056162*^9}, {3.706698490209321*^9, 
  3.70669854546424*^9}, {3.7066988160465307`*^9, 3.7066988308940997`*^9}, {
  3.7067079136585436`*^9, 3.7067079851555705`*^9}, {3.7067080312762012`*^9, 
  3.706708071022498*^9}, {3.7067081321651993`*^9, 3.7067082954546*^9}, {
  3.7067083365748663`*^9, 
  3.706708366015239*^9}},ExpressionUUID->"2bf8674c-22d7-48be-a4b4-\
a17d6fe121fa"],

Cell[TextData[{
 "In most cases, the difference between upvalues and values is not important. \
 Algebra and calculus generally work fine with either, and you do not need to \
worry about the difference.  The one area where the difference does matter is \
",
 StyleBox["lexical scoping",
  FontSlant->"Italic"],
 ".  For example, if you want to temporarily assign a value to a variable \
like this:"
}], "Text",
 CellChangeTimes->{{3.706708370614149*^9, 3.7067084080783415`*^9}, {
  3.7067084449173512`*^9, 3.7067084752317624`*^9}, {3.7067085299593534`*^9, 
  3.706708533151581*^9}},ExpressionUUID->"a4842942-5915-4947-a38b-\
7bab8dc954cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", " ", 
   RowBox[{"Evaluate", "[", 
    SuperscriptBox["a", "2"], " ", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706708477171032*^9, 3.7067084894642897`*^9}, {
  3.706708550313186*^9, 
  3.7067085573213086`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{3.713338979959713*^9, 3.713341287505271*^9, 
  3.7133463649184294`*^9, 3.71334683411222*^9, 3.7133470071005573`*^9, 
  3.7133471301795588`*^9, 3.7133474305006313`*^9, 3.7133475595981255`*^9, 
  3.713348619810763*^9, 3.713349910039451*^9, 3.7133503612607813`*^9, 
  3.7133529521733017`*^9, 3.713353067057189*^9, 3.7133531396832247`*^9, 
  3.7133532843052497`*^9, 3.713354874728448*^9, 3.7133612260792503`*^9, 
  3.7133615222710114`*^9, 3.713365356087522*^9, 3.713369184797988*^9, 
  3.7134243664504085`*^9, 3.7134261309211655`*^9, 
  3.7137164761606417`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[TextData[{
 "Mathematica\[CloseCurlyQuote]s scoping construct \
\[OpenCurlyDoubleQuote]With\[CloseCurlyDoubleQuote] can only create temporary \
",
 StyleBox["values,",
  FontSlant->"Italic"],
 " not ",
 StyleBox["upvalues.",
  FontSlant->"Italic"],
 "  So if we want to use these constructs, we need to use Symbolize."
}], "Text",
 CellChangeTimes->{{3.7067085051628046`*^9, 3.7067085982239428`*^9}, {
  3.706964031058267*^9, 
  3.706964033479744*^9}},ExpressionUUID->"6a5bec25-ed4c-49f9-a3a0-\
688786f20791"],

Cell[TextData[{
 "It is also possible to force Mathematica to say the following\n\
\[OpenCurlyDoubleQuote]the user wants to assign a value to Subscript[a,1].  I \
will add Subscript[a, 1] = 5 to the set of things I know",
 StyleBox[" about the Subscript function",
  FontWeight->"Bold"],
 ".\[CloseCurlyDoubleQuote]\nWhen Mathematica does this, 5 is called a \
\[OpenCurlyDoubleQuote]downvalue\[CloseCurlyDoubleQuote] of the symbol \
Subscript."
}], "Text",
 CellChangeTimes->{{3.7067080753723607`*^9, 3.7067081294614725`*^9}, {
  3.7067083297584944`*^9, 
  3.706708331542101*^9}},ExpressionUUID->"ce8d7095-8cdd-479f-877b-\
cb8d3f7d0e2c"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.655654009881259*^9, 3.6556540709341335`*^9}, {
  3.6556541286705556`*^9, 3.6556541386071386`*^9}, {3.6556541826824427`*^9, 
  3.655654184784837*^9}, {3.65565422925277*^9, 3.6556542656382427`*^9}, {
  3.6556543549254217`*^9, 3.6556543753579626`*^9}, {3.6556545287943487`*^9, 
  3.6556545683435383`*^9}, {3.6556552151106796`*^9, 3.655655243548979*^9}, {
  3.6556559648318224`*^9, 3.6556559758281126`*^9}, {3.6556625350770884`*^9, 
  3.6556625553416767`*^9}, {3.6556636806921215`*^9, 
  3.655663711748703*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["r", "p"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Particle", " ", "Radius"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "p"]},
    "NotationTemplateTag"], "]"}], 
  RowBox[{"(*", 
   RowBox[{"Effective", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "m"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Molecular", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["A", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Column", " ", "Cross", " ", "Section"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["L", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Zone", " ", "Length"}], "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7009332717595787`*^9, 3.700933287443512*^9}, {
  3.7069760577434387`*^9, 3.7069760882452564`*^9}, {3.706976265001667*^9, 
  3.706976327755203*^9}, {3.7069775917314825`*^9, 3.7069776050564218`*^9}, {
  3.7133453064566894`*^9, 3.71334533454174*^9}, {3.71335083265457*^9, 
  3.713350834501753*^9}, {3.713368226641759*^9, 
  3.713368226826703*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[{
 RowBox[{GridBox[{
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "+"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "-"]},
       "NotationTemplateTag"], "]"}]}
   }], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", " ", 
  TemplateBox[{SubscriptBox["y", "target"]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.700682475232301*^9, 3.700682485722865*^9}, 
   3.700682643795794*^9, 3.7009481377110014`*^9, 3.7009500313826027`*^9, {
   3.7133026447441673`*^9, 3.713302647881256*^9}, {3.713348436173435*^9, 
   3.7133484487422404`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubsuperscriptBox["c", "A", "\"F\""]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubsuperscriptBox["c", "B", "\"F\""]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.713348427201262*^9, 3.7133484303337097`*^9}, {
   3.713348538949387*^9, 3.713348552512232*^9}, 
   3.713348610698288*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["q", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["a", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["b", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["c", "A"]},
       "NotationTemplateTag"], "]"}]},
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["q", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["a", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["b", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["c", "B"]},
       "NotationTemplateTag"], "]"}]}
   }], ";"}]], "Input",
 CellChangeTimes->{{3.700682298492797*^9, 3.700682344910399*^9}, 
   3.700682645594619*^9, {3.706971022656542*^9, 
   3.7069710372036867`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubsuperscriptBox["c", "A", 
      RowBox[{"s", "*"}]]},
    "NotationTemplateTag"], "]"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubsuperscriptBox["c", "B", 
      RowBox[{"s", "*"}]]},
    "NotationTemplateTag"], "]"}], " "}]}], "Input",
 CellChangeTimes->{{3.706978085564478*^9, 
  3.7069781207990713`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 TemplateBox[{
  "Symbolize","bsymbexs",
   "\"Warning: The box structure attempting to be symbolized has a similar or \
identical symbol already defined, possibly overriding previously symbolized \
box structure.\"",2,16,1,23047621045309414658,"Local","Notation`Symbolize"},
  "MessageTemplate2"]], "Message", "MSG",
 CellChangeTimes->{3.7134243674883947`*^9, 3.7134261319524155`*^9, 
  3.713716489355951*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 TemplateBox[{
  "Symbolize","bsymbexs",
   "\"Warning: The box structure attempting to be symbolized has a similar or \
identical symbol already defined, possibly overriding previously symbolized \
box structure.\"",2,17,2,23047621045309414658,"Local","Notation`Symbolize"},
  "MessageTemplate2"]], "Message", "MSG",
 CellChangeTimes->{3.7134243674883947`*^9, 3.7134261319524155`*^9, 
  3.7137164899103675`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
        TemplateBox[{SubsuperscriptBox["u", "0", "zone"]},
         "NotationTemplateTag"], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\"\<zone\>\"", "\[Rule]", 
         RowBox[{"\"\<\\\"\>\"", "<>", 
          RowBox[{"RomanNumeral", "[", "z", "]"}], "<>", "\"\<\\\"\>\""}]}], 
        "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "4"}], "}"}]}], "]"}], "//", 
    RowBox[{"MatrixForm", "\[IndentingNewLine]", 
     RowBox[{"Activate", "[", "%", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700952008270067*^9, 3.7009520511002216`*^9}, 
   3.7009532213777666`*^9, {3.713341273798588*^9, 
   3.7133412787739716`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
      TemplateBox[{SubsuperscriptBox["c", "component", "x"]},
       "NotationTemplateTag"], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<x\>\"", "\[Rule]", 
        RowBox[{"\"\<\\\"\>\"", "<>", 
         RowBox[{"ToString", "[", "x", "]"}], "<>", "\"\<\\\"\>\""}]}], ",", 
       RowBox[{"\"\<component\>\"", "\[Rule]", 
        RowBox[{"ToString", "[", "c", "]"}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{
       "s", ",", "p", ",", "feed", ",", "r", ",", "e", ",", "\"\<I\>\"", ",", 
        "\"\<IV\>\""}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Activate", "[", "%", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7009477447394514`*^9, 3.7009478256140194`*^9}, {
   3.700948031117095*^9, 3.7009480372573547`*^9}, {3.7009482672419186`*^9, 
   3.700948271782887*^9}, 3.700950072397784*^9, {3.706978020590043*^9, 
   3.70697806331144*^9}, {3.713346210600847*^9, 
   3.7133462450694036`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"s\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"s\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"p\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"p\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"feed\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"feed\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"r\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"r\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"e\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"e\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"I\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"I\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"IV\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"IV\""]},
        "NotationTemplateTag"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7133389809467134`*^9, 3.7133412881904087`*^9, {3.713346212387309*^9, 
   3.7133462462280884`*^9}, 3.71334636552874*^9, 3.713346834702281*^9, 
   3.713347007719058*^9, 3.7133471307994432`*^9, 3.7133474313024063`*^9, 
   3.7133475602718544`*^9, 3.71334862050708*^9, 3.7133499107296057`*^9, 
   3.713350361996827*^9, 3.713352952809948*^9, 3.713353067682953*^9, 
   3.7133531408722754`*^9, 3.713353285082382*^9, 3.7133548753950434`*^9, 
   3.713361226844001*^9, 3.7133615229008074`*^9, 3.7133653568050795`*^9, 
   3.713369185737153*^9, 3.7134243676247044`*^9, 3.7134261320774155`*^9, 
   3.713716490457816*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 TemplateBox[{
  "Symbolize","bsymbexs",
   "\"Warning: The box structure attempting to be symbolized has a similar or \
identical symbol already defined, possibly overriding previously symbolized \
box structure.\"",2,20,3,23047621045309414658,"Local","Notation`Symbolize"},
  "MessageTemplate2"]], "Message", "MSG",
 CellChangeTimes->{3.7134243677340803`*^9, 3.713426132139914*^9, 
  3.713716496269395*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 TemplateBox[{
  "Symbolize","bsymbexs",
   "\"Warning: The box structure attempting to be symbolized has a similar or \
identical symbol already defined, possibly overriding previously symbolized \
box structure.\"",2,20,4,23047621045309414658,"Local","Notation`Symbolize"},
  "MessageTemplate2"]], "Message", "MSG",
 CellChangeTimes->{3.7134243677340803`*^9, 3.713426132139914*^9, 
  3.71371649680842*^9},ExpressionUUID->"00000000-0000-0000-0000-000000000000"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"toNumericQ", "[", "any___", "]"}], ":=", 
  RowBox[{"NumericQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toStringQ", "[", "any___", "]"}], ":=", 
  RowBox[{"StringQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["x_", "i_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{SubscriptBox[
      RowBox[{"x_", "[", 
        TemplateBox[{
          RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}], 
      "i_"]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.713336229988531*^9, 3.7133362378482275`*^9}, {
  3.7133379022738476`*^9, 
  3.713337902766363*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[TextData[{
 "Add some convenience shortcuts.  Now, to type in ",
 Cell[BoxData[
  SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]],
  CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
    3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
    3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
    3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
    3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
    3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
    3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
    3.7069706345688634`*^9, 3.706970785055435*^9}},ExpressionUUID->
  "955fe48c-2812-4d4f-9717-eaebfbca3e5b"],
 ", we only need to press [esc] d 1 [esc]"
}], "Text",
 CellChangeTimes->{{3.7069708724437337`*^9, 
  3.7069709086295853`*^9}},ExpressionUUID->"ea4eab23-80f8-4522-8c9d-\
17b2273eb400"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]}
   }], ";"}]], "Input",
 CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
   3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
   3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
   3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
   3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
   3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
   3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
   3.7069706345688634`*^9, 3.706970785055435*^9}, {3.7069766810891023`*^9, 
   3.7069767108198867`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[{
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ep\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<eb\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<et\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<feed\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "\"F\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<des\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "des"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ext\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "ext"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<cf1\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["c", "1", "\"F\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<cf2\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["c", "2", "\"F\""]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6726802841433578`*^9, 3.6726802928288794`*^9}, {
   3.672755271908722*^9, 3.6727552869558325`*^9}, {3.6727767324017215`*^9, 
   3.672776745104333*^9}, {3.7069704528909445`*^9, 3.7069705068199396`*^9}, {
   3.706970606368145*^9, 3.706970607027779*^9}, {3.7069767220443125`*^9, 
   3.7069767502680197`*^9}, {3.713337473752632*^9, 3.713337483785607*^9}, 
   3.7133376380505476`*^9, {3.713350841178546*^9, 
   3.713350845169429*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Define The Key Terms", "Section",
 CellChangeTimes->{{3.7069734825274553`*^9, 
  3.7069735032030835`*^9}},ExpressionUUID->"fbad123e-f232-43e4-a632-\
1764d9911915"],

Cell[CellGroupData[{

Cell["Isotherm Definition", "Subsection",
 CellChangeTimes->{{3.67746618373181*^9, 
  3.6774661870844564`*^9}},ExpressionUUID->"9311c4a2-af03-44b9-993e-\
e6e5cacb3469"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isotherm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "A"], "\[Rule]", " ", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["c", "A"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}], " ", ",", 
    RowBox[{
     SubscriptBox["q", "B"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["c", "B"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6774661967728624`*^9, 3.6774662432648315`*^9}, {
  3.706970980944528*^9, 3.7069709973843966`*^9}, {3.7069710689723396`*^9, 
  3.70697113652822*^9}, {3.706971278610673*^9, 
  3.7069712998410425`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "A"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["c", "A"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}], ",", 
   RowBox[{
    SubscriptBox["q", "B"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["c", "B"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982213214*^9, 3.713341289455179*^9, 
  3.7133463666789737`*^9, 3.7133468358342333`*^9, 3.7133470090647235`*^9, 
  3.713347131931735*^9, 3.7133474326873827`*^9, 3.7133475615990705`*^9, 
  3.713348621666252*^9, 3.7133499118989563`*^9, 3.71335036362273*^9, 
  3.7133529540258102`*^9, 3.7133530689820805`*^9, 3.71335314226466*^9, 
  3.7133532868178897`*^9, 3.7133548772316866`*^9, 3.7133612282502403`*^9, 
  3.7133615242155914`*^9, 3.713365358957106*^9, 3.7133691875007467`*^9, 
  3.7134243688501697`*^9, 3.7134261338284254`*^9, 
  3.713716514825806*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Phase Ratio", "Subsection",
 CellChangeTimes->{{3.7069761277850475`*^9, 
  3.7069761303831615`*^9}},ExpressionUUID->"7c0bb7a8-6a00-47bc-95bc-\
07d51c967bc7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Phi]", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SubscriptBox["\[Epsilon]", "b"]}], ")"}], "/", 
   SubscriptBox["\[Epsilon]", "b"]}]}]], "Input",
 CellChangeTimes->{
  3.706976122161029*^9, {3.713338932913249*^9, 
   3.7133389606679296`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   SubscriptBox["\[Epsilon]", "b"]}], 
  SubscriptBox["\[Epsilon]", "b"]]], "Output",
 CellChangeTimes->{3.713338982230715*^9, 3.7133412894761825`*^9, 
  3.7133463666969733`*^9, 3.7133468358652334`*^9, 3.713347009079723*^9, 
  3.713347131950734*^9, 3.713347432700382*^9, 3.71334756161407*^9, 
  3.7133486216833496`*^9, 3.713349911918955*^9, 3.713350363639735*^9, 
  3.7133529540498104`*^9, 3.7133530690030785`*^9, 3.713353142286668*^9, 
  3.7133532868653965`*^9, 3.7133548772696953`*^9, 3.713361228265865*^9, 
  3.713361524222254*^9, 3.7133653589727306`*^9, 3.713369187516389*^9, 
  3.7134243688501697`*^9, 3.7134261338284254`*^9, 
  3.713716514830327*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Retention Factor Definitions", "Subsection",
 CellChangeTimes->{{3.706973516677366*^9, 
  3.7069735217634172`*^9}},ExpressionUUID->"6ebc7b3f-4527-447b-aefc-\
5fb069e8da14"],

Cell[CellGroupData[{

Cell["Ideal", "Subsubsection",
 CellChangeTimes->{{3.700927282836939*^9, 
  3.700927283372059*^9}},ExpressionUUID->"88fbb788-9616-4ea3-9363-\
155602c97d75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealRetention", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["a", "B"]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "B"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.700927250790391*^9, 3.7009272773669167`*^9}, {
   3.7009284912956934`*^9, 3.7009285028657093`*^9}, {3.7009504456319914`*^9, 
   3.7009504521905937`*^9}, {3.706973698819386*^9, 3.7069737083463225`*^9}, {
   3.706974221388472*^9, 3.7069742864664307`*^9}, 3.7069746419989896`*^9, {
   3.706979029946501*^9, 3.706979055616598*^9}, {3.713337533221609*^9, 
   3.7133375442303457`*^9}, {3.7133377288589096`*^9, 3.713337737224095*^9}, {
   3.7133468133210235`*^9, 
   3.713346821616871*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389822512136`*^9, 3.713341289511447*^9, 
  3.713346366746977*^9, 3.7133468358977394`*^9, 3.713347009116723*^9, 
  3.7133471319917383`*^9, 3.7133474327298923`*^9, 3.71334756165107*^9, 
  3.7133486217113495`*^9, 3.71334991196346*^9, 3.7133503636773915`*^9, 
  3.7133529540909233`*^9, 3.7133530690445824`*^9, 3.7133531423326683`*^9, 
  3.7133532869143953`*^9, 3.7133548773006964`*^9, 3.7133612282814903`*^9, 
  3.713361524222254*^9, 3.7133653589948616`*^9, 3.7133691875320144`*^9, 
  3.713424368865795*^9, 3.7134261338440514`*^9, 
  3.713716514830327*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Decay Factor Equations", "Subsection",
 CellChangeTimes->{{3.700927400092606*^9, 
  3.7009274042601995`*^9}},ExpressionUUID->"bf6e2d63-c652-474e-9782-\
f0669108fecb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"decayFactors", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<E\>\""], 
       SubsuperscriptBox["c", "B", "\"\<I\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<ss\>\""], 
       SubsuperscriptBox["c", "A", "\"\<I\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<II\>\""], 
       SubsuperscriptBox["c", "B", "\"\<R\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "A", "\"\<R\>\""], 
       SubsuperscriptBox["c", "A", "\"\<IV\>\""]], "]"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7009274260277*^9, 3.7009274351122284`*^9}, {
  3.7009284705368476`*^9, 3.700928483438323*^9}, {3.700950468393784*^9, 
  3.7009504730975943`*^9}, {3.706973830986437*^9, 3.7069738543944693`*^9}, {
  3.706974589352887*^9, 3.706974605080983*^9}, {3.7133363550795794`*^9, 
  3.7133364412292347`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"E\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"I\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"ss\"\>"], 
      SubsuperscriptBox["c", "A", "\<\"I\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"II\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"R\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "A", "\<\"R\"\>"], 
      SubsuperscriptBox["c", "A", "\<\"IV\"\>"]], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982305214*^9, 3.7133412895467443`*^9, 
  3.713346366784979*^9, 3.7133468359826126`*^9, 3.713347009154746*^9, 
  3.7133471320278144`*^9, 3.713347432764896*^9, 3.713347561697813*^9, 
  3.713348621748351*^9, 3.7133499119995675`*^9, 3.713350363722391*^9, 
  3.713352954141013*^9, 3.7133530690930867`*^9, 3.7133531423879347`*^9, 
  3.7133532870164022`*^9, 3.713354877366704*^9, 3.713361228312741*^9, 
  3.7133615242538404`*^9, 3.713365359010494*^9, 3.713369187553645*^9, 
  3.71342436888142*^9, 3.7134261338596754`*^9, 
  3.713716514845951*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Characteristic Polynomials", "Subsection",
 CellChangeTimes->{{3.706971225391755*^9, 
  3.706971254700155*^9}},ExpressionUUID->"51b0cee2-24ea-416a-bf1d-\
a264d38fe076"],

Cell[CellGroupData[{

Cell["Main Definition", "Subsubsection",
 CellChangeTimes->{{3.7069746936318626`*^9, 
  3.7069746957059355`*^9}},ExpressionUUID->"f9186d00-3e84-4971-a41d-\
a39de914c47d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"characteristicPolynomial", "=", 
  RowBox[{
   RowBox[{"Inactivate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["c", "A"]], 
        SubscriptBox["q", "B"]}]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "B"]], 
          SubscriptBox["q", "B"]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "A"]], 
          SubscriptBox["q", "A"]}]}], ")"}], "\[Gamma]"}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        SubscriptBox["c", "B"]], 
       SubscriptBox["q", "A"]}]}], "\[Equal]", "0"}], "]"}], "/.", 
   "isotherm"}]}]], "Input",
 CellChangeTimes->{{3.706971302611926*^9, 
  3.7069713310704417`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", 
     TagBox["^",
      "InactiveToken",
      BaseStyle->"Inactive",
      SyntaxForm->"^"], "2"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["c", "B"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
     "InactiveD"]}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TemplateBox[{"Inactive",FractionBox[
         RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["c", "B"]}], 
         RowBox[{"1", "+", 
           RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["c", "A"]}], "+", 
           RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
       "InactiveD"], 
      TagBox["+",
       "InactiveToken",
       BaseStyle->"Inactive",
       SyntaxForm->"+"], 
      RowBox[{
       RowBox[{"-", "1"}], 
       TagBox["*",
        "InactiveToken",
        BaseStyle->"Inactive",
        SyntaxForm->"*"], 
       TemplateBox[{"Inactive",FractionBox[
          RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["c", "A"]}], 
          RowBox[{"1", "+", 
            RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}], "+", 
            RowBox[{
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
        "InactiveD"]}]}], ")"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], "\[Gamma]"}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"-", "1"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["c", "A"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
     "InactiveD"]}]}], 
  TagBox["\[Equal]",
   "InactiveToken",
   BaseStyle->"Inactive",
   SyntaxForm->"\[Equal]"], "0"}]], "Output",
 CellChangeTimes->{3.713338982326214*^9, 3.7133412895623007`*^9, 
  3.7133463668029785`*^9, 3.713346836031618*^9, 3.7133470091697474`*^9, 
  3.713347132046815*^9, 3.713347432782899*^9, 3.713347561718814*^9, 
  3.713348621762355*^9, 3.713349912020568*^9, 3.713350363746398*^9, 
  3.713352954165013*^9, 3.713353069118087*^9, 3.7133531424139333`*^9, 
  3.7133532870664062`*^9, 3.713354877394704*^9, 3.713361228328873*^9, 
  3.7133615242538404`*^9, 3.713365359041744*^9, 3.7133691875695424`*^9, 
  3.7134243688970456`*^9, 3.7134261338596754`*^9, 
  3.713716514861596*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Polynomial", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Activate", "@", "characteristicPolynomial"}], ",", 
    RowBox[{"{", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["c", "A"]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "B"]}]}], ">", "0"}], "}"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971351866922*^9, 
  3.706971379406417*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["a", "B"], " ", "\[Gamma]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["b", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["c", "A"], "-", 
        RowBox[{
         SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}], ")"}]}], 
  "\[Equal]", 
  RowBox[{
   SubscriptBox["a", "A"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["b", "B"]}], " ", 
      SubscriptBox["c", "A"]}], "+", "\[Gamma]", "+", 
     RowBox[{
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.7133389824517136`*^9, 3.7133412897588205`*^9, 
  3.7133463669289885`*^9, 3.7133468361733913`*^9, 3.713347009313261*^9, 
  3.7133471322079773`*^9, 3.713347432897738*^9, 3.7133475618713274`*^9, 
  3.7133486218688602`*^9, 3.7133499121415787`*^9, 3.7133503638818655`*^9, 
  3.7133529543015213`*^9, 3.7133530692530236`*^9, 3.7133531424744415`*^9, 
  3.7133532871144066`*^9, 3.713354877505716*^9, 3.713361228497429*^9, 
  3.713361524285092*^9, 3.7133653590729933`*^9, 3.7133691876698217`*^9, 
  3.7134243691001697`*^9, 3.7134261339221783`*^9, 
  3.7137165172502594`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]PolynomialSolutions", "=", 
  RowBox[{"Simplify", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{"\[Gamma]Polynomial", ",", "\[Gamma]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.70697165303078*^9, 3.706971674686119*^9}, {
  3.7069717400542965`*^9, 
  3.706971770398497*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "-", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["c", "A"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "A"], " ", 
           SubscriptBox["c", "B"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "B"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "A"]}], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982555713*^9, 3.7133412898594294`*^9, 
  3.7133463670275445`*^9, 3.713346836303405*^9, 3.713347009414271*^9, 
  3.713347132309057*^9, 3.7133474330117483`*^9, 3.713347561988343*^9, 
  3.713348621970867*^9, 3.713349912244588*^9, 3.713350363994872*^9, 
  3.7133529544030323`*^9, 3.7133530693540306`*^9, 3.713353142577453*^9, 
  3.7133532872201405`*^9, 3.7133548776217265`*^9, 3.713361228597685*^9, 
  3.7133615243942337`*^9, 3.7133653591923895`*^9, 3.713369187785757*^9, 
  3.7134243692235155`*^9, 3.713426134031551*^9, 
  3.713716518284125*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Values", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Gamma]", "-"], ",", 
      SubscriptBox["\[Gamma]", "+"]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "/.", "\[Gamma]PolynomialSolutions"}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971774342685*^9, 3.706971789238475*^9}, {
  3.713349889939475*^9, 3.7133498967686787`*^9}, {3.713353057359313*^9, 
  3.713353059118727*^9}, {3.7133531250268097`*^9, 
  3.713353131503124*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982588214*^9, 3.713341289902938*^9, 
  3.713346367057749*^9, 3.7133468363236265`*^9, 3.7133470094399123`*^9, 
  3.713347132346058*^9, 3.7133474330622835`*^9, 3.7133475620699234`*^9, 
  3.713348622012868*^9, 3.71334991231195*^9, 3.713350364056998*^9, 
  3.713352954467535*^9, 3.7133530694325867`*^9, 3.713353142598951*^9, 
  3.713353287271159*^9, 3.71335487765874*^9, 3.7133612286354523`*^9, 
  3.713361524414875*^9, 3.713365359204217*^9, 3.7133691878169928`*^9, 
  3.7134243692450747`*^9, 3.713426134031551*^9, 
  3.713716518769905*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["A", "-"], ",", 
    SubscriptBox["A", "+"]}], "}"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"]}], 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], 
       RowBox[{
        SubscriptBox["b", "B"], "/", "\[Gamma]"}]}]}]], "/.", 
    "\[Gamma]PolynomialSolutions"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713349873519145*^9, 3.7133498770766993`*^9}, {
  3.713353052157383*^9, 3.7133530548367743`*^9}, {3.7133531347309446`*^9, 
  3.713353136594575*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "+", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]], ",", 
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "-", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983529714*^9, 3.7133412908380857`*^9, 
  3.7133463679593053`*^9, 3.7133468372257614`*^9, 3.713347010391641*^9, 
  3.713347133273785*^9, 3.7133474340628366`*^9, 3.7133475631233788`*^9, 
  3.713348622962989*^9, 3.7133498825963187`*^9, 3.7133499132715073`*^9, 
  3.713350365023613*^9, 3.713352955399082*^9, 3.71335307039218*^9, 
  3.7133531435032554`*^9, 3.7133532882097425`*^9, 3.7133548786288013`*^9, 
  3.7133612296575565`*^9, 3.713361525386848*^9, 3.7133653601611195`*^9, 
  3.7133691888363905`*^9, 3.71342437024856*^9, 3.713426134921768*^9, 
  3.7137165206781883`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Secondary \[Gamma] definition", "Subsubsection",
 CellChangeTimes->{{3.7069747010202184`*^9, 
  3.706974717036033*^9}},ExpressionUUID->"61eeb5f9-6911-4dd5-ad1b-\
d56b502d598b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondary\[Gamma]Values", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       SubscriptBox["a", "A"], "-", 
       RowBox[{
        SubscriptBox["a", "A"], 
        SubscriptBox["b", "B"], 
        SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], 
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubsuperscriptBox["c", "B", "\"\<p\>\""]}]]}], ",", 
    RowBox[{
     SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       SubsuperscriptBox["c", "A", "\"\<p\>\""]}], 
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], 
        SubscriptBox["b", "A"], 
        SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.706974728692503*^9, 3.706974759830389*^9}, {
  3.706974792782261*^9, 3.706974862933106*^9}, {3.7069812267974615`*^9, 
  3.7069812279590883`*^9}, {3.7133377288209095`*^9, 3.7133377371900945`*^9}, {
  3.713346779309186*^9, 
  3.7133467896627607`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubsuperscriptBox["c", "A", "\<\"p\"\>"]}], 
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983591213*^9, 3.7133412908865705`*^9, 
  3.7133463679993057`*^9, 3.7133468372967997`*^9, 3.7133470104321437`*^9, 
  3.713347133318866*^9, 3.7133474341318417`*^9, 3.713347563216889*^9, 
  3.7133486230145664`*^9, 3.713349913336506*^9, 3.7133503650976653`*^9, 
  3.7133529554455895`*^9, 3.7133530704981885`*^9, 3.713353143541258*^9, 
  3.7133532882417445`*^9, 3.7133548786898108`*^9, 3.7133612297165565`*^9, 
  3.7133615254866233`*^9, 3.71336536020774*^9, 3.7133691889053907`*^9, 
  3.71342437029856*^9, 3.713426134984269*^9, 
  3.7137165207186856`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: Outline the Problem", "Section",
 CellChangeTimes->{{3.7069647139816885`*^9, 3.7069647369114227`*^9}, 
   3.7069738098215046`*^9},ExpressionUUID->"695d6c6f-f6c9-46ed-815d-\
e8871cf86a4a"],

Cell["\<\
In this step, we will define various methods for estimating the properties of \
the system.\
\>", "Text",
 CellChangeTimes->{{3.6096062170410075`*^9, 3.609606264631626*^9}, {
  3.706975529035071*^9, 
  3.7069755450306263`*^9}},ExpressionUUID->"b459b8e5-f97d-405f-b088-\
f6362277045e"],

Cell[CellGroupData[{

Cell["Flow Rate Estimates", "Subsection",
 CellChangeTimes->{{3.7069719669644384`*^9, 
  3.70697197321463*^9}},ExpressionUUID->"5172c932-e47a-4486-a0ff-\
dfcadcc49da0"],

Cell[CellGroupData[{

Cell["Zone Velocities", "Subsubsection",
 CellChangeTimes->{{3.7069770657438345`*^9, 
  3.7069770704278774`*^9}},ExpressionUUID->"ce176f91-73e2-4eb9-8ef4-\
05267dc137dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealZoneVelocityEstimates", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Phi]", "*", "#"}]}], ")"}]}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], "}"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7069792305863423`*^9, 3.7069794058816357`*^9}, {
  3.71333893281275*^9, 
  3.713338960678429*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836062136`*^9, 3.713341290901271*^9, 
  3.7133463680133047`*^9, 3.713346837326803*^9, 3.7133470104455504`*^9, 
  3.7133471333368664`*^9, 3.713347434149845*^9, 3.713347563241888*^9, 
  3.713348623027567*^9, 3.7133499133615103`*^9, 3.7133503651146555`*^9, 
  3.71335295546359*^9, 3.713353070547192*^9, 3.7133531435592575`*^9, 
  3.713353288266747*^9, 3.713354878704811*^9, 3.7133612297165565`*^9, 
  3.7133615255183153`*^9, 3.713365360223386*^9, 3.7133691889198914`*^9, 
  3.7134243703105583`*^9, 3.713426134984269*^9, 
  3.7137165207266636`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoneVelocityEstimates", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], 
        SubscriptBox["L", "z"]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<I\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<I\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], 
        SubscriptBox["L", "z"]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<II\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<II\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}]}], ")"}], "v"}],
       "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], 
        SubscriptBox["L", "z"]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<III\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<III\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}]}], ")"}], "v"}], 
      "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], 
        SubscriptBox["L", "z"]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<IV\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<IV\>\""]]}], ")"}]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7069719796706057`*^9, 3.706972129718485*^9}, {
   3.7069755736149435`*^9, 3.7069756677550144`*^9}, {3.7069757049829063`*^9, 
   3.706975719680606*^9}, {3.7069758023276405`*^9, 3.7069758603763356`*^9}, {
   3.7069770519615784`*^9, 3.7069770548532476`*^9}, {3.7069776256388144`*^9, 
   3.7069776324148607`*^9}, 3.7069794091133423`*^9, {3.7133389328242493`*^9, 
   3.71333896063593*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"I\"\>"]}]]}], ")"}]}], 
      SubscriptBox["L", "z"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"II\"\>"]}]]}], ")"}]}], 
      SubscriptBox["L", "z"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"III\"\>"]}]]}], ")"}]}], 
      SubscriptBox["L", "z"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"]}]]}], ")"}]}], 
      SubscriptBox["L", "z"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836237135`*^9, 3.7133412909222713`*^9, 
  3.713346368028304*^9, 3.7133468373598824`*^9, 3.71334701046255*^9, 
  3.713347133356865*^9, 3.713347434170845*^9, 3.713347563265889*^9, 
  3.7133486230415664`*^9, 3.7133499133835135`*^9, 3.713350365134656*^9, 
  3.713352955482589*^9, 3.7133530705941944`*^9, 3.713353143579759*^9, 
  3.7133532882947474`*^9, 3.713354878723811*^9, 3.713361229747815*^9, 
  3.713361525549582*^9, 3.713365360239012*^9, 3.7133691889383917`*^9, 
  3.713424370326559*^9, 3.7134261350467677`*^9, 
  3.7137165207311635`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Zone Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.7069770783616886`*^9, 
  3.706977081577528*^9}},ExpressionUUID->"d35a9e0f-7c73-408a-bd34-\
07090091fc05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoneFlowEstimates", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["f", "\"\<I\>\""], ",", 
      SubscriptBox["f", "\"\<II\>\""], ",", 
      SubscriptBox["f", "\"\<III\>\""], ",", 
      SubscriptBox["f", "\"\<IV\>\""]}], "}"}], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "b"], 
     SubscriptBox["A", "c"], "*", 
     RowBox[{"{", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
       SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
       SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
       SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7069770846770887`*^9, 3.7069771929902897`*^9}, {
  3.7133375715885506`*^9, 
  3.7133376107891293`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"III\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836402135`*^9, 3.713341290942277*^9, 
  3.7133463680443087`*^9, 3.713346837395882*^9, 3.71334701047955*^9, 
  3.7133471333738656`*^9, 3.713347434188848*^9, 3.713347563286434*^9, 
  3.7133486230570717`*^9, 3.713349913405513*^9, 3.7133503651560116`*^9, 
  3.71335295550159*^9, 3.713353070645199*^9, 3.7133531435992637`*^9, 
  3.7133532883227468`*^9, 3.7133548787398167`*^9, 3.713361229763438*^9, 
  3.7133615256026726`*^9, 3.713365360239012*^9, 3.71336918895691*^9, 
  3.7134243703445597`*^9, 3.713426135062393*^9, 
  3.713716520746829*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Port Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.706977332184824*^9, 
  3.7069773361137943`*^9}},ExpressionUUID->"255b9df0-941d-4ff4-bbb7-\
eaabdaf88d7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"portFlowEstimates", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "\"\<R\>\""], "\[Rule]", 
       RowBox[{
        SubscriptBox["f", "\"\<III\>\""], "-", 
        SubscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<D\>\""], "\[Rule]", 
       RowBox[{
        SubscriptBox["f", "\"\<I\>\""], "-", 
        SubscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<E\>\""], "\[Rule]", " ", 
       RowBox[{
        SubscriptBox["f", "\"\<I\>\""], "-", 
        SubscriptBox["f", "\"\<II\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<Recycle\>\""], "\[Rule]", 
       SubscriptBox["f", "\"\<IV\>\""]}]}], "\[IndentingNewLine]", "}"}], "/.",
     "zoneFlowEstimates"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069773390874557`*^9, 3.706977475818272*^9}, {
   3.7133375716075497`*^9, 3.7133376718854723`*^9}, {3.7133503118874207`*^9, 
   3.713350314812169*^9}, {3.7133532725214005`*^9, 3.713353277157241*^9}, {
   3.713437409029659*^9, 3.713437421289695*^9}, 
   3.7134374518333993`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"D\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"Recycle\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836552143`*^9, 3.713341290966863*^9, 3.7133463680580635`*^9, 
   3.7133468374263854`*^9, 3.7133470104935503`*^9, 3.713347133389372*^9, 
   3.7133474342068453`*^9, 3.7133475633084345`*^9, 3.7133486230695705`*^9, 
   3.7133499134265137`*^9, 3.7133503186302757`*^9, 3.713350365179014*^9, 
   3.713352955521597*^9, 3.713353070690838*^9, 3.7133531436192665`*^9, {
   3.7133532788367634`*^9, 3.7133532883594723`*^9}, 3.713354878756819*^9, 
   3.713361229763438*^9, 3.713361525643771*^9, 3.713365360262143*^9, 
   3.7133691889733906`*^9, 3.713424370358559*^9, 3.713426135062393*^9, 
   3.7134374550263414`*^9, 
   3.7137165207624493`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Concentration Estimates", "Subsection",
 CellChangeTimes->{{3.706971482093981*^9, 
  3.7069714862699366`*^9}},ExpressionUUID->"88b83633-23e0-4b1b-ab42-\
149be343168a"],

Cell[CellGroupData[{

Cell["Key Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732610853033`*^9, 
  3.7069732687194195`*^9}},ExpressionUUID->"c022f656-06d6-4a6d-a98d-\
153699a82d0b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakEstimate", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
       SubscriptBox["A", "-"]}], ",", 
      RowBox[{
       SubsuperscriptBox["c", "B", "\"\<p\>\""], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["A", "+"]}], "/", 
        SubscriptBox["\[Gamma]", "+"]}]}]}], "}"}], "/.", "\[Gamma]Values"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.70697149536306*^9, 3.7069715103032227`*^9}, {
  3.706971806165899*^9, 3.7069718106218185`*^9}, {3.7069737726575537`*^9, 
  3.706973778562495*^9}, {3.7133377288449097`*^9, 3.7133377371980944`*^9}, {
  3.7133467663097467`*^9, 
  3.7133467685329013`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983767215*^9, 3.7133412911132517`*^9, 
  3.7133463681673126`*^9, 3.7133468375432997`*^9, 3.7133470105991797`*^9, 
  3.71334713350038*^9, 3.7133474343323584`*^9, 3.7133475634426208`*^9, 
  3.713348623175728*^9, 3.7133499135865283`*^9, 3.7133503653590574`*^9, 
  3.7133529556796036`*^9, 3.7133530707993493`*^9, 3.7133531437767825`*^9, 
  3.7133532885219774`*^9, 3.713354878935832*^9, 3.7133612299327574`*^9, 
  3.713361525803044*^9, 3.7133653604284115`*^9, 3.713369189144891*^9, 
  3.7134243705245595`*^9, 3.7134261352186437`*^9, 
  3.7137165209101086`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakMassBalance", "=", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<F\>\""], 
     SubscriptBox["f", "\"\<F\>\""], 
     SubscriptBox["y", "target"]}], 
    SubscriptBox["f", "\"\<R\>\""]]}]}]], "Input",
 CellChangeTimes->{{3.706980478613745*^9, 3.706980536647952*^9}, 
   3.713337473759631*^9, {3.713337625817992*^9, 3.713337638056546*^9}, 
   3.7133377372050953`*^9, {3.713338095272827*^9, 3.7133381193241405`*^9}, {
   3.713346760373721*^9, 
   3.713346764013403*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
    SubscriptBox["y", "target"], " ", 
    SubscriptBox["f", "\<\"F\"\>"]}], 
   SubscriptBox["f", "\<\"R\"\>"]]}]], "Output",
 CellChangeTimes->{3.7133389837827144`*^9, 3.713341291129759*^9, 
  3.7133463681833134`*^9, 3.7133468375783*^9, 3.713347010614182*^9, 
  3.7133471335173864`*^9, 3.713347434345862*^9, 3.713347563460621*^9, 
  3.713348623189728*^9, 3.713349913603529*^9, 3.7133503268429627`*^9, 
  3.713350365377056*^9, 3.7133529556986027`*^9, 3.7133530708433557`*^9, 
  3.7133531437942853`*^9, 3.7133532885486794`*^9, 3.713354878958838*^9, 
  3.7133612299327574`*^9, 3.713361525834278*^9, 3.7133653604440393`*^9, 
  3.713369189159889*^9, 3.713424370536559*^9, 3.713426135234269*^9, 
  3.7137165209101086`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"denominator", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "A"], 
     SubscriptBox["a", "B"], 
     SubscriptBox["b", "A"], 
     SubscriptBox["b", "B"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Gamma]", "+"], "+", 
       SubscriptBox["\[Gamma]", "-"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "A"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "B"], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "B"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "A"], "2"], 
     SubscriptBox["\[Gamma]", "+"], 
     SubscriptBox["\[Gamma]", "-"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"dilutionEstimate", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubscriptBox["\[Gamma]", "+"], 
       SubscriptBox["\[Gamma]", "-"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}]}], "denominator"]}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], "-", 
         SubscriptBox["a", "A"]}], ")"}]}], "denominator"]}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.706973784342924*^9, 3.706973790586589*^9}, {
  3.71333753325161*^9, 3.7133375442343445`*^9}, {3.7133471532918425`*^9, 
  3.7133471585992737`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["\[Gamma]", "-"], " ", 
      SubscriptBox["\[Gamma]", "+"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["b", "B"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983796213*^9, 3.71334129114583*^9, 3.7133463681993136`*^9, 
   3.713346837604298*^9, 3.713347010630187*^9, {3.7133471335343847`*^9, 
   3.713347162734724*^9}, 3.7133474343608613`*^9, 3.713347563482626*^9, 
   3.713348623203147*^9, 3.713349913619529*^9, 3.7133503653940573`*^9, 
   3.7133529557181067`*^9, 3.7133530708849783`*^9, 3.7133531438122854`*^9, 
   3.7133532885756793`*^9, 3.713354878976839*^9, 3.713361229948386*^9, 
   3.713361525865541*^9, 3.7133653604646673`*^9, 3.7133691891768885`*^9, 
   3.7134243705465593`*^9, 3.713426135249895*^9, 
   3.7137165209322615`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massBalanceEstimate", "=", 
  RowBox[{"{", 
   RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7006907256001806`*^9, 3.700690730979576*^9}, {
   3.7006918848119802`*^9, 3.7006918993014727`*^9}, {3.700692033459654*^9, 
   3.700692084148734*^9}, {3.7006923383643527`*^9, 3.7006923478520517`*^9}, {
   3.70069307842813*^9, 3.7006930822753067`*^9}, {3.700693129332734*^9, 
   3.7006931980636635`*^9}, 3.70092776998028*^9, {3.700928547745931*^9, 
   3.700928555745161*^9}, 3.70697379573298*^9, {3.7069767726165147`*^9, 
   3.70697679668966*^9}, 3.7133374737816315`*^9, 3.713337638077546*^9, 
   3.713337737213095*^9, {3.713346757441712*^9, 3.7133467576987457`*^9}, {
   3.713349463384637*^9, 3.713349494322274*^9}, {3.71335014013033*^9, 
   3.713350147662957*^9}, {3.713350180925575*^9, 
   3.7133502508118877`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
     SubscriptBox["y", "target"], " ", 
     SubscriptBox["f", "\<\"F\"\>"]}], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.713338983813713*^9, 3.71334129116083*^9, 3.7133463682143135`*^9, 
   3.713346837630303*^9, 3.713347010644226*^9, 3.713347133551385*^9, 
   3.7133474343738623`*^9, 3.7133475634996524`*^9, 3.7133486232157273`*^9, 
   3.713349466311381*^9, 3.7133494986520433`*^9, 3.713349913636529*^9, {
   3.7133502099667983`*^9, 3.7133502584217834`*^9}, 3.7133503280318165`*^9, 
   3.7133503654100575`*^9, 3.7133529557365217`*^9, 3.713353070931978*^9, 
   3.7133531438292856`*^9, 3.71335328860168*^9, 3.7133548789938374`*^9, 
   3.713361229948386*^9, 3.713361525918488*^9, 3.7133653604661684`*^9, 
   3.713369189191889*^9, 3.7134243705565586`*^9, 3.713426135249895*^9, 
   3.7137165209322615`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Secondary Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732730436907`*^9, 
  3.706973285566949*^9}},ExpressionUUID->"541e351c-517d-4a0f-afe7-\
d02bb014a3c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondaryEstimateEquations", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<R\>\""], "==", 
     FractionBox[
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "*", 
       SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
       SubscriptBox["y", "target"]}], 
      SubscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<E\>\""], "==", 
     FractionBox[
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "*", 
       SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["y", "target"]}], ")"}]}], 
      SubscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "A", 
      RowBox[{"s", "*"}]], "==", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["f", "\"\<III\>\""], 
        SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "-", 
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], " ", 
        SubsuperscriptBox["c", "A", "\"\<F\>\""]}]}], 
      SubscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<IV\>\""], "==", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["u", "0", "\"\<I\>\""], 
       SubsuperscriptBox["c", "A", "\"\<E\>\""]}], 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<R\>\""], "==", 
     FractionBox[
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "*", 
       SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["y", "target"]}], ")"}]}], 
      SubscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<E\>\""], "==", 
     FractionBox[
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "*", 
       SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
       SubscriptBox["y", "target"]}], 
      SubscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "B", 
      RowBox[{"s", "*"}]], "==", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["f", "\"\<III\>\""], 
        SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "-", 
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], 
      SubscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<I\>\""], "==", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
       SubsuperscriptBox["c", "B", "\"\<R\>\""]}], 
      SubsuperscriptBox["u", "0", "\"\<I\>\""]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.706973366145651*^9, 3.706973371763674*^9}, {
  3.7069768222221403`*^9, 3.7069769272283363`*^9}, {3.706977720252282*^9, 
  3.70697798585865*^9}, {3.7069781378797045`*^9, 3.7069781484618835`*^9}, {
  3.7133374045636263`*^9, 3.713337483761606*^9}, {3.7133375332716093`*^9, 
  3.7133375870669155`*^9}, {3.7133376258399935`*^9, 3.713337655627265*^9}, {
  3.713338074163921*^9, 3.713338119340746*^9}, {3.7133467250756874`*^9, 
  3.713346748863327*^9}, {3.713347058448259*^9, 3.713347070565633*^9}, {
  3.713370699201305*^9, 3.7133706996166167`*^9}, {3.7133716539702883`*^9, 
  3.7133716644701633`*^9}, {3.7133716992269382`*^9, 
  3.713371701689584*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"R\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"R\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"E\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["y", "target"]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"E\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", 
     RowBox[{"s", "*"}]], "\[Equal]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
       SubscriptBox["f", "\<\"III\"\>"]}]}], 
     SubscriptBox["f", "\<\"II\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"IV\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"E\"\>"], " ", 
      SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"R\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["y", "target"]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"R\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"E\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"E\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", 
     RowBox[{"s", "*"}]], "\[Equal]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
       SubscriptBox["f", "\<\"III\"\>"]}]}], 
     SubscriptBox["f", "\<\"II\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"I\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"R\"\>"], " ", 
      SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
     SubsuperscriptBox["u", "0", "\<\"I\"\>"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389838317137`*^9, 3.7133412911788297`*^9, 3.713346368230314*^9, 
   3.7133468376553087`*^9, 3.713347010660226*^9, 3.7133471335693865`*^9, 
   3.7133474343878613`*^9, 3.7133475635226536`*^9, 3.713348623231727*^9, 
   3.7133499136555333`*^9, 3.713350365429056*^9, 3.7133529557575197`*^9, 
   3.7133530709784856`*^9, 3.7133531438482857`*^9, 3.7133532886301837`*^9, 
   3.7133548790108376`*^9, 3.713361229963994*^9, 3.7133615259497547`*^9, 
   3.7133653604817953`*^9, 3.7133691892128887`*^9, 3.71337070026892*^9, {
   3.7133716735669327`*^9, 3.713371703378792*^9}, 3.713424370569559*^9, 
   3.7134261352655177`*^9, 
   3.7137165209479103`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondaryEstimates", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{"secondaryEstimateEquations", ",", 
     RowBox[{"secondaryEstimateEquations", "[", 
      RowBox[{"[", 
       RowBox[{";;", ",", "1"}], "]"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.713371609310346*^9, 3.713371626320961*^9}, {
  3.713371668648596*^9, 3.7133717138592806`*^9}, {3.713371970011698*^9, 
  3.713371971394745*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"R\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"R\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], 
      SubscriptBox["f", "\<\"E\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", 
     RowBox[{"s", "*"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
        SubscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
        SubscriptBox["f", "\<\"III\"\>"]}]}], 
      SubscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
      RowBox[{
       SubscriptBox["f", "\<\"E\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], 
      SubscriptBox["f", "\<\"R\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"E\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"E\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", 
     RowBox[{"s", "*"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
        SubscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
        SubscriptBox["f", "\<\"III\"\>"]}]}], 
      SubscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
      RowBox[{
       SubscriptBox["f", "\<\"R\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7133716872573586`*^9, 3.7133717146897607`*^9}, 
   3.7133719719410524`*^9, 3.713424370585536*^9, 3.713426135281143*^9, 
   3.713716520963529*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Superficial Velocity Estimates", "Subsection",
 CellChangeTimes->{{3.706972981877504*^9, 
  3.706972989294876*^9}},ExpressionUUID->"e54f2530-510f-40e6-9225-\
a3e8f34525c9"],

Cell["\<\
The velocity estimate comes from solving the following system of equations\
\>", "Text",
 CellChangeTimes->{{3.713352961258211*^9, 
  3.713352983208372*^9}},ExpressionUUID->"01d623e4-27c7-49cc-a235-\
f6d05a38764e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<I\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<II\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<III\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], " "}]}]]}], ",", 
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], 
        SubscriptBox["A", "c"], 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\"\<III\>\""], "-", 
          SubsuperscriptBox["u", "0", "\"\<II\>\""]}], ")"}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7133528518942165`*^9, 
  3.713352853603495*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", "\[Rule]", 
     FractionBox[
      SubscriptBox["f", "\<\"F\"\>"], 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}], ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}]}],
    "}"}], "}"}]], "Output",
 CellChangeTimes->{3.713352784695923*^9, 3.713352854211293*^9, 
  3.713352955846099*^9, 3.713353071059018*^9, 3.713353143891296*^9, 
  3.7133532887017336`*^9, 3.713354879072847*^9, 3.713361230017376*^9, 
  3.713361526033969*^9, 3.7133653605286913`*^9, 3.7133691892633896`*^9, 
  3.713424370632413*^9, 3.7134261353436427`*^9, 
  3.7137165209947605`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealVelocityEstimate", "=", 
  RowBox[{"v", "\[Rule]", 
   FractionBox[
    SubscriptBox["f", "\"\<F\>\""], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "-", 
       SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], 
      ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.706979114270035*^9, 3.7069791332719812`*^9}, {
   3.7069794355664086`*^9, 3.706979457693653*^9}, {3.7069795106918306`*^9, 
   3.7069795210761013`*^9}, 3.7133376380365467`*^9, {3.713338932875249*^9, 
   3.71333896066593*^9}, 
   3.713352801180873*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"v", "\[Rule]", 
  FractionBox[
   SubscriptBox["f", "\<\"F\"\>"], 
   RowBox[{
    SubscriptBox["A", "c"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
      SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.7133389838617134`*^9, 3.713341291215831*^9, 
  3.713346368264715*^9, 3.713346837696307*^9, 3.713347010694228*^9, 
  3.713347133608917*^9, 3.713347434417862*^9, 3.713347563564652*^9, 
  3.713348623261731*^9, 3.7133499136925364`*^9, 3.713350365467063*^9, 
  3.7133528034327435`*^9, 3.713352955871101*^9, 3.7133530710930166`*^9, 
  3.713353143914296*^9, 3.7133532887342377`*^9, 3.7133548790948467`*^9, 
  3.713361230017376*^9, 3.71336152606155*^9, 3.7133653605443134`*^9, 
  3.713369189275406*^9, 3.713424370648037*^9, 3.713426135359268*^9, 
  3.7137165209947605`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Compose our Estimates into a Procedure", "Section",
 CellChangeTimes->{{3.7069781924420786`*^9, 
  3.7069782065902877`*^9}},ExpressionUUID->"27df55d9-80c2-4518-9585-\
18efc5249712"],

Cell[CellGroupData[{

Cell["Ideal System", "Subsection",
 CellChangeTimes->{{3.706978229054186*^9, 
  3.706978230912442*^9}},ExpressionUUID->"ad449915-ff2b-4cab-b32b-\
f2e4d2909d9a"],

Cell[CellGroupData[{

Cell[TextData[{
 "The ideal solution starts with the first ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "p"], TraditionalForm]],ExpressionUUID->
  "2919dfc0-c4eb-4f6d-951f-7bf805495cab"],
 " estimate from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "s"], TraditionalForm]],ExpressionUUID->
  "387a438d-a0f4-446a-8bec-de61f5a2f94a"]
}], "Subsubsection",
 CellChangeTimes->{{3.7069788252912216`*^9, 3.706978843148952*^9}, {
  3.706978931021088*^9, 3.7069789313794847`*^9}, {3.7133382915697927`*^9, 
  3.7133382989552493`*^9}},ExpressionUUID->"12bedb87-7e2f-4d47-a2e1-\
3c9271c99466"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"initialIdealPeak", "=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"peakEstimate", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "A"], "\[Rule]", 
       SubsuperscriptBox["c", "A", "\"\<s\>\""]}], ",", 
      RowBox[{
       SubscriptBox["c", "B"], "\[Rule]", 
       SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706978844185402*^9, 3.7069788686256866`*^9}, {
  3.706978934051138*^9, 3.7069789348076525`*^9}, {3.7069806546001153`*^9, 
  3.7069806583859673`*^9}, {3.7069808517667246`*^9, 3.7069808756600485`*^9}, {
  3.71333753328761*^9, 3.713337544227348*^9}, {3.7133469828155413`*^9, 
  3.713346985760971*^9}, {3.7133661435142803`*^9, 
  3.7133661454856467`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983897713*^9, 3.7133412913882713`*^9, 
  3.7133463684602704`*^9, 3.7133468378462677`*^9, 3.7133470108703194`*^9, 
  3.7133471338241405`*^9, 3.7133474345808783`*^9, 3.7133475638220005`*^9, 
  3.713348623472971*^9, 3.71334991391333*^9, 3.713350365710972*^9, 
  3.7133529560969033`*^9, 3.713353071401167*^9, 3.713353144186309*^9, 
  3.7133532890377617`*^9, 3.713354879333375*^9, 3.713361230117645*^9, 
  3.713361526450296*^9, 3.7133653606823587`*^9, 3.7133661461137094`*^9, 
  3.7133691894225435`*^9, 3.7134243707496576`*^9, 3.7134261354530177`*^9, 
  3.7137165210104027`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Which are used to calculate the first estimate of the retention factors\
\>", "Subsubsection",
 CellChangeTimes->{{3.706978954974704*^9, 3.706978973606929*^9}, {
  3.713338325625347*^9, 
  3.713338332237108*^9}},ExpressionUUID->"84207f9a-4f49-417a-9ce7-\
434c9be769ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealR", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"idealRetention", "/.", "initialIdealPeak"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069789952388783`*^9, 3.7069790183939857`*^9}, {
   3.7069790642834597`*^9, 3.706979074178793*^9}, {3.7069797213514547`*^9, 
   3.706979725015319*^9}, {3.706980634020439*^9, 3.706980651580159*^9}, 
   3.7069808912429395`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["a", "B"], "+", 
     SubscriptBox["\[Epsilon]", "p"], "-", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["\[Epsilon]", "p"]}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389840757136`*^9, 3.713341291561488*^9, 
  3.7133463686323147`*^9, 3.7133468380142717`*^9, 3.713347011028054*^9, 
  3.7133471339733505`*^9, 3.713347434746896*^9, 3.7133475639974847`*^9, 
  3.7133486236250505`*^9, 3.7133499140658445`*^9, 3.7133503658649874`*^9, 
  3.7133529562464504`*^9, 3.7133530715962114`*^9, 3.7133531443443136`*^9, 
  3.71335328918832*^9, 3.713354879493922*^9, 3.713361230264829*^9, 
  3.7133615266349545`*^9, 3.713365360844646*^9, 3.713369189576254*^9, 
  3.7134243709136567`*^9, 3.713426135609268*^9, 
  3.713716521163285*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
These retention factors are then used to calculate the system velocities\
\>", "Subsubsection",
 CellChangeTimes->{{3.7069796980414314`*^9, 3.7069797111351843`*^9}, {
  3.7133383466774664`*^9, 
  3.713338349635667*^9}},ExpressionUUID->"782874f5-be02-4a57-8fec-\
6360cc051264"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zones", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"idealZoneVelocityEstimates", "/.", "idealVelocityEstimate"}], "/.",
     "idealR"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.706979713657446*^9, 3.706979768519618*^9}, {
  3.706979867971958*^9, 3.706979867974459*^9}, {3.70697990218363*^9, 
  3.70697991552148*^9}, {3.7069799908921824`*^9, 3.7069799933624125`*^9}, {
  3.706980055128106*^9, 
  3.706980056637744*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "B"], "+", 
            SubscriptBox["\[Epsilon]", "p"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["\[Epsilon]", "p"]}]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "B"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338984590214*^9, 3.713341292084383*^9, 
  3.7133463691382647`*^9, 3.7133468385553055`*^9, 3.713347011650095*^9, 
  3.7133471346043415`*^9, 3.7133474353986936`*^9, 3.713347564709545*^9, 
  3.713348624246535*^9, 3.7133499146817293`*^9, 3.7133503664802117`*^9, 
  3.7133529568380756`*^9, 3.7133530722077527`*^9, 3.713353144941352*^9, 
  3.713353289764444*^9, 3.7133548801019726`*^9, 3.713361230895975*^9, 
  3.7133615272208395`*^9, 3.713365361446576*^9, 3.7133691902386775`*^9, 
  3.713424371550476*^9, 3.713426136203017*^9, 
  3.7137165217703457`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Estimate the peak concentrations again, based on mass balances\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980682132275*^9, 
  3.70698070656619*^9}},ExpressionUUID->"1485bbfd-c931-4a48-a2c6-\
094478f992fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peak2", "=", 
  RowBox[{
   RowBox[{"peakEstimate", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "A"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<F\>\""]}], ",", 
     RowBox[{
      SubscriptBox["c", "B"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.70698039541459*^9, 3.7069804487190475`*^9}, {
  3.706980749074515*^9, 3.7069807513023925`*^9}, {3.713337473733631*^9, 
  3.7133374837736053`*^9}, {3.7133469766355376`*^9, 
  3.7133469789252863`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "A"]}], "+", 
    SubscriptBox["a", "B"], "+", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"], " ", 
     SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
    RowBox[{
     SubscriptBox["a", "A"], " ", 
     SubscriptBox["b", "B"], " ", 
     SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["a", "A"], " ", 
    SubscriptBox["b", "B"]}]]}]], "Output",
 CellChangeTimes->{3.7133389846647153`*^9, 3.7133412921336527`*^9, 
  3.713346369174189*^9, 3.7133468386123066`*^9, 3.713347011685094*^9, 
  3.713347134643341*^9, 3.7133474354577703`*^9, 3.7133475647690434`*^9, 
  3.7133486243025513`*^9, 3.7133499147247295`*^9, 3.7133503665588183`*^9, 
  3.713352956882077*^9, 3.713353072231753*^9, 3.7133531449828577`*^9, 
  3.713353289806444*^9, 3.7133548801367817`*^9, 3.713361230937462*^9, 
  3.713361527252093*^9, 3.713365361512575*^9, 3.7133691902906766`*^9, 
  3.713424371588476*^9, 3.7134261362655177`*^9, 
  3.713716521799845*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peak1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "/.", "zones"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706980556163006*^9, 3.7069806034279537`*^9}, {
  3.706980753848175*^9, 
  3.7069807554623966`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubsuperscriptBox["a", "A", "2"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"]}], "+", 
       SubsuperscriptBox["a", "B", "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubsuperscriptBox["a", "B", "2"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]}], ")"}], " ", 
     SubscriptBox["y", "target"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "A"]}], "+", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.713338984773714*^9, 3.713341292283202*^9, 
  3.7133463692802043`*^9, 3.7133468387608414`*^9, 3.713347011790102*^9, 
  3.713347134745865*^9, 3.713347435546276*^9, 3.713347564875677*^9, 
  3.713348624392061*^9, 3.7133495161872025`*^9, 3.713349914806242*^9, 
  3.7133503666453238`*^9, 3.7133529569620867`*^9, 3.713353072320616*^9, 
  3.7133531450799017`*^9, 3.713353289884452*^9, 3.713354880220786*^9, 
  3.713361231016588*^9, 3.7133615273211327`*^9, 3.713365361589594*^9, 
  3.7133691903746915`*^9, 3.7134243716674767`*^9, 3.7134261363436437`*^9, 
  3.7137165218663635`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakUpdate", "=", 
  RowBox[{"{", 
   RowBox[{"peak1", ",", "peak2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7069807619015074`*^9, 
  3.706980768562213*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["a", "A", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "+", 
         SubsuperscriptBox["a", "B", "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389847912135`*^9, 3.7133412923132033`*^9, 
  3.713346369303203*^9, 3.7133468388058386`*^9, 3.7133470118171034`*^9, 
  3.713347134792368*^9, 3.7133474355792756`*^9, 3.7133475649071817`*^9, 
  3.7133486244350615`*^9, 3.7133499148412404`*^9, 3.7133503666733274`*^9, 
  3.7133529569911337`*^9, 3.713353072352622*^9, 3.713353145134404*^9, 
  3.7133532899139*^9, 3.713354880247792*^9, 3.7133612310352287`*^9, 
  3.7133615273367567`*^9, 3.7133653616070924`*^9, 3.7133691903961906`*^9, 
  3.7134243716884766`*^9, 3.713426136359268*^9, 
  3.7137165218819847`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Calculate the difference between the initial peak values, and this second \
estimate\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980733620349*^9, 3.706980741374005*^9}, {
  3.713338403127731*^9, 
  3.713338417737518*^9}},ExpressionUUID->"66763d3e-ff8d-4a33-8c14-\
8f623391c92d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tolerances", "=", 
  RowBox[{
   RowBox[{"Simplify", "@", "Abs"}], "/@", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
         SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "/.", 
       "initialIdealPeak"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
         SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "/.", 
       "peakUpdate"}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7069807890536585`*^9, 3.70698082903454*^9}, {
  3.7069809659889245`*^9, 3.7069810725202613`*^9}, {3.7133377288549094`*^9, 
  3.7133377372220945`*^9}, {3.7133469633377705`*^9, 3.713346970737501*^9}, {
  3.713347376709869*^9, 3.713347420997893*^9}, {3.7133482657229424`*^9, 
  3.7133482685052032`*^9}, {3.713348302317844*^9, 
  3.713348341253765*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "B", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "B", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]],
            " ", 
           SubscriptBox["y", "target"]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "A"]}], "+", 
          SubscriptBox["a", "B"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}]}], ")"}]}], "]"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Abs", "[", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "B"]}], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]], 
       "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"]}]], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338987410713*^9, 3.713341294913064*^9, 3.713346371882241*^9, 
   3.7133468388693476`*^9, 3.713347014351598*^9, 3.7133471373950915`*^9, 
   3.713347438303015*^9, 3.7133475677350173`*^9, {3.713348299338397*^9, 
   3.713348309373665*^9}, 3.713348342015746*^9, 3.7133486247108936`*^9, 
   3.7133499150362864`*^9, 3.7133503668540983`*^9, 3.7133529571791477`*^9, 
   3.7133530725655937`*^9, 3.7133531453574257`*^9, 3.713353290101416*^9, 
   3.7133548804648795`*^9, 3.7133612312171164`*^9, 3.713361527521701*^9, 
   3.7133653617859807`*^9, 3.7133691905963025`*^9, 3.713424371897476*^9, 
   3.713426136546768*^9, 
   3.71371652206142*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"toleranceFunction", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"Thread", "[", 
    RowBox[{"tolerances", ">", "0.0001"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toleranceFunction", "[", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7133474435819225`*^9, 3.7133474792362638`*^9}, {
   3.713347594019288*^9, 3.7133476000400352`*^9}, {3.713347630147417*^9, 
   3.7133476671386166`*^9}, 3.7133477791622925`*^9, {3.713347821214241*^9, 
   3.713347848366146*^9}, {3.713347986141308*^9, 3.7133479865219297`*^9}, 
   3.713348225226048*^9, {3.7133483570125556`*^9, 
   3.713348361995498*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["a", "B", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "A", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "-", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["a", "B", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], ")"}], "2"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "A", "2"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "A"], "-", 
                 RowBox[{
                  SubscriptBox["a", "B"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
               "2"]}]], " ", 
            SubscriptBox["y", "target"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "+", 
           SubscriptBox["a", "B"], "+", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "A"]}], "+", 
           SubscriptBox["a", "B"], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}]}], ")"}]}], "]"}]}], ">", "0.0001`"}], ",", 
   "False"}], "}"}]], "Output",
 CellChangeTimes->{{3.7133474521191287`*^9, 3.7133474797163615`*^9}, 
   3.713347567819892*^9, 3.713347600651068*^9, {3.713347640492735*^9, 
   3.713347667920186*^9}, {3.713347780618233*^9, 3.7133477929002504`*^9}, {
   3.71334782507133*^9, 3.713347849392953*^9}, 3.713347990450783*^9, 
   3.7133481906596584`*^9, 3.713348225955258*^9, {3.7133483524182343`*^9, 
   3.7133483626505995`*^9}, 3.713348624766897*^9, 3.713349915065791*^9, 
   3.713350366886099*^9, 3.7133529572071548`*^9, 3.7133530726195965`*^9, 
   3.713353145418434*^9, 3.713353290129919*^9, 3.7133548804918795`*^9, 
   3.7133612312332516`*^9, 3.7133615275529337`*^9, 3.7133653618081307`*^9, 
   3.7133691906127987`*^9, 3.713424371922476*^9, 3.713426136578018*^9, 
   3.7137165220704193`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assuming we haven\[CloseCurlyQuote]t converged, calculate new \[Gamma] \
values", "Subsubsection",
 CellChangeTimes->{{3.7069810861321573`*^9, 
  3.706981113672449*^9}},ExpressionUUID->"9f5febe5-be12-4cad-a8bf-\
4726ae041a8a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"second\[Gamma]Estimate", "=", 
  RowBox[{"secondary\[Gamma]Values", "/.", "peakUpdate"}]}]], "Input",
 CellChangeTimes->{{3.7069811158565035`*^9, 3.7069811277049484`*^9}, {
  3.706981188772627*^9, 
  3.7069811946623883`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           SubscriptBox["a", "B"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["a", "A", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "+", 
         SubsuperscriptBox["a", "B", "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "+", 
              SubscriptBox["a", "B"], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SubsuperscriptBox["a", "A", "2"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"]}], "+", 
              SubsuperscriptBox["a", "B", "2"], "-", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "B", "2"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]}], ")"}], " ", 
            SubscriptBox["y", "target"]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "+", 
              SubscriptBox["a", "B"], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["a", "A"]}], "+", 
              SubscriptBox["a", "B"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.713338987481716*^9, 3.7133412950125704`*^9, 
  3.71334637195024*^9, 3.7133468389013467`*^9, 3.7133470144115973`*^9, 
  3.713347137437094*^9, 3.713347438380742*^9, 3.7133475678474064`*^9, 
  3.713348366048337*^9, 3.713348624824019*^9, 3.713349915092864*^9, 
  3.713350366917099*^9, 3.7133529572361574`*^9, 3.7133530726491003`*^9, 
  3.7133531454794455`*^9, 3.7133532901584234`*^9, 3.7133548805198812`*^9, 
  3.713361231248596*^9, 3.7133615275685577`*^9, 3.7133653618237743`*^9, 
  3.7133691906284213`*^9, 3.7134243719574766`*^9, 3.7134261365936427`*^9, 
  3.713716522074419*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Use the new \[Gamma] values to calculate new cs estimates", \
"Subsubsection",
 CellChangeTimes->{{3.706981149036009*^9, 3.7069811736421733`*^9}, {
  3.7137164391625586`*^9, 
  3.713716442222807*^9}},ExpressionUUID->"8240279e-f206-4752-a47a-\
f644e4b1e8a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nextEstimate", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"dilutionEstimate", "/.", "second\[Gamma]Estimate"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706981177248345*^9, 3.7069811995752*^9}, {
  3.706981263784754*^9, 3.706981265664357*^9}, {3.7133461141988926`*^9, 
  3.7133461169762964`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "-", 
         SubsuperscriptBox["a", "B", "2"], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}], " ", 
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["a", "A", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], 
            "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], 
            "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
              ")"}]}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
            RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}], "+", 
            RowBox[{
             SubsuperscriptBox["b", "A", "2"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "B"], "+", 
                  RowBox[{
                   SubscriptBox["a", "B"], " ", 
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "A"], "+", 
                  RowBox[{
                   SubscriptBox["a", "A"], " ", 
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], 
               "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "-", 
                  RowBox[{
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
                 ")"}]}]}]]}], "+", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], "-", 
                  RowBox[{"2", " ", 
                   SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
                   SubscriptBox["y", "target"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338988135714*^9, 3.7133412956481447`*^9, 
  3.713346118603695*^9, 3.7133463725891953`*^9, 3.7133468402458277`*^9, 
  3.7133470150076265`*^9, 3.713347138083175*^9, 3.713347168590292*^9, 
  3.713347439044397*^9, 3.7133475685831337`*^9, 3.7133486255111685`*^9, 
  3.7133499157464705`*^9, 3.7133503675786076`*^9, 3.7133529578722143`*^9, 
  3.713353073286603*^9, 3.7133531461687775`*^9, 3.7133532907490005`*^9, 
  3.713354881174929*^9, 3.713361231920519*^9, 3.713361528111741*^9, 
  3.713365362358979*^9, 3.7133691913661003`*^9, 3.7134243726868105`*^9, 
  3.7134261371405177`*^9, 
  3.713716522723442*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define the iteration", "Subsubsection",
 CellChangeTimes->{{3.7133460384320483`*^9, 
  3.713346042106112*^9}},ExpressionUUID->"bd60ad2a-5e10-4b60-b6fa-\
e04fe6a034ac"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"generateCs", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<s\>\"\)]\)\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<s\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<s\>\"\)]\)\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}], "|>"}], "/.", 
   RowBox[{"peakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateCpinitial", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<p\>\"\)]\) initial\>\"",
       "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<p\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<p\>\"\)]\) initial\>\"",
       "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], "|>"}], "/.", 
   RowBox[{"initialPeakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateCpfinal", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<p\>\"\)]\) final\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<p\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<p\>\"\)]\) final\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], "|>"}], "/.", 
   RowBox[{"peakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateResults", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"generateCs", "[", "#", "]"}], ",", 
      RowBox[{"generateCpinitial", "[", "#", "]"}], ",", 
      RowBox[{"generateCpfinal", "[", "#", "]"}]}], "]"}], "&"}]}], 
  ";"}]}], "Input",ExpressionUUID->"00000000-0000-0000-0000-000000000000"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"doIdealSWD", "[", 
    RowBox[{
    "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "yt_", ",", "cf1_", ",", 
     "cf2_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "A"], "=", "a1"}], ",", 
       RowBox[{
        SubscriptBox["a", "B"], "=", "a2"}], ",", 
       RowBox[{
        SubscriptBox["b", "A"], "=", "b1"}], ",", 
       RowBox[{
        SubscriptBox["b", "B"], "=", "b2"}], ",", 
       RowBox[{
        SubscriptBox["y", "target"], "=", "yt"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "=", "cf1"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "=", "cf2"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"idealNextEstimateFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], "/.", 
         "nextEstimate"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zoneFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "zones", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"velFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"idealVelocityEstimate", "/.", "idealR"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"toleranceFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"Or", "@@", 
         RowBox[{"Thread", "[", 
          RowBox[{"tolerances", ">", "0.0001"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"peakEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "peakUpdate", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"initialPeakEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "initialIdealPeak", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"minorEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"secondaryEstimates", "/.", "portFlowEstimates"}], "/.", 
         "zoneFlowEstimates"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"csHist", "=", 
       RowBox[{"NestWhileList", "[", 
        RowBox[{"idealNextEstimateFunction", ",", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], ",", 
         "toleranceFunction"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"results", "=", 
       RowBox[{"Dataset", "[", 
        RowBox[{"generateResults", "/@", "csHist"}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.71334838892173*^9, 3.7133484157749825`*^9}, {
   3.7133484816074657`*^9, 3.713348572964994*^9}, {3.713348635877905*^9, 
   3.7133486398002987`*^9}, {3.7133486804523497`*^9, 
   3.7133487328985577`*^9}, {3.713348763591322*^9, 3.713348808444786*^9}, {
   3.713348904038522*^9, 3.7133490143287745`*^9}, {3.7133491223601575`*^9, 
   3.713349367417217*^9}, {3.7133496184772663`*^9, 3.7133496189549747`*^9}, {
   3.713349961875225*^9, 3.713349997097623*^9}, {3.713350386061716*^9, 
   3.713350393408285*^9}, {3.7133504391341023`*^9, 3.713350545011199*^9}, {
   3.713350577847618*^9, 3.713350627902082*^9}, {3.713350771208232*^9, 
   3.7133508195275707`*^9}, {3.7133508547945404`*^9, 3.713350899612611*^9}, {
   3.7133509764347796`*^9, 3.7133510136961746`*^9}, {3.713351052158817*^9, 
   3.7133510526720405`*^9}, {3.7133511511511936`*^9, 
   3.7133512038268733`*^9}, {3.7133514342412663`*^9, 
   3.7133515120269003`*^9}, {3.713351555865802*^9, 3.7133516816647587`*^9}, {
   3.713351755707103*^9, 3.713351889697209*^9}, {3.713351929849571*^9, 
   3.713352002820095*^9}, {3.713352033776746*^9, 3.7133520625675793`*^9}, {
   3.713353010025146*^9, 3.713353039045745*^9}, {3.7133533084968605`*^9, 
   3.713353390241003*^9}, {3.7133548915358353`*^9, 3.7133549002485185`*^9}, {
   3.7133550094882603`*^9, 3.713355019306679*^9}, {3.7133550504322205`*^9, 
   3.7133550525490665`*^9}, {3.7133553989446926`*^9, 3.713355400779934*^9}, {
   3.713356458992903*^9, 3.7133565024254293`*^9}, {3.7133574498348975`*^9, 
   3.7133574824327354`*^9}, {3.7133575229169674`*^9, 
   3.7133575815353537`*^9}, {3.7133578332619047`*^9, 
   3.7133578351232114`*^9}, {3.7133651530581465`*^9, 
   3.7133651769821053`*^9}, {3.7133653772263184`*^9, 
   3.7133653790974874`*^9}, {3.713365415273676*^9, 3.71336545184683*^9}, {
   3.7133659058127365`*^9, 3.713365932263769*^9}, {3.7133660328995714`*^9, 
   3.7133660742673492`*^9}, {3.7133661911362677`*^9, 3.713366258940174*^9}, {
   3.713366826113123*^9, 3.7133670111623077`*^9}, {3.713370511286664*^9, 
   3.713370531406848*^9}, {3.7133709068987303`*^9, 3.7133709078515434`*^9}, {
   3.71337099701313*^9, 3.7133710006736345`*^9}, {3.7133710873571415`*^9, 
   3.7133710972342978`*^9}, 3.713371511464295*^9, {3.71337173003877*^9, 
   3.713371743942113*^9}, {3.713371785064848*^9, 
   3.713371814559945*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "\"\<F\>\""], "\[Equal]", 
  RowBox[{
   SubscriptBox["\[Epsilon]", "b"], 
   SubscriptBox["A", "c"], 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<III\>\""], "-", 
     SubsuperscriptBox["u", "0", "\"\<II\>\""]}], ")"}]}]}]], "Input",Expressi\
onUUID->"00000000-0000-0000-0000-000000000000"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "\<\"F\"\>"], "\[Equal]", 
  RowBox[{
   SubscriptBox["A", "c"], " ", 
   SubscriptBox["\[Epsilon]", "b"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], "+", 
     SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7137165227500687`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"calculateMvalues", "[", 
   RowBox[{
   "cs_", ",", "ep_", ",", "eb_", ",", "lc_", ",", "db_", ",", "ff_", ",", 
    "yt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "c"], "=", 
       RowBox[{"\[Pi]", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["db", "2"], ")"}], "2"]}]}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], "=", "ep"}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "b"], "=", "eb"}], ",", 
      RowBox[{
       SubscriptBox["L", "c"], "=", "lc"}], ",", 
      RowBox[{"feed", "=", 
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "\[Rule]", "ff"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "t"], "=", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]}]}], ",", "mvals", ",", 
      "tsw"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"minorEstimates", "=", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"minorEstFunc", "[", "cs", "]"}], "/.", 
         RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tsw", "=", 
      RowBox[{
       RowBox[{
        FractionBox[
         SubscriptBox["L", "c"], "v"], "/.", 
        RowBox[{"velFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mvals", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "zone"], "\[Rule]", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox[
                RowBox[{"u", "[", "zone", "]"}], "0"], " ", 
               SubscriptBox["\[Epsilon]", "b"], "tsw"}], "-", 
              RowBox[{
               SubscriptBox["\[Epsilon]", "t"], 
               SubscriptBox["L", "c"]}]}], 
             RowBox[{
              SubscriptBox["L", "c"], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"zone", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<I\>\"", ",", "\"\<II\>\"", ",", "\"\<III\>\"", ",", 
               "\"\<IV\>\""}], "}"}]}], "}"}]}], "]"}], "]"}], "/.", 
        RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"newF", "=", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mvals", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "2"}], "]"}], "]"}], "-", 
           RowBox[{"mvals", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}], 
         SubscriptBox["L", "c"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "t"]}], ")"}]}], "tsw"], "*", 
       SubscriptBox["A", "c"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"testF", "=", 
      RowBox[{
       RowBox[{"portFlowEstimates", "/.", 
        RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"testU", "=", 
      RowBox[{
       RowBox[{"zoneFunction", "[", "cs", "]"}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Association", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(t\), \(sw\)]\)\>\"", "\[Rule]", "tsw"}], 
        "}"}], "~", "Join", "~", "mvals", "~", "Join", "~", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["f", "\"\<Feed\>\""], "\[Rule]", "newF"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.71336534820242*^9, 3.713365348903594*^9}, {
   3.7133672166640797`*^9, 3.713367232379471*^9}, {3.713367264943421*^9, 
   3.7133673251679497`*^9}, {3.7133673656191206`*^9, 3.71336740881384*^9}, {
   3.713367624385961*^9, 3.713368012610828*^9}, {3.713368183923693*^9, 
   3.713368193439434*^9}, {3.7133683422540445`*^9, 3.7133684012941003`*^9}, {
   3.713368494751278*^9, 3.7133685183730564`*^9}, {3.71336992564083*^9, 
   3.713369955953268*^9}, {3.7133703907290297`*^9, 3.7133704713900423`*^9}, {
   3.7133705494647818`*^9, 3.713370553830155*^9}, {3.7133709615908437`*^9, 
   3.713371022737687*^9}, 3.7133710808620205`*^9, {3.713371121118045*^9, 
   3.7133711228027134`*^9}, 3.7133714387729197`*^9, {3.7133714801891603`*^9, 
   3.713371485234321*^9}, {3.713371754168645*^9, 3.713371764519052*^9}, {
   3.7133718536693773`*^9, 3.7133718739033484`*^9}, {3.713372001583313*^9, 
   3.713372030686575*^9}, {3.7134259763403625`*^9, 3.713425980214201*^9}, {
   3.7134260550145335`*^9, 3.7134261155612726`*^9}, 3.7134264672378664`*^9, {
   3.713426582662972*^9, 3.7134265938661394`*^9}, {3.713426642282429*^9, 
   3.713426698906968*^9}, {3.713426732974614*^9, 3.713426750642109*^9}, {
   3.7134268135470448`*^9, 3.713426854374708*^9}, {3.713426899412753*^9, 
   3.713426901512068*^9}, {3.71343515320172*^9, 3.713435188094446*^9}, {
   3.71343636268979*^9, 3.713436383211113*^9}, {3.713437293805332*^9, 
   3.713437306873647*^9}, {3.713437581792432*^9, 3.713437584636244*^9}, {
   3.7134384424884524`*^9, 3.71343846449323*^9}, {3.7134385578378057`*^9, 
   3.7134385586182456`*^9}, {3.7134408867741084`*^9, 
   3.7134409215385637`*^9}, {3.7134412441244307`*^9, 
   3.7134412708929024`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Wrap the Procedure into a User Interface", "Section",
 CellChangeTimes->{{3.7133620544850044`*^9, 
  3.7133620682539067`*^9}},ExpressionUUID->"0f6723bd-85ba-4ca1-a9c1-\
86b1ee32b56f"],

Cell[CellGroupData[{

Cell["Ideal", "Subsection",
 CellChangeTimes->{{3.71344494192712*^9, 
  3.7134449433781724`*^9}},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"],

Cell[CellGroupData[{

Cell[BoxData[{"Manipulate", "\[IndentingNewLine]", 
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "=", "0.2"}], ",", 
     RowBox[{"b1", "=", "0.1"}], ",", 
     RowBox[{"cf2", "=", "3"}], ",", 
     RowBox[{"cf1", "=", "3"}], ",", 
     RowBox[{"update", "=", "0"}], ",", 
     RowBox[{"a1", "=", "1"}], ",", 
     RowBox[{"a2", "=", "2"}], ",", 
     RowBox[{"ep", "=", "0"}], ",", 
     RowBox[{"eb", "=", "0.45"}], ",", 
     RowBox[{"fFeed", "=", "5"}], ",", 
     RowBox[{"yt", "=", "0.99"}], ",", 
     RowBox[{"lc", "=", "90"}], ",", 
     RowBox[{"db", "=", "2.5"}], ",", 
     RowBox[{"plot1", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot2", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot3", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Ideal Standing Wave Design Applied to the Langmuir Isotherm\>\
\"", ",", "Bold", ",", "Large"}], "]"}], "]"}], ",", "SpanFromLeft"}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"Dynamic", "[", "a2", "]"}]}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Dynamic", "[", "a1", "]"}], ",", "30"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \
\(2\)]\)\>\"", ",", 
            "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \
\(2\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "fFeed", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "yt", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Feed Concentration 1\>\"", ",", 
            "\"\<Feed Concentration 2\>\"", ",", "\"\<Feed Flow Rate\>\"", 
            ",", "\"\<Yield Target\>\""}], "}"}]}], ",", 
         "\[IndentingNewLine]", "List"}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "eb", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "ep", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "db", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "lc", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \
\(b\)]\)\>\"", ",", 
            "\"\<Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\
\)]\)\>\"", ",", "\"\<Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)\>\"", 
            ",", "\"\<Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)\>\""}], 
           "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Button", "[", 
          RowBox[{
          "\"\<Generate Standing Wave Design Results\>\"", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"plot1", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<SWD Iterations History\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"doIdealSWD", "[", 
               RowBox[{
               "a1", ",", "a2", ",", "b1", ",", "b2", ",", "yt", ",", "cf1", 
                ",", "cf2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"plot2", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions\
\>\"", ",", "Bold"}], "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"calculateMvalues", "[", 
                RowBox[{
                 RowBox[{"Last", "[", "csHist", "]"}], ",", "ep", ",", "eb", 
                 ",", "lc", ",", "db", ",", "fFeed", ",", "yt"}], "]"}]}]}]}],
             ";", "\[IndentingNewLine]", 
            RowBox[{"plot3", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD Concentration Predictions\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"Association", "@", "minorEstimates"}]}]}]}], ";"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}], ",", 
         "\[IndentingNewLine]", "SpanFromLeft"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Dynamic", "[", "plot1", "]"}], ",", "SpanFromLeft", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Dynamic", "[", "plot2", "]"}], ",", 
         RowBox[{"Dynamic", "[", "plot3", "]"}]}], "\[IndentingNewLine]", 
        "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "2"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0EFIU3EABvAx0Nhh6MS12g4tNBYznBdXKokDCUEcNprlMzWN4auRzmF1
WIuZpLKeFK1ixKYxZNpae7ZgVKSHEdtYg0rQbYUWCBuxQzYiF0ztff/Dx+/y
8R2+o4MjOgOfx+MpuECneSJM+3Katt+zxC6hIwoXVe40fHQiswk/pGTfYWZo
7Q+0uDv+QVec3YU21TbxSbqZf4WzstoqgJlQvRSOu+aPwDHlrSr43q+vgR52
RQULnctqOJylO6CzoaCFx+Ohbih/66FIL9E4AO2MxADz6gUvfHMhSeyy+/zw
i/kTC80P1nQvOWWjh3qgrXOnD44dNBjh3uxPN2Q2Pnph8HVqCT4zZUMw4Ln2
DZZX3iXGTp77AeOnNXuw9lIJP8AZtkSIn/v/WllO3rGr05AKn2HgxsTz+/Dm
SrIIpWdN+/DUpLh0CTt0UQRtQ/wWWLpMER8+7W+F0cNOIlNfq4fex/7zcF5U
1gu3hIo+uBtcHYR2i9IAXTGhEX69N2eCtFNxHdYJtVOQcjQ54LaAIS6uJ8Sv
OC83HpBBT6hGBVdTt4nq4K91OBO7k4IV7TfyUCl5R6STtukE/hKzxEh6rod6
kdP45GUX4X8td1tX
  "],ExpressionUUID->"00000000-0000-0000-0000-000000000000"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 3, $CellContext`cf1$$ = 3, $CellContext`update$$ =
   0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 
  1.99999999999998, $CellContext`ep$$ = 0, $CellContext`eb$$ = 
  0.45, $CellContext`fFeed$$ = 5, $CellContext`yt$$ = 
  0.9900000000000005, $CellContext`lc$$ = 90, $CellContext`db$$ = 
  2.5, $CellContext`plot1$$ = Labeled[
   Dataset[{
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 3, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 3, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      4.405124837953328, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466728`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      2.439966230616413, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      1.661677923127861, "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.373163469535223, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      2.439966230616413, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466712`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.2969863607944765`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.245330029506925, "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.6465314933342245`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.2969863607944774`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466726`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      2.923233575249214, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      1.9907950508440415`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.527313686451844, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      2.923233575249214, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466721`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.0862299154563213`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.101799628150984, "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5793054493520104`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0862299154563226`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466721`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.01514601200888, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0533897151094718`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5566314589460784`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0151460120088798`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466708`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.0461462254057246`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0745016344333616`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5665197530190347`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0461462254057237`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.594875162046672, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.032626804214113, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0652945710545003`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.562207395206285, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0326268042141136`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466717`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.038522723284619, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0693098391484077`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.564088046182881, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.038522723284618, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466715`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.0359514695901546`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0675587511844684`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.563267880452358, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0359514695901546`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466717`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.037072812248056, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.0683224135317237`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5636255607630036`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0370728122480557`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466715`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.0365837864630323`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.067989374762327, "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5634695737473794`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0365837864630327`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.594875162046673, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.0367970542066005`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`], 
     Association[
     "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)" -> 
      2.068134615420479, "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)" -> 
      2.5635376008327935`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial" -> 
      3.0367970542066014`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial" -> 
      1.5948751620466717`, 
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final" -> 
      3.036704046574202, 
      "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final" -> 
      1.5948751620466728`]}, 
    TypeSystem`Vector[
     TypeSystem`Struct[{
      "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"s\"\)]\)", 
       "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"s\"\)]\)", 
       "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) initial", 
       "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) initial", 
       "\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"p\"\)]\) final", 
       "\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"p\"\)]\) final"}, {
       TypeSystem`Atom[Real], 
       TypeSystem`Atom[Real], 
       TypeSystem`Atom[Real], 
       TypeSystem`Atom[Real], 
       TypeSystem`Atom[Real], 
       TypeSystem`Atom[Real]}], 13], 
    Association["ID" -> 6098969739266]], 
   Style["SWD Iterations History", Bold], Top], $CellContext`plot2$$ = Labeled[
   Dataset[
    Association[
    "\!\(\*SubscriptBox[\(t\), \(sw\)]\)" -> 19.679164991781988`, 
     Subscript[$CellContext`m, "I"] -> 1.9999999999999998`, 
     Subscript[$CellContext`m, "II"] -> 0.7581644651554384, 
     Subscript[$CellContext`m, "III"] -> 1.1631146239417764`, 
     Subscript[$CellContext`m, "IV"] -> 0.7670595744046876, 
     Subscript[$CellContext`f, "Feed"] -> 5.0000000000000036`], 
    TypeSystem`Assoc[TypeSystem`AnyType, 
     TypeSystem`Atom[Real], 6], 
    Association["ID" -> 6103264706562]], 
   Style["SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
   Top], $CellContext`plot3$$ = Labeled[
   Dataset[
    Association[Subscript[
       $CellContext`c["R"], $CellContext`A] -> 3.0367040465742003`, Subscript[
       $CellContext`c["E"], $CellContext`A] -> 
     0.00978270022294921, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]s\[UnderBracket]Times -> 
     1.828746202200722, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]A\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]IV\
\[UnderBracket]DoubleQuote -> 0.01739131215597137, Subscript[
       $CellContext`c["R"], $CellContext`B] -> 0.03067377824822428, Subscript[
       $CellContext`c["E"], $CellContext`B] -> 
     0.9684873220719709, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]s\[UnderBracket]Times -> 
     2.4514140657216883`, $CellContext`c\[UnderBracket]Subsuperscript\
\[UnderBracket]B\[UnderBracket]and\[UnderBracket]DoubleQuote\[UnderBracket]I\
\[UnderBracket]DoubleQuote -> 0.017254153948617807`], 
    TypeSystem`Assoc[TypeSystem`AnyType, 
     TypeSystem`Atom[Real], 8], 
    Association["ID" -> 6107559673858]], 
   Style["SWD Concentration Predictions", Bold], Top]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Ideal Standing Wave Design Applied to the Langmuir \
Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "a8050475-3d0b-4236-9048-3c0cb90c0aae"],
       Text[
        Style[
        "Ideal Standing Wave Design Applied to the Langmuir Isotherm", Bold, 
         Large]]], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`fFeed$$], 
              Dynamic[$CellContext`fFeed$$], {0, 100}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`fFeed$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Flow Rate\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Feed Flow Rate", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`yt$$], 
              Dynamic[$CellContext`yt$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`yt$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Yield Target\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Yield Target", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`eb$$], 
              Dynamic[$CellContext`eb$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`eb$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Inter-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(b\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`ep$$], 
              Dynamic[$CellContext`ep$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`ep$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Intra-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(p\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`db$$], 
              Dynamic[$CellContext`db$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`db$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Diameter: \\!\\(\\*SubscriptBox[\\(d\\), \\(b\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`lc$$], 
              Dynamic[$CellContext`lc$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`lc$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(L\\), \\(c\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      ButtonBox["\<\"Generate Standing Wave Design Results\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = (Labeled[#, 
           Style["SWD Iterations History", Bold], Top]& )[
           $CellContext`doIdealSWD[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, $CellContext`cf1$$, \
$CellContext`cf2$$]]; $CellContext`plot2$$ = (Labeled[#, 
           Style[
           "SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
           Top]& )[
           Dataset[
            $CellContext`calculateMvalues[
             
             Last[$CellContext`csHist], $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`fFeed$$, \
$CellContext`yt$$]]]; $CellContext`plot3$$ = (Labeled[#, 
           Style["SWD Concentration Predictions", Bold], Top]& )[
           Dataset[
            Association[$CellContext`minorEstimates]]]; Null),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{477., {222., 252.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{361., {99., 129.}}], 
      DynamicBox[ToBoxes[$CellContext`plot3$$, StandardForm],
       ImageSizeCache->{261., {133., 163.}}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.713223241383704*^9, 3.7132232896068115`*^9, 3.713223383218844*^9, 
   3.7132234661310496`*^9, 3.713223992065814*^9, 3.713224063571741*^9, {
   3.713362586351867*^9, 3.713362594576082*^9}, 3.7133628310622797`*^9, 
   3.7133632585342674`*^9, {3.713363781116953*^9, 3.713363849061535*^9}, {
   3.713363911329649*^9, 3.7133639955439067`*^9}, 3.713365362732664*^9, 
   3.7133671093565598`*^9, {3.7133671501463985`*^9, 3.7133671659828863`*^9}, 
   3.713368105071067*^9, {3.713368210996333*^9, 3.713368232770593*^9}, 
   3.713368417912986*^9, 3.7133685816867037`*^9, 3.713368613921942*^9, 
   3.7133687665096045`*^9, 3.713368824320736*^9, 3.7133688759322624`*^9, 
   3.713368965722555*^9, {3.713369003058175*^9, 3.7133690298689814`*^9}, {
   3.7133690659175253`*^9, 3.7133690945952635`*^9}, {3.7133691248880153`*^9, 
   3.7133691470626163`*^9}, 3.7133691917193623`*^9, {3.713369250604365*^9, 
   3.713369256374468*^9}, 3.7133693156829243`*^9, 3.713370304739688*^9, 
   3.713370493179987*^9, 3.713370558345594*^9, 3.7133709216459208`*^9, {
   3.713371005907857*^9, 3.713371026005542*^9}, 3.7133711258712177`*^9, 
   3.713371445391468*^9, 3.713371490601407*^9, 3.7133717676675353`*^9, 
   3.7133718202299795`*^9, 3.713371862636008*^9, {3.7133719900514994`*^9, 
   3.7133720078994675`*^9}, 3.713372054783559*^9, 3.713424372949809*^9, 
   3.713426137443293*^9, 3.7134264197804017`*^9, 3.713426502097022*^9, 
   3.71344124979888*^9, 
   3.7137165228812113`*^9},ExpressionUUID->"00000000-0000-0000-0000-\
000000000000"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1718, 1021},
WindowMargins->{{Automatic, -7}, {Automatic, 0}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "d1" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"I\""], "d2" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"II\""], "d3" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"III\""], "d4" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"IV\""], "b1" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"I\""], "b2" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"II\""], "b3" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"III\""], "b4" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"IV\""], "u1" -> 
  SubsuperscriptBox["u", "0", "\"I\""], "u2" -> 
  SubsuperscriptBox["u", "0", "\"II\""], "u3" -> 
  SubsuperscriptBox["u", "0", "\"III\""], "u4" -> 
  SubsuperscriptBox["u", "0", "\"IV\""], "kf1" -> 
  SubsuperscriptBox["Kf", "B", "\"I\""], "kf2" -> 
  SubsuperscriptBox["Kf", "A", "\"II\""], "kf3" -> 
  SubsuperscriptBox["Kf", "B", "\"III\""], "kf4" -> 
  SubsuperscriptBox["Kf", "A", "\"IV\""], "e1" -> 
  SubsuperscriptBox["E", "B", "\"I\""], "e2" -> 
  SubsuperscriptBox["E", "A", "\"II\""], "e3" -> 
  SubsuperscriptBox["E", "B", "\"III\""], "e4" -> 
  SubsuperscriptBox["E", "A", "\"IV\""], "ep" -> 
  SubscriptBox["\[Epsilon]", "p"], "eb" -> SubscriptBox["\[Epsilon]", "b"], 
  "et" -> SubscriptBox["\[Epsilon]", "t"], "feed" -> 
  SubscriptBox["f", "\"F\""], "des" -> SubscriptBox["f", "des"], "ext" -> 
  SubscriptBox["f", "ext"], "cf1" -> SubsuperscriptBox["c", "1", "\"F\""], 
  "cf2" -> SubsuperscriptBox["c", "2", "\"F\""]},
Magnification:>1.3 Inherited,
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (March 13, 2017)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 231, 4, 129, "Title"],
Cell[CellGroupData[{
Cell[836, 30, 182, 3, 93, "Section"],
Cell[1021, 35, 2534, 58, 91, "Text"],
Cell[3558, 95, 640, 13, 91, "Text"],
Cell[CellGroupData[{
Cell[4223, 112, 380, 10, 91, "Input"],
Cell[4606, 124, 663, 10, 70, "Output"]
}, Open  ]],
Cell[5284, 137, 514, 14, 91, "Text"],
Cell[5801, 153, 638, 13, 91, "Text"],
Cell[6442, 168, 661, 10, 91, "Input"],
Cell[7106, 180, 1977, 49, 91, "Input"],
Cell[9086, 231, 756, 17, 91, "Input"],
Cell[9845, 250, 482, 10, 91, "Input"],
Cell[10330, 262, 1228, 32, 91, "Input"],
Cell[CellGroupData[{
Cell[11583, 298, 485, 13, 91, "Input"],
Cell[12071, 313, 481, 9, 70, "Message"],
Cell[12555, 324, 483, 9, 70, "Message"]
}, Open  ]],
Cell[13053, 336, 945, 24, 91, "Input"],
Cell[CellGroupData[{
Cell[14023, 364, 1347, 34, 91, "Input"],
Cell[15373, 400, 5216, 145, 70, "Output"],
Cell[20592, 547, 479, 9, 70, "Message"],
Cell[21074, 558, 476, 8, 70, "Message"]
}, Open  ]],
Cell[21565, 569, 978, 24, 91, "Input"],
Cell[22546, 595, 960, 17, 91, "Text"],
Cell[23509, 614, 4388, 97, 91, "Input"],
Cell[27900, 713, 1939, 40, 91, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[29876, 758, 177, 3, 74, "Section"],
Cell[CellGroupData[{
Cell[30078, 765, 168, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[30271, 772, 1149, 34, 75, "Input"],
Cell[31423, 808, 1414, 38, 75, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32886, 852, 163, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[33074, 859, 356, 10, 50, "Input"],
Cell[33433, 871, 762, 14, 78, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34244, 891, 178, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[34447, 898, 156, 3, 44, "Subsubsection"],
Cell[CellGroupData[{
Cell[34628, 905, 2536, 69, 263, "Input"],
Cell[37167, 976, 2446, 66, 81, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39674, 1049, 172, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[39871, 1056, 1532, 37, 331, "Input"],
Cell[41406, 1095, 1612, 36, 86, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43067, 1137, 174, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[43266, 1144, 170, 3, 44, "Subsubsection"],
Cell[CellGroupData[{
Cell[43461, 1151, 979, 30, 55, "Input"],
Cell[44443, 1183, 3379, 105, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47859, 1293, 651, 19, 50, "Input"],
Cell[48513, 1314, 1323, 34, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49873, 1353, 363, 8, 50, "Input"],
Cell[50239, 1363, 3577, 98, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53853, 1466, 605, 15, 50, "Input"],
Cell[54461, 1483, 3487, 98, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57985, 1586, 781, 24, 75, "Input"],
Cell[58769, 1612, 3166, 90, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[61984, 1708, 182, 3, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[62191, 1715, 1315, 37, 88, "Input"],
Cell[63509, 1754, 1611, 41, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65193, 1803, 201, 3, 93, "Section"],
Cell[65397, 1808, 294, 7, 39, "Text"],
Cell[CellGroupData[{
Cell[65716, 1819, 168, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[65909, 1826, 170, 3, 44, "Subsubsection"],
Cell[CellGroupData[{
Cell[66104, 1833, 1053, 27, 55, "Input"],
Cell[67160, 1862, 2319, 60, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69516, 1927, 3887, 110, 359, "Input"],
Cell[73406, 2039, 5271, 140, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[78726, 2185, 168, 3, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[78919, 2192, 872, 23, 55, "Input"],
Cell[79794, 2217, 1521, 36, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[81364, 2259, 168, 3, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[81557, 2266, 1313, 30, 179, "Input"],
Cell[82873, 2298, 1921, 47, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[84855, 2352, 173, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[85053, 2359, 168, 3, 44, "Subsubsection"],
Cell[CellGroupData[{
Cell[85246, 2366, 823, 21, 57, "Input"],
Cell[86072, 2389, 3396, 95, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89505, 2489, 643, 15, 83, "Input"],
Cell[90151, 2506, 934, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91122, 2529, 1723, 54, 102, "Input"],
Cell[92848, 2585, 2677, 72, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95562, 2662, 941, 15, 50, "Input"],
Cell[96506, 2679, 1288, 28, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[97843, 2713, 172, 3, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[98040, 2720, 3592, 89, 575, "Input"],
Cell[101635, 2811, 3395, 90, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105067, 2906, 511, 11, 91, "Input"],
Cell[105581, 2919, 3521, 102, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[109163, 3028, 178, 3, 45, "Subsection"],
Cell[109344, 3033, 224, 5, 39, "Text"],
Cell[CellGroupData[{
Cell[109593, 3042, 1835, 48, 86, "Input"],
Cell[111431, 3092, 4769, 135, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116237, 3232, 821, 21, 85, "Input"],
Cell[117061, 3255, 1080, 24, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118202, 3286, 195, 3, 93, "Section"],
Cell[CellGroupData[{
Cell[118422, 3293, 160, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[118607, 3300, 596, 15, 44, "Subsubsection"],
Cell[CellGroupData[{
Cell[119228, 3319, 831, 19, 55, "Input"],
Cell[120062, 3340, 3630, 95, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[123741, 3441, 279, 6, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[124045, 3451, 447, 8, 50, "Input"],
Cell[124495, 3461, 5009, 134, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[129553, 3601, 286, 6, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[129864, 3611, 515, 11, 50, "Input"],
Cell[130382, 3624, 15988, 424, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[146419, 4054, 220, 5, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[146664, 4063, 684, 17, 55, "Input"],
Cell[147351, 4082, 2036, 52, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149424, 4139, 356, 9, 50, "Input"],
Cell[149783, 4150, 7112, 189, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156932, 4344, 241, 6, 50, "Input"],
Cell[157176, 4352, 8962, 233, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[166187, 4591, 292, 7, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[166504, 4602, 1055, 26, 57, "Input"],
Cell[167562, 4630, 9801, 250, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177400, 4885, 1030, 24, 85, "Input"],
Cell[178433, 4911, 7503, 181, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[185985, 5098, 232, 4, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[186242, 5106, 306, 6, 50, "Input"],
Cell[186551, 5114, 18723, 471, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[205323, 5591, 263, 5, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[205611, 5600, 383, 8, 50, "Input"],
Cell[205997, 5610, 16415, 427, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[222461, 6043, 173, 3, 43, "Subsubsection"],
Cell[222637, 6048, 2916, 84, 145, "Input"],
Cell[225556, 6134, 7019, 161, 429, "Input"],
Cell[CellGroupData[{
Cell[232600, 6299, 359, 10, 55, "Input"],
Cell[232962, 6311, 439, 13, 55, "Output"]
}, Open  ]],
Cell[233416, 6327, 5801, 140, 382, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[239278, 6474, 197, 3, 93, "Section"],
Cell[CellGroupData[{
Cell[239500, 6481, 154, 3, 45, "Subsection"],
Cell[CellGroupData[{
Cell[239679, 6488, 15139, 332, 1304, "Input"],
Cell[254821, 6822, 43105, 929, 1033, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

