(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    553629,      13764]
NotebookOptionsPosition[    524832,      13068]
NotebookOutlinePosition[    530441,      13183]
CellTagsIndexPosition[    530398,      13180]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Standing Wave Design - Ideal Langmuir", "Title",
 CellChangeTimes->{{3.706963901015277*^9, 3.706963917889349*^9}, {
  3.713336670750559*^9, 
  3.7133366707705584`*^9}},ExpressionUUID->"844850aa-9b17-4736-b88b-\
edee74b5a5c1"],

Cell[CellGroupData[{

Cell["Step 1: Define the Problem Notation", "Section",
 CellChangeTimes->{{3.7069639650830946`*^9, 
  3.706963974809104*^9}},ExpressionUUID->"6ad0c834-3786-49ca-8c6e-\
49dc4a403272"],

Cell[TextData[{
 "In this section, we \
\[OpenCurlyDoubleQuote]symbolize\[CloseCurlyDoubleQuote] some variables so \
that we can use them later.  By default, if we enter a variable with a \
subscript (e.g. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "36252514-941e-4a5e-8895-0ed1182851d3"],
 ") Mathematica sees Subscript[a,1] instead of a regular symbol like a1.  So \
when you try to assign a value to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "7cccaf37-83e1-43dc-9957-2e1ad77ade90"],
 " (e.g. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "6"}], TraditionalForm]],ExpressionUUID->
  "c16c83f0-a931-43fc-ac9a-36b2a50348b9"],
 "), Mathematica instead says to itself:\n\[OpenCurlyDoubleQuote]the user \
wants to assign a value to Subscript[a,1].  I will add Subscript[_, 1] = 5 to \
the set of things I know about a.\[CloseCurlyDoubleQuote]\nWhen Mathematica \
does this, it is referred to as an \[OpenCurlyDoubleQuote]Upvalue\
\[CloseCurlyDoubleQuote] of the symbol a.\nUsing the Symbolize, function lets \
us tell Mathematica not to interpret ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "ecbb0117-3069-4818-a396-0a505293d427"],
 " as a Subscript function, and so we avoid the use of upvalues.  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "392c2751-62df-465d-827e-5b13a7148baf"],
 " is treated as its own symbol and is no longer connected to the \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] symbol.  That way, when we \
say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "5"}], TraditionalForm]],ExpressionUUID->
  "0a284276-da21-46d7-99e6-f2d927ec645c"],
 " all Mathematica does is assign the value of 5 to the symbol ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]],ExpressionUUID->
  "755dd16d-d00b-491c-96c4-f1aec4472e24"],
 " without any kind of upvalues."
}], "Text",
 CellChangeTimes->{{3.706697811970934*^9, 3.7066978572260523`*^9}, {
  3.706698028311755*^9, 3.706698138056162*^9}, {3.706698490209321*^9, 
  3.70669854546424*^9}, {3.7066988160465307`*^9, 3.7066988308940997`*^9}, {
  3.7067079136585436`*^9, 3.7067079851555705`*^9}, {3.7067080312762012`*^9, 
  3.706708071022498*^9}, {3.7067081321651993`*^9, 3.7067082954546*^9}, {
  3.7067083365748663`*^9, 
  3.706708366015239*^9}},ExpressionUUID->"2bf8674c-22d7-48be-a4b4-\
a17d6fe121fa"],

Cell[TextData[{
 "In most cases, the difference between upvalues and values is not important. \
 Algebra and calculus generally work fine with either, and you do not need to \
worry about the difference.  The one area where the difference does matter is \
",
 StyleBox["lexical scoping",
  FontSlant->"Italic"],
 ".  For example, if you want to temporarily assign a value to a variable \
like this:"
}], "Text",
 CellChangeTimes->{{3.706708370614149*^9, 3.7067084080783415`*^9}, {
  3.7067084449173512`*^9, 3.7067084752317624`*^9}, {3.7067085299593534`*^9, 
  3.706708533151581*^9}},ExpressionUUID->"a4842942-5915-4947-a38b-\
7bab8dc954cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", "=", "5"}], "}"}], ",", " ", 
   RowBox[{"Evaluate", "[", 
    SuperscriptBox["a", "2"], " ", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706708477171032*^9, 3.7067084894642897`*^9}, {
  3.706708550313186*^9, 
  3.7067085573213086`*^9}},ExpressionUUID->"31ff04fb-efe9-46a5-9cdb-\
9866d4f26fb7"],

Cell[BoxData["25"], "Output",
 CellChangeTimes->{3.713338979959713*^9, 3.713341287505271*^9, 
  3.7133463649184294`*^9, 3.71334683411222*^9, 3.7133470071005573`*^9, 
  3.7133471301795588`*^9, 3.7133474305006313`*^9, 3.7133475595981255`*^9, 
  3.713348619810763*^9, 3.713349910039451*^9, 3.7133503612607813`*^9, 
  3.7133529521733017`*^9, 3.713353067057189*^9, 3.7133531396832247`*^9, 
  3.7133532843052497`*^9, 3.713354874728448*^9, 3.7133612260792503`*^9, 
  3.7133615222710114`*^9, 3.713365356087522*^9, 3.713369184797988*^9, 
  3.7134243664504085`*^9, 3.7134261309211655`*^9, 3.7134563636430097`*^9, 
  3.7134644337951756`*^9, 3.71348408704692*^9, 3.7135121277261877`*^9, 
  3.713517720333322*^9, 3.7135230292744884`*^9, 3.7135233912055326`*^9, 
  3.7135284077546053`*^9, 3.7135300532972903`*^9, 
  3.713530745095542*^9},ExpressionUUID->"61d7a354-ff8c-4af8-9599-\
3913c9ada6bb"]
}, Open  ]],

Cell[TextData[{
 "Mathematica\[CloseCurlyQuote]s scoping construct \
\[OpenCurlyDoubleQuote]With\[CloseCurlyDoubleQuote] can only create temporary \
",
 StyleBox["values,",
  FontSlant->"Italic"],
 " not ",
 StyleBox["upvalues.",
  FontSlant->"Italic"],
 "  So if we want to use these constructs, we need to use Symbolize."
}], "Text",
 CellChangeTimes->{{3.7067085051628046`*^9, 3.7067085982239428`*^9}, {
  3.706964031058267*^9, 
  3.706964033479744*^9}},ExpressionUUID->"6a5bec25-ed4c-49f9-a3a0-\
688786f20791"],

Cell[TextData[{
 "It is also possible to force Mathematica to say the following\n\
\[OpenCurlyDoubleQuote]the user wants to assign a value to Subscript[a,1].  I \
will add Subscript[a, 1] = 5 to the set of things I know",
 StyleBox[" about the Subscript function",
  FontWeight->"Bold"],
 ".\[CloseCurlyDoubleQuote]\nWhen Mathematica does this, 5 is called a \
\[OpenCurlyDoubleQuote]downvalue\[CloseCurlyDoubleQuote] of the symbol \
Subscript."
}], "Text",
 CellChangeTimes->{{3.7067080753723607`*^9, 3.7067081294614725`*^9}, {
  3.7067083297584944`*^9, 
  3.706708331542101*^9}},ExpressionUUID->"ce8d7095-8cdd-479f-877b-\
cb8d3f7d0e2c"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Notation`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.655654009881259*^9, 3.6556540709341335`*^9}, {
  3.6556541286705556`*^9, 3.6556541386071386`*^9}, {3.6556541826824427`*^9, 
  3.655654184784837*^9}, {3.65565422925277*^9, 3.6556542656382427`*^9}, {
  3.6556543549254217`*^9, 3.6556543753579626`*^9}, {3.6556545287943487`*^9, 
  3.6556545683435383`*^9}, {3.6556552151106796`*^9, 3.655655243548979*^9}, {
  3.6556559648318224`*^9, 3.6556559758281126`*^9}, {3.6556625350770884`*^9, 
  3.6556625553416767`*^9}, {3.6556636806921215`*^9, 
  3.655663711748703*^9}},ExpressionUUID->"753256b4-6e1d-468c-ad8a-\
fdcf82663ed3"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["r", "p"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Particle", " ", "Radius"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "p"]},
    "NotationTemplateTag"], "]"}], 
  RowBox[{"(*", 
   RowBox[{"Effective", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["D", "m"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Molecular", " ", "diffusion", " ", "coefficient"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["A", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Column", " ", "Cross", " ", "Section"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubscriptBox["L", "c"]},
    "NotationTemplateTag"], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Zone", " ", "Length"}], "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7009332717595787`*^9, 3.700933287443512*^9}, {
  3.7069760577434387`*^9, 3.7069760882452564`*^9}, {3.706976265001667*^9, 
  3.706976327755203*^9}, {3.7069775917314825`*^9, 3.7069776050564218`*^9}, {
  3.7133453064566894`*^9, 3.71334533454174*^9}, {3.71335083265457*^9, 
  3.713350834501753*^9}, {3.713368226641759*^9, 
  3.713368226826703*^9}},ExpressionUUID->"7042c0e2-f205-4e61-b221-\
d58a2695e0b2"],

Cell[BoxData[{
 RowBox[{GridBox[{
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "+"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["\[Gamma]_", "-"]},
       "NotationTemplateTag"], "]"}]}
   }], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", " ", 
  TemplateBox[{SubscriptBox["y", "target"]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.700682475232301*^9, 3.700682485722865*^9}, 
   3.700682643795794*^9, 3.7009481377110014`*^9, 3.7009500313826027`*^9, {
   3.7133026447441673`*^9, 3.713302647881256*^9}, {3.713348436173435*^9, 
   3.7133484487422404`*^9}},ExpressionUUID->"2e3eaca9-003f-498d-a5ad-\
547a6651af32"],

Cell[BoxData[{
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubsuperscriptBox["c", "A", "\"F\""]},
   "NotationTemplateTag"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Symbolize", "[", 
  TemplateBox[{SubsuperscriptBox["c", "B", "\"F\""]},
   "NotationTemplateTag"], "]"}]}], "Input",
 CellChangeTimes->{{3.713348427201262*^9, 3.7133484303337097`*^9}, {
   3.713348538949387*^9, 3.713348552512232*^9}, 
   3.713348610698288*^9},ExpressionUUID->"3c2b4174-b203-4c59-afa5-\
a9632798d46c"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["q", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["a", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["b", "A"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["c", "A"]},
       "NotationTemplateTag"], "]"}]},
    {
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["q", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["a", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["b", "B"]},
       "NotationTemplateTag"], "]"}], 
     RowBox[{"Symbolize", "[", " ", 
      TemplateBox[{SubscriptBox["c", "B"]},
       "NotationTemplateTag"], "]"}]}
   }], ";"}]], "Input",
 CellChangeTimes->{{3.700682298492797*^9, 3.700682344910399*^9}, 
   3.700682645594619*^9, {3.706971022656542*^9, 
   3.7069710372036867`*^9}},ExpressionUUID->"2862fd36-9b07-4478-8a93-\
3a361d833b65"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubsuperscriptBox["c", "A", 
      RowBox[{"s", "*"}]]},
    "NotationTemplateTag"], "]"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TemplateBox[{SubsuperscriptBox["c", "B", 
      RowBox[{"s", "*"}]]},
    "NotationTemplateTag"], "]"}], " "}]}], "Input",
 CellChangeTimes->{{3.706978085564478*^9, 
  3.7069781207990713`*^9}},ExpressionUUID->"c4c7dd47-9c82-43a2-8c20-\
a1a5478f4314"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
        TemplateBox[{SubsuperscriptBox["u", "0", "zone"]},
         "NotationTemplateTag"], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"\"\<zone\>\"", "\[Rule]", 
         RowBox[{"\"\<\\\"\>\"", "<>", 
          RowBox[{"RomanNumeral", "[", "z", "]"}], "<>", "\"\<\\\"\>\""}]}], 
        "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "4"}], "}"}]}], "]"}], "//", 
    RowBox[{"MatrixForm", "\[IndentingNewLine]", 
     RowBox[{"Activate", "[", "%", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.700952008270067*^9, 3.7009520511002216`*^9}, 
   3.7009532213777666`*^9, {3.713341273798588*^9, 
   3.7133412787739716`*^9}},ExpressionUUID->"b470a06a-10a3-434f-a03c-\
1e516abcd31a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Inactive", "[", "Symbolize", "]"}], "[", 
      TemplateBox[{SubsuperscriptBox["c", "component", "x"]},
       "NotationTemplateTag"], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<x\>\"", "\[Rule]", 
        RowBox[{"\"\<\\\"\>\"", "<>", 
         RowBox[{"ToString", "[", "x", "]"}], "<>", "\"\<\\\"\>\""}]}], ",", 
       RowBox[{"\"\<component\>\"", "\[Rule]", 
        RowBox[{"ToString", "[", "c", "]"}]}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"{", 
       RowBox[{
       "s", ",", "p", ",", "feed", ",", "r", ",", "e", ",", "\"\<I\>\"", ",", 
        "\"\<IV\>\""}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Activate", "[", "%", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7009477447394514`*^9, 3.7009478256140194`*^9}, {
   3.700948031117095*^9, 3.7009480372573547`*^9}, {3.7009482672419186`*^9, 
   3.700948271782887*^9}, 3.700950072397784*^9, {3.706978020590043*^9, 
   3.70697806331144*^9}, {3.713346210600847*^9, 
   3.7133462450694036`*^9}},ExpressionUUID->"1fe50f99-d266-49ac-83ef-\
0535743be926"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"s\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"s\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"p\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"p\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"feed\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"feed\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"r\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"r\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"e\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"e\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"I\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"I\""]},
        "NotationTemplateTag"], "]"}]},
     {
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "A", "\"IV\""]},
        "NotationTemplateTag"], "]"}], 
      RowBox[{
       TemplateBox[{"Symbolize"},
        "InactiveHead",
        BaseStyle->"Inactive",
        SyntaxForm->"Symbol",
        Tooltip->"Inactive[Symbolize]"], "[", 
       TemplateBox[{SubsuperscriptBox["c", "B", "\"IV\""]},
        "NotationTemplateTag"], "]"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7133389809467134`*^9, 3.7133412881904087`*^9, {3.713346212387309*^9, 
   3.7133462462280884`*^9}, 3.71334636552874*^9, 3.713346834702281*^9, 
   3.713347007719058*^9, 3.7133471307994432`*^9, 3.7133474313024063`*^9, 
   3.7133475602718544`*^9, 3.71334862050708*^9, 3.7133499107296057`*^9, 
   3.713350361996827*^9, 3.713352952809948*^9, 3.713353067682953*^9, 
   3.7133531408722754`*^9, 3.713353285082382*^9, 3.7133548753950434`*^9, 
   3.713361226844001*^9, 3.7133615229008074`*^9, 3.7133653568050795`*^9, 
   3.713369185737153*^9, 3.7134243676247044`*^9, 3.7134261320774155`*^9, 
   3.713456364830977*^9, 3.7134644349632173`*^9, 3.7134840885071015`*^9, 
   3.7135121285047503`*^9, 3.713517725711784*^9, 3.7135230300454235`*^9, 
   3.713523392531023*^9, 3.7135284097090673`*^9, 3.713530055141783*^9, 
   3.7135307465170355`*^9},ExpressionUUID->"5c88a8f8-b0a0-4e6e-bf26-\
eaaa0c4c8dc0"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"toNumericQ", "[", "any___", "]"}], ":=", 
  RowBox[{"NumericQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"toStringQ", "[", "any___", "]"}], ":=", 
  RowBox[{"StringQ", "[", 
   RowBox[{"ToExpression", "[", "any", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Notation", "[", 
  RowBox[{
   TemplateBox[{SubsuperscriptBox["x_", "i_", 
      TemplateBox[{
        RowBox[{"a_", "?", "toStringQ"}]}, "NotationPatternTag"]]},
    "NotationTemplateTag"], "\[DoubleLongLeftRightArrow]", 
   TemplateBox[{SubscriptBox[
      RowBox[{"x_", "[", 
        TemplateBox[{
          RowBox[{"a_", "?", "StringQ"}]}, "NotationPatternTag"], "]"}], 
      "i_"]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.713336229988531*^9, 3.7133362378482275`*^9}, {
  3.7133379022738476`*^9, 
  3.713337902766363*^9}},ExpressionUUID->"57e36cee-859e-4dd0-8581-\
44b85880fbac"],

Cell[TextData[{
 "Add some convenience shortcuts.  Now, to type in ",
 Cell[BoxData[
  SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]],
  CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
    3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
    3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
    3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
    3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
    3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
    3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
    3.7069706345688634`*^9, 3.706970785055435*^9}},ExpressionUUID->
  "955fe48c-2812-4d4f-9717-eaebfbca3e5b"],
 ", we only need to press [esc] d 1 [esc]"
}], "Text",
 CellChangeTimes->{{3.7069708724437337`*^9, 
  3.7069709086295853`*^9}},ExpressionUUID->"ea4eab23-80f8-4522-8c9d-\
17b2273eb400"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<d4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Delta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<b4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["\[Beta]", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<u4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["u", "0", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<kf4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["Kf", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]},
    {
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e1\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"I\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e2\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"II\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e3\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "B", "\"III\""]},
        "NotationTemplateTag"]}], "]"}], 
     RowBox[{"AddInputAlias", "[", 
      RowBox[{"\"\<e4\>\"", "\[Rule]", 
       TemplateBox[{SubsuperscriptBox["E", "A", "\"IV\""]},
        "NotationTemplateTag"]}], "]"}]}
   }], ";"}]], "Input",
 CellChangeTimes->{{3.700681980792652*^9, 3.700681985846924*^9}, {
   3.700682153392302*^9, 3.700682199563922*^9}, {3.70068251114641*^9, 
   3.7006826091556444`*^9}, {3.7006826479742804`*^9, 3.70068266755241*^9}, {
   3.7006920920388765`*^9, 3.700692096087956*^9}, 3.7009275742950983`*^9, {
   3.7009277017061925`*^9, 3.700927702157324*^9}, {3.7009282588237453`*^9, 
   3.700928324701059*^9}, 3.7009318354863815`*^9, {3.7009501045512724`*^9, 
   3.7009501351400976`*^9}, {3.700952881254289*^9, 3.7009529360599456`*^9}, {
   3.7069706345688634`*^9, 3.706970785055435*^9}, {3.7069766810891023`*^9, 
   3.7069767108198867`*^9}},ExpressionUUID->"f014b37e-ddd0-4c98-b55b-\
c9de9e14a7d0"],

Cell[BoxData[{
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ep\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "p"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<eb\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "b"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<et\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["\[Epsilon]", "t"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<feed\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "\"F\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<des\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "des"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<ext\>\"", "\[Rule]", 
   TemplateBox[{SubscriptBox["f", "ext"]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<cf1\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["c", "1", "\"F\""]},
    "NotationTemplateTag"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AddInputAlias", "[", 
  RowBox[{"\"\<cf2\>\"", "\[Rule]", 
   TemplateBox[{SubsuperscriptBox["c", "2", "\"F\""]},
    "NotationTemplateTag"]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6726802841433578`*^9, 3.6726802928288794`*^9}, {
   3.672755271908722*^9, 3.6727552869558325`*^9}, {3.6727767324017215`*^9, 
   3.672776745104333*^9}, {3.7069704528909445`*^9, 3.7069705068199396`*^9}, {
   3.706970606368145*^9, 3.706970607027779*^9}, {3.7069767220443125`*^9, 
   3.7069767502680197`*^9}, {3.713337473752632*^9, 3.713337483785607*^9}, 
   3.7133376380505476`*^9, {3.713350841178546*^9, 
   3.713350845169429*^9}},ExpressionUUID->"7963f2ec-b0be-4a9b-ba4f-\
ea2d7bd41829"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 2: Define The Key Terms", "Section",
 CellChangeTimes->{{3.7069734825274553`*^9, 
  3.7069735032030835`*^9}},ExpressionUUID->"fbad123e-f232-43e4-a632-\
1764d9911915"],

Cell[CellGroupData[{

Cell["Isotherm Definition", "Subsection",
 CellChangeTimes->{{3.67746618373181*^9, 
  3.6774661870844564`*^9}},ExpressionUUID->"9311c4a2-af03-44b9-993e-\
e6e5cacb3469"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"isotherm", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "A"], "\[Rule]", " ", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["c", "A"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}], " ", ",", 
    RowBox[{
     SubscriptBox["q", "B"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["c", "B"]}], 
      RowBox[{"1", "+", " ", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6774661967728624`*^9, 3.6774662432648315`*^9}, {
  3.706970980944528*^9, 3.7069709973843966`*^9}, {3.7069710689723396`*^9, 
  3.70697113652822*^9}, {3.706971278610673*^9, 
  3.7069712998410425`*^9}},ExpressionUUID->"ccdd7964-9bd6-45f6-9b11-\
135d47b574b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "A"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["c", "A"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}], ",", 
   RowBox[{
    SubscriptBox["q", "B"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["c", "B"]}], 
     RowBox[{"1", "+", 
      RowBox[{
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982213214*^9, 3.713341289455179*^9, 
  3.7133463666789737`*^9, 3.7133468358342333`*^9, 3.7133470090647235`*^9, 
  3.713347131931735*^9, 3.7133474326873827`*^9, 3.7133475615990705`*^9, 
  3.713348621666252*^9, 3.7133499118989563`*^9, 3.71335036362273*^9, 
  3.7133529540258102`*^9, 3.7133530689820805`*^9, 3.71335314226466*^9, 
  3.7133532868178897`*^9, 3.7133548772316866`*^9, 3.7133612282502403`*^9, 
  3.7133615242155914`*^9, 3.713365358957106*^9, 3.7133691875007467`*^9, 
  3.7134243688501697`*^9, 3.7134261338284254`*^9, 3.7134563676280594`*^9, 
  3.713464436426861*^9, 3.7134840900989485`*^9, 3.713512129337883*^9, 
  3.7135177275521946`*^9, 3.713523032012829*^9, 3.7135233958164434`*^9, 
  3.7135284124835095`*^9, 3.713530058167734*^9, 
  3.713530749345479*^9},ExpressionUUID->"ee17a179-c857-4a20-8fa1-\
404b3346c7fe"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase Ratio Definition", "Subsection",
 CellChangeTimes->{{3.7069761277850475`*^9, 3.7069761303831615`*^9}, {
  3.7134645729564495`*^9, 
  3.7134645901779776`*^9}},ExpressionUUID->"7c0bb7a8-6a00-47bc-95bc-\
07d51c967bc7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Phi]", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SubscriptBox["\[Epsilon]", "b"]}], ")"}], "/", 
   SubscriptBox["\[Epsilon]", "b"]}]}]], "Input",
 CellChangeTimes->{
  3.706976122161029*^9, {3.713338932913249*^9, 
   3.7133389606679296`*^9}},ExpressionUUID->"79175476-39ed-46d3-8fdf-\
476691d4723b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1", "-", 
   SubscriptBox["\[Epsilon]", "b"]}], 
  SubscriptBox["\[Epsilon]", "b"]]], "Output",
 CellChangeTimes->{3.713338982230715*^9, 3.7133412894761825`*^9, 
  3.7133463666969733`*^9, 3.7133468358652334`*^9, 3.713347009079723*^9, 
  3.713347131950734*^9, 3.713347432700382*^9, 3.71334756161407*^9, 
  3.7133486216833496`*^9, 3.713349911918955*^9, 3.713350363639735*^9, 
  3.7133529540498104`*^9, 3.7133530690030785`*^9, 3.713353142286668*^9, 
  3.7133532868653965`*^9, 3.7133548772696953`*^9, 3.713361228265865*^9, 
  3.713361524222254*^9, 3.7133653589727306`*^9, 3.713369187516389*^9, 
  3.7134243688501697`*^9, 3.7134261338284254`*^9, 3.713456367638542*^9, 
  3.713464436436858*^9, 3.7134840901589556`*^9, 3.713512129344884*^9, 
  3.7135177275611954`*^9, 3.7135230320284557`*^9, 3.713523395824443*^9, 
  3.7135284124994226`*^9, 3.71353005817975*^9, 
  3.7135307493579617`*^9},ExpressionUUID->"fc80d709-fb83-4f8f-b14d-\
6daa64bee7c3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Interstitial Velocity Definition", "Subsection",
 CellChangeTimes->{{3.713464594821023*^9, 
  3.7134646005630226`*^9}},ExpressionUUID->"fdf84075-ee7c-4281-b4c4-\
dd3056608ccb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"interstitialVelocity", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "==", 
    FractionBox[
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["f", "\"\<I\>\""], ",", 
       SubscriptBox["f", "\"\<II\>\""], ",", 
       SubscriptBox["f", "\"\<III\>\""], ",", 
       SubscriptBox["f", "\"\<IV\>\""]}], "}"}], 
     RowBox[{
      SubscriptBox["\[Epsilon]", "b"], 
      SubscriptBox["A", "c"]}]]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069770846770887`*^9, 3.7069771929902897`*^9}, {
  3.7133375715885506`*^9, 3.7133376107891293`*^9}, {3.7134646230118504`*^9, 
  3.713464679504154*^9}},ExpressionUUID->"2496b2eb-cb92-43d7-92fb-\
f7fea3875b76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Equal]", 
    FractionBox[
     SubscriptBox["f", "\<\"I\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Equal]", 
    FractionBox[
     SubscriptBox["f", "\<\"II\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Equal]", 
    FractionBox[
     SubscriptBox["f", "\<\"III\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Equal]", 
    FractionBox[
     SubscriptBox["f", "\<\"IV\"\>"], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      SubscriptBox["\[Epsilon]", "b"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713464657444455*^9, 3.7134647287200375`*^9, 
  3.71348409019346*^9, 3.7135121293518834`*^9, 3.713517727572194*^9, 
  3.7135230320284557`*^9, 3.713523395832945*^9, 3.7135284124994226`*^9, 
  3.713530058194751*^9, 
  3.7135307493709803`*^9},ExpressionUUID->"a1abd4f8-42d7-41c0-bb5a-\
5e1e75964218"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Retention Factor Definitions", "Subsection",
 CellChangeTimes->{{3.706973516677366*^9, 
  3.7069735217634172`*^9}},ExpressionUUID->"6ebc7b3f-4527-447b-aefc-\
5fb069e8da14"],

Cell[CellGroupData[{

Cell["Ideal", "Subsubsection",
 CellChangeTimes->{{3.700927282836939*^9, 
  3.700927283372059*^9}},ExpressionUUID->"88fbb788-9616-4ea3-9363-\
155602c97d75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealRetention", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["a", "B"]}]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "B"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}]]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.700927250790391*^9, 3.7009272773669167`*^9}, {
   3.7009284912956934`*^9, 3.7009285028657093`*^9}, {3.7009504456319914`*^9, 
   3.7009504521905937`*^9}, {3.706973698819386*^9, 3.7069737083463225`*^9}, {
   3.706974221388472*^9, 3.7069742864664307`*^9}, 3.7069746419989896`*^9, {
   3.706979029946501*^9, 3.706979055616598*^9}, {3.713337533221609*^9, 
   3.7133375442303457`*^9}, {3.7133377288589096`*^9, 3.713337737224095*^9}, {
   3.7133468133210235`*^9, 
   3.713346821616871*^9}},ExpressionUUID->"41f7307d-2bc3-47ca-a69c-\
27d608836603"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389822512136`*^9, 3.713341289511447*^9, 
  3.713346366746977*^9, 3.7133468358977394`*^9, 3.713347009116723*^9, 
  3.7133471319917383`*^9, 3.7133474327298923`*^9, 3.71334756165107*^9, 
  3.7133486217113495`*^9, 3.71334991196346*^9, 3.7133503636773915`*^9, 
  3.7133529540909233`*^9, 3.7133530690445824`*^9, 3.7133531423326683`*^9, 
  3.7133532869143953`*^9, 3.7133548773006964`*^9, 3.7133612282814903`*^9, 
  3.713361524222254*^9, 3.7133653589948616`*^9, 3.7133691875320144`*^9, 
  3.713424368865795*^9, 3.7134261338440514`*^9, 3.713456367650057*^9, 
  3.713464436466864*^9, 3.7134840902389655`*^9, 3.713512129364388*^9, 
  3.713517727585194*^9, 3.7135230320505843`*^9, 3.7135233958444448`*^9, 
  3.7135284125150642`*^9, 3.713530058210235*^9, 
  3.7135307493849897`*^9},ExpressionUUID->"755f569b-0dd0-4e20-a426-\
dd6d6068e43c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Non-Ideal", "Subsubsection",
 CellChangeTimes->{{3.7009272879844604`*^9, 
  3.700927290804271*^9}},ExpressionUUID->"6d3f297d-4d10-4114-bdf0-\
bc82d5f7699c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonidealRetention", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       SubscriptBox["a", "B"]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "B"], 
          SubsuperscriptBox["c", "2", "\"\<p\>\""]}]}]]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "A"], 
            SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "+", 
           RowBox[{
            SubscriptBox["b", "B"], 
            SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}], ")"}]}], ")"}]}], 
      "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}], 
       FractionBox[
        SubscriptBox["a", "A"], 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], 
          SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}], "+", 
      FractionBox["DV", 
       RowBox[{"\[Phi]", " ", 
        SubscriptBox["L", "c"], " ", 
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"]}]]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.700927305349064*^9, 3.7009273314721465`*^9}, {
  3.700928504670043*^9, 3.700928515225958*^9}, {3.7009504564876337`*^9, 
  3.700950461206908*^9}, {3.7069737114683585`*^9, 3.706973718580208*^9}, {
  3.706974303686753*^9, 3.7069743528909817`*^9}, {3.706975331666441*^9, 
  3.7069753749932384`*^9}, {3.706983809528408*^9, 3.7069838327496595`*^9}, {
  3.7133375332446113`*^9, 3.7133375442323446`*^9}, {3.71333772888491*^9, 
  3.713337737161096*^9}, {3.7133389329462495`*^9, 3.7133389606724305`*^9}, {
  3.713346803429296*^9, 3.713346809543415*^9}, {3.713464148691203*^9, 
  3.713464162619529*^9}},ExpressionUUID->"39ae7b36-ee99-4442-a493-\
1f049848ef44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389822752156`*^9, 3.7133412895294476`*^9, 
  3.71334636676598*^9, 3.713346835937611*^9, 3.713347009137748*^9, 
  3.7133471320108147`*^9, 3.7133474327478957`*^9, 3.7133475616710763`*^9, 
  3.7133486217303505`*^9, 3.713349911980771*^9, 3.7133503637003913`*^9, 
  3.7133529541174307`*^9, 3.7133530690700855`*^9, 3.713353142364668*^9, 
  3.7133532869644012`*^9, 3.7133548773366985`*^9, 3.713361228297117*^9, 
  3.7133615242382336`*^9, 3.713365359010494*^9, 3.7133691875496473`*^9, 
  3.71342436888142*^9, 3.7134261338440514`*^9, 3.713456367663542*^9, 
  3.713464436486869*^9, 3.7134840902589684`*^9, 3.713512129375891*^9, 
  3.713517727598194*^9, 3.7135230320505843`*^9, 3.713523395856944*^9, 
  3.7135284125306883`*^9, 3.713530058227235*^9, 
  3.713530749399477*^9},ExpressionUUID->"31a9b6a2-a270-419d-9843-\
16c11e655b95"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Decay Factor Definitions", "Subsection",
 CellChangeTimes->{{3.700927400092606*^9, 3.7009274042601995`*^9}, {
  3.7134642255993366`*^9, 
  3.7134642271096077`*^9}},ExpressionUUID->"bf6e2d63-c652-474e-9782-\
f0669108fecb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"decayFactors", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<E\>\""], 
       SubsuperscriptBox["c", "B", "\"\<I\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", 
        RowBox[{"s", "*"}]], 
       SubsuperscriptBox["c", "A", "\"\<I\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "B", "\"\<II\>\""], 
       SubsuperscriptBox["c", "B", "\"\<R\>\""]], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{"Log", "[", 
      FractionBox[
       SubsuperscriptBox["c", "A", "\"\<R\>\""], 
       SubsuperscriptBox["c", "A", "\"\<IV\>\""]], "]"}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7009274260277*^9, 3.7009274351122284`*^9}, {
  3.7009284705368476`*^9, 3.700928483438323*^9}, {3.700950468393784*^9, 
  3.7009504730975943`*^9}, {3.706973830986437*^9, 3.7069738543944693`*^9}, {
  3.706974589352887*^9, 3.706974605080983*^9}, {3.7133363550795794`*^9, 
  3.7133364412292347`*^9}, {3.7134840814429717`*^9, 
  3.713484082073532*^9}},ExpressionUUID->"b86cef38-423f-4521-9f25-\
eb02c793ad63"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"E\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"I\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", 
       RowBox[{"s", "*"}]], 
      SubsuperscriptBox["c", "A", "\<\"I\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "B", "\<\"II\"\>"], 
      SubsuperscriptBox["c", "B", "\<\"R\"\>"]], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     FractionBox[
      SubsuperscriptBox["c", "A", "\<\"R\"\>"], 
      SubsuperscriptBox["c", "A", "\<\"IV\"\>"]], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982305214*^9, 3.7133412895467443`*^9, 
  3.713346366784979*^9, 3.7133468359826126`*^9, 3.713347009154746*^9, 
  3.7133471320278144`*^9, 3.713347432764896*^9, 3.713347561697813*^9, 
  3.713348621748351*^9, 3.7133499119995675`*^9, 3.713350363722391*^9, 
  3.713352954141013*^9, 3.7133530690930867`*^9, 3.7133531423879347`*^9, 
  3.7133532870164022`*^9, 3.713354877366704*^9, 3.713361228312741*^9, 
  3.7133615242538404`*^9, 3.713365359010494*^9, 3.713369187553645*^9, 
  3.71342436888142*^9, 3.7134261338596754`*^9, 3.71345636767704*^9, 
  3.713464436506871*^9, 3.7134840902689676`*^9, 3.7135121293828926`*^9, 
  3.7135177276111946`*^9, 3.7135230320662155`*^9, 3.7135233958704443`*^9, 
  3.7135284125463123`*^9, 3.7135300582447295`*^9, 
  3.71353074941196*^9},ExpressionUUID->"180acdfc-2dfe-48cf-8b40-23bc50e8260f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Characteristic Polynomials", "Subsection",
 CellChangeTimes->{{3.706971225391755*^9, 
  3.706971254700155*^9}},ExpressionUUID->"51b0cee2-24ea-416a-bf1d-\
a264d38fe076"],

Cell[CellGroupData[{

Cell["Primary Definition", "Subsubsection",
 CellChangeTimes->{{3.7069746936318626`*^9, 3.7069746957059355`*^9}, {
  3.7134642440418725`*^9, 
  3.7134642455332575`*^9}},ExpressionUUID->"f9186d00-3e84-4971-a41d-\
a39de914c47d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"characteristicPolynomial", "=", 
  RowBox[{
   RowBox[{"Inactivate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Gamma]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SubscriptBox["c", "A"]], 
        SubscriptBox["q", "B"]}]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "B"]], 
          SubscriptBox["q", "B"]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           SubscriptBox["c", "A"]], 
          SubscriptBox["q", "A"]}]}], ")"}], "\[Gamma]"}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        SubscriptBox["c", "B"]], 
       SubscriptBox["q", "A"]}]}], "\[Equal]", "0"}], "]"}], "/.", 
   "isotherm"}]}]], "Input",ExpressionUUID->"13c03c34-db2e-4b15-99d7-\
c981246d2400"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", 
     TagBox["^",
      "InactiveToken",
      BaseStyle->"Inactive",
      SyntaxForm->"^"], "2"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["c", "B"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
     "InactiveD"]}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TemplateBox[{"Inactive",FractionBox[
         RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["c", "B"]}], 
         RowBox[{"1", "+", 
           RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["c", "A"]}], "+", 
           RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
       "InactiveD"], 
      TagBox["+",
       "InactiveToken",
       BaseStyle->"Inactive",
       SyntaxForm->"+"], 
      RowBox[{
       RowBox[{"-", "1"}], 
       TagBox["*",
        "InactiveToken",
        BaseStyle->"Inactive",
        SyntaxForm->"*"], 
       TemplateBox[{"Inactive",FractionBox[
          RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["c", "A"]}], 
          RowBox[{"1", "+", 
            RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}], "+", 
            RowBox[{
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "A"]},
        "InactiveD"]}]}], ")"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], "\[Gamma]"}], 
   TagBox["+",
    "InactiveToken",
    BaseStyle->"Inactive",
    SyntaxForm->"+"], 
   RowBox[{
    RowBox[{"-", "1"}], 
    TagBox["*",
     "InactiveToken",
     BaseStyle->"Inactive",
     SyntaxForm->"*"], 
    TemplateBox[{"Inactive",FractionBox[
       RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["c", "A"]}], 
       RowBox[{"1", "+", 
         RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["c", "A"]}], "+", 
         RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}]],SubscriptBox["c", "B"]},
     "InactiveD"]}]}], 
  TagBox["\[Equal]",
   "InactiveToken",
   BaseStyle->"Inactive",
   SyntaxForm->"\[Equal]"], "0"}]], "Output",
 CellChangeTimes->{3.7135350339818296`*^9, 
  3.713535270391146*^9},ExpressionUUID->"8e1b2549-8336-4cec-8017-\
d1ffa67a46fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Polynomial", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Activate", "@", "characteristicPolynomial"}], ",", 
    RowBox[{"{", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["c", "A"]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "B"]}]}], ">", "0"}], "}"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971351866922*^9, 
  3.706971379406417*^9}},ExpressionUUID->"15b92b42-536a-42a4-b2a1-\
40be6dea754c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["a", "B"], " ", "\[Gamma]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      SubscriptBox["b", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["c", "A"], "-", 
        RowBox[{
         SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}], ")"}]}], 
  "\[Equal]", 
  RowBox[{
   SubscriptBox["a", "A"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["b", "B"]}], " ", 
      SubscriptBox["c", "A"]}], "+", "\[Gamma]", "+", 
     RowBox[{
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"], " ", "\[Gamma]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.7133389824517136`*^9, 3.7133412897588205`*^9, 
  3.7133463669289885`*^9, 3.7133468361733913`*^9, 3.713347009313261*^9, 
  3.7133471322079773`*^9, 3.713347432897738*^9, 3.7133475618713274`*^9, 
  3.7133486218688602`*^9, 3.7133499121415787`*^9, 3.7133503638818655`*^9, 
  3.7133529543015213`*^9, 3.7133530692530236`*^9, 3.7133531424744415`*^9, 
  3.7133532871144066`*^9, 3.713354877505716*^9, 3.713361228497429*^9, 
  3.713361524285092*^9, 3.7133653590729933`*^9, 3.7133691876698217`*^9, 
  3.7134243691001697`*^9, 3.7134261339221783`*^9, 3.7134563677375526`*^9, 
  3.713464436706906*^9, 3.7134840903085594`*^9, 3.7135121295859027`*^9, 
  3.7135177277692256`*^9, 3.7135230322486086`*^9, 3.7135233960249557`*^9, 
  3.713528412681818*^9, 3.7135300584397244`*^9, 
  3.7135307495519753`*^9},ExpressionUUID->"0918e5ca-5439-4056-b3d7-\
f3ac431d5e28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]PolynomialSolutions", "=", 
  RowBox[{"Simplify", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{"\[Gamma]Polynomial", ",", "\[Gamma]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.70697165303078*^9, 3.706971674686119*^9}, {
  3.7069717400542965`*^9, 
  3.706971770398497*^9}},ExpressionUUID->"2fb05ade-ed7a-40f6-a5db-\
25621532eb2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"], "-", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["c", "A"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "A"], " ", 
           SubscriptBox["c", "B"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "B"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Gamma]", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "A"]}], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982555713*^9, 3.7133412898594294`*^9, 
  3.7133463670275445`*^9, 3.713346836303405*^9, 3.713347009414271*^9, 
  3.713347132309057*^9, 3.7133474330117483`*^9, 3.713347561988343*^9, 
  3.713348621970867*^9, 3.713349912244588*^9, 3.713350363994872*^9, 
  3.7133529544030323`*^9, 3.7133530693540306`*^9, 3.713353142577453*^9, 
  3.7133532872201405`*^9, 3.7133548776217265`*^9, 3.713361228597685*^9, 
  3.7133615243942337`*^9, 3.7133653591923895`*^9, 3.713369187785757*^9, 
  3.7134243692235155`*^9, 3.713426134031551*^9, 3.7134563678475504`*^9, 
  3.7134644368167915`*^9, 3.7134840903185616`*^9, 3.713512129688907*^9, 
  3.7135177278702326`*^9, 3.7135230323509784`*^9, 3.7135233961314545`*^9, 
  3.7135284127837887`*^9, 3.7135300585582237`*^9, 
  3.7135307496734548`*^9},ExpressionUUID->"d1f72c43-d04e-4689-92c9-\
deb623154756"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]Values", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Gamma]", "-"], ",", 
      SubscriptBox["\[Gamma]", "+"]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"\[Gamma]", "/.", "\[Gamma]PolynomialSolutions"}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706971774342685*^9, 3.706971789238475*^9}, {
  3.713349889939475*^9, 3.7133498967686787`*^9}, {3.713353057359313*^9, 
  3.713353059118727*^9}, {3.7133531250268097`*^9, 
  3.713353131503124*^9}},ExpressionUUID->"7e45159a-1bf2-4dd3-b327-\
98fd836cd0df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["c", "A"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubscriptBox["c", "A"], " ", 
          SubscriptBox["c", "B"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "B"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338982588214*^9, 3.713341289902938*^9, 
  3.713346367057749*^9, 3.7133468363236265`*^9, 3.7133470094399123`*^9, 
  3.713347132346058*^9, 3.7133474330622835`*^9, 3.7133475620699234`*^9, 
  3.713348622012868*^9, 3.71334991231195*^9, 3.713350364056998*^9, 
  3.713352954467535*^9, 3.7133530694325867`*^9, 3.713353142598951*^9, 
  3.713353287271159*^9, 3.71335487765874*^9, 3.7133612286354523`*^9, 
  3.713361524414875*^9, 3.713365359204217*^9, 3.7133691878169928`*^9, 
  3.7134243692450747`*^9, 3.713426134031551*^9, 3.713456367858038*^9, 
  3.7134644369164248`*^9, 3.7134840903285594`*^9, 3.7135121297199073`*^9, 
  3.713517727959243*^9, 3.713523032397853*^9, 3.7135233962889366`*^9, 
  3.7135284128465486`*^9, 3.7135300586607213`*^9, 
  3.713530749783971*^9},ExpressionUUID->"b4ed1a92-4347-4f44-a656-\
1afc9341cd75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["A", "-"], ",", 
    SubscriptBox["A", "+"]}], "}"}], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"]}], 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], 
       RowBox[{
        SubscriptBox["b", "B"], "/", "\[Gamma]"}]}]}]], "/.", 
    "\[Gamma]PolynomialSolutions"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.713349873519145*^9, 3.7133498770766993`*^9}, {
  3.713353052157383*^9, 3.7133530548367743`*^9}, {3.7133531347309446`*^9, 
  3.713353136594575*^9}},ExpressionUUID->"09c3c0af-9d6e-4bc8-a253-\
88526c0a1648"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "+", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]], ",", 
   FractionBox[
    RowBox[{
     SubscriptBox["a", "A"], "-", 
     SubscriptBox["a", "B"], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["c", "A"]}], "+", 
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubscriptBox["c", "B"]}], "-", 
     SqrtBox[
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubscriptBox["c", "A"], " ", 
        SubscriptBox["c", "B"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
    RowBox[{"2", " ", 
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983529714*^9, 3.7133412908380857`*^9, 
  3.7133463679593053`*^9, 3.7133468372257614`*^9, 3.713347010391641*^9, 
  3.713347133273785*^9, 3.7133474340628366`*^9, 3.7133475631233788`*^9, 
  3.713348622962989*^9, 3.7133498825963187`*^9, 3.7133499132715073`*^9, 
  3.713350365023613*^9, 3.713352955399082*^9, 3.71335307039218*^9, 
  3.7133531435032554`*^9, 3.7133532882097425`*^9, 3.7133548786288013`*^9, 
  3.7133612296575565`*^9, 3.713361525386848*^9, 3.7133653601611195`*^9, 
  3.7133691888363905`*^9, 3.71342437024856*^9, 3.713426134921768*^9, 
  3.7134563688222084`*^9, 3.713464437864501*^9, 3.71348409033856*^9, 
  3.713512130702756*^9, 3.713517728953312*^9, 3.7135230334464884`*^9, 
  3.7135233972999325`*^9, 3.71352841384127*^9, 3.7135300597232037`*^9, 
  3.713530750799579*^9},ExpressionUUID->"3c2457b8-222f-4aa7-a21a-\
5cc5f8a33449"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Secondary \[Gamma] definition", "Subsubsection",
 CellChangeTimes->{{3.7069747010202184`*^9, 
  3.706974717036033*^9}},ExpressionUUID->"61eeb5f9-6911-4dd5-ad1b-\
d56b502d598b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondary\[Gamma]Values", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       SubscriptBox["a", "A"], "-", 
       RowBox[{
        SubscriptBox["a", "A"], 
        SubscriptBox["b", "B"], 
        SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], 
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubsuperscriptBox["c", "B", "\"\<p\>\""]}]]}], ",", 
    RowBox[{
     SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       SubsuperscriptBox["c", "A", "\"\<p\>\""]}], 
      RowBox[{
       SubscriptBox["a", "A"], "-", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], 
        SubscriptBox["b", "A"], 
        SubsuperscriptBox["c", "A", "\"\<p\>\""]}]}]]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.706974728692503*^9, 3.706974759830389*^9}, {
  3.706974792782261*^9, 3.706974862933106*^9}, {3.7069812267974615`*^9, 
  3.7069812279590883`*^9}, {3.7133377288209095`*^9, 3.7133377371900945`*^9}, {
  3.713346779309186*^9, 
  3.7133467896627607`*^9}},ExpressionUUID->"13250e18-e1ba-4eb2-b53b-\
2dbe4b58f52e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]}], 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubsuperscriptBox["c", "B", "\<\"p\"\>"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"], " ", 
      SubsuperscriptBox["c", "A", "\<\"p\"\>"]}], 
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "-", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983591213*^9, 3.7133412908865705`*^9, 
  3.7133463679993057`*^9, 3.7133468372967997`*^9, 3.7133470104321437`*^9, 
  3.713347133318866*^9, 3.7133474341318417`*^9, 3.713347563216889*^9, 
  3.7133486230145664`*^9, 3.713349913336506*^9, 3.7133503650976653`*^9, 
  3.7133529554455895`*^9, 3.7133530704981885`*^9, 3.713353143541258*^9, 
  3.7133532882417445`*^9, 3.7133548786898108`*^9, 3.7133612297165565`*^9, 
  3.7133615254866233`*^9, 3.71336536020774*^9, 3.7133691889053907`*^9, 
  3.71342437029856*^9, 3.713426134984269*^9, 3.713456368881709*^9, 
  3.713464437927006*^9, 3.7134840903485603`*^9, 3.71351213075826*^9, 
  3.7135177290443153`*^9, 3.7135230335003695`*^9, 3.713523397381418*^9, 
  3.713528413885561*^9, 3.713530059788703*^9, 
  3.7135307508490753`*^9},ExpressionUUID->"751a4151-9f6e-4925-8e75-\
149f462a817e"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: Outline the Problem", "Section",
 CellChangeTimes->{{3.7069647139816885`*^9, 3.7069647369114227`*^9}, 
   3.7069738098215046`*^9},ExpressionUUID->"695d6c6f-f6c9-46ed-815d-\
e8871cf86a4a"],

Cell[CellGroupData[{

Cell["Flow Rate Estimates", "Subsection",
 CellChangeTimes->{{3.7069719669644384`*^9, 
  3.70697197321463*^9}},ExpressionUUID->"5172c932-e47a-4486-a0ff-\
dfcadcc49da0"],

Cell[CellGroupData[{

Cell["Zone Velocities", "Subsubsection",
 CellChangeTimes->{{3.7069770657438345`*^9, 
  3.7069770704278774`*^9}},ExpressionUUID->"ce176f91-73e2-4eb9-8ef4-\
05267dc137dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealZoneVelocityEstimates", "=", 
  RowBox[{"Thread", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[Phi]", "*", "#"}]}], ")"}]}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], ",", 
        SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], "}"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7069792305863423`*^9, 3.7069794058816357`*^9}, {
  3.71333893281275*^9, 3.713338960678429*^9}, {3.713464276128871*^9, 
  3.713464298999878*^9}, {3.713523218427025*^9, 
  3.713523221538406*^9}},ExpressionUUID->"29347fbb-6e56-44c5-be8e-\
d6eacb287965"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
        SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836062136`*^9, 3.713341290901271*^9, 
  3.7133463680133047`*^9, 3.713346837326803*^9, 3.7133470104455504`*^9, 
  3.7133471333368664`*^9, 3.713347434149845*^9, 3.713347563241888*^9, 
  3.713348623027567*^9, 3.7133499133615103`*^9, 3.7133503651146555`*^9, 
  3.71335295546359*^9, 3.713353070547192*^9, 3.7133531435592575`*^9, 
  3.713353288266747*^9, 3.713354878704811*^9, 3.7133612297165565`*^9, 
  3.7133615255183153`*^9, 3.713365360223386*^9, 3.7133691889198914`*^9, 
  3.7134243703105583`*^9, 3.713426134984269*^9, 3.713456368892206*^9, 
  3.713464299832625*^9, 3.713464437947006*^9, 3.7134840903685617`*^9, 
  3.7135121307657585`*^9, 3.713517729052318*^9, 3.7135230335003695`*^9, 
  3.7135233973899145`*^9, 3.713528413901184*^9, 3.7135300598037*^9, 
  3.7135307508605556`*^9},ExpressionUUID->"7dd1f616-5ebf-47d1-be23-\
3a09b250accb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonIdealZoneVelocityEstimates", "=", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<I\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<I\>\""], 
        SubsuperscriptBox["L", "z", "\"\<I\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<I\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<I\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<II\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}]}], ")"}], "v"}], 
      "+", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], 
        SubsuperscriptBox["L", "z", "\"\<II\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<II\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<II\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<III\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}]}], ")"}], "v"}],
       "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], 
        SubsuperscriptBox["L", "z", "\"\<III\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "B", "\"\<III\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "B", "\"\<III\>\""]]}], ")"}]}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<IV\>\""], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", "*", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}]}], ")"}], "v"}], 
      "-", 
      RowBox[{
       FractionBox[
        SubsuperscriptBox["\[Beta]", "A", "\"\<IV\>\""], 
        SubsuperscriptBox["L", "z", "\"\<IV\>\""]], 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["E", "A", "\"\<IV\>\""], "+", 
         FractionBox[
          RowBox[{"\[Phi]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"v", " ", 
              SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""]}], ")"}], 
            "2"]}], 
          SubsuperscriptBox["Kf", "A", "\"\<IV\>\""]]}], ")"}]}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7069719796706057`*^9, 3.706972129718485*^9}, {
   3.7069755736149435`*^9, 3.7069756677550144`*^9}, {3.7069757049829063`*^9, 
   3.706975719680606*^9}, {3.7069758023276405`*^9, 3.7069758603763356`*^9}, {
   3.7069770519615784`*^9, 3.7069770548532476`*^9}, {3.7069776256388144`*^9, 
   3.7069776324148607`*^9}, 3.7069794091133423`*^9, {3.7133389328242493`*^9, 
   3.71333896063593*^9}, {3.7134641850843487`*^9, 3.7134641898369284`*^9}, {
   3.7135150193606396`*^9, 
   3.713515039846447*^9}},ExpressionUUID->"6d54e71e-3ed1-489e-9f46-\
a835ef9b0a52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"I\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"I\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"II\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "B", "\<\"III\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"III\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"v", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["v", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], ")"}], "2"]}], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], " ", 
           SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"]}]]}], ")"}]}], 
      SubsuperscriptBox["L", "z", "\<\"IV\"\>"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836237135`*^9, 3.7133412909222713`*^9, 
  3.713346368028304*^9, 3.7133468373598824`*^9, 3.71334701046255*^9, 
  3.713347133356865*^9, 3.713347434170845*^9, 3.713347563265889*^9, 
  3.7133486230415664`*^9, 3.7133499133835135`*^9, 3.713350365134656*^9, 
  3.713352955482589*^9, 3.7133530705941944`*^9, 3.713353143579759*^9, 
  3.7133532882947474`*^9, 3.713354878723811*^9, 3.713361229747815*^9, 
  3.713361525549582*^9, 3.713365360239012*^9, 3.7133691889383917`*^9, 
  3.713424370326559*^9, 3.7134261350467677`*^9, 3.7134563689071884`*^9, 
  3.7134644379570074`*^9, 3.713484090389064*^9, 3.7135121308012624`*^9, 
  3.713515041015314*^9, 3.713517729134323*^9, 3.7135230335537453`*^9, 
  3.713523397459931*^9, 3.713528413916811*^9, 3.7135300598196993`*^9, 
  3.7135307508750715`*^9},ExpressionUUID->"93cb44c0-62fa-44c6-a3d8-\
f9bce58d1d92"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Zone Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.7069770783616886`*^9, 
  3.706977081577528*^9}},ExpressionUUID->"d35a9e0f-7c73-408a-bd34-\
07090091fc05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoneFlowEstimates", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solve", "[", "interstitialVelocity", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7069770846770887`*^9, 3.7069771929902897`*^9}, {
  3.7133375715885506`*^9, 3.7133376107891293`*^9}, {3.7134647090697107`*^9, 
  3.7134647269088154`*^9}},ExpressionUUID->"92dd5b59-e768-4aab-8bac-\
dfdf8e887954"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"II\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"III\"\>"]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389836402135`*^9, 3.713341290942277*^9, 
  3.7133463680443087`*^9, 3.713346837395882*^9, 3.71334701047955*^9, 
  3.7133471333738656`*^9, 3.713347434188848*^9, 3.713347563286434*^9, 
  3.7133486230570717`*^9, 3.713349913405513*^9, 3.7133503651560116`*^9, 
  3.71335295550159*^9, 3.713353070645199*^9, 3.7133531435992637`*^9, 
  3.7133532883227468`*^9, 3.7133548787398167`*^9, 3.713361229763438*^9, 
  3.7133615256026726`*^9, 3.713365360239012*^9, 3.71336918895691*^9, 
  3.7134243703445597`*^9, 3.713426135062393*^9, 3.7134563689216905`*^9, 
  3.7134644379866085`*^9, 3.7134647347843623`*^9, 3.7134840904190683`*^9, 
  3.7135121308617682`*^9, 3.7135177292113266`*^9, 3.713523033600624*^9, 
  3.7135233975329294`*^9, 3.713528413951583*^9, 3.713530059853199*^9, 
  3.7135307509005556`*^9},ExpressionUUID->"4ff99d19-f38b-4549-8d52-\
a5fe9d4ae932"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Port Flow Rates", "Subsubsection",
 CellChangeTimes->{{3.706977332184824*^9, 
  3.7069773361137943`*^9}},ExpressionUUID->"255b9df0-941d-4ff4-bbb7-\
eaabdaf88d7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"portFlowEstimates", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "\"\<R\>\""], "\[Rule]", 
       RowBox[{
        SubscriptBox["f", "\"\<III\>\""], "-", 
        SubscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<D\>\""], "\[Rule]", 
       RowBox[{
        SubscriptBox["f", "\"\<I\>\""], "-", 
        SubscriptBox["f", "\"\<IV\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<E\>\""], "\[Rule]", " ", 
       RowBox[{
        SubscriptBox["f", "\"\<I\>\""], "-", 
        SubscriptBox["f", "\"\<II\>\""]}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["f", "\"\<Recycle\>\""], "\[Rule]", 
       SubscriptBox["f", "\"\<IV\>\""]}]}], "\[IndentingNewLine]", "}"}], "/.",
     "zoneFlowEstimates"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069773390874557`*^9, 3.706977475818272*^9}, {
   3.7133375716075497`*^9, 3.7133376718854723`*^9}, {3.7133503118874207`*^9, 
   3.713350314812169*^9}, {3.7133532725214005`*^9, 3.713353277157241*^9}, {
   3.713437409029659*^9, 3.713437421289695*^9}, 
   3.7134374518333993`*^9},ExpressionUUID->"8a5b69ec-4f79-4b2a-a1da-\
54d803409d35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"D\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"Recycle\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7133389836552143`*^9, 3.713341290966863*^9, 3.7133463680580635`*^9, 
   3.7133468374263854`*^9, 3.7133470104935503`*^9, 3.713347133389372*^9, 
   3.7133474342068453`*^9, 3.7133475633084345`*^9, 3.7133486230695705`*^9, 
   3.7133499134265137`*^9, 3.7133503186302757`*^9, 3.713350365179014*^9, 
   3.713352955521597*^9, 3.713353070690838*^9, 3.7133531436192665`*^9, {
   3.7133532788367634`*^9, 3.7133532883594723`*^9}, 3.713354878756819*^9, 
   3.713361229763438*^9, 3.713361525643771*^9, 3.713365360262143*^9, 
   3.7133691889733906`*^9, 3.713424370358559*^9, 3.713426135062393*^9, 
   3.7134374550263414`*^9, 3.713456368933689*^9, 3.7134644379966087`*^9, 
   3.71348409043907*^9, 3.7135121309002714`*^9, 3.7135177292223244`*^9, 
   3.7135230336162496`*^9, 3.7135233975454283`*^9, 3.713528413954591*^9, 
   3.7135300598677187`*^9, 
   3.713530750915554*^9},ExpressionUUID->"089f158a-834c-44a7-af96-\
ea5688bc99bf"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Concentration Estimates", "Subsection",
 CellChangeTimes->{{3.706971482093981*^9, 
  3.7069714862699366`*^9}},ExpressionUUID->"88b83633-23e0-4b1b-ab42-\
149be343168a"],

Cell[CellGroupData[{

Cell["Peak Concentration Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732610853033`*^9, 3.7069732687194195`*^9}, {
  3.713464355467513*^9, 
  3.7134643582089806`*^9}},ExpressionUUID->"c022f656-06d6-4a6d-a98d-\
153699a82d0b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakEstimate", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
       SubscriptBox["A", "-"]}], ",", 
      RowBox[{
       SubsuperscriptBox["c", "B", "\"\<p\>\""], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["A", "+"]}], "/", 
        SubscriptBox["\[Gamma]", "+"]}]}]}], "}"}], "/.", "\[Gamma]Values"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.70697149536306*^9, 3.7069715103032227`*^9}, {
  3.706971806165899*^9, 3.7069718106218185`*^9}, {3.7069737726575537`*^9, 
  3.706973778562495*^9}, {3.7133377288449097`*^9, 3.7133377371980944`*^9}, {
  3.7133467663097467`*^9, 
  3.7133467685329013`*^9}},ExpressionUUID->"803b2072-64c3-4b9f-b1c8-\
84458cce2c4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["c", "A"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubscriptBox["c", "B"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubscriptBox["c", "A"], " ", 
         SubscriptBox["c", "B"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["c", "A"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubscriptBox["c", "B"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983767215*^9, 3.7133412911132517`*^9, 
  3.7133463681673126`*^9, 3.7133468375432997`*^9, 3.7133470105991797`*^9, 
  3.71334713350038*^9, 3.7133474343323584`*^9, 3.7133475634426208`*^9, 
  3.713348623175728*^9, 3.7133499135865283`*^9, 3.7133503653590574`*^9, 
  3.7133529556796036`*^9, 3.7133530707993493`*^9, 3.7133531437767825`*^9, 
  3.7133532885219774`*^9, 3.713354878935832*^9, 3.7133612299327574`*^9, 
  3.713361525803044*^9, 3.7133653604284115`*^9, 3.713369189144891*^9, 
  3.7134243705245595`*^9, 3.7134261352186437`*^9, 3.713456369101683*^9, 
  3.713464438156639*^9, 3.713484090449069*^9, 3.7135121310692844`*^9, 
  3.713517729382341*^9, 3.713523033769948*^9, 3.7135233977059093`*^9, 
  3.7135284141173897`*^9, 3.7135300600416937`*^9, 
  3.713530751082571*^9},ExpressionUUID->"f55d7c9e-ec4d-4fdb-abe5-\
96c9470852de"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakMassBalance", "=", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\"\<p\>\""], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<F\>\""], 
     SubscriptBox["f", "\"\<F\>\""], 
     SubscriptBox["y", "target"]}], 
    SubscriptBox["f", "\"\<R\>\""]]}]}]], "Input",
 CellChangeTimes->{{3.706980478613745*^9, 3.706980536647952*^9}, 
   3.713337473759631*^9, {3.713337625817992*^9, 3.713337638056546*^9}, 
   3.7133377372050953`*^9, {3.713338095272827*^9, 3.7133381193241405`*^9}, {
   3.713346760373721*^9, 
   3.713346764013403*^9}},ExpressionUUID->"2f6a71a0-4600-486d-962b-\
179ec90a8a86"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
    SubscriptBox["y", "target"], " ", 
    SubscriptBox["f", "\<\"F\"\>"]}], 
   SubscriptBox["f", "\<\"R\"\>"]]}]], "Output",
 CellChangeTimes->{3.7133389837827144`*^9, 3.713341291129759*^9, 
  3.7133463681833134`*^9, 3.7133468375783*^9, 3.713347010614182*^9, 
  3.7133471335173864`*^9, 3.713347434345862*^9, 3.713347563460621*^9, 
  3.713348623189728*^9, 3.713349913603529*^9, 3.7133503268429627`*^9, 
  3.713350365377056*^9, 3.7133529556986027`*^9, 3.7133530708433557`*^9, 
  3.7133531437942853`*^9, 3.7133532885486794`*^9, 3.713354878958838*^9, 
  3.7133612299327574`*^9, 3.713361525834278*^9, 3.7133653604440393`*^9, 
  3.713369189159889*^9, 3.713424370536559*^9, 3.713426135234269*^9, 
  3.713456369112187*^9, 3.7134644381711445`*^9, 3.7134840904590673`*^9, 
  3.713512131078806*^9, 3.713517729393342*^9, 3.713523033785554*^9, 
  3.713523397717909*^9, 3.713528414133013*^9, 3.7135300600546956`*^9, 
  3.7135307510940514`*^9},ExpressionUUID->"2b966a10-11c5-429c-a6ba-\
baf468b1e295"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dilution Concentration Estimates", "Subsubsection",
 CellChangeTimes->{{3.7134643667021017`*^9, 
  3.7134643724749856`*^9}},ExpressionUUID->"da0619e9-58eb-4360-a53f-\
61c24d0c7920"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"denominator", "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "A"], 
     SubscriptBox["a", "B"], 
     SubscriptBox["b", "A"], 
     SubscriptBox["b", "B"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Gamma]", "+"], "+", 
       SubscriptBox["\[Gamma]", "-"]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "A"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "B"], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "B"], "2"], 
     SuperscriptBox[
      SubscriptBox["b", "A"], "2"], 
     SubscriptBox["\[Gamma]", "+"], 
     SubscriptBox["\[Gamma]", "-"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"dilutionEstimate", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["c", "A", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], 
       SubscriptBox["b", "A"], 
       SubscriptBox["\[Gamma]", "+"], 
       SubscriptBox["\[Gamma]", "-"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}]}], "denominator"]}], ",", 
    RowBox[{
     SubsuperscriptBox["c", "B", "\"\<s\>\""], "\[Rule]", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], 
       SubscriptBox["b", "B"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], "-", 
         SubscriptBox["a", "A"]}], ")"}]}], "denominator"]}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.706973784342924*^9, 3.706973790586589*^9}, {
  3.71333753325161*^9, 3.7133375442343445`*^9}, {3.7133471532918425`*^9, 
  3.7133471585992737`*^9}},ExpressionUUID->"2cb14d8e-8767-4c4d-8108-\
d0bb24d1f014"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], "-", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"], " ", 
      SubscriptBox["\[Gamma]", "-"], " ", 
      SubscriptBox["\[Gamma]", "+"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["a", "A"]}], "+", 
        SubscriptBox["a", "B"]}], ")"}], " ", 
      SubscriptBox["b", "B"]}], 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["a", "A", "2"], " ", 
       SubsuperscriptBox["b", "B", "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["a", "B", "2"], " ", 
       SubsuperscriptBox["b", "A", "2"], " ", 
       SubscriptBox["\[Gamma]", "-"], " ", 
       SubscriptBox["\[Gamma]", "+"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Gamma]", "-"], "+", 
         SubscriptBox["\[Gamma]", "+"]}], ")"}]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338983796213*^9, 3.71334129114583*^9, 3.7133463681993136`*^9, 
   3.713346837604298*^9, 3.713347010630187*^9, {3.7133471335343847`*^9, 
   3.713347162734724*^9}, 3.7133474343608613`*^9, 3.713347563482626*^9, 
   3.713348623203147*^9, 3.713349913619529*^9, 3.7133503653940573`*^9, 
   3.7133529557181067`*^9, 3.7133530708849783`*^9, 3.7133531438122854`*^9, 
   3.7133532885756793`*^9, 3.713354878976839*^9, 3.713361229948386*^9, 
   3.713361525865541*^9, 3.7133653604646673`*^9, 3.7133691891768885`*^9, 
   3.7134243705465593`*^9, 3.713426135249895*^9, 3.7134563691241827`*^9, 
   3.7134644381766453`*^9, 3.7134840904690685`*^9, 3.7135121310878057`*^9, 
   3.7135177294043417`*^9, 3.713523033801179*^9, 3.713523397727919*^9, 
   3.713528414150648*^9, 3.713530060069694*^9, 
   3.7135307511075077`*^9},ExpressionUUID->"19229599-6192-451e-9870-\
39e6a3c4154e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massBalanceEstimate", "=", 
  RowBox[{"{", 
   RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7006907256001806`*^9, 3.700690730979576*^9}, {
   3.7006918848119802`*^9, 3.7006918993014727`*^9}, {3.700692033459654*^9, 
   3.700692084148734*^9}, {3.7006923383643527`*^9, 3.7006923478520517`*^9}, {
   3.70069307842813*^9, 3.7006930822753067`*^9}, {3.700693129332734*^9, 
   3.7006931980636635`*^9}, 3.70092776998028*^9, {3.700928547745931*^9, 
   3.700928555745161*^9}, 3.70697379573298*^9, {3.7069767726165147`*^9, 
   3.70697679668966*^9}, 3.7133374737816315`*^9, 3.713337638077546*^9, 
   3.713337737213095*^9, {3.713346757441712*^9, 3.7133467576987457`*^9}, {
   3.713349463384637*^9, 3.713349494322274*^9}, {3.71335014013033*^9, 
   3.713350147662957*^9}, {3.713350180925575*^9, 
   3.7133502508118877`*^9}},ExpressionUUID->"feb7c103-939e-40c0-8455-\
7d3474dfacb9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
     SubscriptBox["y", "target"], " ", 
     SubscriptBox["f", "\<\"F\"\>"]}], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.713338983813713*^9, 3.71334129116083*^9, 3.7133463682143135`*^9, 
   3.713346837630303*^9, 3.713347010644226*^9, 3.713347133551385*^9, 
   3.7133474343738623`*^9, 3.7133475634996524`*^9, 3.7133486232157273`*^9, 
   3.713349466311381*^9, 3.7133494986520433`*^9, 3.713349913636529*^9, {
   3.7133502099667983`*^9, 3.7133502584217834`*^9}, 3.7133503280318165`*^9, 
   3.7133503654100575`*^9, 3.7133529557365217`*^9, 3.713353070931978*^9, 
   3.7133531438292856`*^9, 3.71335328860168*^9, 3.7133548789938374`*^9, 
   3.713361229948386*^9, 3.713361525918488*^9, 3.7133653604661684`*^9, 
   3.713369189191889*^9, 3.7134243705565586`*^9, 3.713426135249895*^9, 
   3.713456369134182*^9, 3.713464438187146*^9, 3.713484090493573*^9, 
   3.713512131095806*^9, 3.7135177294133415`*^9, 3.713523033801179*^9, 
   3.7135233977379117`*^9, 3.7135284141566496`*^9, 3.713530060084193*^9, 
   3.7135307511199875`*^9},ExpressionUUID->"85a3e3a2-74f0-478c-97e0-\
0d55cd32a750"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Secondary Estimates", "Subsubsection",
 CellChangeTimes->{{3.7069732730436907`*^9, 
  3.706973285566949*^9}},ExpressionUUID->"541e351c-517d-4a0f-afe7-\
d02bb014a3c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondaryEstimates", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"First", "@", 
     RowBox[{"Solve", "[", 
      RowBox[{"#", ",", 
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", "1"}], "]"}], "]"}]}], "]"}]}], "&"}], "@", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<R\>\""], "==", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
        SubscriptBox["y", "target"]}], 
       SubscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<E\>\""], "==", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["y", "target"]}], ")"}]}], 
       SubscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", 
       RowBox[{"s", "*"}]], "==", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["f", "\"\<III\>\""], 
         SubsuperscriptBox["c", "A", "\"\<s\>\""]}], "-", 
        RowBox[{
         SubscriptBox["f", "\"\<F\>\""], " ", 
         SubsuperscriptBox["c", "A", "\"\<F\>\""]}]}], 
       SubscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<IV\>\""], "==", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["u", "0", "\"\<I\>\""], 
        SubsuperscriptBox["c", "A", "\"\<E\>\""]}], 
       SubsuperscriptBox["u", "0", "\"\<IV\>\""]]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<R\>\""], "==", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SubscriptBox["y", "target"]}], ")"}]}], 
       SubscriptBox["f", "\"\<R\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<E\>\""], "==", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "*", 
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "*", 
        SubscriptBox["y", "target"]}], 
       SubscriptBox["f", "\"\<E\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", 
       RowBox[{"s", "*"}]], "==", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubscriptBox["f", "\"\<III\>\""], 
         SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "-", 
        RowBox[{
         SubscriptBox["f", "\"\<F\>\""], "*", 
         SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], 
       SubscriptBox["f", "\"\<II\>\""]]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<I\>\""], "==", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
        SubsuperscriptBox["c", "B", "\"\<R\>\""]}], 
       SubsuperscriptBox["u", "0", "\"\<I\>\""]]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.706973366145651*^9, 3.706973371763674*^9}, {
  3.7069768222221403`*^9, 3.7069769272283363`*^9}, {3.706977720252282*^9, 
  3.70697798585865*^9}, {3.7069781378797045`*^9, 3.7069781484618835`*^9}, {
  3.7133374045636263`*^9, 3.713337483761606*^9}, {3.7133375332716093`*^9, 
  3.7133375870669155`*^9}, {3.7133376258399935`*^9, 3.713337655627265*^9}, {
  3.713338074163921*^9, 3.713338119340746*^9}, {3.7133467250756874`*^9, 
  3.713346748863327*^9}, {3.713347058448259*^9, 3.713347070565633*^9}, {
  3.713370699201305*^9, 3.7133706996166167`*^9}, {3.7133716539702883`*^9, 
  3.7133716644701633`*^9}, {3.7133716992269382`*^9, 3.713371701689584*^9}, {
  3.7134644168068514`*^9, 
  3.7134644172974186`*^9}},ExpressionUUID->"1d2e6ee2-6988-435b-9353-\
bcee3f9dbf7d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"R\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"R\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], 
      SubscriptBox["f", "\<\"E\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", 
     RowBox[{"s", "*"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
        SubscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
        SubscriptBox["f", "\<\"III\"\>"]}]}], 
      SubscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
      RowBox[{
       SubscriptBox["f", "\<\"E\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"]}], 
      SubscriptBox["f", "\<\"R\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"E\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
      SubscriptBox["y", "target"], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     SubscriptBox["f", "\<\"E\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", 
     RowBox[{"s", "*"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
        SubscriptBox["f", "\<\"F\"\>"]}], "-", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
        SubscriptBox["f", "\<\"III\"\>"]}]}], 
      SubscriptBox["f", "\<\"II\"\>"]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["y", "target"]}], ")"}], " ", 
       SubscriptBox["f", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
      RowBox[{
       SubscriptBox["f", "\<\"R\"\>"], " ", 
       SubsuperscriptBox["u", "0", "\<\"I\"\>"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713464438227147*^9, 3.713484090508735*^9, 
  3.7135121311268053`*^9, 3.7135177294853497`*^9, 3.713523033854558*^9, 
  3.713523397806424*^9, 3.713528414172297*^9, 3.713530060101194*^9, 
  3.713530751134507*^9},ExpressionUUID->"ca077ba5-ce4d-4248-b3cb-\
059d16de04c9"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Superficial Velocity Estimates", "Subsection",
 CellChangeTimes->{{3.706972981877504*^9, 
  3.706972989294876*^9}},ExpressionUUID->"e54f2530-510f-40e6-9225-\
a3e8f34525c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonidealVelocityEstimate", "=", 
  RowBox[{"v", "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"K", " ", 
      SubscriptBox["L", "z"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], "+", 
        SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "-", 
              SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], ")"}], 
            "2"], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
                SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], "+", 
               RowBox[{
                SuperscriptBox[
                 SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
                SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}]}], ")"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["f", "\"\<F\>\""], "*", 
                SubscriptBox["L", "z"]}], "+", 
               RowBox[{"E", "*", 
                SubscriptBox["A", "c"], "*", 
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], "+", 
                  SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}], ")"}], 
                "*", 
                SubscriptBox["\[Epsilon]", "b"]}]}], ")"}]}], 
            RowBox[{"K", "*", 
             SuperscriptBox[
              SubscriptBox["L", "z"], "2"], " ", "*", "\[Phi]", "*", 
             SubscriptBox["A", "c"], "*", 
             SubscriptBox["\[Epsilon]", "b"]}]]}], ")"}]}]}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
         SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], "+", 
        RowBox[{
         SuperscriptBox[
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
         SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}]}], ")"}]}], 
     ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7069721727465696`*^9, 3.7069722269069753`*^9}, {
   3.706972267155734*^9, 3.7069723204820533`*^9}, {3.706976369157633*^9, 
   3.706976375884715*^9}, {3.7069791087554893`*^9, 3.7069791250947285`*^9}, {
   3.7069794238777647`*^9, 3.7069794242312737`*^9}, {3.706979461174863*^9, 
   3.7069794848329644`*^9}, 3.713337638018546*^9, {3.713338932854249*^9, 
   3.71333896065143*^9}},ExpressionUUID->"9d7d760b-1887-4006-8d0b-\
b9c7417000da"],

Cell[BoxData[
 RowBox[{"v", "\[Rule]", 
  FractionBox[
   RowBox[{"K", " ", 
    SubscriptBox["L", "z"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], "+", 
      SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}], "2"], 
        "-", 
        FractionBox[
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["f", "\<\"F\"\>"], " ", 
             SubscriptBox["L", "z"]}], "+", 
            RowBox[{
             SubscriptBox["A", "c"], " ", "\[ExponentialE]", " ", 
             SubscriptBox["\[Epsilon]", "b"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "+", 
               SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], 
              "2"]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], 
              "2"]}]}], ")"}]}], 
         RowBox[{
          SubscriptBox["A", "c"], " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          SubsuperscriptBox["L", "z", "2"]}]]}]]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], "+", 
      RowBox[{
       SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.7133389838472137`*^9, 3.7133412911988297`*^9, 
  3.7133463682488184`*^9, 3.7133468376873083`*^9, 3.7133470106782274`*^9, 
  3.7133471335898895`*^9, 3.7133474344048615`*^9, 3.713347563542653*^9, 
  3.713348623247727*^9, 3.713349913675536*^9, 3.713350365449561*^9, 
  3.71335295577752*^9, 3.7133530710224857`*^9, 3.7133531438697925`*^9, 
  3.713353288664733*^9, 3.713354879028838*^9, 3.7133612299796343`*^9, 
  3.713361525987032*^9, 3.7133653604974203`*^9, 3.713369189229388*^9, 
  3.713424370601162*^9, 3.713426135281143*^9, 3.7134563691736813`*^9, 
  3.7134644382471485`*^9, 3.713484090528735*^9, 3.713512131140806*^9, 
  3.713517729500351*^9, 3.7135230338701873`*^9, 3.713523397824422*^9, 
  3.7135284141879215`*^9, 3.7135300601151943`*^9, 
  3.7135307511484866`*^9},ExpressionUUID->"a299d3d3-6676-4237-8215-\
3435e978a709"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonidealVelocityEstimate", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"First", "[", "#", "]"}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", "<", 
         SubscriptBox["\[Epsilon]", "b"], "<", "1"}], "}"}]}]}], "]"}], "&"}],
    "@", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox[
             SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "2"], " ", 
            SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""]}], 
           RowBox[{
            SubsuperscriptBox["Kf", "A", "\"\<II\>\""], 
            SubsuperscriptBox["L", "z", "\"\<II\>\""]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "2"], " ", 
            SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""]}], 
           RowBox[{
            SubsuperscriptBox["Kf", "B", "\"\<III\>\""], 
            SubsuperscriptBox["L", "z", "\"\<III\>\""]}]]}], ")"}], 
        SuperscriptBox["v", "2"]}], "-", 
       RowBox[{"\[Phi]", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], "-", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""]}], ")"}], "v"}], 
       "+", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SubscriptBox["f", "\"\<F\>\""], 
          RowBox[{
           SubscriptBox["\[Epsilon]", "b"], 
           SubscriptBox["A", "c"]}]], "+", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{
            SubsuperscriptBox["\[Beta]", "A", "\"\<II\>\""], 
            SubsuperscriptBox["E", "A", "\"\<II\>\""]}]}], 
          SubsuperscriptBox["L", "z", "\"\<II\>\""]], "+", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{
            SubsuperscriptBox["\[Beta]", "B", "\"\<III\>\""], 
            SubsuperscriptBox["E", "B", "\"\<III\>\""]}]}], 
          SubsuperscriptBox["L", "z", "\"\<III\>\""]]}], ")"}]}], "\[Equal]", 
      "0"}], ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.713514026309306*^9, 3.7135140334644513`*^9}, {
  3.7135141619521914`*^9, 3.713514177750845*^9}, {3.7135142125830193`*^9, 
  3.713514481852901*^9}, {3.7135146589506416`*^9, 3.713514678937645*^9}, {
  3.713514827116113*^9, 3.7135148289776287`*^9}, {3.7135148985791974`*^9, 
  3.713514900559186*^9}},ExpressionUUID->"db3e678e-df0f-4360-b0e1-\
3feaddb4ce92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v", "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "b"], " ", 
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}], "-", 
        SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "b"], " ", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
                 SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}], 
               "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["f", "\<\"F\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"]}], "+", 
                  RowBox[{
                   SubscriptBox["A", "c"], " ", 
                   SubscriptBox["\[Epsilon]", "b"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], 
                    " ", 
                    SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
                    SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], 
                    " ", 
                    SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                    SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"]}]}], 
                    ")"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
                   SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], 
                    "2"]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], 
                    "2"]}]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["A", "c"], " ", 
                SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"II\"\>"], ")"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"III\"\>"], ")"}], "2"]}], 
               ")"}]}]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], ")"}], "2"]}], 
        "+", 
        RowBox[{
         SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], ")"}], "2"]}]}],
        ")"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.713514472152644*^9, 3.713514483717857*^9}, 
   3.7135146812463875`*^9, 3.7135148304454803`*^9, 3.7135149015156884`*^9, 
   3.7135177301686287`*^9, 3.7135230345761185`*^9, 3.713523398503894*^9, 
   3.7135284148690186`*^9, 3.7135300608226986`*^9, 
   3.713530751848493*^9},ExpressionUUID->"606188a6-44ce-4feb-a07d-\
3884d82b6e2f"]
}, Open  ]],

Cell["\<\
The velocity estimate comes from solving the following system of equations\
\>", "Text",
 CellChangeTimes->{{3.713352961258211*^9, 
  3.713352983208372*^9}},ExpressionUUID->"01d623e4-27c7-49cc-a235-\
f6d05a38764e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "@", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<I\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<I\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<II\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<III\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""], " "}]}]]}], ",", 
      RowBox[{"v", "\[Equal]", 
       FractionBox[
        SubsuperscriptBox["u", "0", "\"\<IV\>\""], 
        RowBox[{"1", "+", 
         RowBox[{"\[Phi]", " ", 
          SubsuperscriptBox["\[Delta]", "A", "\"\<IV\>\""], " "}]}]]}], ",", 
      RowBox[{
       SubscriptBox["f", "\"\<F\>\""], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], 
        SubscriptBox["A", "c"], 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\"\<III\>\""], "-", 
          SubsuperscriptBox["u", "0", "\"\<II\>\""]}], ")"}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7133528518942165`*^9, 
  3.713352853603495*^9}},ExpressionUUID->"511e8d07-31d4-4c76-96dd-\
35a11564f6e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"v", "\[Rule]", 
     FractionBox[
      SubscriptBox["f", "\<\"F\"\>"], 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
         SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}], ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}], 
    ",", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["f", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["\[Epsilon]", "b"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"]}]}], ")"}]}], 
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
          SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], ")"}]}]]}]}]}],
    "}"}], "}"}]], "Output",
 CellChangeTimes->{3.713352784695923*^9, 3.713352854211293*^9, 
  3.713352955846099*^9, 3.713353071059018*^9, 3.713353143891296*^9, 
  3.7133532887017336`*^9, 3.713354879072847*^9, 3.713361230017376*^9, 
  3.713361526033969*^9, 3.7133653605286913`*^9, 3.7133691892633896`*^9, 
  3.713424370632413*^9, 3.7134261353436427`*^9, 3.7134563692251806`*^9, 
  3.713464438287161*^9, 3.713484090639249*^9, 3.7135121311743126`*^9, 
  3.7135177302726374`*^9, 3.713523034646871*^9, 3.7135233986334066`*^9, 
  3.7135284149066644`*^9, 3.7135300608901787`*^9, 
  3.7135307519164734`*^9},ExpressionUUID->"dd3841e6-bbc9-41f0-b565-\
14e4c7be7d2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealVelocityEstimate", "=", 
  RowBox[{"v", "\[Rule]", 
   FractionBox[
    SubscriptBox["f", "\"\<F\>\""], 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Delta]", "A", "\"\<II\>\""], "-", 
       SubsuperscriptBox["\[Delta]", "B", "\"\<III\>\""]}], 
      ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.706979114270035*^9, 3.7069791332719812`*^9}, {
   3.7069794355664086`*^9, 3.706979457693653*^9}, {3.7069795106918306`*^9, 
   3.7069795210761013`*^9}, 3.7133376380365467`*^9, {3.713338932875249*^9, 
   3.71333896066593*^9}, 
   3.713352801180873*^9},ExpressionUUID->"cecb3816-3bf3-42f6-9881-\
4ebdd40fbb94"],

Cell[BoxData[
 RowBox[{"v", "\[Rule]", 
  FractionBox[
   SubscriptBox["f", "\<\"F\"\>"], 
   RowBox[{
    SubscriptBox["A", "c"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "-", 
      SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"]}], 
     ")"}]}]]}]], "Output",
 CellChangeTimes->{3.7133389838617134`*^9, 3.713341291215831*^9, 
  3.713346368264715*^9, 3.713346837696307*^9, 3.713347010694228*^9, 
  3.713347133608917*^9, 3.713347434417862*^9, 3.713347563564652*^9, 
  3.713348623261731*^9, 3.7133499136925364`*^9, 3.713350365467063*^9, 
  3.7133528034327435`*^9, 3.713352955871101*^9, 3.7133530710930166`*^9, 
  3.713353143914296*^9, 3.7133532887342377`*^9, 3.7133548790948467`*^9, 
  3.713361230017376*^9, 3.71336152606155*^9, 3.7133653605443134`*^9, 
  3.713369189275406*^9, 3.713424370648037*^9, 3.713426135359268*^9, 
  3.7134563692376795`*^9, 3.713464438307163*^9, 3.713484090649249*^9, 
  3.7135121311813126`*^9, 3.713517730285637*^9, 3.713523034662497*^9, 
  3.7135233986489067`*^9, 3.7135284149222755`*^9, 3.7135300609031954`*^9, 
  3.713530751927475*^9},ExpressionUUID->"9a70788a-17a8-485c-b1b9-\
779cea75b0de"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mass Transfer Estimates", "Subsection",
 CellChangeTimes->{{3.7069760065371075`*^9, 
  3.7069760128208933`*^9}},ExpressionUUID->"c5e0dbfe-6e83-426a-8cc1-\
c00aa110190d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"effectiveDiffusionEstimate", "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["D", "p"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["\[Epsilon]", "p"], 
      SubscriptBox["D", "m"]}], 
     SubscriptBox["\[Tau]", "tor"]]}], "/.", 
   RowBox[{
    SubscriptBox["\[Tau]", "tor"], "\[Rule]", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], 
     SubscriptBox["\[Epsilon]", "p"]]}]}]}]], "Input",
 CellChangeTimes->{{3.713345371386857*^9, 
  3.713345451756318*^9}},ExpressionUUID->"414c6039-fce9-4858-83b6-\
3d164c3f0d06"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["D", "p"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["D", "m"], " ", 
    SubsuperscriptBox["\[Epsilon]", "p", "2"]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "-", 
      SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"]]}]], "Output",
 CellChangeTimes->{3.713345452721058*^9, 3.7133463682797155`*^9, 
  3.7133468377063084`*^9, 3.7133470107112293`*^9, 3.7133471336309185`*^9, 
  3.713347434430867*^9, 3.7133475635918255`*^9, 3.71334862327481*^9, 
  3.713349913711536*^9, 3.713350365488063*^9, 3.713352955894099*^9, 
  3.7133530711260166`*^9, 3.713353143940753*^9, 3.713353288764241*^9, 
  3.713354879116849*^9, 3.713361230033009*^9, 3.7133615261028805`*^9, 
  3.713365360566428*^9, 3.713369189291054*^9, 3.713424370648037*^9, 
  3.7134261353748937`*^9, 3.7134563692496796`*^9, 3.7134644383171597`*^9, 
  3.7134840906692476`*^9, 3.7135121311913133`*^9, 3.713517730299638*^9, 
  3.713523034678122*^9, 3.7135233986599073`*^9, 3.7135284149379168`*^9, 
  3.713530060918178*^9, 
  3.71353075193999*^9},ExpressionUUID->"bd70bf6d-0cb3-4493-af78-961f28f99703"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"massTransferEstimate", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "\[Rule]", 
     FractionBox[
      RowBox[{"15", " ", 
       SubscriptBox["D", "p"], " ", 
       SubscriptBox["\[Epsilon]", "p"]}], 
      SubsuperscriptBox["r", "p", "2"]]}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["Kf", "B", "\"\<I\>\""], ",", 
     SubsuperscriptBox["Kf", "A", "\"\<II\>\""], ",", 
     SubsuperscriptBox["Kf", "B", "\"\<III\>\""], ",", 
     SubsuperscriptBox["Kf", "A", "\"\<IV\>\""]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.706976018369915*^9, 3.706976101145649*^9}, {
  3.70697640799788*^9, 
  3.7069765081339483`*^9}},ExpressionUUID->"92ce6dd1-e9f7-49e9-a32f-\
20250a094e44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983877714*^9, 3.7133412912358384`*^9, 
  3.713346368298715*^9, 3.7133468377368145`*^9, 3.71334701072873*^9, 
  3.7133471336549177`*^9, 3.713347434446871*^9, 3.713347563618825*^9, 
  3.7133486232928095`*^9, 3.7133499137325363`*^9, 3.7133503655120635`*^9, 
  3.713352955916602*^9, 3.713353071159525*^9, 3.7133531439677525`*^9, 
  3.713353288794241*^9, 3.713354879140355*^9, 3.713361230033009*^9, 
  3.713361526149774*^9, 3.71336536058206*^9, 3.713369189306676*^9, 
  3.713424370663662*^9, 3.7134261353748937`*^9, 3.713456369261179*^9, 
  3.7134644383378134`*^9, 3.71348409067925*^9, 3.7135121312013135`*^9, 
  3.7135177303126373`*^9, 3.713523034678122*^9, 3.713523398672392*^9, 
  3.7135284149535418`*^9, 3.713530060931184*^9, 
  3.713530751952973*^9},ExpressionUUID->"30d6321e-22c7-4fde-b98a-\
f0725a750893"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"filmTransferEstimate", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{"5", 
     SubscriptBox["D", "p"]}], 
    SubscriptBox["r", "p"]]}]}]], "Input",
 CellChangeTimes->{{3.713344709290055*^9, 
  3.7133447510517273`*^9}},ExpressionUUID->"1fa8fa9b-22d2-4a03-b3f3-\
c2fe602bb47d"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"5", " ", 
    SubscriptBox["D", "p"]}], 
   SubscriptBox["r", "p"]]}]], "Output",
 CellChangeTimes->{3.7133412912553434`*^9, 3.7133447578410683`*^9, 
  3.7133463683237143`*^9, 3.7133468377453146`*^9, 3.71334701074629*^9, 
  3.7133471336779184`*^9, 3.713347434463872*^9, 3.7133475636418257`*^9, 
  3.7133486233118114`*^9, 3.713349913755044*^9, 3.713350365535112*^9, 
  3.713352955935169*^9, 3.713353071191524*^9, 3.7133531439942594`*^9, 
  3.7133532888252416`*^9, 3.713354879160859*^9, 3.7133612300486317`*^9, 
  3.7133615261870513`*^9, 3.7133653605976863`*^9, 3.713369189322301*^9, 
  3.7134243706792865`*^9, 3.713426135390519*^9, 3.7134563692736773`*^9, 
  3.7134644383578157`*^9, 3.7134840906987543`*^9, 3.7135121312168713`*^9, 
  3.7135177303276377`*^9, 3.7135230346937466`*^9, 3.713523398685392*^9, 
  3.7135284149535418`*^9, 3.713530060945682*^9, 
  3.7135307519649725`*^9},ExpressionUUID->"fbee4593-d723-4b5f-a07e-\
239f7639bd50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wilsonGeankoplis", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["D", "p"], 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubscriptBox["r", "p"]], 
    FractionBox["1.09", 
     SubscriptBox["\[Epsilon]", "b"]], 
    SuperscriptBox[
     SubscriptBox[
      RowBox[{"Pe", "[", "zone", "]"}], "i"], "0.33"]}]}]}]], "Input",
 CellChangeTimes->{{3.713344944575387*^9, 
  3.7133450596717334`*^9}},ExpressionUUID->"699167c9-63d8-4a65-976c-\
55c09efa384d"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"1.09`", " ", 
    SubscriptBox["D", "p"], " ", 
    SubscriptBox["\[Epsilon]", "p"], " ", 
    SubsuperscriptBox[
     RowBox[{"Pe", "[", "zone", "]"}], "i", "0.33`"]}], 
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox["\[Epsilon]", "b"]}]]}]], "Output",
 CellChangeTimes->{3.7133450740752134`*^9, 3.713346368347719*^9, 
  3.713346837755316*^9, 3.7133470107632885`*^9, 3.713347133700921*^9, 
  3.7133474344808707`*^9, 3.7133475636694684`*^9, 3.7133486233398094`*^9, 
  3.713349913776181*^9, 3.7133503655591145`*^9, 3.71335295595817*^9, 
  3.713353071223524*^9, 3.7133531440222597`*^9, 3.7133532888552494`*^9, 
  3.7133548791828585`*^9, 3.7133612300642567`*^9, 3.7133615262183332`*^9, 
  3.7133653606133122`*^9, 3.7133691893379264`*^9, 3.7134243706792865`*^9, 
  3.713426135390519*^9, 3.713456369285178*^9, 3.713464438374955*^9, 
  3.7134840907067556`*^9, 3.713512131229871*^9, 3.7135177303426423`*^9, 
  3.7135230346937466`*^9, 3.7135233986948924`*^9, 3.7135284149691668`*^9, 
  3.7135300609606824`*^9, 
  3.713530751977471*^9},ExpressionUUID->"38455069-a43a-4d6a-841b-\
c8106f26cfb9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"chungWen", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"E", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{"2", 
     SubscriptBox["r", "p"], " ", 
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     SubscriptBox["\[Epsilon]", "b"]}], 
    RowBox[{"0.2", "+", 
     RowBox[{"0.011", 
      SuperscriptBox[
       RowBox[{"Reynolds", "[", "zone", "]"}], "0.48"]}]}]]}]}]], "Input",
 CellChangeTimes->{{3.71334259224177*^9, 3.7133427202762713`*^9}, {
  3.7133428461904764`*^9, 
  3.7133428480610447`*^9}},ExpressionUUID->"03e838d7-a9e7-4163-ab5e-\
984a39feb6ba"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"\[ExponentialE]", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["r", "p"], " ", 
    SubscriptBox["\[Epsilon]", "b"], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], 
   RowBox[{"0.2`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.011`", " ", 
     SuperscriptBox[
      RowBox[{"Reynolds", "[", "zone", "]"}], "0.48`"]}]}]]}]], "Output",
 CellChangeTimes->{3.7133455123297296`*^9, 3.713346368367256*^9, 
  3.7133468377643166`*^9, 3.713347010781288*^9, 3.713347133721979*^9, 
  3.7133474344988737`*^9, 3.7133475637024746`*^9, 3.7133486233598146`*^9, 
  3.7133499137971807`*^9, 3.713350365584114*^9, 3.7133529559811687`*^9, 
  3.713353071254533*^9, 3.7133531440542574`*^9, 3.7133532888862495`*^9, 
  3.713354879211859*^9, 3.7133612300642567`*^9, 3.7133615262652073`*^9, 
  3.7133653606133122`*^9, 3.7133691893535504`*^9, 3.7134243706949115`*^9, 
  3.713426135406143*^9, 3.7134563692966805`*^9, 3.713464438387462*^9, 
  3.7134840907256975`*^9, 3.7135121312408714`*^9, 3.7135177303546467`*^9, 
  3.713523034714879*^9, 3.713523398706394*^9, 3.7135284149863186`*^9, 
  3.713530060975184*^9, 
  3.713530751989972*^9},ExpressionUUID->"2c55653f-8b2c-46dd-bdd8-\
2845c87462a0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimensionless Quantities", "Subsection",
 CellChangeTimes->{{3.7133406818150587`*^9, 
  3.7133406871171308`*^9}},ExpressionUUID->"1cb0c961-905c-46af-a2ed-\
f2d2b7f9508d"],

Cell[CellGroupData[{

Cell["Peclet Number", "Subsubsection",
 CellChangeTimes->{{3.713340897251177*^9, 
  3.713340900217434*^9}},ExpressionUUID->"35a10c39-b522-4ac9-9804-\
adf2edffcc61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peclet", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"Pe", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     SubscriptBox["r", "p"]}], 
    SubscriptBox[
     RowBox[{"E", "[", "zone", "]"}], "i"]]}]}]], "Input",
 CellChangeTimes->{{3.713340911679635*^9, 3.7133409336074166`*^9}, {
  3.7133409641920156`*^9, 3.71334100516239*^9}, {3.713341093955575*^9, 
  3.7133411216715937`*^9}, {3.713345575526943*^9, 
  3.713345607774027*^9}},ExpressionUUID->"612e6348-2d35-46dc-9095-\
c309bb07a939"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"Pe", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], 
   SubscriptBox[
    RowBox[{"\[ExponentialE]", "[", "zone", "]"}], "i"]]}]], "Output",
 CellChangeTimes->{
  3.71334093719689*^9, {3.713341105600179*^9, 3.713341122833452*^9}, 
   3.713341291293342*^9, 3.7133456881473856`*^9, 3.7133463683892565`*^9, 
   3.7133468377753167`*^9, 3.7133470107992887`*^9, 3.713347133744978*^9, 
   3.7133474345148716`*^9, 3.7133475637324734`*^9, 3.713348623379833*^9, 
   3.7133499138191805`*^9, 3.7133503656121144`*^9, 3.7133529560036736`*^9, 
   3.7133530712845325`*^9, 3.713353144080763*^9, 3.7133532889162498`*^9, 
   3.7133548792318583`*^9, 3.7133612300798793`*^9, 3.713361526303136*^9, 
   3.713365360628935*^9, 3.7133691893706636`*^9, 3.7134243706949115`*^9, 
   3.713426135421768*^9, 3.7134563693076773`*^9, 3.713464438402678*^9, 
   3.71348409073678*^9, 3.7135121312528715`*^9, 3.713517730367646*^9, 
   3.7135230347158794`*^9, 3.7135233987168913`*^9, 3.7135284149863186`*^9, 
   3.713530060990183*^9, 
   3.713530752002493*^9},ExpressionUUID->"8f1f9bd8-c502-49f7-b3c6-\
cc08ca854190"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Stanton Number", "Subsubsection",
 CellChangeTimes->{{3.713341131935182*^9, 
  3.7133411348525944`*^9}},ExpressionUUID->"1a4f0ffd-7cb5-46a3-b239-\
5e2a5b875606"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stanton", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"St", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox["1", 
    RowBox[{
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SubscriptBox["R", "p"], 
        RowBox[{"15", " ", 
         SubscriptBox["\[Epsilon]", "p"], " ", "Dp"}]], "+", 
       FractionBox["1", 
        RowBox[{"3", 
         SubscriptBox[
          RowBox[{"kf", "[", "zone", "]"}], "i"]}]]}], ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.713341144721283*^9, 3.713341213283687*^9}, {
  3.713341251363948*^9, 3.7133412527759175`*^9}, {3.7133413396362753`*^9, 
  3.713341359779224*^9}, {3.71334154323908*^9, 
  3.7133415440023394`*^9}},ExpressionUUID->"cd575dcb-0e08-41df-8d2d-\
5266d24bc34d"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"St", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SubscriptBox["R", "p"], 
       RowBox[{"15", " ", "Dp", " ", 
        SubscriptBox["\[Epsilon]", "p"]}]], "+", 
      FractionBox["1", 
       RowBox[{"3", " ", 
        SubscriptBox[
         RowBox[{"kf", "[", "zone", "]"}], "i"]}]]}], ")"}], " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}]]}]], "Output",
 CellChangeTimes->{
  3.7133412172627444`*^9, 3.7133412533418956`*^9, 3.713341291312343*^9, {
   3.7133413463754425`*^9, 3.7133413613973427`*^9}, 3.713341544812383*^9, 
   3.7133463684062557`*^9, 3.713346837788318*^9, 3.713347010817289*^9, 
   3.713347133766979*^9, 3.7133474345323753`*^9, 3.713347563757476*^9, 
   3.7133486234018326`*^9, 3.7133499138431816`*^9, 3.713350365644619*^9, 
   3.7133529560261984`*^9, 3.713353071316532*^9, 3.7133531441057973`*^9, 
   3.713353288946258*^9, 3.7133548792618713`*^9, 3.7133612300798793`*^9, 
   3.713361526334387*^9, 3.71336536064456*^9, 3.713369189375663*^9, 
   3.713424370710538*^9, 3.713426135421768*^9, 3.7134563693206816`*^9, 
   3.7134644384158125`*^9, 3.7134840907567816`*^9, 3.713512131265375*^9, 
   3.7135177303826456`*^9, 3.713523034731511*^9, 3.713523398728391*^9, 
   3.7135284150019646`*^9, 3.7135300610046825`*^9, 
   3.7135307520149713`*^9},ExpressionUUID->"d5e4af67-10fd-4618-a8ad-\
2c744a6417db"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sherwood Number", "Subsubsection",
 CellChangeTimes->{{3.7133415158931227`*^9, 
  3.7133415199855165`*^9}},ExpressionUUID->"53a5b5b8-1164-4583-b3e3-\
fbf3dff893a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sherwood", "=", 
  RowBox[{
   SubscriptBox[
    RowBox[{"Sh", "[", "zone_", "]"}], "i_"], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox[
      RowBox[{"kf", "[", "zone", "]"}], "i"], " ", 
     SubscriptBox["r", "p"]}], 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], " ", 
     SubscriptBox["D", "p"]}]]}]}]], "Input",
 CellChangeTimes->{{3.7133415226754265`*^9, 3.7133416093960714`*^9}, 
   3.7133417070769014`*^9, {3.7133417990181446`*^9, 3.7133418261415596`*^9}, 
   3.713342412820716*^9},ExpressionUUID->"8c2ae4ec-8440-4fcc-81ac-\
ba84b921e93b"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   RowBox[{"Sh", "[", "zone_", "]"}], "i_"], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", 
    SubscriptBox[
     RowBox[{"kf", "[", "zone", "]"}], "i"]}], 
   RowBox[{
    SubscriptBox["D", "p"], " ", 
    SubscriptBox["\[Epsilon]", "p"]}]]}]], "Output",
 CellChangeTimes->{3.7133418298001804`*^9, 3.7133424137693167`*^9, 
  3.7133463684242563`*^9, 3.713346837800317*^9, 3.7133470108352933`*^9, 
  3.713347133787983*^9, 3.7133474345478783`*^9, 3.713347563777477*^9, 
  3.7133486234258337`*^9, 3.713349913865184*^9, 3.713350365666972*^9, 
  3.7133529560501986`*^9, 3.7133530713335333`*^9, 3.713353144131798*^9, 
  3.7133532889772577`*^9, 3.713354879284872*^9, 3.7133612300955095`*^9, 
  3.713361526365636*^9, 3.713365360666729*^9, 3.7133691893912935`*^9, 
  3.713424370726162*^9, 3.7134261354373927`*^9, 3.7134563693316817`*^9, 
  3.7134644384258127`*^9, 3.7134840907877846`*^9, 3.7135121312763777`*^9, 
  3.713517730395646*^9, 3.713523034731511*^9, 3.7135233987388897`*^9, 
  3.713528415017576*^9, 3.7135300610186806`*^9, 
  3.713530752026972*^9},ExpressionUUID->"0f757d72-208c-416b-a6e7-\
ff609aed91ea"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reynolds Number", "Subsubsection",
 CellChangeTimes->{{3.713342577845748*^9, 
  3.713342580758417*^9}},ExpressionUUID->"7155024d-55f0-4098-9455-\
c015d9776609"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"reynolds", "=", 
  RowBox[{
   RowBox[{"Reynolds", "[", "zone_", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SubscriptBox["r", "p"], 
     SubscriptBox[
      RowBox[{"u", "[", "zone", "]"}], "0"], "\[Rho]"}], 
    "\[Mu]"]}]}]], "Input",
 CellChangeTimes->{{3.713342582454962*^9, 3.7133425844041386`*^9}, {
  3.71334273631691*^9, 3.71334274062188*^9}, {3.7133428317805986`*^9, 
  3.713342860120889*^9}, {3.713343014926419*^9, 
  3.7133430216207924`*^9}},ExpressionUUID->"fe258052-f864-4fbc-a066-\
081fe35b9306"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Reynolds", "[", "zone_", "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "p"], " ", "\[Rho]", " ", 
    SubscriptBox[
     RowBox[{"u", "[", "zone", "]"}], "0"]}], "\[Mu]"]}]], "Output",
 CellChangeTimes->{3.7133458129267263`*^9, 3.713346368441761*^9, 
  3.713346837812315*^9, 3.713347010853318*^9, 3.7133471338051405`*^9, 
  3.713347434563879*^9, 3.7133475637980003`*^9, 3.713348623450832*^9, 
  3.7133499138903303`*^9, 3.713350365688972*^9, 3.7133529560726347`*^9, 
  3.713353071372167*^9, 3.7133531441587963`*^9, 3.713353289006257*^9, 
  3.7133548793058715`*^9, 3.7133612300955095`*^9, 3.7133615264034076`*^9, 
  3.713365360666729*^9, 3.713369189406919*^9, 3.713424370726162*^9, 
  3.7134261354373927`*^9, 3.713456369343195*^9, 3.713464438446322*^9, 
  3.713484090809291*^9, 3.7135121312873774`*^9, 3.7135177304086437`*^9, 
  3.713523034747135*^9, 3.713523398750388*^9, 3.7135284150331993`*^9, 
  3.7135300610311813`*^9, 
  3.7135307520394707`*^9},ExpressionUUID->"70c9d867-2473-416f-8b7f-\
3e2130cb75fa"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Compose our Estimates into a Procedure", "Section",
 CellChangeTimes->{{3.7069781924420786`*^9, 
  3.7069782065902877`*^9}},ExpressionUUID->"27df55d9-80c2-4518-9585-\
18efc5249712"],

Cell[CellGroupData[{

Cell["Ideal System", "Subsection",
 CellChangeTimes->{{3.706978229054186*^9, 
  3.706978230912442*^9}},ExpressionUUID->"ad449915-ff2b-4cab-b32b-\
f2e4d2909d9a"],

Cell[CellGroupData[{

Cell[TextData[{
 "The ideal solution starts with the first ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "p"], TraditionalForm]],ExpressionUUID->
  "2919dfc0-c4eb-4f6d-951f-7bf805495cab"],
 " estimate from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "s"], TraditionalForm]],ExpressionUUID->
  "387a438d-a0f4-446a-8bec-de61f5a2f94a"]
}], "Subsubsection",
 CellChangeTimes->{{3.7069788252912216`*^9, 3.706978843148952*^9}, {
  3.706978931021088*^9, 3.7069789313794847`*^9}, {3.7133382915697927`*^9, 
  3.7133382989552493`*^9}},ExpressionUUID->"12bedb87-7e2f-4d47-a2e1-\
3c9271c99466"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"initialIdealPeak", "=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"peakEstimate", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "A"], "\[Rule]", 
       SubsuperscriptBox["c", "A", "\"\<s\>\""]}], ",", 
      RowBox[{
       SubscriptBox["c", "B"], "\[Rule]", 
       SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706978844185402*^9, 3.7069788686256866`*^9}, {
  3.706978934051138*^9, 3.7069789348076525`*^9}, {3.7069806546001153`*^9, 
  3.7069806583859673`*^9}, {3.7069808517667246`*^9, 3.7069808756600485`*^9}, {
  3.71333753328761*^9, 3.713337544227348*^9}, {3.7133469828155413`*^9, 
  3.713346985760971*^9}, {3.7133661435142803`*^9, 
  3.7133661454856467`*^9}},ExpressionUUID->"bd9259d9-af97-404c-9e8c-\
64a80e0a51f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["a", "A"], "-", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["b", "A"]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338983897713*^9, 3.7133412913882713`*^9, 
  3.7133463684602704`*^9, 3.7133468378462677`*^9, 3.7133470108703194`*^9, 
  3.7133471338241405`*^9, 3.7133474345808783`*^9, 3.7133475638220005`*^9, 
  3.713348623472971*^9, 3.71334991391333*^9, 3.713350365710972*^9, 
  3.7133529560969033`*^9, 3.713353071401167*^9, 3.713353144186309*^9, 
  3.7133532890377617`*^9, 3.713354879333375*^9, 3.713361230117645*^9, 
  3.713361526450296*^9, 3.7133653606823587`*^9, 3.7133661461137094`*^9, 
  3.7133691894225435`*^9, 3.7134243707496576`*^9, 3.7134261354530177`*^9, 
  3.713456369354679*^9, 3.7134644384588337`*^9, 3.713484090849291*^9, 
  3.713512131300378*^9, 3.713517730421645*^9, 3.713523034747135*^9, 
  3.713523398763386*^9, 3.7135284150488386`*^9, 3.7135300610466814`*^9, 
  3.7135307520539875`*^9},ExpressionUUID->"ba385af2-a8e2-4392-b50f-\
402b42fc79a0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Which are used to calculate the first estimate of the retention factors\
\>", "Subsubsection",
 CellChangeTimes->{{3.706978954974704*^9, 3.706978973606929*^9}, {
  3.713338325625347*^9, 
  3.713338332237108*^9}},ExpressionUUID->"84207f9a-4f49-417a-9ce7-\
434c9be769ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"idealR", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"idealRetention", "/.", "initialIdealPeak"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7069789952388783`*^9, 3.7069790183939857`*^9}, {
   3.7069790642834597`*^9, 3.706979074178793*^9}, {3.7069797213514547`*^9, 
   3.706979725015319*^9}, {3.706980634020439*^9, 3.706980651580159*^9}, 
   3.7069808912429395`*^9},ExpressionUUID->"52e71e18-b300-49bb-b85e-\
027103315562"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["a", "B"], "+", 
     SubscriptBox["\[Epsilon]", "p"], "-", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["\[Epsilon]", "p"], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["\[Epsilon]", "p"]}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
       RowBox[{
        SubscriptBox["a", "A"], "+", 
        SubscriptBox["a", "B"], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389840757136`*^9, 3.713341291561488*^9, 
  3.7133463686323147`*^9, 3.7133468380142717`*^9, 3.713347011028054*^9, 
  3.7133471339733505`*^9, 3.713347434746896*^9, 3.7133475639974847`*^9, 
  3.7133486236250505`*^9, 3.7133499140658445`*^9, 3.7133503658649874`*^9, 
  3.7133529562464504`*^9, 3.7133530715962114`*^9, 3.7133531443443136`*^9, 
  3.71335328918832*^9, 3.713354879493922*^9, 3.713361230264829*^9, 
  3.7133615266349545`*^9, 3.713365360844646*^9, 3.713369189576254*^9, 
  3.7134243709136567`*^9, 3.713426135609268*^9, 3.71345636950869*^9, 
  3.713464438607359*^9, 3.7134840909793015`*^9, 3.713512131450157*^9, 
  3.7135177305686646`*^9, 3.713523034916422*^9, 3.713523398920888*^9, 
  3.7135284151869087`*^9, 3.7135300612036734`*^9, 
  3.7135307522064857`*^9},ExpressionUUID->"40a230cd-73c1-4ee9-98e7-\
0c590d0486cf"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
These retention factors are then used to calculate the system velocities\
\>", "Subsubsection",
 CellChangeTimes->{{3.7069796980414314`*^9, 3.7069797111351843`*^9}, {
  3.7133383466774664`*^9, 
  3.713338349635667*^9}},ExpressionUUID->"782874f5-be02-4a57-8fec-\
6360cc051264"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zones", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"idealZoneVelocityEstimates", "/.", "idealVelocityEstimate"}], "/.",
     "idealR"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.706979713657446*^9, 3.706979768519618*^9}, {
  3.706979867971958*^9, 3.706979867974459*^9}, {3.70697990218363*^9, 
  3.70697991552148*^9}, {3.7069799908921824`*^9, 3.7069799933624125`*^9}, {
  3.706980055128106*^9, 
  3.706980056637744*^9}},ExpressionUUID->"0351873c-2bb1-4eb9-a6df-\
bcbcd4182ce2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "B"], "+", 
            SubscriptBox["\[Epsilon]", "p"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["\[Epsilon]", "p"]}]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "B"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}], ",", 
   RowBox[{
    SubsuperscriptBox["u", "0", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]]}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         SubscriptBox["\[Epsilon]", "b"]]}], ")"}], " ", 
      SubscriptBox["f", "\<\"F\"\>"]}], 
     RowBox[{
      SubscriptBox["A", "c"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SubscriptBox["a", "B"], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338984590214*^9, 3.713341292084383*^9, 
  3.7133463691382647`*^9, 3.7133468385553055`*^9, 3.713347011650095*^9, 
  3.7133471346043415`*^9, 3.7133474353986936`*^9, 3.713347564709545*^9, 
  3.713348624246535*^9, 3.7133499146817293`*^9, 3.7133503664802117`*^9, 
  3.7133529568380756`*^9, 3.7133530722077527`*^9, 3.713353144941352*^9, 
  3.713353289764444*^9, 3.7133548801019726`*^9, 3.713361230895975*^9, 
  3.7133615272208395`*^9, 3.713365361446576*^9, 3.7133691902386775`*^9, 
  3.713424371550476*^9, 3.713426136203017*^9, 3.7134563701076765`*^9, 
  3.7134644386173587`*^9, 3.7134840909963045`*^9, 3.713512131458662*^9, 
  3.713517730576666*^9, 3.713523034916422*^9, 3.7135233995403748`*^9, 
  3.7135284158149824`*^9, 3.7135300618431597`*^9, 
  3.7135307528315496`*^9},ExpressionUUID->"69cc59b2-7d9c-4c10-9b21-\
aef86a8741b1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Estimate the peak concentrations again, based on mass balances\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980682132275*^9, 
  3.70698070656619*^9}},ExpressionUUID->"1485bbfd-c931-4a48-a2c6-\
094478f992fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peak2", "=", 
  RowBox[{
   RowBox[{"peakEstimate", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "A"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<F\>\""]}], ",", 
     RowBox[{
      SubscriptBox["c", "B"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.70698039541459*^9, 3.7069804487190475`*^9}, {
  3.706980749074515*^9, 3.7069807513023925`*^9}, {3.713337473733631*^9, 
  3.7133374837736053`*^9}, {3.7133469766355376`*^9, 
  3.7133469789252863`*^9}},ExpressionUUID->"93ad0c3a-f9b6-443b-b1c9-\
dd88d4be3158"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "A"]}], "+", 
    SubscriptBox["a", "B"], "+", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"], " ", 
     SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
    RowBox[{
     SubscriptBox["a", "A"], " ", 
     SubscriptBox["b", "B"], " ", 
     SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["a", "A"], " ", 
    SubscriptBox["b", "B"]}]]}]], "Output",
 CellChangeTimes->{3.7133389846647153`*^9, 3.7133412921336527`*^9, 
  3.713346369174189*^9, 3.7133468386123066`*^9, 3.713347011685094*^9, 
  3.713347134643341*^9, 3.7133474354577703`*^9, 3.7133475647690434`*^9, 
  3.7133486243025513`*^9, 3.7133499147247295`*^9, 3.7133503665588183`*^9, 
  3.713352956882077*^9, 3.713353072231753*^9, 3.7133531449828577`*^9, 
  3.713353289806444*^9, 3.7133548801367817`*^9, 3.713361230937462*^9, 
  3.713361527252093*^9, 3.713365361512575*^9, 3.7133691902906766`*^9, 
  3.713424371588476*^9, 3.7134261362655177`*^9, 3.7134563701651764`*^9, 
  3.7134644386273594`*^9, 3.7134840909988046`*^9, 3.7135121314686604`*^9, 
  3.7135177305846653`*^9, 3.713523034932048*^9, 3.7135233996233735`*^9, 
  3.7135284158269644`*^9, 3.7135300618911605`*^9, 
  3.7135307528430524`*^9},ExpressionUUID->"d3f69536-8aa9-4255-a865-\
8e5d06ccf9d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peak1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "/.", "zones"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706980556163006*^9, 3.7069806034279537`*^9}, {
  3.706980753848175*^9, 
  3.7069807554623966`*^9}},ExpressionUUID->"dc4a1fc6-e36f-455e-972b-\
df8f1298f493"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubsuperscriptBox["a", "A", "2"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"]}], "+", 
       SubsuperscriptBox["a", "B", "2"], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubsuperscriptBox["a", "B", "2"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["a", "A", "2"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
           "2"]}]]}]}], ")"}], " ", 
     SubscriptBox["y", "target"]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], "+", 
       SubscriptBox["a", "B"], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["a", "A"]}], "+", 
       SubscriptBox["a", "B"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
       SqrtBox[
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
      ")"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.713338984773714*^9, 3.713341292283202*^9, 
  3.7133463692802043`*^9, 3.7133468387608414`*^9, 3.713347011790102*^9, 
  3.713347134745865*^9, 3.713347435546276*^9, 3.713347564875677*^9, 
  3.713348624392061*^9, 3.7133495161872025`*^9, 3.713349914806242*^9, 
  3.7133503666453238`*^9, 3.7133529569620867`*^9, 3.713353072320616*^9, 
  3.7133531450799017`*^9, 3.713353289884452*^9, 3.713354880220786*^9, 
  3.713361231016588*^9, 3.7133615273211327`*^9, 3.713365361589594*^9, 
  3.7133691903746915`*^9, 3.7134243716674767`*^9, 3.7134261363436437`*^9, 
  3.713456370241155*^9, 3.7134644386880727`*^9, 3.7134840910092354`*^9, 
  3.713512131499665*^9, 3.713517730662675*^9, 3.7135230349789233`*^9, 
  3.713523399706871*^9, 3.71352841590539*^9, 3.713530061975658*^9, 
  3.7135307529255543`*^9},ExpressionUUID->"90412fdc-f1ed-4c60-98d3-\
06b5854c8479"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peakUpdate", "=", 
  RowBox[{"{", 
   RowBox[{"peak1", ",", "peak2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7069807619015074`*^9, 
  3.706980768562213*^9}},ExpressionUUID->"416c2130-6ec5-4cc5-9a1a-\
fac17ffe143b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"p\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["a", "A", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "+", 
         SubsuperscriptBox["a", "B", "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["a", "A"]}], "+", 
      SubscriptBox["a", "B"], "+", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", 
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "-", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", 
      SubscriptBox["a", "A"], " ", 
      SubscriptBox["b", "B"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7133389847912135`*^9, 3.7133412923132033`*^9, 
  3.713346369303203*^9, 3.7133468388058386`*^9, 3.7133470118171034`*^9, 
  3.713347134792368*^9, 3.7133474355792756`*^9, 3.7133475649071817`*^9, 
  3.7133486244350615`*^9, 3.7133499148412404`*^9, 3.7133503666733274`*^9, 
  3.7133529569911337`*^9, 3.713353072352622*^9, 3.713353145134404*^9, 
  3.7133532899139*^9, 3.713354880247792*^9, 3.7133612310352287`*^9, 
  3.7133615273367567`*^9, 3.7133653616070924`*^9, 3.7133691903961906`*^9, 
  3.7134243716884766`*^9, 3.713426136359268*^9, 3.7134563702536716`*^9, 
  3.7134644386980715`*^9, 3.713484091019236*^9, 3.713512131508664*^9, 
  3.713517730675674*^9, 3.7135230349945498`*^9, 3.7135233997223873`*^9, 
  3.7135284159275384`*^9, 3.7135300619911585`*^9, 
  3.7135307529705534`*^9},ExpressionUUID->"ec058a58-9822-4551-937a-\
a5966f287f71"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Calculate the difference between the initial peak values, and this second \
estimate\
\>", "Subsubsection",
 CellChangeTimes->{{3.706980733620349*^9, 3.706980741374005*^9}, {
  3.713338403127731*^9, 
  3.713338417737518*^9}},ExpressionUUID->"66763d3e-ff8d-4a33-8c14-\
8f623391c92d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tolerances", "=", 
  RowBox[{
   RowBox[{"Simplify", "@", "Abs"}], "/@", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
         SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "/.", 
       "initialIdealPeak"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["c", "A", "\"\<p\>\""], ",", 
         SubsuperscriptBox["c", "B", "\"\<p\>\""]}], "}"}], "/.", 
       "peakUpdate"}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7069807890536585`*^9, 3.70698082903454*^9}, {
  3.7069809659889245`*^9, 3.7069810725202613`*^9}, {3.7133377288549094`*^9, 
  3.7133377372220945`*^9}, {3.7133469633377705`*^9, 3.713346970737501*^9}, {
  3.713347376709869*^9, 3.713347420997893*^9}, {3.7133482657229424`*^9, 
  3.7133482685052032`*^9}, {3.713348302317844*^9, 
  3.713348341253765*^9}},ExpressionUUID->"ea39d5e0-c8fb-41c3-8f9c-\
c711cf94c6cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "B", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["a", "B", "2"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubsuperscriptBox["a", "A", "2"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
           SubscriptBox["y", "target"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]],
            " ", 
           SubscriptBox["y", "target"]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "B"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", "A"], "+", 
          SubscriptBox["a", "B"], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["a", "A"]}], "+", 
          SubscriptBox["a", "B"], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}], ")"}]}], ")"}]}], "]"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"Abs", "[", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SubscriptBox["a", "A"], " ", 
        SubscriptBox["b", "B"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "B"]}], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         SubscriptBox["b", "A"], " ", 
         SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]], 
        "+", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         SubscriptBox["b", "B"], " ", 
         SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["a", "B"], " ", 
           SubscriptBox["b", "A"], " ", 
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["a", "A"], "-", 
             RowBox[{
              SubscriptBox["a", "B"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{
                 SubscriptBox["b", "A"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
             RowBox[{
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}], 
       ")"}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.713338987410713*^9, 3.713341294913064*^9, 3.713346371882241*^9, 
   3.7133468388693476`*^9, 3.713347014351598*^9, 3.7133471373950915`*^9, 
   3.713347438303015*^9, 3.7133475677350173`*^9, {3.713348299338397*^9, 
   3.713348309373665*^9}, 3.713348342015746*^9, 3.7133486247108936`*^9, 
   3.7133499150362864`*^9, 3.7133503668540983`*^9, 3.7133529571791477`*^9, 
   3.7133530725655937`*^9, 3.7133531453574257`*^9, 3.713353290101416*^9, 
   3.7133548804648795`*^9, 3.7133612312171164`*^9, 3.713361527521701*^9, 
   3.7133653617859807`*^9, 3.7133691905963025`*^9, 3.713424371897476*^9, 
   3.713426136546768*^9, 3.7134563704381666`*^9, 3.713464438847641*^9, 
   3.7134840911090803`*^9, 3.7135121316426697`*^9, 3.713517730815683*^9, 
   3.7135230351482067`*^9, {3.713523384430252*^9, 3.7135233999093666`*^9}, 
   3.7135284161215663`*^9, 3.7135300621826534`*^9, 
   3.7135307531670265`*^9},ExpressionUUID->"5b512b75-3ba5-495b-bd67-\
6bb55f0141a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"toleranceFunction", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"Thread", "[", 
    RowBox[{"tolerances", ">", "0.0001"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"toleranceFunction", "[", 
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
    SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7133474435819225`*^9, 3.7133474792362638`*^9}, {
   3.713347594019288*^9, 3.7133476000400352`*^9}, {3.713347630147417*^9, 
   3.7133476671386166`*^9}, 3.7133477791622925`*^9, {3.713347821214241*^9, 
   3.713347848366146*^9}, {3.713347986141308*^9, 3.7133479865219297`*^9}, 
   3.713348225226048*^9, {3.7133483570125556`*^9, 
   3.713348361995498*^9}},ExpressionUUID->"35173073-f8ca-4119-bcbc-\
f0b6b8700ac1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["a", "B", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "A", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "-", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["a", "B", "2"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], ")"}], "2"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubsuperscriptBox["a", "A", "2"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
            SubscriptBox["y", "target"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "A"], "-", 
                 RowBox[{
                  SubscriptBox["a", "B"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
               "2"]}]], " ", 
            SubscriptBox["y", "target"]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "B"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["a", "A"], "+", 
           SubscriptBox["a", "B"], "+", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["a", "A"]}], "+", 
           SubscriptBox["a", "B"], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
           RowBox[{
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
           RowBox[{
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["a", "A"], " ", 
              SubscriptBox["a", "B"], " ", 
              SubscriptBox["b", "A"], " ", 
              SubscriptBox["b", "B"], " ", 
              SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["a", "A"], "-", 
                RowBox[{
                 SubscriptBox["a", "B"], " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
              "2"]}]]}], ")"}]}], ")"}]}], "]"}]}], ">", "0.0001`"}], ",", 
   "False"}], "}"}]], "Output",
 CellChangeTimes->{{3.7133474521191287`*^9, 3.7133474797163615`*^9}, 
   3.713347567819892*^9, 3.713347600651068*^9, {3.713347640492735*^9, 
   3.713347667920186*^9}, {3.713347780618233*^9, 3.7133477929002504`*^9}, {
   3.71334782507133*^9, 3.713347849392953*^9}, 3.713347990450783*^9, 
   3.7133481906596584`*^9, 3.713348225955258*^9, {3.7133483524182343`*^9, 
   3.7133483626505995`*^9}, 3.713348624766897*^9, 3.713349915065791*^9, 
   3.713350366886099*^9, 3.7133529572071548`*^9, 3.7133530726195965`*^9, 
   3.713353145418434*^9, 3.713353290129919*^9, 3.7133548804918795`*^9, 
   3.7133612312332516`*^9, 3.7133615275529337`*^9, 3.7133653618081307`*^9, 
   3.7133691906127987`*^9, 3.713424371922476*^9, 3.713426136578018*^9, 
   3.7134563704506893`*^9, 3.7134644388576374`*^9, 3.713484091129079*^9, 
   3.7135121316536694`*^9, 3.7135177308276834`*^9, 3.713523035163827*^9, 
   3.7135233999263835`*^9, 3.713528416127589*^9, 3.7135300621971564`*^9, 
   3.713530753183045*^9},ExpressionUUID->"3f5a5c0f-ade0-4781-8398-\
bce83dbe9a29"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Assuming we haven\[CloseCurlyQuote]t converged, calculate new \[Gamma] \
values", "Subsubsection",
 CellChangeTimes->{{3.7069810861321573`*^9, 
  3.706981113672449*^9}},ExpressionUUID->"9f5febe5-be12-4cad-a8bf-\
4726ae041a8a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"second\[Gamma]Estimate", "=", 
  RowBox[{"secondary\[Gamma]Values", "/.", "peakUpdate"}]}]], "Input",
 CellChangeTimes->{{3.7069811158565035`*^9, 3.7069811277049484`*^9}, {
  3.706981188772627*^9, 
  3.7069811946623883`*^9}},ExpressionUUID->"3a5d21c5-b1b5-4394-9e9d-\
d5cc7529de24"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "+"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["a", "A"], "-", 
            SubscriptBox["a", "B"], "-", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
            RowBox[{
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
            SqrtBox[
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["a", "A"], "-", 
                 RowBox[{
                  SubscriptBox["a", "B"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], 
               "2"]}]]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Gamma]", "-"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["a", "A", "2"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "+", 
         SubsuperscriptBox["a", "B", "2"], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["a", "A"]}], "+", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["b", "A"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "+", 
              SubscriptBox["a", "B"], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SubsuperscriptBox["a", "A", "2"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"]}], "+", 
              SubsuperscriptBox["a", "B", "2"], "-", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubsuperscriptBox["a", "B", "2"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["a", "A", "2"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["a", "A"], " ", 
                  SubscriptBox["a", "B"], " ", 
                  SubscriptBox["b", "A"], " ", 
                  SubscriptBox["b", "B"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                  SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                  "2"]}]]}]}], ")"}], " ", 
            SubscriptBox["y", "target"]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "+", 
              SubscriptBox["a", "B"], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["a", "A"]}], "+", 
              SubscriptBox["a", "B"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
              SqrtBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["a", "A"], " ", 
                 SubscriptBox["a", "B"], " ", 
                 SubscriptBox["b", "A"], " ", 
                 SubscriptBox["b", "B"], " ", 
                 SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                 SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["a", "A"], "-", 
                   RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
                 "2"]}]]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.713338987481716*^9, 3.7133412950125704`*^9, 
  3.71334637195024*^9, 3.7133468389013467`*^9, 3.7133470144115973`*^9, 
  3.713347137437094*^9, 3.713347438380742*^9, 3.7133475678474064`*^9, 
  3.713348366048337*^9, 3.713348624824019*^9, 3.713349915092864*^9, 
  3.713350366917099*^9, 3.7133529572361574`*^9, 3.7133530726491003`*^9, 
  3.7133531454794455`*^9, 3.7133532901584234`*^9, 3.7133548805198812`*^9, 
  3.713361231248596*^9, 3.7133615275685577`*^9, 3.7133653618237743`*^9, 
  3.7133691906284213`*^9, 3.7134243719574766`*^9, 3.7134261365936427`*^9, 
  3.713456370465167*^9, 3.713464438894104*^9, 3.713484091149078*^9, 
  3.7135121316646733`*^9, 3.713517730838189*^9, 3.713523035179452*^9, 
  3.7135233999428673`*^9, 3.713528416143248*^9, 3.713530062218154*^9, 
  3.7135307531985264`*^9},ExpressionUUID->"a816ee95-54cf-4dcb-a035-\
64ca484db3b5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["then use the new \[Gamma] values to calculate new cs estimates", \
"Subsubsection",
 CellChangeTimes->{{3.706981149036009*^9, 
  3.7069811736421733`*^9}},ExpressionUUID->"8240279e-f206-4752-a47a-\
f644e4b1e8a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nextEstimate", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"dilutionEstimate", "/.", "second\[Gamma]Estimate"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.706981177248345*^9, 3.7069811995752*^9}, {
  3.706981263784754*^9, 3.706981265664357*^9}, {3.7133461141988926`*^9, 
  3.7133461169762964`*^9}},ExpressionUUID->"b7f30324-484c-45a7-8122-\
2469e130dd31"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["c", "A", "\<\"s\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "+", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"]}], "-", 
         SubsuperscriptBox["a", "B", "2"], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubsuperscriptBox["a", "B", "2"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["a", "A", "2"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             SubscriptBox["b", "A"], " ", 
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "-", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], 
             "2"]}]]}]}], ")"}], " ", 
       SubscriptBox["y", "target"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}], " ", 
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["c", "B", "\<\"s\"\>"], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "-", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["a", "A", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "B"], "+", 
               RowBox[{
                SubscriptBox["a", "B"], " ", 
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], 
            "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["a", "A"], "+", 
               RowBox[{
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], 
            "+", 
            RowBox[{"2", " ", 
             SubscriptBox["a", "A"], " ", 
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", 
               RowBox[{
                SubscriptBox["b", "B"], " ", 
                SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
              ")"}]}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
            RowBox[{
             SubscriptBox["b", "B"], " ", 
             SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubscriptBox["y", "target"]}], "+", 
            RowBox[{
             SubsuperscriptBox["b", "A", "2"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
             SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
             SubscriptBox["y", "target"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SqrtBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "B"], "+", 
                  RowBox[{
                   SubscriptBox["a", "B"], " ", 
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}], "2"], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["a", "A"], "+", 
                  RowBox[{
                   SubscriptBox["a", "A"], " ", 
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"], 
               "+", 
               RowBox[{"2", " ", 
                SubscriptBox["a", "A"], " ", 
                SubscriptBox["a", "B"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "-", 
                  RowBox[{
                   SubscriptBox["b", "B"], " ", 
                   SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
                  RowBox[{
                   SubscriptBox["b", "A"], " ", 
                   SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}]}]}], 
                 ")"}]}]}]]}], "+", 
            RowBox[{
             SubscriptBox["a", "B"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SubscriptBox["b", "A"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"], "-", 
                  RowBox[{"2", " ", 
                   SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
                   SubscriptBox["y", "target"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"]}], ")"}], " ", 
       SubscriptBox["b", "B"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         SubscriptBox["a", "B"], "+", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["b", "A"], " ", 
          SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["a", "A"], " ", 
            SubscriptBox["a", "B"], " ", 
            SubscriptBox["b", "A"], " ", 
            SubscriptBox["b", "B"], " ", 
            SubsuperscriptBox["c", "A", "\<\"s\"\>"], " ", 
            SubsuperscriptBox["c", "B", "\<\"s\"\>"]}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{
                  SubscriptBox["b", "A"], " ", 
                  SubsuperscriptBox["c", "A", "\<\"s\"\>"]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}], ")"}], "2"]}]]}],
         ")"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.713338988135714*^9, 3.7133412956481447`*^9, 
  3.713346118603695*^9, 3.7133463725891953`*^9, 3.7133468402458277`*^9, 
  3.7133470150076265`*^9, 3.713347138083175*^9, 3.713347168590292*^9, 
  3.713347439044397*^9, 3.7133475685831337`*^9, 3.7133486255111685`*^9, 
  3.7133499157464705`*^9, 3.7133503675786076`*^9, 3.7133529578722143`*^9, 
  3.713353073286603*^9, 3.7133531461687775`*^9, 3.7133532907490005`*^9, 
  3.713354881174929*^9, 3.713361231920519*^9, 3.713361528111741*^9, 
  3.713365362358979*^9, 3.7133691913661003`*^9, 3.7134243726868105`*^9, 
  3.7134261371405177`*^9, 3.713456370977154*^9, 3.713464439009616*^9, 
  3.713484091166777*^9, 3.7135121316986775`*^9, 3.7135177309146957`*^9, 
  3.7135230352328405`*^9, 3.713523400618371*^9, 3.7135284167934227`*^9, 
  3.713530062875165*^9, 
  3.713530753871579*^9},ExpressionUUID->"7c0097bc-17cf-4b36-bd00-\
e763810a2079"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define the iteration", "Subsubsection",
 CellChangeTimes->{{3.7133460384320483`*^9, 
  3.713346042106112*^9}},ExpressionUUID->"bd60ad2a-5e10-4b60-b6fa-\
e04fe6a034ac"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"generateCs", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<s\>\"\)]\)\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<s\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<s\>\"\)]\)\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}]}], "|>"}], "/.", 
   RowBox[{"peakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateCpinitial", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<p\>\"\)]\) initial\>\"",
       "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<p\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<p\>\"\)]\) initial\>\"",
       "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], "|>"}], "/.", 
   RowBox[{"initialPeakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateCpfinal", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
     RowBox[{
      SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"<|", 
    RowBox[{
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(A\), \(\"\<p\>\"\)]\) final\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<p\>\""]}], ",", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(c\), \(B\), \(\"\<p\>\"\)]\) final\>\"", 
      "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<p\>\""]}]}], "|>"}], "/.", 
   RowBox[{"peakEstFunc", "[", 
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
      SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"generateResults", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"generateCs", "[", "#", "]"}], ",", 
      RowBox[{"generateCpinitial", "[", "#", "]"}], ",", 
      RowBox[{"generateCpfinal", "[", "#", "]"}]}], "]"}], "&"}]}], 
  ";"}]}], "Input",ExpressionUUID->"af3d0c25-0e70-46a3-b914-261c80c12486"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"doIdealSWD", "[", 
    RowBox[{
    "a1_", ",", "a2_", ",", "b1_", ",", "b2_", ",", "yt_", ",", "cf1_", ",", 
     "cf2_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "A"], "=", "a1"}], ",", 
       RowBox[{
        SubscriptBox["a", "B"], "=", "a2"}], ",", 
       RowBox[{
        SubscriptBox["b", "A"], "=", "b1"}], ",", 
       RowBox[{
        SubscriptBox["b", "B"], "=", "b2"}], ",", 
       RowBox[{
        SubscriptBox["y", "target"], "=", "yt"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "A", "\"\<F\>\""], "=", "cf1"}], ",", 
       RowBox[{
        SubsuperscriptBox["c", "B", "\"\<F\>\""], "=", "cf2"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"idealNextEstimateFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<s\>\""]}], "}"}], "/.", 
         "nextEstimate"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"zoneFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "zones", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"velFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"idealVelocityEstimate", "/.", "idealR"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"toleranceFunction", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"Or", "@@", 
         RowBox[{"Thread", "[", 
          RowBox[{"tolerances", ">", "0.0001"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"peakEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "peakUpdate", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"initialPeakEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", "initialIdealPeak", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"minorEstFunc", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<s\>\""], ":", "_"}], ",", 
          RowBox[{
           SubsuperscriptBox["c", "B", "\"\<s\>\""], ":", "_"}]}], "}"}], 
        "]"}], ":=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"secondaryEstimates", "/.", "portFlowEstimates"}], "/.", 
         "zoneFlowEstimates"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"csHist", "=", 
       RowBox[{"NestWhileList", "[", 
        RowBox[{"idealNextEstimateFunction", ",", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["c", "A", "\"\<F\>\""], ",", 
           SubsuperscriptBox["c", "B", "\"\<F\>\""]}], "}"}], ",", 
         "toleranceFunction"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"results", "=", 
       RowBox[{"Dataset", "[", 
        RowBox[{"generateResults", "/@", "csHist"}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.71334838892173*^9, 3.7133484157749825`*^9}, {
   3.7133484816074657`*^9, 3.713348572964994*^9}, {3.713348635877905*^9, 
   3.7133486398002987`*^9}, {3.7133486804523497`*^9, 
   3.7133487328985577`*^9}, {3.713348763591322*^9, 3.713348808444786*^9}, {
   3.713348904038522*^9, 3.7133490143287745`*^9}, {3.7133491223601575`*^9, 
   3.713349367417217*^9}, {3.7133496184772663`*^9, 3.7133496189549747`*^9}, {
   3.713349961875225*^9, 3.713349997097623*^9}, {3.713350386061716*^9, 
   3.713350393408285*^9}, {3.7133504391341023`*^9, 3.713350545011199*^9}, {
   3.713350577847618*^9, 3.713350627902082*^9}, {3.713350771208232*^9, 
   3.7133508195275707`*^9}, {3.7133508547945404`*^9, 3.713350899612611*^9}, {
   3.7133509764347796`*^9, 3.7133510136961746`*^9}, {3.713351052158817*^9, 
   3.7133510526720405`*^9}, {3.7133511511511936`*^9, 
   3.7133512038268733`*^9}, {3.7133514342412663`*^9, 
   3.7133515120269003`*^9}, {3.713351555865802*^9, 3.7133516816647587`*^9}, {
   3.713351755707103*^9, 3.713351889697209*^9}, {3.713351929849571*^9, 
   3.713352002820095*^9}, {3.713352033776746*^9, 3.7133520625675793`*^9}, {
   3.713353010025146*^9, 3.713353039045745*^9}, {3.7133533084968605`*^9, 
   3.713353390241003*^9}, {3.7133548915358353`*^9, 3.7133549002485185`*^9}, {
   3.7133550094882603`*^9, 3.713355019306679*^9}, {3.7133550504322205`*^9, 
   3.7133550525490665`*^9}, {3.7133553989446926`*^9, 3.713355400779934*^9}, {
   3.713356458992903*^9, 3.7133565024254293`*^9}, {3.7133574498348975`*^9, 
   3.7133574824327354`*^9}, {3.7133575229169674`*^9, 
   3.7133575815353537`*^9}, {3.7133578332619047`*^9, 
   3.7133578351232114`*^9}, {3.7133651530581465`*^9, 
   3.7133651769821053`*^9}, {3.7133653772263184`*^9, 
   3.7133653790974874`*^9}, {3.713365415273676*^9, 3.71336545184683*^9}, {
   3.7133659058127365`*^9, 3.713365932263769*^9}, {3.7133660328995714`*^9, 
   3.7133660742673492`*^9}, {3.7133661911362677`*^9, 3.713366258940174*^9}, {
   3.713366826113123*^9, 3.7133670111623077`*^9}, {3.713370511286664*^9, 
   3.713370531406848*^9}, {3.7133709068987303`*^9, 3.7133709078515434`*^9}, {
   3.71337099701313*^9, 3.7133710006736345`*^9}, {3.7133710873571415`*^9, 
   3.7133710972342978`*^9}, 3.713371511464295*^9, {3.71337173003877*^9, 
   3.713371743942113*^9}, {3.713371785064848*^9, 
   3.713371814559945*^9}},ExpressionUUID->"73402eb0-c107-4c41-96b6-\
47f23066cda7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "\"\<F\>\""], "\[Equal]", 
  RowBox[{
   SubscriptBox["\[Epsilon]", "b"], 
   SubscriptBox["A", "c"], 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["u", "0", "\"\<III\>\""], "-", 
     SubsuperscriptBox["u", "0", "\"\<II\>\""]}], ")"}]}]}]], "Input",Expressi\
onUUID->"fe7022f7-8fb1-49bc-97b6-ea62cefd4afc"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "\<\"F\"\>"], "\[Equal]", 
  RowBox[{
   SubscriptBox["A", "c"], " ", 
   SubscriptBox["\[Epsilon]", "b"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], "+", 
     SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.7134563710076466`*^9, 3.713464439054617*^9, 
  3.7134840912195487`*^9, 3.7135121317596817`*^9, 3.7135177309432*^9, 
  3.7135230352640896`*^9, 3.7135234007063537`*^9, 3.7135284168220806`*^9, 
  3.7135300629436407`*^9, 
  3.7135307539060783`*^9},ExpressionUUID->"6675e422-4698-4ad7-9d0c-\
46f05b72741d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"calculateMvalues", "[", 
   RowBox[{
   "cs_", ",", "ep_", ",", "eb_", ",", "lc_", ",", "db_", ",", "ff_", ",", 
    "yt_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "c"], "=", 
       RowBox[{"\[Pi]", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["db", "2"], ")"}], "2"]}]}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "p"], "=", "ep"}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "b"], "=", "eb"}], ",", 
      RowBox[{
       SubscriptBox["L", "c"], "=", "lc"}], ",", 
      RowBox[{"feed", "=", 
       RowBox[{
        SubscriptBox["f", "\"\<F\>\""], "\[Rule]", "ff"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Epsilon]", "t"], "=", 
       RowBox[{
        SubscriptBox["\[Epsilon]", "b"], "+", 
        RowBox[{
         SubscriptBox["\[Epsilon]", "p"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]}]}], ",", "mvals", ",", 
      "tsw"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"minorEstimates", "=", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"minorEstFunc", "[", "cs", "]"}], "/.", 
         RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tsw", "=", 
      RowBox[{
       RowBox[{
        FractionBox[
         SubscriptBox["L", "c"], "v"], "/.", 
        RowBox[{"velFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mvals", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["m", "zone"], "\[Rule]", 
            FractionBox[
             RowBox[{
              RowBox[{
               SubscriptBox[
                RowBox[{"u", "[", "zone", "]"}], "0"], " ", 
               SubscriptBox["\[Epsilon]", "b"], "tsw"}], "-", 
              RowBox[{
               SubscriptBox["\[Epsilon]", "t"], 
               SubscriptBox["L", "c"]}]}], 
             RowBox[{
              SubscriptBox["L", "c"], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SubscriptBox["\[Epsilon]", "t"]}], ")"}]}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"zone", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<I\>\"", ",", "\"\<II\>\"", ",", "\"\<III\>\"", ",", 
               "\"\<IV\>\""}], "}"}]}], "}"}]}], "]"}], "]"}], "/.", 
        RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"newF", "=", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"mvals", "[", 
            RowBox[{"[", 
             RowBox[{"3", ",", "2"}], "]"}], "]"}], "-", 
           RowBox[{"mvals", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}], 
         SubscriptBox["L", "c"], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SubscriptBox["\[Epsilon]", "t"]}], ")"}]}], "tsw"], "*", 
       SubscriptBox["A", "c"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"testF", "=", 
      RowBox[{
       RowBox[{"portFlowEstimates", "/.", 
        RowBox[{"zoneFunction", "[", "cs", "]"}]}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"testU", "=", 
      RowBox[{
       RowBox[{"zoneFunction", "[", "cs", "]"}], "/.", "feed"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Association", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(t\), \(sw\)]\)\>\"", "\[Rule]", "tsw"}], 
        "}"}], "~", "Join", "~", "mvals", "~", "Join", "~", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["f", "\"\<Feed\>\""], "\[Rule]", "newF"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.71336534820242*^9, 3.713365348903594*^9}, {
   3.7133672166640797`*^9, 3.713367232379471*^9}, {3.713367264943421*^9, 
   3.7133673251679497`*^9}, {3.7133673656191206`*^9, 3.71336740881384*^9}, {
   3.713367624385961*^9, 3.713368012610828*^9}, {3.713368183923693*^9, 
   3.713368193439434*^9}, {3.7133683422540445`*^9, 3.7133684012941003`*^9}, {
   3.713368494751278*^9, 3.7133685183730564`*^9}, {3.71336992564083*^9, 
   3.713369955953268*^9}, {3.7133703907290297`*^9, 3.7133704713900423`*^9}, {
   3.7133705494647818`*^9, 3.713370553830155*^9}, {3.7133709615908437`*^9, 
   3.713371022737687*^9}, 3.7133710808620205`*^9, {3.713371121118045*^9, 
   3.7133711228027134`*^9}, 3.7133714387729197`*^9, {3.7133714801891603`*^9, 
   3.713371485234321*^9}, {3.713371754168645*^9, 3.713371764519052*^9}, {
   3.7133718536693773`*^9, 3.7133718739033484`*^9}, {3.713372001583313*^9, 
   3.713372030686575*^9}, {3.7134259763403625`*^9, 3.713425980214201*^9}, {
   3.7134260550145335`*^9, 3.7134261155612726`*^9}, 3.7134264672378664`*^9, {
   3.713426582662972*^9, 3.7134265938661394`*^9}, {3.713426642282429*^9, 
   3.713426698906968*^9}, {3.713426732974614*^9, 3.713426750642109*^9}, {
   3.7134268135470448`*^9, 3.713426854374708*^9}, {3.713426899412753*^9, 
   3.713426901512068*^9}, {3.71343515320172*^9, 3.713435188094446*^9}, {
   3.71343636268979*^9, 3.713436383211113*^9}, {3.713437293805332*^9, 
   3.713437306873647*^9}, {3.713437581792432*^9, 3.713437584636244*^9}, {
   3.7134384424884524`*^9, 3.71343846449323*^9}, {3.7134385578378057`*^9, 
   3.7134385586182456`*^9}, {3.7134408867741084`*^9, 
   3.7134409215385637`*^9}, {3.7134412441244307`*^9, 
   3.7134412708929024`*^9}},ExpressionUUID->"2da1baef-9b37-4bb6-9905-\
981bb8421881"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-Ideal System", "Subsection",
 CellChangeTimes->{{3.706978271400811*^9, 
  3.706978275886545*^9}},ExpressionUUID->"cb3341e0-cfc5-4c39-b8f8-\
ca008f3d3df1"],

Cell[CellGroupData[{

Cell["\<\
Start by generating estimates of the mass transfer and dispersive parameters\
\>", "Subsubsection",
 CellChangeTimes->{{3.713345980305724*^9, 3.713345995660266*^9}, {
  3.713446639104769*^9, 
  3.7134466460443535`*^9}},ExpressionUUID->"a1f35ae9-936a-4984-a0a9-\
62504cac2e8c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Thread", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubsuperscriptBox["Pe", "B", "\"\<I\>\""], ",", 
     SubsuperscriptBox["Pe", "A", "\"\<II\>\""], ",", 
     SubsuperscriptBox["Pe", "B", "\"\<III\>\""], ",", 
     SubsuperscriptBox["Pe", "A", "\"\<IV\>\""]}], "}"}], "\[Equal]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubsuperscriptBox["Pe", "B", "\"\<I\>\""], ",", 
       SubsuperscriptBox["Pe", "A", "\"\<II\>\""], ",", 
       SubsuperscriptBox["Pe", "B", "\"\<III\>\""], ",", 
       SubsuperscriptBox["Pe", "A", "\"\<IV\>\""]}], "}"}], "/.", "peclet"}], 
    ")"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"pecletBasedDispersion", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{
       SubsuperscriptBox["E", "B", "\"\<I\>\""], ",", 
       SubsuperscriptBox["E", "A", "\"\<II\>\""], ",", 
       SubsuperscriptBox["E", "B", "\"\<III\>\""], ",", 
       SubsuperscriptBox["E", "A", "\"\<IV\>\""]}], "}"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7135164385809283`*^9, 3.7135165803111877`*^9}, {
  3.7135166301975813`*^9, 
  3.713516632781106*^9}},ExpressionUUID->"9b6b7ac1-04fc-4322-8fe9-\
f11d37cf0176"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["Pe", "B", "\<\"I\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
     SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Pe", "A", "\<\"II\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], 
     SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Pe", "B", "\<\"III\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], 
     SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Pe", "A", "\<\"IV\"\>"], "\[Equal]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
     SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7135164959703665`*^9, 3.7135165810554385`*^9}, 
   3.7135166388449545`*^9, 3.713517731024243*^9, 3.7135230352797146`*^9, 
   3.713523400721367*^9, 3.7135284168377266`*^9, 3.7135300629721427`*^9, 
   3.7135307539315696`*^9},ExpressionUUID->"44256826-b45d-481c-ba76-\
3f11f39c7a6b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
     SubsuperscriptBox["Pe", "B", "\<\"I\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], 
     SubsuperscriptBox["Pe", "A", "\<\"II\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], 
     SubsuperscriptBox["Pe", "B", "\<\"III\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
     SubsuperscriptBox["Pe", "A", "\<\"IV\"\>"]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7135164959703665`*^9, 3.7135165810554385`*^9}, 
   3.7135166388449545`*^9, 3.713517731024243*^9, 3.7135230352797146`*^9, 
   3.713523400721367*^9, 3.7135284168377266`*^9, 3.7135300629721427`*^9, 
   3.713530753934558*^9},ExpressionUUID->"2d423eea-e652-4c81-9c3a-\
35409b9bb076"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonIdealParameterEstimate", "=", 
  RowBox[{"massTransferEstimate", "~", "Join", "~", 
   RowBox[{"{", "filmTransferEstimate", "}"}], "~", "Join", "~", 
   "pecletBasedDispersion"}]}]], "Input",
 CellChangeTimes->{{3.7134466243332148`*^9, 3.713446705522729*^9}, {
  3.7135166214050803`*^9, 
  3.713516626357581*^9}},ExpressionUUID->"f96ac693-abed-4952-9bce-\
9fe69bff57e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["Kf", "A", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{"15", " ", 
      SubscriptBox["D", "p"], " ", 
      SubscriptBox["\[Epsilon]", "p"]}], 
     SubsuperscriptBox["r", "p", "2"]]}], ",", 
   RowBox[{
    SubscriptBox[
     RowBox[{"kf", "[", "zone_", "]"}], "i_"], "\[Rule]", 
    FractionBox[
     RowBox[{"5", " ", 
      SubscriptBox["D", "p"]}], 
     SubscriptBox["r", "p"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "B", "\<\"I\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"I\"\>"]}], 
     SubsuperscriptBox["Pe", "B", "\<\"I\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], 
     SubsuperscriptBox["Pe", "A", "\<\"II\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], 
     SubsuperscriptBox["Pe", "B", "\<\"III\"\>"]]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"IV\"\>"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SubscriptBox["r", "p"], " ", 
      SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
     SubsuperscriptBox["Pe", "A", "\<\"IV\"\>"]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7135150623592834`*^9, 3.713516640036951*^9, 
  3.7135177310417485`*^9, 3.7135230352953396`*^9, 3.713523400739354*^9, 
  3.7135284168538165`*^9, 3.7135300629911427`*^9, 
  3.713530753976078*^9},ExpressionUUID->"21dd224d-ca8b-4564-8ecd-\
bad4f73a9bd1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculate the \[Beta] values", "Subsubsection",
 CellChangeTimes->{{3.7134467288943214`*^9, 
  3.7134467437454133`*^9}},ExpressionUUID->"bef142d4-29be-4820-b3b6-\
0474ae9f2c60"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonIdealDecay", "=", 
  RowBox[{
   RowBox[{"decayFactors", "/.", "secondaryEstimates"}], "/.", 
   "portFlowEstimates"}]}]], "Input",
 CellChangeTimes->{{3.713446815265033*^9, 3.7134468165558367`*^9}, {
  3.7134839962449727`*^9, 3.7134840210158777`*^9}, {3.713512984782543*^9, 
  3.7135129909021664`*^9}},ExpressionUUID->"20728d86-715e-46cd-9ba5-\
89f55b82a708"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["y", "target"], " ", 
        SubsuperscriptBox["u", "0", "\<\"I\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
          SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["y", "target"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
          SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]]}], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
         SubscriptBox["f", "\<\"F\"\>"]}], "-", 
        RowBox[{
         SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
         SubscriptBox["f", "\<\"III\"\>"]}]}], 
       RowBox[{
        SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
        SubscriptBox["f", "\<\"II\"\>"]}]]}], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["A", "c"], " ", 
        SubscriptBox["\[Epsilon]", "b"], " ", 
        SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
          SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
       RowBox[{
        SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["y", "target"]}], ")"}], " ", 
        SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Beta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{"Log", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["y", "target"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
          SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}], " ", 
        SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SubscriptBox["y", "target"]}], ")"}], " ", 
        SubsuperscriptBox["u", "0", "\<\"I\"\>"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
          SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]]}], "]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7134468183425713`*^9, 3.7134563711781487`*^9, 3.7134644391665926`*^9, {
   3.7134840000847716`*^9, 3.713484021676425*^9}, 3.713484091339299*^9, 
   3.71351213188898*^9, 3.713512991995141*^9, 3.713515067011289*^9, 
   3.713516643600109*^9, 3.713517731055258*^9, 3.7135230353174706`*^9, 
   3.7135234007508545`*^9, 3.713528416869464*^9, 3.7135300630066423`*^9, 
   3.7135307539910583`*^9},ExpressionUUID->"80357bfe-d122-4958-8e4d-\
8b7d53347d7d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculate the non-ideal zone velocities", "Subsubsection",
 CellChangeTimes->{{3.7134468437758904`*^9, 
  3.7134468571123886`*^9}},ExpressionUUID->"fd0ebb3c-d14d-4dc2-8f02-\
d780212dacb5"],

Cell[CellGroupData[{

Cell[BoxData["nonidealRetention"], "Input",ExpressionUUID->"9cca2ddc-2c11-42fd-a4ff-65c3e941f591"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"I\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     RowBox[{
      SubscriptBox["a", "B"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"II\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "B", "\<\"III\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "B"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
       RowBox[{
        SubscriptBox["b", "B"], " ", 
        SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Delta]", "A", "\<\"IV\"\>"], "\[Rule]", 
    RowBox[{
     FractionBox["DV", 
      RowBox[{
       SubscriptBox["A", "c"], " ", 
       SubscriptBox["L", "c"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "b"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SubscriptBox["a", "A"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
      RowBox[{"1", "+", 
       RowBox[{
        SubscriptBox["b", "A"], " ", 
        SubsuperscriptBox["c", "A", "\<\"p\"\>"]}]}]], "+", 
     SubscriptBox["\[Epsilon]", "p"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7135171025622587`*^9, 3.7135177310692596`*^9, 
  3.7135230353174706`*^9, 3.713523400762868*^9, 3.7135284168865995`*^9, 
  3.7135300630216413`*^9, 
  3.713530754003557*^9},ExpressionUUID->"261d6ef7-46e3-46ac-bc99-\
09207e43eede"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"nonidealVelocityEstimate", "/.", "nonidealRetention"}], "/.", 
   "nonIdealDecay"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"nonIdealV", "=", 
  RowBox[{"%", "/.", "pecletBasedDispersion"}]}]}], "Input",
 CellChangeTimes->{{3.713512944838237*^9, 3.713512945394586*^9}, {
   3.713513000405657*^9, 3.7135130009050303`*^9}, {3.713514916678089*^9, 
   3.7135149269523053`*^9}, {3.713516035850896*^9, 3.7135160386200085`*^9}, {
   3.7135165937299414`*^9, 3.713516594023975*^9}, 3.713516664744439*^9, {
   3.713516695681774*^9, 3.713516715566919*^9}, {3.713516773131446*^9, 
   3.713516778116973*^9}},ExpressionUUID->"194eb849-2799-4df5-b114-\
8be83c678d27"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v", "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["\[Epsilon]", "b"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["\[Epsilon]", "b"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]], "+", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["\[Epsilon]", "p"]}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  SubscriptBox["a", "B"], 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
                   RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
                 FractionBox[
                  SubscriptBox["a", "A"], 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], 
               "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["DV", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"]}], "-", 
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
                    SubscriptBox["\[Epsilon]", "p"], "+", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["a", "B"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    SubscriptBox["\[Epsilon]", "p"]}]}], 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}], 
                    "2"], " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
                    SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["y", "target"]}], ")"}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
                   SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
                    SubscriptBox["f", "\<\"III\"\>"]}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
                    SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["DV", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"]}], "-", 
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
                    SubscriptBox["\[Epsilon]", "p"], "+", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["\[Epsilon]", "p"]}]}], 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], 
                    "2"], " ", 
                   SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["A", "c"], " ", 
                   SubscriptBox["\[Epsilon]", "b"], " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
                    SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["y", "target"]}], ")"}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
                   SubsuperscriptBox["\[ExponentialE]", "B", "\<\"III\"\>"], 
                   " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
                    SubscriptBox["f", "\<\"III\"\>"]}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
                    SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
                    SubsuperscriptBox["\[ExponentialE]", "A", "\<\"II\"\>"]}],
                     "+", 
                    RowBox[{
                    SubscriptBox["f", "\<\"F\"\>"], " ", 
                    SubsuperscriptBox["L", "z", "\<\"II\"\>"]}]}], ")"}], " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"]}]}], ")"}]}], 
               ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["A", "c"], " ", 
                SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"II\"\>"], ")"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"III\"\>"], ")"}], "2"]}], 
               ")"}]}]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["DV", 
             RowBox[{
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"]}], "-", 
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"], " ", 
               SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "B"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}], "2"], 
         " ", 
         RowBox[{"Log", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SubscriptBox["A", "c"], " ", 
             SubscriptBox["\[Epsilon]", "b"], " ", 
             SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
               SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
            RowBox[{
             SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["y", "target"]}], ")"}], " ", 
             SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
         SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
             SubscriptBox["f", "\<\"F\"\>"]}], "+", 
            RowBox[{
             SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
             SubscriptBox["f", "\<\"III\"\>"]}]}], 
           RowBox[{
            SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
            SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["DV", 
             RowBox[{
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"]}], "-", 
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"], " ", 
               SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], "2"], 
         " ", 
         SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"III\"\>"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.71344686961959*^9, 3.7134563711901474`*^9, 3.713464439180602*^9, 
   3.7134840913592987`*^9, 3.71351213189998*^9, 3.7135129470281153`*^9, 
   3.7135130015581503`*^9, 3.713514906546729*^9, 3.7135150161809015`*^9, 
   3.7135150688220825`*^9, 3.713516085018056*^9, {3.7135166378736076`*^9, 
   3.71351666594646*^9}, {3.7135167038355103`*^9, 3.7135167160335765`*^9}, 
   3.713516778785452*^9, 3.7135178185631804`*^9, 3.713523129634339*^9, 
   3.713523493578275*^9, 3.7135285099338303`*^9, 3.713530157605499*^9, 
   3.7135308480538197`*^9},ExpressionUUID->"9f415d0d-b3f3-46a2-bef6-\
b3ddc3a41dcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v", "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
      SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          SubscriptBox["\[Epsilon]", "b"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "A"], " ", 
           SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "+", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["\[Epsilon]", "b"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SubscriptBox["\[Epsilon]", "p"]}], ")"}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]], "+", 
        FractionBox[
         RowBox[{
          SubscriptBox["a", "A"], "-", 
          RowBox[{
           SubscriptBox["a", "A"], " ", 
           SubscriptBox["\[Epsilon]", "p"]}]}], 
         RowBox[{"1", "+", 
          RowBox[{
           SubscriptBox["b", "B"], " ", 
           SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]], "+", 
        RowBox[{"\[Sqrt]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SubscriptBox["\[Epsilon]", "p"]}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  SubscriptBox["a", "B"], 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
                   RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]], "-", 
                 FractionBox[
                  SubscriptBox["a", "A"], 
                  RowBox[{"1", "+", 
                   RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], 
               "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["DV", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"]}], "-", 
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
                    SubscriptBox["\[Epsilon]", "p"], "+", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["a", "B"], "-", 
                    RowBox[{
                    SubscriptBox["a", "B"], " ", 
                    SubscriptBox["\[Epsilon]", "p"]}]}], 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "A"], " ", 
                    SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}], 
                    "2"], " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
                    SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["y", "target"]}], ")"}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
                   SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
                    SubscriptBox["f", "\<\"III\"\>"]}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
                    SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["DV", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"]}], "-", 
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["L", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
                    SubscriptBox["\[Epsilon]", "p"], "+", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["a", "A"], "-", 
                    RowBox[{
                    SubscriptBox["a", "A"], " ", 
                    SubscriptBox["\[Epsilon]", "p"]}]}], 
                    RowBox[{"1", "+", 
                    RowBox[{
                    SubscriptBox["b", "B"], " ", 
                    SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], 
                    "2"], " ", 
                   SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["L", "z", "\<\"III\"\>"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["f", "\<\"F\"\>"], " ", 
                    SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["r", "p"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    RowBox[{"Log", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
                    SubscriptBox["f", "\<\"III\"\>"]}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
                    SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
                    SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], 
                    SubsuperscriptBox["Pe", "A", "\<\"II\"\>"]]}], ")"}]}], 
                  "+", 
                  FractionBox[
                   RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["r", "p"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    SubscriptBox["A", "c"], " ", 
                    SubscriptBox["\[Epsilon]", "b"], " ", 
                    SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
                    SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
                    RowBox[{
                    SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SubscriptBox["y", "target"]}], ")"}], " ", 
                    SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
                    SubsuperscriptBox["L", "z", "\<\"II\"\>"], " ", 
                    SubsuperscriptBox["u", "0", "\<\"III\"\>"]}], 
                   SubsuperscriptBox["Pe", "B", "\<\"III\"\>"]]}], ")"}]}], 
               ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["A", "c"], " ", 
                SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
                SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"II\"\>"], ")"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  SubsuperscriptBox["L", "z", "\<\"III\"\>"], ")"}], "2"]}], 
               ")"}]}]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SubscriptBox["\[Epsilon]", "b"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["DV", 
             RowBox[{
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"]}], "-", 
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"], " ", 
               SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "B"], "-", 
              RowBox[{
               SubscriptBox["a", "B"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "A"], " ", 
               SubsuperscriptBox["c", "A", "\<\"s\"\>"]}], "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "B", "\<\"s\"\>"]}]}]]}], ")"}], "2"], 
         " ", 
         RowBox[{"Log", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SubscriptBox["A", "c"], " ", 
             SubscriptBox["\[Epsilon]", "b"], " ", 
             SubsuperscriptBox["c", "B", "\<\"II\"\>"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
               SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}], 
            RowBox[{
             SubsuperscriptBox["c", "B", "\<\"F\"\>"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SubscriptBox["y", "target"]}], ")"}], " ", 
             SubscriptBox["f", "\<\"F\"\>"]}]]}], "]"}], " ", 
         SubsuperscriptBox["Kf", "A", "\<\"II\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"II\"\>"]}], "+", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], " ", 
             SubscriptBox["f", "\<\"F\"\>"]}], "+", 
            RowBox[{
             SubsuperscriptBox["c", "B", "\<\"s\"\>"], " ", 
             SubscriptBox["f", "\<\"III\"\>"]}]}], 
           RowBox[{
            SubsuperscriptBox["c", "A", "\<\"I\"\>"], " ", 
            SubscriptBox["f", "\<\"II\"\>"]}]], "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FractionBox["DV", 
             RowBox[{
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"]}], "-", 
              RowBox[{
               SubscriptBox["A", "c"], " ", 
               SubscriptBox["L", "c"], " ", 
               SubscriptBox["\[Epsilon]", "b"]}]}]], "+", 
            SubscriptBox["\[Epsilon]", "p"], "+", 
            FractionBox[
             RowBox[{
              SubscriptBox["a", "A"], "-", 
              RowBox[{
               SubscriptBox["a", "A"], " ", 
               SubscriptBox["\[Epsilon]", "p"]}]}], 
             RowBox[{"1", "+", 
              RowBox[{
               SubscriptBox["b", "B"], " ", 
               SubsuperscriptBox["c", "2", "\<\"p\"\>"]}]}]]}], ")"}], "2"], 
         " ", 
         SubsuperscriptBox["Kf", "B", "\<\"III\"\>"], " ", 
         SubsuperscriptBox["L", "z", "\<\"III\"\>"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.71344686961959*^9, 3.7134563711901474`*^9, 3.713464439180602*^9, 
   3.7134840913592987`*^9, 3.71351213189998*^9, 3.7135129470281153`*^9, 
   3.7135130015581503`*^9, 3.713514906546729*^9, 3.7135150161809015`*^9, 
   3.7135150688220825`*^9, 3.713516085018056*^9, {3.7135166378736076`*^9, 
   3.71351666594646*^9}, {3.7135167038355103`*^9, 3.7135167160335765`*^9}, 
   3.713516778785452*^9, 3.7135178185631804`*^9, 3.713523129634339*^9, 
   3.713523493578275*^9, 3.7135285099338303`*^9, 3.713530157605499*^9, 
   3.71353084806032*^9},ExpressionUUID->"1d48b3d4-3117-4aa7-9ca6-\
80ecdc8fcfea"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "nonIdealZoneVelocityEstimates", "/.", "nonidealVelocityEstimate"}], "/.",
       "nonIdealParameterEstimate"}], "/.", "nonidealRetention"}], "/.", 
    "nonIdealDecay"}], "/.", "zoneFlowEstimates"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nonIdealZones", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"%", "/.", "pecletBasedDispersion"}], ",", 
      RowBox[{"TimeConstraint", "\[Rule]", "0.1"}]}], "]"}], "//", 
    "Quiet"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.713513063994703*^9, 3.7135130917090187`*^9}, {
   3.713515093893995*^9, 3.7135150978860235`*^9}, {3.7135160139749184`*^9, 
   3.713516014315014*^9}, {3.7135166000934415`*^9, 3.7135166005354424`*^9}, {
   3.713516682671514*^9, 3.713516683773522*^9}, {3.7135167852231555`*^9, 
   3.713516796911483*^9}, {3.713517116668585*^9, 3.713517121613782*^9}, {
   3.7135172197038784`*^9, 3.713517221114627*^9}, {3.713517253801222*^9, 
   3.713517257951331*^9}, {3.713517298652378*^9, 3.7135173001420965`*^9}, {
   3.7135173351555104`*^9, 3.713517376462963*^9}, {3.71351769650218*^9, 
   3.7135177011337285`*^9}, {3.7135178403879905`*^9, 3.71351784940945*^9}, {
   3.713517885460489*^9, 3.713517888112627*^9}, 
   3.7135179223454647`*^9},ExpressionUUID->"00a8d35c-82bb-42bc-8156-\
ca9f22737302"]
}, Closed]],

Cell[CellGroupData[{

Cell["Check whether the new velocities have changed much", "Subsubsection",
 CellChangeTimes->{{3.7134470019800725`*^9, 
  3.713447017874628*^9}},ExpressionUUID->"f2d2804b-e2ee-4cc2-87fd-\
c9d3cd8986c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonIdealVelocityTolerance", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
      SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubsuperscriptBox["u", "0", "\"\<I\>\""], ",", 
        SubsuperscriptBox["u", "0", "\"\<II\>\""], ",", 
        SubsuperscriptBox["u", "0", "\"\<III\>\""], ",", 
        SubsuperscriptBox["u", "0", "\"\<IV\>\""]}], "}"}], "/.", 
      "nonIdealZones"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7135170057390947`*^9, 3.7135170474231195`*^9}, {
   3.7135179364437113`*^9, 3.713517943653818*^9}, 
   3.7135180692487965`*^9},ExpressionUUID->"6b66906b-32bc-4767-ac30-\
f4d0c6a429f6"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Estimate ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["c", "A", "p"], TraditionalForm]],ExpressionUUID->
  "1b3baf2d-704c-43f1-b2cf-3247e1dddded"]
}], "Subsubsection",
 CellChangeTimes->{{3.7134491737093925`*^9, 
  3.7134491870656414`*^9}},ExpressionUUID->"9bd34ed3-0935-446b-afaf-\
cbe748ef7042"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"peak2", "=", 
  RowBox[{
   RowBox[{"peakEstimate", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "A"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "A", "\"\<F\>\""]}], ",", 
     RowBox[{
      SubscriptBox["c", "B"], " ", "\[Rule]", 
      SubsuperscriptBox["c", "B", "\"\<F\>\""]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.70698039541459*^9, 3.7069804487190475`*^9}, {
  3.706980749074515*^9, 3.7069807513023925`*^9}, {3.713337473733631*^9, 
  3.7133374837736053`*^9}, {3.7133469766355376`*^9, 
  3.7133469789252863`*^9}},ExpressionUUID->"9b21d350-d518-4bf9-8217-\
0ef71a63df8b"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["c", "B", "\<\"p\"\>"], "\[Rule]", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", "A"]}], "+", 
    SubscriptBox["a", "B"], "+", 
    RowBox[{
     SubscriptBox["a", "B"], " ", 
     SubscriptBox["b", "A"], " ", 
     SubsuperscriptBox["c", "A", "\<\"F\"\>"]}], "+", 
    RowBox[{
     SubscriptBox["a", "A"], " ", 
     SubscriptBox["b", "B"], " ", 
     SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "-", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SubscriptBox["a", "A"], " ", 
       SubscriptBox["a", "B"], " ", 
       SubscriptBox["b", "A"], " ", 
       SubscriptBox["b", "B"], " ", 
       SubsuperscriptBox["c", "A", "\<\"F\"\>"], " ", 
       SubsuperscriptBox["c", "B", "\<\"F\"\>"]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["a", "A"], "-", 
         RowBox[{
          SubscriptBox["a", "B"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SubscriptBox["b", "A"], " ", 
             SubsuperscriptBox["c", "A", "\<\"F\"\>"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["a", "A"], " ", 
          SubscriptBox["b", "B"], " ", 
          SubsuperscriptBox["c", "B", "\<\"F\"\>"]}]}], ")"}], "2"]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["a", "A"], " ", 
    SubscriptBox["b", "B"]}]]}]], "Output",
 CellChangeTimes->{3.7133389846647153`*^9, 3.7133412921336527`*^9, 
  3.713346369174189*^9, 3.7133468386123066`*^9, 3.713347011685094*^9, 
  3.713347134643341*^9, 3.7133474354577703`*^9, 3.7133475647690434`*^9, 
  3.7133486243025513`*^9, 3.7133499147247295`*^9, 3.7133503665588183`*^9, 
  3.713352956882077*^9, 3.713353072231753*^9, 3.7133531449828577`*^9, 
  3.713353289806444*^9, 3.7133548801367817`*^9, 3.713361230937462*^9, 
  3.713361527252093*^9, 3.713365361512575*^9, 3.7133691902906766`*^9, 
  3.713424371588476*^9, 3.7134261362655177`*^9, 3.7134563701651764`*^9, 
  3.7134644386273594`*^9, 3.7134840909988046`*^9, 3.7135121314686604`*^9, 
  3.7135177305846653`*^9, 3.713518150206207*^9, 3.7135231417774267`*^9, 
  3.7135235051457615`*^9, 3.7135285216991186`*^9, 3.7135301691049957`*^9, 
  3.7135308595508523`*^9},ExpressionUUID->"015543fc-8d18-4d17-ba7e-\
78e9e6409c80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["portFlowEstimates"], "Input",
 CellChangeTimes->{
  3.7135181734927025`*^9},ExpressionUUID->"1aa090ea-5c21-42f5-bc34-\
f920adc485bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["f", "\<\"R\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"III\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"D\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"E\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["u", "0", "\<\"I\"\>"], "-", 
       SubsuperscriptBox["u", "0", "\<\"II\"\>"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["f", "\<\"Recycle\"\>"], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "c"], " ", 
     SubscriptBox["\[Epsilon]", "b"], " ", 
     SubsuperscriptBox["u", "0", "\<\"IV\"\>"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.713518168888409*^9, 3.7135181738571167`*^9}, 
   3.7135231417930512`*^9, 3.713523505155779*^9, 3.7135285217147655`*^9, 
   3.7135301691204925`*^9, 
   3.713530859564357*^9},ExpressionUUID->"d7e25f17-aafb-404c-afec-\
e30535daefb3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"peak1", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"peakMassBalance", "/.", "portFlowEstimates"}], "]"}], "/.", 
    "nonIdealZones"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.706980556163006*^9, 3.7069806034279537`*^9}, {
  3.706980753848175*^9, 3.7069807554623966`*^9}, {3.713518181501935*^9, 
  3.713518209439622*^9}},ExpressionUUID->"7439a04d-ee93-4547-81b2-\
acfeb1e8a774"],

Cell[BoxData[
 RowBox[{
  RowBox[{"peakUpdate", "=", 
   RowBox[{"{", 
    RowBox[{"peak1", ",", "peak2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7069807619015074`*^9, 3.706980768562213*^9}, 
   3.7135182341862373`*^9},ExpressionUUID->"9a155ebc-2edc-49a2-847b-\
7aeae4469e4c"]
}, Closed]],

Cell[TextData[{
 "Check the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["c", "p"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "989333a8-f157-4c49-9612-a340f8db43a5"],
 " tolerance"
}], "Subsubsection",
 CellChangeTimes->{{3.713518247407303*^9, 
  3.713518260499363*^9}},ExpressionUUID->"ba45c296-10dc-414f-b27e-\
0b5973d98ce5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Wrap the Procedure into a User Interface", "Section",
 CellChangeTimes->{{3.7133620544850044`*^9, 
  3.7133620682539067`*^9}},ExpressionUUID->"0f6723bd-85ba-4ca1-a9c1-\
86b1ee32b56f"],

Cell[CellGroupData[{

Cell["Ideal", "Subsection",
 CellChangeTimes->{{3.71344494192712*^9, 
  3.7134449433781724`*^9}},ExpressionUUID->"a1a803cc-debb-46aa-810a-\
6837b2475b94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "=", "0.2"}], ",", 
     RowBox[{"b1", "=", "0.1"}], ",", 
     RowBox[{"cf2", "=", "3"}], ",", 
     RowBox[{"cf1", "=", "3"}], ",", 
     RowBox[{"update", "=", "0"}], ",", 
     RowBox[{"a1", "=", "1"}], ",", 
     RowBox[{"a2", "=", "2"}], ",", 
     RowBox[{"ep", "=", "0"}], ",", 
     RowBox[{"eb", "=", "0.45"}], ",", 
     RowBox[{"fFeed", "=", "5"}], ",", 
     RowBox[{"yt", "=", "0.99"}], ",", 
     RowBox[{"lc", "=", "90"}], ",", 
     RowBox[{"db", "=", "2.5"}], ",", 
     RowBox[{"plot1", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot2", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot3", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Ideal Standing Wave Design Applied to the Langmuir Isotherm\>\
\"", ",", "Bold", ",", "Large"}], "]"}], "]"}], ",", "SpanFromLeft"}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"Dynamic", "[", "a2", "]"}]}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Dynamic", "[", "a1", "]"}], ",", "30"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \
\(2\)]\)\>\"", ",", 
            "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \
\(2\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "fFeed", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "yt", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Feed Concentration 1\>\"", ",", 
            "\"\<Feed Concentration 2\>\"", ",", "\"\<Feed Flow Rate\>\"", 
            ",", "\"\<Yield Target\>\""}], "}"}]}], ",", 
         "\[IndentingNewLine]", "List"}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "eb", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "ep", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "db", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "lc", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \
\(b\)]\)\>\"", ",", 
            "\"\<Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\
\)]\)\>\"", ",", "\"\<Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)\>\"", 
            ",", "\"\<Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)\>\""}], 
           "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Button", "[", 
          RowBox[{
          "\"\<Generate Standing Wave Design Results\>\"", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"plot1", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<SWD Iterations History\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"doIdealSWD", "[", 
               RowBox[{
               "a1", ",", "a2", ",", "b1", ",", "b2", ",", "yt", ",", "cf1", 
                ",", "cf2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"plot2", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions\
\>\"", ",", "Bold"}], "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"calculateMvalues", "[", 
                RowBox[{
                 RowBox[{"Last", "[", "csHist", "]"}], ",", "ep", ",", "eb", 
                 ",", "lc", ",", "db", ",", "fFeed", ",", "yt"}], "]"}]}]}]}],
             ";", "\[IndentingNewLine]", 
            RowBox[{"plot3", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD Concentration Predictions\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"Association", "@", "minorEstimates"}]}]}]}], ";"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}], ",", 
         "\[IndentingNewLine]", "SpanFromLeft"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Dynamic", "[", "plot1", "]"}], ",", "SpanFromLeft", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Dynamic", "[", "plot2", "]"}], ",", 
         RowBox[{"Dynamic", "[", "plot3", "]"}]}], "\[IndentingNewLine]", 
        "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "2"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0F1IU3EABfAxaLKHUYpL2x5K+phs4Xxx1aJoIBGIopKaEzUnY7dGtYbV
wzKWosm6YTiNEZvFGGuNuTsnXEycD0N0rEE1cJvFSgg2ogc/EDNwq3v+D4ff
y+E8nCrdvVY9n8fjneECHebhKOX/rbm2PU1sF9lXoU/pWoeTZ3Pf4XJG+gPm
DGu70OJq/AudcaYArcot4qv1y/xbnOWnBoUwx9ZJ4FOn5zgckD8+CRcDbQro
ZpaUcL85ooJ381QjdFzYb4LVcbYTnvjg1pJeQt0HbXSFHu6o3nnh/I00sd3m
D8Av5k8MNL9ca53hlN6v7ILW5j89cOCo3giL079ckM5+9MLwXCYE35ryLAy6
73yDR8pHiLFz1zdg/JKmCGtuHuIHOaOWFeLn3r1BhpN3+vYY1Eav0jA7/H4c
PlpKH0BJi+kfPD8qFoSwQx2UQquBfwUKIlrixOveerh6zEGk62raoHcq0AE9
pYe74U+RrAcWwkkdtFnkeuiMiYzw6/M3Jkg5ZA9grajpGdTaL9rhlpAm+lIJ
8Sxnv7pECt2sQgmTmSdEVXgzBV/EhjKwrOHhDpRXLBCptHUsgb/EDPE/rP9T
Jg==
  "],ExpressionUUID->"4e16f10f-33be-4462-bd1e-097879cd5e7a"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 3, $CellContext`cf1$$ = 3, $CellContext`update$$ =
   0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 
  1.9999999999989087`, $CellContext`ep$$ = 0, $CellContext`eb$$ = 
  0.45, $CellContext`fFeed$$ = 5, $CellContext`yt$$ = 
  0.9899999999999636, $CellContext`lc$$ = 90, $CellContext`db$$ = 
  2.5, $CellContext`plot1$$ = Text["No Results Yet"], $CellContext`plot2$$ = 
  Text["No Results Yet"], $CellContext`plot3$$ = Text["No Results Yet"]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Ideal Standing Wave Design Applied to the Langmuir \
Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "8a08174b-d923-4255-8b33-0cd823475494"],
       Text[
        Style[
        "Ideal Standing Wave Design Applied to the Langmuir Isotherm", Bold, 
         Large]]], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`fFeed$$], 
              Dynamic[$CellContext`fFeed$$], {0, 100}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`fFeed$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Flow Rate\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Feed Flow Rate", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`yt$$], 
              Dynamic[$CellContext`yt$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`yt$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Yield Target\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Yield Target", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`eb$$], 
              Dynamic[$CellContext`eb$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`eb$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Inter-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(b\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`ep$$], 
              Dynamic[$CellContext`ep$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`ep$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Intra-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(p\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`db$$], 
              Dynamic[$CellContext`db$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`db$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Diameter: \\!\\(\\*SubscriptBox[\\(d\\), \\(b\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`lc$$], 
              Dynamic[$CellContext`lc$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`lc$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(L\\), \\(c\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      ButtonBox["\<\"Generate Standing Wave Design Results\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = (Labeled[#, 
           Style["SWD Iterations History", Bold], Top]& )[
           $CellContext`doIdealSWD[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, $CellContext`cf1$$, \
$CellContext`cf2$$]]; $CellContext`plot2$$ = (Labeled[#, 
           Style[
           "SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
           Top]& )[
           Dataset[
            $CellContext`calculateMvalues[
             
             Last[$CellContext`csHist], $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`fFeed$$, \
$CellContext`yt$$]]]; $CellContext`plot3$$ = (Labeled[#, 
           Style["SWD Concentration Predictions", Bold], Top]& )[
           Dataset[
            Association[$CellContext`minorEstimates]]]; Null),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], 
      DynamicBox[ToBoxes[$CellContext`plot3$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.713223241383704*^9, 3.7132232896068115`*^9, 3.713223383218844*^9, 
   3.7132234661310496`*^9, 3.713223992065814*^9, 3.713224063571741*^9, {
   3.713362586351867*^9, 3.713362594576082*^9}, 3.7133628310622797`*^9, 
   3.7133632585342674`*^9, {3.713363781116953*^9, 3.713363849061535*^9}, {
   3.713363911329649*^9, 3.7133639955439067`*^9}, 3.713365362732664*^9, 
   3.7133671093565598`*^9, {3.7133671501463985`*^9, 3.7133671659828863`*^9}, 
   3.713368105071067*^9, {3.713368210996333*^9, 3.713368232770593*^9}, 
   3.713368417912986*^9, 3.7133685816867037`*^9, 3.713368613921942*^9, 
   3.7133687665096045`*^9, 3.713368824320736*^9, 3.7133688759322624`*^9, 
   3.713368965722555*^9, {3.713369003058175*^9, 3.7133690298689814`*^9}, {
   3.7133690659175253`*^9, 3.7133690945952635`*^9}, {3.7133691248880153`*^9, 
   3.7133691470626163`*^9}, 3.7133691917193623`*^9, {3.713369250604365*^9, 
   3.713369256374468*^9}, 3.7133693156829243`*^9, 3.713370304739688*^9, 
   3.713370493179987*^9, 3.713370558345594*^9, 3.7133709216459208`*^9, {
   3.713371005907857*^9, 3.713371026005542*^9}, 3.7133711258712177`*^9, 
   3.713371445391468*^9, 3.713371490601407*^9, 3.7133717676675353`*^9, 
   3.7133718202299795`*^9, 3.713371862636008*^9, {3.7133719900514994`*^9, 
   3.7133720078994675`*^9}, 3.713372054783559*^9, 3.713424372949809*^9, 
   3.713426137443293*^9, 3.7134264197804017`*^9, 3.713426502097022*^9, 
   3.71344124979888*^9, 3.713456371261146*^9, 3.7134644392546034`*^9, 
   3.71348409147023*^9, 3.713512131986988*^9, 3.7135178200462294`*^9, 
   3.713523141862564*^9, 3.713523505243774*^9, 3.7135285217992983`*^9, 
   3.713530169189493*^9, 
   3.7135308596448517`*^9},ExpressionUUID->"3a709bdf-7d5b-4fbb-b266-\
5b6cd6bb41f2"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 3, $CellContext`cf1$$ = 3, $CellContext`update$$ =
   0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 
  2.0000000000002274`, $CellContext`ep$$ = 0, $CellContext`eb$$ = 
  0.45, $CellContext`fFeed$$ = 5, $CellContext`yt$$ = 
  0.9900000000000091, $CellContext`lc$$ = 90, $CellContext`db$$ = 
  2.5, $CellContext`plot1$$ = Text["No Results Yet"], $CellContext`plot2$$ = 
  Text["No Results Yet"], $CellContext`plot3$$ = Text["No Results Yet"]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Ideal Standing Wave Design Applied to the Langmuir \
Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "8a764cd7-6ccd-4c1f-8c81-9969a775f8b3"],
       Text[
        Style[
        "Ideal Standing Wave Design Applied to the Langmuir Isotherm", Bold, 
         Large]]], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`fFeed$$], 
              Dynamic[$CellContext`fFeed$$], {0, 100}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`fFeed$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Flow Rate\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Feed Flow Rate", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`yt$$], 
              Dynamic[$CellContext`yt$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`yt$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Yield Target\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Yield Target", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`eb$$], 
              Dynamic[$CellContext`eb$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`eb$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Inter-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(b\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`ep$$], 
              Dynamic[$CellContext`ep$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`ep$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Intra-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(p\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`db$$], 
              Dynamic[$CellContext`db$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`db$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Diameter: \\!\\(\\*SubscriptBox[\\(d\\), \\(b\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`lc$$], 
              Dynamic[$CellContext`lc$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`lc$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(L\\), \\(c\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      ButtonBox["\<\"Generate Standing Wave Design Results\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = (Labeled[#, 
           Style["SWD Iterations History", Bold], Top]& )[
           $CellContext`doIdealSWD[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, $CellContext`cf1$$, \
$CellContext`cf2$$]]; $CellContext`plot2$$ = (Labeled[#, 
           Style[
           "SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
           Top]& )[
           Dataset[
            $CellContext`calculateMvalues[
             
             Last[$CellContext`csHist], $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`fFeed$$, \
$CellContext`yt$$]]]; $CellContext`plot3$$ = (Labeled[#, 
           Style["SWD Concentration Predictions", Bold], Top]& )[
           Dataset[
            Association[$CellContext`minorEstimates]]]; Null),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], 
      DynamicBox[ToBoxes[$CellContext`plot3$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.713223241383704*^9, 3.7132232896068115`*^9, 3.713223383218844*^9, 
   3.7132234661310496`*^9, 3.713223992065814*^9, 3.713224063571741*^9, {
   3.713362586351867*^9, 3.713362594576082*^9}, 3.7133628310622797`*^9, 
   3.7133632585342674`*^9, {3.713363781116953*^9, 3.713363849061535*^9}, {
   3.713363911329649*^9, 3.7133639955439067`*^9}, 3.713365362732664*^9, 
   3.7133671093565598`*^9, {3.7133671501463985`*^9, 3.7133671659828863`*^9}, 
   3.713368105071067*^9, {3.713368210996333*^9, 3.713368232770593*^9}, 
   3.713368417912986*^9, 3.7133685816867037`*^9, 3.713368613921942*^9, 
   3.7133687665096045`*^9, 3.713368824320736*^9, 3.7133688759322624`*^9, 
   3.713368965722555*^9, {3.713369003058175*^9, 3.7133690298689814`*^9}, {
   3.7133690659175253`*^9, 3.7133690945952635`*^9}, {3.7133691248880153`*^9, 
   3.7133691470626163`*^9}, 3.7133691917193623`*^9, {3.713369250604365*^9, 
   3.713369256374468*^9}, 3.7133693156829243`*^9, 3.713370304739688*^9, 
   3.713370493179987*^9, 3.713370558345594*^9, 3.7133709216459208`*^9, {
   3.713371005907857*^9, 3.713371026005542*^9}, 3.7133711258712177`*^9, 
   3.713371445391468*^9, 3.713371490601407*^9, 3.7133717676675353`*^9, 
   3.7133718202299795`*^9, 3.713371862636008*^9, {3.7133719900514994`*^9, 
   3.7133720078994675`*^9}, 3.713372054783559*^9, 3.713424372949809*^9, 
   3.713426137443293*^9, 3.7134264197804017`*^9, 3.713426502097022*^9, 
   3.71344124979888*^9, 3.713456371261146*^9, 3.7134644392546034`*^9, 
   3.71348409147023*^9, 3.713512131986988*^9, 3.7135178200462294`*^9, 
   3.713523141862564*^9, 3.713523505243774*^9, 3.7135285217992983`*^9, 
   3.713530169189493*^9},ExpressionUUID->"0f020d81-c372-4f80-90a3-\
807f98a5cbda"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-Ideal", "Subsection",
 CellChangeTimes->{{3.7134449520694275`*^9, 
  3.7134449561457386`*^9}},ExpressionUUID->"f1e0306f-d002-4074-9c0f-\
f85ddb68e7c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "=", "0.2"}], ",", 
     RowBox[{"b1", "=", "0.1"}], ",", 
     RowBox[{"cf2", "=", "3"}], ",", 
     RowBox[{"cf1", "=", "3"}], ",", 
     RowBox[{"update", "=", "0"}], ",", 
     RowBox[{"a1", "=", "1"}], ",", 
     RowBox[{"a2", "=", "2"}], ",", 
     RowBox[{"ep", "=", "0"}], ",", 
     RowBox[{"eb", "=", "0.45"}], ",", 
     RowBox[{"fFeed", "=", "5"}], ",", 
     RowBox[{"yt", "=", "0.99"}], ",", 
     RowBox[{"lc", "=", "90"}], ",", 
     RowBox[{"db", "=", "2.5"}], ",", 
     RowBox[{"effect", "=", "0.01"}], ",", 
     RowBox[{"kF1", "=", "0.01"}], ",", 
     RowBox[{"kF2", "=", "0.01"}], ",", 
     RowBox[{"pec1", "=", "500"}], ",", 
     RowBox[{"pec2", "=", "500"}], ",", 
     RowBox[{"plot1", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot2", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}], ",", 
     RowBox[{"plot3", "=", 
      RowBox[{"Text", "[", "\"\<No Results Yet\>\"", "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<Ideal Standing Wave Design Applied to the Langmuir Isotherm\>\
\"", ",", "Bold", ",", "Large"}], "]"}], "]"}], ",", "SpanFromLeft"}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"Dynamic", "[", "a2", "]"}]}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "a2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Dynamic", "[", "a1", "]"}], ",", "30"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "b2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \
\(2\)]\)\>\"", ",", 
            "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)\>\"", 
            ",", "\"\<Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \
\(2\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "cf2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "10"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "fFeed", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "yt", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Feed Concentration 1\>\"", ",", 
            "\"\<Feed Concentration 2\>\"", ",", "\"\<Feed Flow Rate\>\"", 
            ",", "\"\<Yield Target\>\""}], "}"}]}], ",", 
         "\[IndentingNewLine]", "List"}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "eb", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "ep", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "db", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "lc", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "100"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \
\(b\)]\)\>\"", ",", 
            "\"\<Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\
\)]\)\>\"", ",", "\"\<Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)\>\"", 
            ",", "\"\<Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)\>\""}], 
           "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Inner", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Labeled", "[", 
           RowBox[{"#1", ",", "#2", ",", "Top"}], "]"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "kF2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "5"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "kF2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "5"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "pec1", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1000"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Manipulator", "[", 
            RowBox[{
             RowBox[{"Dynamic", "[", "pec2", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1000"}], "}"}], ",", 
             RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}], ",", 
             RowBox[{"AppearanceElements", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<InputField\>\"", ",", "\"\<StepLeftButton\>\"", ",", 
                "\"\<StepRightButton\>\""}], "}"}]}], ",", 
             RowBox[{"ContinuousAction", "\[Rule]", "True"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "Bold"}], "]"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \
\(A\)]\)\>\"", ",", 
            "\"\<Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \(B\)]\)\
\>\"", ",", "\"\<Peclet Number: \!\(\*SubscriptBox[\(Pe\), \(A\)]\)\>\"", 
            ",", "\"\<Bed Length: \!\(\*SubscriptBox[\(Pe\), \(B\)]\)\>\""}], 
           "}"}]}], ",", "\[IndentingNewLine]", "List"}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Button", "[", 
          RowBox[{
          "\"\<Generate Standing Wave Design Results\>\"", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"plot1", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{"\"\<SWD Iterations History\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"doIdealSWD", "[", 
               RowBox[{
               "a1", ",", "a2", ",", "b1", ",", "b2", ",", "yt", ",", "cf1", 
                ",", "cf2"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"plot2", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions\
\>\"", ",", "Bold"}], "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"calculateMvalues", "[", 
                RowBox[{
                 RowBox[{"Last", "[", "csHist", "]"}], ",", "ep", ",", "eb", 
                 ",", "lc", ",", "db", ",", "fFeed", ",", "yt"}], "]"}]}]}]}],
             ";", "\[IndentingNewLine]", 
            RowBox[{"plot3", "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Labeled", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "\"\<SWD Concentration Predictions\>\"", ",", "Bold"}], 
                  "]"}], ",", "Top"}], "]"}], "&"}], "@", 
              RowBox[{"Dataset", "@", 
               RowBox[{"Association", "@", "minorEstimates"}]}]}]}], ";"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}], ",", 
         "\[IndentingNewLine]", "SpanFromLeft"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Dynamic", "[", "plot1", "]"}], ",", "SpanFromLeft", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Dynamic", "[", "plot2", "]"}], ",", 
         RowBox[{"Dynamic", "[", "plot3", "]"}]}], "\[IndentingNewLine]", 
        "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "2"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0V9IU3EcBfAxzPRhluG03INFqTXNBeIsrVAICcwxR/6bqGUM75RyDito
KVuiybxltJIRm8XQpTK9OuWilT4M0bEGlaC7KpogTKKHVKQUnHnP7+HL5+Vw
Hs73THW9SiMUCASp/EGrvsVDDfzOvbnVTSwWWWZhn8y+CN+kBlfhNCf5CYM1
8zvQYC/YgzYfE4JG2Saxa/G6UMsbc64pEgbZjHhosvUkwEbp07Pwi6soBTqY
KRncVU7K4YMNqgBar+wq4HkfWwZPTzjUJOfPugvNdJwGbss/OuF4aYBYbB5w
wR/6bwzUv5pXDfJKGk6WQ6PyXyVsjNXUwYPuX3ZIr3x1QvcoNww/6DZYOOS4
vwyPx7QSvZm316DvWu4BTLtzRDjE6zHMEL9X/W1ieAWJte1Q7cmj4UpLfyd8
PBXYh/GFuv/wcps4fBg91H40NNYIc2D4pJr4+l3VDTh7ykqkM9KKoPOtqwT2
RB+rgOui5EoYcs9VQ7NBqoE2r6gOLnW810HKmvwQXhIpnkO1JdsCNyNpYt+C
XzzCey/rqAQ62BQZnOOaiXL3nwX4wvuMgyfyH21DadwnIhUwtvuxl5ghvmwN
o5fw7wkTUdmrZeHe+IXPsDkz4uIy76o9SNSLE9Ph2Jr2KlQkmXJgflvULdjJ
cSoYesKWwkNdB4pI
  "],ExpressionUUID->"befc9bf3-ca23-48dc-b232-7e728feae633"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 3, $CellContext`cf1$$ = 3, $CellContext`update$$ =
   0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 2, $CellContext`ep$$ = 
  0, $CellContext`eb$$ = 0.45, $CellContext`fFeed$$ = 5, $CellContext`yt$$ = 
  0.99, $CellContext`lc$$ = 90, $CellContext`db$$ = 
  2.5, $CellContext`effect$$ = 0.01, $CellContext`kF1$$ = 
  0.01, $CellContext`kF2$$ = 0.01, $CellContext`pec1$$ = 
  500, $CellContext`pec2$$ = 500, $CellContext`plot1$$ = Text[
  "No Results Yet"], $CellContext`plot2$$ = Text[
  "No Results Yet"], $CellContext`plot3$$ = Text["No Results Yet"]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Ideal Standing Wave Design Applied to the Langmuir \
Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "01426997-38e2-44f4-a54f-6d400780a157"],
       Text[
        Style[
        "Ideal Standing Wave Design Applied to the Langmuir Isotherm", Bold, 
         Large]]], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`fFeed$$], 
              Dynamic[$CellContext`fFeed$$], {0, 100}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`fFeed$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Flow Rate\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Feed Flow Rate", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`yt$$], 
              Dynamic[$CellContext`yt$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`yt$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Yield Target\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Yield Target", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`eb$$], 
              Dynamic[$CellContext`eb$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`eb$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Inter-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(b\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`ep$$], 
              Dynamic[$CellContext`ep$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`ep$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Intra-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(p\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`db$$], 
              Dynamic[$CellContext`db$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`db$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Diameter: \\!\\(\\*SubscriptBox[\\(d\\), \\(b\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`lc$$], 
              Dynamic[$CellContext`lc$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`lc$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(L\\), \\(c\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`kF2$$], 
              Dynamic[$CellContext`kF2$$], {0, 5}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`kF2$$], {0, 5}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Effective Mass Transfer: \\!\\(\\*SubscriptBox[\\(Kf\\), \
\\(A\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \(A\)]\)", 
           Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`kF2$$], 
              Dynamic[$CellContext`kF2$$], {0, 5}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`kF2$$], {0, 5}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Effective Mass Transfer: \\!\\(\\*SubscriptBox[\\(Kf\\), \
\\(B\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \(B\)]\)", 
           Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`pec1$$], 
              Dynamic[$CellContext`pec1$$], {0, 1000}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`pec1$$], {0, 1000}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Peclet Number: \\!\\(\\*SubscriptBox[\\(Pe\\), \\(A\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Peclet Number: \!\(\*SubscriptBox[\(Pe\), \(A\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`pec2$$], 
              Dynamic[$CellContext`pec2$$], {0, 1000}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`pec2$$], {0, 1000}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(Pe\\), \\(B\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(Pe\), \(B\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      ButtonBox["\<\"Generate Standing Wave Design Results\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = (Labeled[#, 
           Style["SWD Iterations History", Bold], Top]& )[
           $CellContext`doIdealSWD[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, $CellContext`cf1$$, \
$CellContext`cf2$$]]; $CellContext`plot2$$ = (Labeled[#, 
           Style[
           "SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
           Top]& )[
           Dataset[
            $CellContext`calculateMvalues[
             
             Last[$CellContext`csHist], $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`fFeed$$, \
$CellContext`yt$$]]]; $CellContext`plot3$$ = (Labeled[#, 
           Style["SWD Concentration Predictions", Bold], Top]& )[
           Dataset[
            Association[$CellContext`minorEstimates]]]; Null),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], 
      DynamicBox[ToBoxes[$CellContext`plot3$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.713223241383704*^9, 3.7132232896068115`*^9, 3.713223383218844*^9, 
   3.7132234661310496`*^9, 3.713223992065814*^9, 3.713224063571741*^9, {
   3.713362586351867*^9, 3.713362594576082*^9}, 3.7133628310622797`*^9, 
   3.7133632585342674`*^9, {3.713363781116953*^9, 3.713363849061535*^9}, {
   3.713363911329649*^9, 3.7133639955439067`*^9}, 3.713365362732664*^9, 
   3.7133671093565598`*^9, {3.7133671501463985`*^9, 3.7133671659828863`*^9}, 
   3.713368105071067*^9, {3.713368210996333*^9, 3.713368232770593*^9}, 
   3.713368417912986*^9, 3.7133685816867037`*^9, 3.713368613921942*^9, 
   3.7133687665096045`*^9, 3.713368824320736*^9, 3.7133688759322624`*^9, 
   3.713368965722555*^9, {3.713369003058175*^9, 3.7133690298689814`*^9}, {
   3.7133690659175253`*^9, 3.7133690945952635`*^9}, {3.7133691248880153`*^9, 
   3.7133691470626163`*^9}, 3.7133691917193623`*^9, {3.713369250604365*^9, 
   3.713369256374468*^9}, 3.7133693156829243`*^9, 3.713370304739688*^9, 
   3.713370493179987*^9, 3.713370558345594*^9, 3.7133709216459208`*^9, {
   3.713371005907857*^9, 3.713371026005542*^9}, 3.7133711258712177`*^9, 
   3.713371445391468*^9, 3.713371490601407*^9, 3.7133717676675353`*^9, 
   3.7133718202299795`*^9, 3.713371862636008*^9, {3.7133719900514994`*^9, 
   3.7133720078994675`*^9}, 3.713372054783559*^9, 3.713424372949809*^9, 
   3.713426137443293*^9, 3.7134264197804017`*^9, 3.713426502097022*^9, 
   3.71344124979888*^9, 3.713455519084379*^9, 3.7134563713136435`*^9, 
   3.71345685247747*^9, 3.7134644392976136`*^9, 3.713484091619297*^9, 
   3.713512132035987*^9, 3.713517820136238*^9, 3.713523141915944*^9, 
   3.7135235053232727`*^9, 3.7135285218461924`*^9, 3.7135301693854856`*^9, 
   3.713530859773367*^9},ExpressionUUID->"f231721a-1a74-4316-a211-\
586df8570d7d"],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`b2$$ = 0.2, $CellContext`b1$$ = 
  0.1, $CellContext`cf2$$ = 3, $CellContext`cf1$$ = 3, $CellContext`update$$ =
   0, $CellContext`a1$$ = 1, $CellContext`a2$$ = 
  2.0000000000002274`, $CellContext`ep$$ = 0, $CellContext`eb$$ = 
  0.45, $CellContext`fFeed$$ = 5, $CellContext`yt$$ = 
  0.9900000000000091, $CellContext`lc$$ = 90, $CellContext`db$$ = 
  2.5, $CellContext`effect$$ = 0.01, $CellContext`kF1$$ = 
  0.01, $CellContext`kF2$$ = 0.01, $CellContext`pec1$$ = 
  500, $CellContext`pec2$$ = 500, $CellContext`plot1$$ = Text[
  "No Results Yet"], $CellContext`plot2$$ = Text[
  "No Results Yet"], $CellContext`plot3$$ = Text["No Results Yet"]}, 
  TagBox[GridBox[{
     {
      InterpretationBox[Cell[BoxData[
        FormBox[
         StyleBox["\<\"Ideal Standing Wave Design Applied to the Langmuir \
Isotherm\"\>",
          StripOnInput->False,
          FontSize->Large,
          FontWeight->Bold], TextForm]], "InlineText",ExpressionUUID->
        "6c55568b-e84a-40ab-a06d-6e16b37a91e8"],
       Text[
        Style[
        "Ideal Standing Wave Design Applied to the Langmuir Isotherm", Bold, 
         Large]]], "\[SpanFromLeft]", "\[SpanFromLeft]", "\[SpanFromLeft]"},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a1$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a1$$, {
                0, $CellContext`a2$$}], 
               BoxForm`RemapValue[#, $CellContext`a1$$, {
                0, $CellContext`a2$$}]& ], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a1$$, {0, $CellContext`a2$$}], 
           BoxForm`RemapValue[#, $CellContext`a1$$, {
            0, $CellContext`a2$$}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`a2$$], 
              Dynamic[
               
               BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 
                 30}], BoxForm`RemapValue[#, $CellContext`a2$$, \
{$CellContext`a1$$, 30}]& ], {0, 1}, Medium, Small, Automatic, True, 
              Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[
           BoxForm`RemapVariable[$CellContext`a2$$, {$CellContext`a1$$, 30}], 
           BoxForm`RemapValue[#, $CellContext`a2$$, {$CellContext`a1$$, 
             30}]& ], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(a\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b1$$], 
              Dynamic[$CellContext`b1$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b1$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(1\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(1\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`b2$$], 
              Dynamic[$CellContext`b2$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`b2$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Isotherm Parameter: \\!\\(\\*SubscriptBox[\\(b\\), \\(2\\)]\\)\
\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Isotherm Parameter: \!\(\*SubscriptBox[\(b\), \(2\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf1$$], 
              Dynamic[$CellContext`cf1$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf1$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 1\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 1", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`cf2$$], 
              Dynamic[$CellContext`cf2$$], {0, 10}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`cf2$$], {0, 10}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Concentration 2\"", Bold, StripOnInput -> False],
             TextForm]], "InlineText"], 
         Text[
          Style["Feed Concentration 2", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`fFeed$$], 
              Dynamic[$CellContext`fFeed$$], {0, 100}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`fFeed$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Feed Flow Rate\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Feed Flow Rate", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`yt$$], 
              Dynamic[$CellContext`yt$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`yt$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Yield Target\"", Bold, StripOnInput -> False], 
            TextForm]], "InlineText"], 
         Text[
          Style["Yield Target", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`eb$$], 
              Dynamic[$CellContext`eb$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`eb$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Inter-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(b\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Inter-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(b\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`ep$$], 
              Dynamic[$CellContext`ep$$], {0, 1}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`ep$$], {0, 1}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Intra-particle Voids: \\!\\(\\*SubscriptBox[\\(\[Epsilon]\\), \
\\(p\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Intra-particle Voids: \!\(\*SubscriptBox[\(\[Epsilon]\), \(p\)]\)",
            Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`db$$], 
              Dynamic[$CellContext`db$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`db$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Diameter: \\!\\(\\*SubscriptBox[\\(d\\), \\(b\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Diameter: \!\(\*SubscriptBox[\(d\), \(b\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`lc$$], 
              Dynamic[$CellContext`lc$$], {0, 100}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`lc$$], {0, 100}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(L\\), \\(c\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(L\), \(c\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`kF2$$], 
              Dynamic[$CellContext`kF2$$], {0, 5}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`kF2$$], {0, 5}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Effective Mass Transfer: \\!\\(\\*SubscriptBox[\\(Kf\\), \
\\(A\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \(A\)]\)", 
           Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`kF2$$], 
              Dynamic[$CellContext`kF2$$], {0, 5}, Medium, Small, Automatic, 
              True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`kF2$$], {0, 5}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Effective Mass Transfer: \\!\\(\\*SubscriptBox[\\(Kf\\), \
\\(B\\)]\\)\"", Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style[
          "Effective Mass Transfer: \!\(\*SubscriptBox[\(Kf\), \(B\)]\)", 
           Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`pec1$$], 
              Dynamic[$CellContext`pec1$$], {0, 1000}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`pec1$$], {0, 1000}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Peclet Number: \\!\\(\\*SubscriptBox[\\(Pe\\), \\(A\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Peclet Number: \!\(\*SubscriptBox[\(Pe\), \(A\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )], 
      TemplateBox[{TagBox[
         PaneBox[
          
          DynamicModuleBox[{
           Typeset`open$$ = True, Typeset`paused$$ = Automatic, 
            Typeset`running$$ = False, Typeset`index$$ = Automatic, 
            Typeset`rate$$ = Automatic, Typeset`dir$$ = Forward}, 
           StyleBox[
            DynamicBox[
             FEPrivate`FrontEndResource["FEExpressions", "Manipulator06"][
              Dynamic[$CellContext`pec2$$], 
              Dynamic[$CellContext`pec2$$], {0, 1000}, Medium, Small, 
              Automatic, True, Automatic, False, True, True, {
              "StepLeftButton", "StepRightButton"}, False, {}, 
              Dynamic[Typeset`open$$], 
              Dynamic[Typeset`running$$], 
              Dynamic[Typeset`index$$], 
              Dynamic[Typeset`rate$$], 
              Dynamic[Typeset`dir$$]], ImageSizeCache -> {279., {41., 16.}}], 
            DynamicUpdating -> True], DynamicModuleValues :> {}], 
          BaselinePosition -> Baseline, ImageMargins -> 0], 
         Manipulate`InterpretManipulator[
          Dynamic[$CellContext`pec2$$], {0, 1000}, {
          Appearance -> "Open", 
           AppearanceElements -> {
            "InputField", "StepLeftButton", "StepRightButton"}, 
           ContinuousAction -> True}]],InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox[
            "\"Bed Length: \\!\\(\\*SubscriptBox[\\(Pe\\), \\(B\\)]\\)\"", 
             Bold, StripOnInput -> False], TextForm]], "InlineText"], 
         Text[
          Style["Bed Length: \!\(\*SubscriptBox[\(Pe\), \(B\)]\)", Bold]]]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {2, 1}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
     {
      ButtonBox["\<\"Generate Standing Wave Design Results\"\>",
       Appearance->Automatic,
       ButtonFunction:>($CellContext`plot1$$ = (Labeled[#, 
           Style["SWD Iterations History", Bold], Top]& )[
           $CellContext`doIdealSWD[$CellContext`a1$$, $CellContext`a2$$, \
$CellContext`b1$$, $CellContext`b2$$, $CellContext`yt$$, $CellContext`cf1$$, \
$CellContext`cf2$$]]; $CellContext`plot2$$ = (Labeled[#, 
           Style[
           "SWD \!\(\*SubscriptBox[\(M\), \(value\)]\) Predictions", Bold], 
           Top]& )[
           Dataset[
            $CellContext`calculateMvalues[
             
             Last[$CellContext`csHist], $CellContext`ep$$, $CellContext`eb$$, \
$CellContext`lc$$, $CellContext`db$$, $CellContext`fFeed$$, \
$CellContext`yt$$]]]; $CellContext`plot3$$ = (Labeled[#, 
           Style["SWD Concentration Predictions", Bold], Top]& )[
           Dataset[
            Association[$CellContext`minorEstimates]]]; Null),
       Evaluator->Automatic,
       Method->"Queued"], "\[SpanFromLeft]", "\[SpanFromLeft]", 
      "\[SpanFromLeft]"},
     {
      DynamicBox[ToBoxes[$CellContext`plot1$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], "\[SpanFromLeft]", 
      DynamicBox[ToBoxes[$CellContext`plot2$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}], 
      DynamicBox[ToBoxes[$CellContext`plot3$$, StandardForm],
       ImageSizeCache->{107., {4., 15.}}]}
    },
    AutoDelete->False,
    GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{2}}}],
   "Grid"],
  DynamicModuleValues:>{}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.713223241383704*^9, 3.7132232896068115`*^9, 3.713223383218844*^9, 
   3.7132234661310496`*^9, 3.713223992065814*^9, 3.713224063571741*^9, {
   3.713362586351867*^9, 3.713362594576082*^9}, 3.7133628310622797`*^9, 
   3.7133632585342674`*^9, {3.713363781116953*^9, 3.713363849061535*^9}, {
   3.713363911329649*^9, 3.7133639955439067`*^9}, 3.713365362732664*^9, 
   3.7133671093565598`*^9, {3.7133671501463985`*^9, 3.7133671659828863`*^9}, 
   3.713368105071067*^9, {3.713368210996333*^9, 3.713368232770593*^9}, 
   3.713368417912986*^9, 3.7133685816867037`*^9, 3.713368613921942*^9, 
   3.7133687665096045`*^9, 3.713368824320736*^9, 3.7133688759322624`*^9, 
   3.713368965722555*^9, {3.713369003058175*^9, 3.7133690298689814`*^9}, {
   3.7133690659175253`*^9, 3.7133690945952635`*^9}, {3.7133691248880153`*^9, 
   3.7133691470626163`*^9}, 3.7133691917193623`*^9, {3.713369250604365*^9, 
   3.713369256374468*^9}, 3.7133693156829243`*^9, 3.713370304739688*^9, 
   3.713370493179987*^9, 3.713370558345594*^9, 3.7133709216459208`*^9, {
   3.713371005907857*^9, 3.713371026005542*^9}, 3.7133711258712177`*^9, 
   3.713371445391468*^9, 3.713371490601407*^9, 3.7133717676675353`*^9, 
   3.7133718202299795`*^9, 3.713371862636008*^9, {3.7133719900514994`*^9, 
   3.7133720078994675`*^9}, 3.713372054783559*^9, 3.713424372949809*^9, 
   3.713426137443293*^9, 3.7134264197804017`*^9, 3.713426502097022*^9, 
   3.71344124979888*^9, 3.713455519084379*^9, 3.7134563713136435`*^9, 
   3.71345685247747*^9, 3.7134644392976136`*^9, 3.713484091619297*^9, 
   3.713512132035987*^9, 3.713517820136238*^9, 3.713523141915944*^9, 
   3.7135235053232727`*^9, 3.7135285218461924`*^9, 
   3.7135301693854856`*^9},ExpressionUUID->"a3777f03-79c5-4c1d-ae4e-\
6ca6f1b24180"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1039, 1021},
WindowMargins->{{94, Automatic}, {Automatic, 70}},
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "d1" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"I\""], "d2" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"II\""], "d3" -> 
  SubsuperscriptBox["\[Delta]", "B", "\"III\""], "d4" -> 
  SubsuperscriptBox["\[Delta]", "A", "\"IV\""], "b1" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"I\""], "b2" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"II\""], "b3" -> 
  SubsuperscriptBox["\[Beta]", "B", "\"III\""], "b4" -> 
  SubsuperscriptBox["\[Beta]", "A", "\"IV\""], "u1" -> 
  SubsuperscriptBox["u", "0", "\"I\""], "u2" -> 
  SubsuperscriptBox["u", "0", "\"II\""], "u3" -> 
  SubsuperscriptBox["u", "0", "\"III\""], "u4" -> 
  SubsuperscriptBox["u", "0", "\"IV\""], "kf1" -> 
  SubsuperscriptBox["Kf", "B", "\"I\""], "kf2" -> 
  SubsuperscriptBox["Kf", "A", "\"II\""], "kf3" -> 
  SubsuperscriptBox["Kf", "B", "\"III\""], "kf4" -> 
  SubsuperscriptBox["Kf", "A", "\"IV\""], "e1" -> 
  SubsuperscriptBox["E", "B", "\"I\""], "e2" -> 
  SubsuperscriptBox["E", "A", "\"II\""], "e3" -> 
  SubsuperscriptBox["E", "B", "\"III\""], "e4" -> 
  SubsuperscriptBox["E", "A", "\"IV\""], "ep" -> 
  SubscriptBox["\[Epsilon]", "p"], "eb" -> SubscriptBox["\[Epsilon]", "b"], 
  "et" -> SubscriptBox["\[Epsilon]", "t"], "feed" -> 
  SubscriptBox["f", "\"F\""], "des" -> SubscriptBox["f", "des"], "ext" -> 
  SubscriptBox["f", "ext"], "cf1" -> SubsuperscriptBox["c", "1", "\"F\""], 
  "cf2" -> SubsuperscriptBox["c", "2", "\"F\""]},
Magnification:>1.3 Inherited,
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (March 13, 2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData["Inactive"], FontFamily -> "Segoe UI", FontSize -> 12, 
    FontWeight -> "Bold", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}, 
    FontColor -> GrayLevel[0], Background -> None]}, WindowSize -> {775, 872},
   WindowMargins -> {{Automatic, 458}, {51, Automatic}}, Visible -> False, 
  FrontEndVersion -> "11.1 for Microsoft Windows (64-bit) (March 13, 2017)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 231, 4, 129, "Title", "ExpressionUUID" -> \
"844850aa-9b17-4736-b88b-edee74b5a5c1"],
Cell[CellGroupData[{
Cell[836, 30, 182, 3, 93, "Section", "ExpressionUUID" -> \
"6ad0c834-3786-49ca-8c6e-49dc4a403272"],
Cell[1021, 35, 2534, 58, 358, "Text", "ExpressionUUID" -> \
"2bf8674c-22d7-48be-a4b4-a17d6fe121fa"],
Cell[3558, 95, 640, 13, 141, "Text", "ExpressionUUID" -> \
"a4842942-5915-4947-a38b-7bab8dc954cb"],
Cell[CellGroupData[{
Cell[4223, 112, 380, 10, 119, "Input", "ExpressionUUID" -> \
"31ff04fb-efe9-46a5-9cdb-9866d4f26fb7"],
Cell[4606, 124, 881, 13, 70, "Output", "ExpressionUUID" -> \
"61d7a354-ff8c-4af8-9599-3913c9ada6bb"]
}, Open  ]],
Cell[5502, 140, 514, 14, 87, "Text", "ExpressionUUID" -> \
"6a5bec25-ed4c-49f9-a3a0-688786f20791"],
Cell[6019, 156, 638, 13, 193, "Text", "ExpressionUUID" -> \
"ce8d7095-8cdd-479f-877b-cb8d3f7d0e2c"],
Cell[6660, 171, 661, 10, 109, "Input", "ExpressionUUID" -> \
"753256b4-6e1d-468c-ad8a-fdcf82663ed3"],
Cell[7324, 183, 1977, 49, 871, "Input", "ExpressionUUID" -> \
"7042c0e2-f205-4e61-b221-d58a2695e0b2"],
Cell[9304, 234, 756, 17, 244, "Input", "ExpressionUUID" -> \
"2e3eaca9-003f-498d-a5ad-547a6651af32"],
Cell[10063, 253, 482, 10, 243, "Input", "ExpressionUUID" -> \
"3c2b4174-b203-4c59-afa5-a9632798d46c"],
Cell[10548, 265, 1228, 32, 234, "Input", "ExpressionUUID" -> \
"2862fd36-9b07-4478-8a93-3a361d833b65"],
Cell[11779, 299, 485, 13, 243, "Input", "ExpressionUUID" -> \
"c4c7dd47-9c82-43a2-8c20-a1a5478f4314"],
Cell[12267, 314, 945, 24, 317, "Input", "ExpressionUUID" -> \
"b470a06a-10a3-434f-a03c-1e516abcd31a"],
Cell[CellGroupData[{
Cell[13237, 342, 1347, 34, 211, "Input", "ExpressionUUID" -> \
"1fe50f99-d266-49ac-83ef-0535743be926"],
Cell[14587, 378, 5438, 148, 70, "Output", "ExpressionUUID" -> \
"5c88a8f8-b0a0-4e6e-bf26-eaaa0c4c8dc0"]
}, Open  ]],
Cell[20040, 529, 978, 24, 330, "Input", "ExpressionUUID" -> \
"57e36cee-859e-4dd0-8581-44b85880fbac"],
Cell[21021, 555, 960, 17, 87, "Text", "ExpressionUUID" -> \
"ea4eab23-80f8-4522-8c9d-17b2273eb400"],
Cell[21984, 574, 4388, 97, 514, "Input", "ExpressionUUID" -> \
"f014b37e-ddd0-4c98-b55b-c9de9e14a7d0"],
Cell[26375, 673, 1939, 40, 812, "Input", "ExpressionUUID" -> \
"7963f2ec-b0be-4a9b-ba4f-ea2d7bd41829"]
}, Closed]],
Cell[CellGroupData[{
Cell[28351, 718, 177, 3, 74, "Section", "ExpressionUUID" -> \
"fbad123e-f232-43e4-a632-1764d9911915"],
Cell[CellGroupData[{
Cell[28553, 725, 168, 3, 45, "Subsection", "ExpressionUUID" -> \
"9311c4a2-af03-44b9-993e-e6e5cacb3469"],
Cell[CellGroupData[{
Cell[28746, 732, 1149, 34, 126, "Input", "ExpressionUUID" -> \
"ccdd7964-9bd6-45f6-9b11-135d47b574b2"],
Cell[29898, 768, 1631, 41, 70, "Output", "ExpressionUUID" -> \
"ee17a179-c857-4a20-8fa1-404b3346c7fe"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31578, 815, 227, 4, 44, "Subsection", "ExpressionUUID" -> \
"7c0bb7a8-6a00-47bc-95bc-07d51c967bc7"],
Cell[CellGroupData[{
Cell[31830, 823, 356, 10, 84, "Input", "ExpressionUUID" -> \
"79175476-39ed-46d3-8fdf-476691d4723b"],
Cell[32189, 835, 978, 17, 70, "Output", "ExpressionUUID" -> \
"fc80d709-fb83-4f8f-b14d-6daa64bee7c3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[33216, 858, 182, 3, 44, "Subsection", "ExpressionUUID" -> \
"fdf84075-ee7c-4281-b4c4-dd3056608ccb"],
Cell[CellGroupData[{
Cell[33423, 865, 930, 23, 78, "Input", "ExpressionUUID" -> \
"2496b2eb-cb92-43d7-92fb-f7fea3875b76"],
Cell[34356, 890, 1283, 36, 70, "Output", "ExpressionUUID" -> \
"a1abd4f8-42d7-41c0-bb5a-5e1e75964218"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[35688, 932, 178, 3, 44, "Subsection", "ExpressionUUID" -> \
"6ebc7b3f-4527-447b-aefc-5fb069e8da14"],
Cell[CellGroupData[{
Cell[35891, 939, 156, 3, 44, "Subsubsection", "ExpressionUUID" -> \
"88fbb788-9616-4ea3-9363-155602c97d75"],
Cell[CellGroupData[{
Cell[36072, 946, 2536, 69, 263, "Input", "ExpressionUUID" -> \
"41f7307d-2bc3-47ca-a69c-27d608836603"],
Cell[38611, 1017, 2663, 69, 70, "Output", "ExpressionUUID" -> \
"755f569b-0dd0-4e20-a426-dd6d6068e43c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[41323, 1092, 162, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"6d3f297d-4d10-4114-bdf0-bc82d5f7699c"],
Cell[CellGroupData[{
Cell[41510, 1099, 3445, 90, 300, "Input", "ExpressionUUID" -> \
"39ae7b36-ee99-4442-a493-1f049848ef44"],
Cell[44958, 1191, 3541, 97, 70, "Output", "ExpressionUUID" -> \
"31a9b6a2-a270-419d-9843-16c11e655b95"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48560, 1295, 227, 4, 45, "Subsection", "ExpressionUUID" -> \
"bf6e2d63-c652-474e-9782-f0669108fecb"],
Cell[CellGroupData[{
Cell[48812, 1303, 1598, 39, 329, "Input", "ExpressionUUID" -> \
"b86cef38-423f-4521-9f25-eb02c793ad63"],
Cell[50413, 1344, 1843, 39, 70, "Output", "ExpressionUUID" -> \
"180acdfc-2dfe-48cf-8b40-23bc50e8260f"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[52305, 1389, 174, 3, 44, "Subsection", "ExpressionUUID" -> \
"51b0cee2-24ea-416a-bf1d-a264d38fe076"],
Cell[CellGroupData[{
Cell[52504, 1396, 226, 4, 44, "Subsubsection", "ExpressionUUID" -> \
"f9186d00-3e84-4971-a41d-a39de914c47d"],
Cell[CellGroupData[{
Cell[52755, 1404, 908, 28, 55, "Input", "ExpressionUUID" -> \
"13c03c34-db2e-4b15-99d7-c981246d2400"],
Cell[53666, 1434, 2880, 98, 77, "Output", "ExpressionUUID" -> \
"8e1b2549-8336-4cec-8017-d1ffa67a46fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56583, 1537, 651, 19, 50, "Input", "ExpressionUUID" -> \
"15b92b42-536a-42a4-b2a1-40be6dea754c"],
Cell[57237, 1558, 1544, 37, 50, "Output", "ExpressionUUID" -> \
"0918e5ca-5439-4056-b3d7-f3ac431d5e28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58818, 1600, 363, 8, 50, "Input", "ExpressionUUID" -> \
"2fb05ade-ed7a-40f6-a5db-25621532eb2d"],
Cell[59184, 1610, 3802, 101, 171, "Output", "ExpressionUUID" -> \
"d1f72c43-d04e-4689-92c9-deb623154756"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63023, 1716, 605, 15, 50, "Input", "ExpressionUUID" -> \
"7e45159a-1bf2-4dd3-b327-98fd836cd0df"],
Cell[63631, 1733, 3706, 101, 171, "Output", "ExpressionUUID" -> \
"b4ed1a92-4347-4f44-a656-1afc9341cd75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67374, 1839, 781, 24, 75, "Input", "ExpressionUUID" -> \
"09c3c0af-9d6e-4bc8-a253-88526c0a1648"],
Cell[68158, 1865, 3377, 93, 171, "Output", "ExpressionUUID" -> \
"3c2457b8-222f-4aa7-a21a-5cc5f8a33449"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71584, 1964, 182, 3, 44, "Subsubsection", "ExpressionUUID" -> \
"61eeb5f9-6911-4dd5-ad1b-d56b502d598b"],
Cell[CellGroupData[{
Cell[71791, 1971, 1315, 37, 88, "Input", "ExpressionUUID" -> \
"13250e18-e1ba-4eb2-b53b-2dbe4b58f52e"],
Cell[73109, 2010, 1823, 44, 70, "Output", "ExpressionUUID" -> \
"751a4151-9f6e-4925-8e75-149f462a817e"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75005, 2062, 201, 3, 93, "Section", "ExpressionUUID" -> \
"695d6c6f-f6c9-46ed-815d-e8871cf86a4a"],
Cell[CellGroupData[{
Cell[75231, 2069, 168, 3, 45, "Subsection", "ExpressionUUID" -> \
"5172c932-e47a-4486-a0ff-dfcadcc49da0"],
Cell[CellGroupData[{
Cell[75424, 2076, 170, 3, 44, "Subsubsection", "ExpressionUUID" -> \
"ce176f91-73e2-4eb9-8ef4-05267dc137dd"],
Cell[CellGroupData[{
Cell[75619, 2083, 1148, 28, 55, "Input", "ExpressionUUID" -> \
"29347fbb-6e56-44c5-be8e-d6eacb287965"],
Cell[76770, 2113, 2554, 63, 70, "Output", "ExpressionUUID" -> \
"7dd1f616-5ebf-47d1-be23-3a09b250accb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79361, 2181, 4077, 112, 359, "Input", "ExpressionUUID" -> \
"6d54e71e-3ed1-489e-9f46-a835ef9b0a52"],
Cell[83441, 2295, 5586, 143, 70, "Output", "ExpressionUUID" -> \
"93cb44c0-62fa-44c6-a3d8-f9bce58d1d92"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[89076, 2444, 168, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"d35a9e0f-7c73-408a-bd34-07090091fc05"],
Cell[CellGroupData[{
Cell[89269, 2451, 377, 7, 50, "Input", "ExpressionUUID" -> \
"92dd5b59-e768-4aab-8bac-dfdf8e887954"],
Cell[89649, 2460, 1766, 39, 70, "Output", "ExpressionUUID" -> \
"4ff99d19-f38b-4549-8d52-a5fe9d4ae932"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[91464, 2505, 168, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"255b9df0-941d-4ff4-bbb7-eaabdaf88d7b"],
Cell[CellGroupData[{
Cell[91657, 2512, 1313, 30, 179, "Input", "ExpressionUUID" -> \
"8a5b69ec-4f79-4b2a-a1da-54d803409d35"],
Cell[92973, 2544, 2140, 50, 70, "Output", "ExpressionUUID" -> \
"089f158a-834c-44a7-af96-ea5688bc99bf"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[95174, 2601, 173, 3, 45, "Subsection", "ExpressionUUID" -> \
"88b83633-23e0-4b1b-ab42-149be343168a"],
Cell[CellGroupData[{
Cell[95372, 2608, 234, 4, 44, "Subsubsection", "ExpressionUUID" -> \
"c022f656-06d6-4a6d-a98d-153699a82d0b"],
Cell[CellGroupData[{
Cell[95631, 2616, 823, 21, 57, "Input", "ExpressionUUID" -> \
"803b2072-64c3-4b9f-b1c8-84458cce2c4d"],
Cell[96457, 2639, 3609, 98, 70, "Output", "ExpressionUUID" -> \
"f55d7c9e-ec4d-4fdb-abe5-96c9470852de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100103, 2742, 643, 15, 83, "Input", "ExpressionUUID" -> \
"2f6a71a0-4600-486d-962b-179ec90a8a86"],
Cell[100749, 2759, 1147, 21, 70, "Output", "ExpressionUUID" -> \
"2b966a10-11c5-429c-a6ba-baf468b1e295"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[101945, 2786, 187, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"da0619e9-58eb-4360-a53f-61c24d0c7920"],
Cell[CellGroupData[{
Cell[102157, 2793, 1723, 54, 102, "Input", "ExpressionUUID" -> \
"2cb14d8e-8767-4c4d-8108-d0bb24d1f014"],
Cell[103883, 2849, 2897, 75, 70, "Output", "ExpressionUUID" -> \
"19229599-6192-451e-9870-39e6a3c4154e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106817, 2929, 941, 15, 50, "Input", "ExpressionUUID" -> \
"feb7c103-939e-40c0-8455-7d3474dfacb9"],
Cell[107761, 2946, 1504, 31, 70, "Output", "ExpressionUUID" -> \
"85a3e3a2-74f0-478c-97e0-0d55cd32a750"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[109314, 2983, 172, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"541e351c-517d-4a0f-afe7-d02bb014a3c3"],
Cell[CellGroupData[{
Cell[109511, 2990, 3940, 98, 575, "Input", "ExpressionUUID" -> \
"1d2e6ee2-6988-435b-9353-bcee3f9dbf7d"],
Cell[113454, 3090, 3584, 103, 70, "Output", "ExpressionUUID" -> \
"ca077ba5-ce4d-4248-b3cb-059d16de04c9"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117099, 3200, 178, 3, 45, "Subsection", "ExpressionUUID" -> \
"e54f2530-510f-40e6-9225-a3e8f34525c9"],
Cell[CellGroupData[{
Cell[117302, 3207, 2963, 72, 90, "Input", "ExpressionUUID" -> \
"9d7d760b-1887-4006-8d0b-b9c7417000da"],
Cell[120268, 3281, 3241, 79, 70, "Output", "ExpressionUUID" -> \
"a299d3d3-6676-4237-8215-3435e978a709"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123546, 3365, 2607, 67, 86, "Input", "ExpressionUUID" -> \
"db3e678e-df0f-4360-b0e1-3feaddb4ce92"],
Cell[126156, 3434, 5387, 124, 70, "Output", "ExpressionUUID" -> \
"606188a6-44ce-4feb-a07d-3884d82b6e2f"]
}, Open  ]],
Cell[131558, 3561, 224, 5, 39, "Text", "ExpressionUUID" -> \
"01d623e4-27c7-49cc-a235-f6d05a38764e"],
Cell[CellGroupData[{
Cell[131807, 3570, 1835, 48, 86, "Input", "ExpressionUUID" -> \
"511e8d07-31d4-4c76-96dd-35a11564f6e2"],
Cell[133645, 3620, 4988, 138, 70, "Output", "ExpressionUUID" -> \
"dd3841e6-bbc9-41f0-b565-14e4c7be7d2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138670, 3763, 821, 21, 85, "Input", "ExpressionUUID" -> \
"cecb3816-3bf3-42f6-9881-4ebdd40fbb94"],
Cell[139494, 3786, 1295, 27, 70, "Output", "ExpressionUUID" -> \
"9a70788a-17a8-485c-b1b9-779cea75b0de"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[140838, 3819, 175, 3, 44, "Subsection", "ExpressionUUID" -> \
"c5e0dbfe-6e83-426a-8cc1-c00aa110190d"],
Cell[CellGroupData[{
Cell[141038, 3826, 652, 20, 85, "Input", "ExpressionUUID" -> \
"414c6039-fce9-4858-83b6-3d164c3f0d06"],
Cell[141693, 3848, 1117, 22, 70, "Output", "ExpressionUUID" -> \
"bd70bf6d-0cb3-4493-af78-961f28f99703"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142847, 3875, 728, 19, 84, "Input", "ExpressionUUID" -> \
"92ce6dd1-e9f7-49e9-a32f-20250a094e44"],
Cell[143578, 3896, 1848, 43, 70, "Output", "ExpressionUUID" -> \
"30d6321e-22c7-4fde-b98a-f0725a750893"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145463, 3944, 375, 11, 81, "Input", "ExpressionUUID" -> \
"1fa8fa9b-22d2-4a03-b3f3-c2fe602bb47d"],
Cell[145841, 3957, 1060, 20, 70, "Output", "ExpressionUUID" -> \
"fbee4593-d723-4b5f-a07e-239f7639bd50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146938, 3982, 584, 18, 81, "Input", "ExpressionUUID" -> \
"699167c9-63d8-4a65-976c-55c09efa384d"],
Cell[147525, 4002, 1224, 25, 70, "Output", "ExpressionUUID" -> \
"38455069-a43a-4d6a-841b-c8106f26cfb9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148786, 4032, 625, 18, 81, "Input", "ExpressionUUID" -> \
"03e838d7-a9e7-4163-ab5e-984a39feb6ba"],
Cell[149414, 4052, 1286, 26, 70, "Output", "ExpressionUUID" -> \
"2c55653f-8b2c-46dd-bdd8-2845c87462a0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[150749, 4084, 176, 3, 44, "Subsection", "ExpressionUUID" -> \
"1cb0c961-905c-46af-a2ed-f2d2b7f9508d"],
Cell[CellGroupData[{
Cell[150950, 4091, 164, 3, 44, "Subsubsection", "ExpressionUUID" -> \
"35a10c39-b522-4ac9-9804-adf2edffcc61"],
Cell[CellGroupData[{
Cell[151139, 4098, 602, 16, 81, "Input", "ExpressionUUID" -> \
"612e6348-2d35-46dc-9095-c309bb07a939"],
Cell[151744, 4116, 1248, 25, 70, "Output", "ExpressionUUID" -> \
"8f1f9bd8-c502-49f7-b3c6-cc08ca854190"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[153041, 4147, 167, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"1a4f0ffd-7cb5-46a3-b239-5e2a5b875606"],
Cell[CellGroupData[{
Cell[153233, 4154, 825, 23, 101, "Input", "ExpressionUUID" -> \
"cd575dcb-0e08-41df-8d2d-5266d24bc34d"],
Cell[154061, 4179, 1475, 32, 70, "Output", "ExpressionUUID" -> \
"d5e4af67-10fd-4618-a8ad-2c744a6417db"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[155585, 4217, 170, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"53a5b5b8-1164-4583-b3e3-fbf3dff893a3"],
Cell[CellGroupData[{
Cell[155780, 4224, 592, 16, 81, "Input", "ExpressionUUID" -> \
"8c2ae4ec-8440-4fcc-81ac-ba84b921e93b"],
Cell[156375, 4242, 1172, 24, 70, "Output", "ExpressionUUID" -> \
"0f757d72-208c-416b-a6e7-ff609aed91ea"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[157596, 4272, 166, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"7155024d-55f0-4098-9455-c015d9776609"],
Cell[CellGroupData[{
Cell[157787, 4279, 545, 14, 78, "Input", "ExpressionUUID" -> \
"fe258052-f864-4fbc-a066-081fe35b9306"],
Cell[158335, 4295, 1063, 20, 70, "Output", "ExpressionUUID" -> \
"70c9d867-2473-416f-8b7f-3e2130cb75fa"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159471, 4323, 195, 3, 93, "Section", "ExpressionUUID" -> \
"27df55d9-80c2-4518-9585-18efc5249712"],
Cell[CellGroupData[{
Cell[159691, 4330, 160, 3, 45, "Subsection", "ExpressionUUID" -> \
"ad449915-ff2b-4cab-b32b-f2e4d2909d9a"],
Cell[CellGroupData[{
Cell[159876, 4337, 596, 15, 44, "Subsubsection", "ExpressionUUID" -> \
"12bedb87-7e2f-4d47-a2e1-3c9271c99466"],
Cell[CellGroupData[{
Cell[160497, 4356, 831, 19, 55, "Input", "ExpressionUUID" -> \
"bd9259d9-af97-404c-9e8c-64a80e0a51f8"],
Cell[161331, 4377, 3843, 98, 70, "Output", "ExpressionUUID" -> \
"ba385af2-a8e2-4392-b50f-402b42fc79a0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[165223, 4481, 279, 6, 43, "Subsubsection", "ExpressionUUID" -> \
"84207f9a-4f49-417a-9ce7-434c9be769ad"],
Cell[CellGroupData[{
Cell[165527, 4491, 447, 8, 50, "Input", "ExpressionUUID" -> \
"52e71e18-b300-49bb-b85e-027103315562"],
Cell[165977, 4501, 5225, 137, 70, "Output", "ExpressionUUID" -> \
"40a230cd-73c1-4ee9-98e7-0c590d0486cf"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[171251, 4644, 286, 6, 43, "Subsubsection", "ExpressionUUID" -> \
"782874f5-be02-4a57-8fec-6360cc051264"],
Cell[CellGroupData[{
Cell[171562, 4654, 515, 11, 50, "Input", "ExpressionUUID" -> \
"0351873c-2bb1-4eb9-a6df-bcbcd4182ce2"],
Cell[172080, 4667, 16207, 427, 70, "Output", "ExpressionUUID" -> \
"69cc59b2-7d9c-4c10-9b21-aef86a8741b1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[188336, 5100, 220, 5, 43, "Subsubsection", "ExpressionUUID" -> \
"1485bbfd-c931-4a48-a2c6-094478f992fb"],
Cell[CellGroupData[{
Cell[188581, 5109, 684, 17, 55, "Input", "ExpressionUUID" -> \
"93ad0c3a-f9b6-443b-b1c9-dd88d4be3158"],
Cell[189268, 5128, 2261, 55, 70, "Output", "ExpressionUUID" -> \
"d3f69536-8aa9-4255-a865-8e5d06ccf9d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191566, 5188, 356, 9, 50, "Input", "ExpressionUUID" -> \
"dc4a1fc6-e36f-455e-972b-df8f1298f493"],
Cell[191925, 5199, 7324, 192, 70, "Output", "ExpressionUUID" -> \
"90412fdc-f1ed-4c60-98d3-06b5854c8479"]
}, Open  ]],
Cell[CellGroupData[{
Cell[199286, 5396, 241, 6, 50, "Input", "ExpressionUUID" -> \
"416c2130-6ec5-4cc5-9a1a-fac17ffe143b"],
Cell[199530, 5404, 9181, 236, 70, "Output", "ExpressionUUID" -> \
"ec058a58-9822-4551-937a-a5966f287f71"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[208760, 5646, 292, 7, 43, "Subsubsection", "ExpressionUUID" -> \
"66763d3e-ff8d-4a33-8c14-8f623391c92d"],
Cell[CellGroupData[{
Cell[209077, 5657, 1055, 26, 57, "Input", "ExpressionUUID" -> \
"ea39d5e0-c8fb-41c3-8f9c-c711cf94c6cf"],
Cell[210135, 5685, 10179, 256, 70, "Output", "ExpressionUUID" -> \
"5b512b75-3ba5-495b-bd67-6bb55f0141a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220351, 5946, 1030, 24, 85, "Input", "ExpressionUUID" -> \
"35173073-f8ca-4119-bcbc-f0b6b8700ac1"],
Cell[221384, 5972, 7723, 184, 70, "Output", "ExpressionUUID" -> \
"3f5a5c0f-ade0-4781-8398-bce83dbe9a29"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[229156, 6162, 232, 4, 43, "Subsubsection", "ExpressionUUID" -> \
"9f5febe5-be12-4cad-a8bf-4726ae041a8a"],
Cell[CellGroupData[{
Cell[229413, 6170, 306, 6, 50, "Input", "ExpressionUUID" -> \
"3a5d21c5-b1b5-4394-9e9d-d5cc7529de24"],
Cell[229722, 6178, 19077, 476, 70, "Output", "ExpressionUUID" -> \
"a816ee95-54cf-4dcb-a035-64ca484db3b5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[248848, 6660, 217, 4, 43, "Subsubsection", "ExpressionUUID" -> \
"8240279e-f206-4752-a47a-f644e4b1e8a7"],
Cell[CellGroupData[{
Cell[249090, 6668, 383, 8, 50, "Input", "ExpressionUUID" -> \
"b7f30324-484c-45a7-8122-2469e130dd31"],
Cell[249476, 6678, 16630, 430, 70, "Output", "ExpressionUUID" -> \
"7c0097bc-17cf-4b36-bd00-e763810a2079"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[266155, 7114, 173, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"bd60ad2a-5e10-4b60-b6fa-e04fe6a034ac"],
Cell[266331, 7119, 2916, 84, 145, "Input", "ExpressionUUID" -> \
"af3d0c25-0e70-46a3-b914-261c80c12486"],
Cell[269250, 7205, 7019, 161, 429, "Input", "ExpressionUUID" -> \
"73402eb0-c107-4c41-96b6-47f23066cda7"],
Cell[CellGroupData[{
Cell[276294, 7370, 359, 10, 55, "Input", "ExpressionUUID" -> \
"fe7022f7-8fb1-49bc-97b6-ea62cefd4afc"],
Cell[276656, 7382, 658, 16, 55, "Output", "ExpressionUUID" -> \
"6675e422-4698-4ad7-9d0c-46f05b72741d"]
}, Open  ]],
Cell[277329, 7401, 5801, 140, 382, "Input", "ExpressionUUID" -> \
"2da1baef-9b37-4bb6-9905-981bb8421881"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283179, 7547, 164, 3, 45, "Subsection", "ExpressionUUID" -> \
"cb3341e0-cfc5-4c39-b8f8-ca008f3d3df1"],
Cell[CellGroupData[{
Cell[283368, 7554, 286, 6, 44, "Subsubsection", "ExpressionUUID" -> \
"a1f35ae9-936a-4984-a0a9-62504cac2e8c"],
Cell[CellGroupData[{
Cell[283679, 7564, 1259, 32, 85, "Input", "ExpressionUUID" -> \
"9b6b7ac1-04fc-4322-8fe9-f11d37cf0176"],
Cell[284941, 7598, 1411, 36, 70, "Output", "ExpressionUUID" -> \
"44256826-b45d-481c-ba76-3f11f39c7a6b"],
Cell[286355, 7636, 1402, 35, 70, "Output", "ExpressionUUID" -> \
"2d423eea-e652-4c81-9c3a-35409b9bb076"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287794, 7676, 397, 8, 50, "Input", "ExpressionUUID" -> \
"f96ac693-abed-4952-9bce-9fe69bff57e6"],
Cell[288194, 7686, 2534, 70, 70, "Output", "ExpressionUUID" -> \
"21dd224d-ca8b-4564-8ecd-bad4f73a9bd1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[290777, 7762, 183, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"bef142d4-29be-4820-b3b6-0474ae9f2c60"],
Cell[CellGroupData[{
Cell[290985, 7769, 387, 8, 50, "Input", "ExpressionUUID" -> \
"20728d86-715e-46cd-9ba5-89f55b82a708"],
Cell[291375, 7779, 3390, 90, 70, "Output", "ExpressionUUID" -> \
"80357bfe-d122-4958-8e4d-8b7d53347d7d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[294814, 7875, 194, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"fd0ebb3c-d14d-4dc2-8f02-d780212dacb5"],
Cell[CellGroupData[{
Cell[295033, 7882, 98, 0, 50, "Input", "ExpressionUUID" -> \
"9cca2ddc-2c11-42fd-a4ff-65c3e941f591"],
Cell[295134, 7884, 2945, 89, 70, "Output", "ExpressionUUID" -> \
"261d6ef7-46e3-46ac-bc99-09207e43eede"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298116, 7978, 718, 13, 76, "Input", "ExpressionUUID" -> \
"194eb849-2799-4df5-b114-8be83c678d27"],
Cell[298837, 7993, 15012, 364, 70, "Output", "ExpressionUUID" -> \
"9f415d0d-b3f3-46a2-bef6-b3ddc3a41dcb"],
Cell[313852, 8359, 15261, 369, 70, "Output", "ExpressionUUID" -> \
"1d48b3d4-3117-4aa7-9ca6-80ecdc8fcfea"]
}, Open  ]],
Cell[329128, 8731, 1395, 30, 76, "Input", "ExpressionUUID" -> \
"00a8d35c-82bb-42bc-8156-ca9f22737302"]
}, Closed]],
Cell[CellGroupData[{
Cell[330560, 8766, 203, 3, 43, "Subsubsection", "ExpressionUUID" -> \
"f2d2804b-e2ee-4cc2-87fd-c9d3cd8986c7"],
Cell[330766, 8771, 907, 22, 55, "Input", "ExpressionUUID" -> \
"6b66906b-32bc-4767-ac30-f4d0c6a429f6"]
}, Closed]],
Cell[CellGroupData[{
Cell[331710, 8798, 320, 9, 43, "Subsubsection", "ExpressionUUID" -> \
"9bd34ed3-0935-446b-afaf-cbe748ef7042"],
Cell[CellGroupData[{
Cell[332055, 8811, 684, 17, 55, "Input", "ExpressionUUID" -> \
"9b21d350-d518-4bf9-8217-0ef71a63df8b"],
Cell[332742, 8830, 2285, 55, 70, "Output", "ExpressionUUID" -> \
"015543fc-8d18-4d17-ba7e-78e9e6409c80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335064, 8890, 147, 3, 50, "Input", "ExpressionUUID" -> \
"1aa090ea-5c21-42f5-bc34-f920adc485bc"],
Cell[335214, 8895, 1454, 40, 70, "Output", "ExpressionUUID" -> \
"d7e25f17-aafb-404c-afec-e30535daefb3"]
}, Open  ]],
Cell[336683, 8938, 432, 10, 50, "Input", "ExpressionUUID" -> \
"7439a04d-ee93-4547-81b2-acfeb1e8a774"],
Cell[337118, 8950, 286, 7, 50, "Input", "ExpressionUUID" -> \
"9a155ebc-2edc-49a2-847b-7aeae4469e4c"]
}, Closed]],
Cell[337419, 8960, 357, 11, 43, "Subsubsection", "ExpressionUUID" -> \
"ba45c296-10dc-414f-b27e-0b5973d98ce5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[337825, 8977, 197, 3, 93, "Section", "ExpressionUUID" -> \
"0f6723bd-85ba-4ca1-a9c1-86b1ee32b56f"],
Cell[CellGroupData[{
Cell[338047, 8984, 154, 3, 45, "Subsection", "ExpressionUUID" -> \
"a1a803cc-debb-46aa-810a-6837b2475b94"],
Cell[CellGroupData[{
Cell[338226, 8991, 15088, 332, 1279, "Input", "ExpressionUUID" -> \
"4e16f10f-33be-4462-bd1e-097879cd5e7a"],
Cell[353317, 9325, 33275, 721, 578, "Output", "ExpressionUUID" -> \
"3a709bdf-7d5b-4fbb-b266-5b6cd6bb41f2"],
Cell[386595, 10048, 33247, 720, 578, "Output", "ExpressionUUID" -> \
"0f020d81-c372-4f80-90a3-807f98a5cbda"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[419891, 10774, 161, 3, 45, "Subsection", "ExpressionUUID" -> \
"f1e0306f-d002-4074-9c0f-f85ddb68e7c1"],
Cell[CellGroupData[{
Cell[420077, 10781, 18824, 412, 1529, "Input", "ExpressionUUID" -> \
"befc9bf3-ca23-48dc-b232-7e728feae633"],
Cell[438904, 11195, 42930, 932, 695, "Output", "ExpressionUUID" -> \
"f231721a-1a74-4316-a211-586df8570d7d"],
Cell[481837, 12129, 42943, 933, 695, "Output", "ExpressionUUID" -> \
"a3777f03-79c5-4c1d-ae4e-6ca6f1b24180"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

